@@ -28,7 +28,7 @@ IS_ARM64 = platform.machine() in ("arm64", "aarch64")
 
 
 # The Rust toolchain to use for builds
-RUST_TOOLCHAIN = os.getenv("RUST_TOOLCHAIN", "stable")
+RUSTUP_TOOLCHAIN = os.getenv("RUSTUP_TOOLCHAIN", "stable")
 # The Cargo build mode
 BUILD_MODE = os.getenv("BUILD_MODE", "release")
 # If PROFILE_MODE mode is enabled, include traces necessary for coverage and profiling
@@ -41,6 +41,8 @@ PARALLEL_BUILD = os.getenv("PARALLEL_BUILD", "true").lower() == "true"
 COPY_TO_SOURCE = os.getenv("COPY_TO_SOURCE", "true").lower() == "true"
 # If PyO3 only then don't build C extensions to reduce compilation time
 PYO3_ONLY = os.getenv("PYO3_ONLY", "").lower() != ""
+# If dry run only print the commands that would be executed
+DRY_RUN = bool(os.getenv("DRY_RUN", ""))
 
 # Precision mode configuration
 # https://nautilustrader.io/docs/nightly/getting_started/installation#precision-mode
@@ -74,8 +76,8 @@ if IS_LINUX:
     os.environ["LDSHARED"] = "clang -shared"
 
 if IS_MACOS and IS_ARM64:
-    os.environ["CFLAGS"] = "-arch arm64"
-    os.environ["LDFLAGS"] = "-arch arm64 -w"
+    os.environ["CFLAGS"] = f"{os.environ.get('CFLAGS', '')} -arch arm64"
+    os.environ["LDFLAGS"] = f"{os.environ.get('LDFLAGS', '')} -arch arm64 -w"
 
 if IS_LINUX and IS_ARM64:
     os.environ["CFLAGS"] = f"{os.environ.get('CFLAGS', '')} -fPIC"
@@ -120,30 +122,49 @@ RUST_LIB_PATHS: list[Path] = [
 RUST_LIBS: list[str] = [str(path) for path in RUST_LIB_PATHS]
 
 
+def _set_feature_flags() -> list[str]:
+    features = "ffi,python,extension-module,postgres"
+    flags = ["--no-default-features", "--features"]
+
+    if HIGH_PRECISION:
+        features += ",high-precision"
+
+    flags.append(features)
+
+    return flags
+
+
 def _build_rust_libs() -> None:
     print("Compiling Rust libraries...")
 
     try:
         # Build the Rust libraries using Cargo
-        if RUST_TOOLCHAIN not in ("stable", "nightly"):
-            raise ValueError(f"Invalid `RUST_TOOLCHAIN` '{RUST_TOOLCHAIN}'")
+        if RUSTUP_TOOLCHAIN not in ("stable", "nightly"):
+            raise ValueError(f"Invalid `RUSTUP_TOOLCHAIN` '{RUSTUP_TOOLCHAIN}'")
+
+        needed_crates = [
+            "nautilus-backtest",
+            "nautilus-common",
+            "nautilus-core",
+            "nautilus-infrastructure",
+            "nautilus-model",
+            "nautilus-persistence",
+            "nautilus-pyo3",
+        ]
 
         build_options = " --release" if BUILD_MODE == "release" else ""
-
-        if HIGH_PRECISION:
-            features = ["--all-features"]
-        else:
-            # Enable features needed for main build, but not high_precision
-            features = ["--features", "ffi,python,extension-module"]
+        features = _set_feature_flags()
 
         cmd_args = [
             "cargo",
             "build",
+            "--lib",
+            *itertools.chain.from_iterable(("-p", p) for p in needed_crates),
             *build_options.split(),
             *features,
         ]
 
-        if RUST_TOOLCHAIN == "nightly":
+        if RUSTUP_TOOLCHAIN == "nightly":
             cmd_args.insert(1, "+nightly")
 
         print(" ".join(cmd_args))
@@ -180,7 +201,7 @@ CYTHON_COMPILER_DIRECTIVES = {
 }
 
 # TODO: Temporarily separate Cython configuration while we require v3.0.11 for coverage
-if cython_compiler_version == "3.1.0b1":
+if cython_compiler_version == "3.1.2":
     Options.warning_errors = True  # Treat compiler warnings as errors
     Options.extra_warnings = True
     CYTHON_COMPILER_DIRECTIVES["warn.deprecated.IF"] = False
@@ -209,28 +230,31 @@ def _build_extensions() -> list[Extension]:
             extra_compile_args.append("-pipe")
 
     if IS_WINDOWS:
+        # Standard Windows system libraries required when linking Cython extensions.
+        # Keep this list lowercase and alphabetically sorted for easy maintenance
+        # and to avoid duplicates sneaking in.
         extra_link_args += [
-            "AdvAPI32.Lib",
+            "advapi32.lib",
             "bcrypt.lib",
-            "Crypt32.lib",
-            "Iphlpapi.lib",
-            "Kernel32.lib",
+            "crypt32.lib",
+            "iphlpapi.lib",
+            "kernel32.lib",
             "ncrypt.lib",
-            "Netapi32.lib",
+            "netapi32.lib",
             "ntdll.lib",
-            "Ole32.lib",
-            "OleAut32.lib",
-            "Pdh.lib",
-            "PowrProf.lib",
-            "Propsys.lib",
-            "Psapi.lib",
+            "ole32.lib",
+            "oleaut32.lib",
+            "pdh.lib",
+            "powrprof.lib",
+            "propsys.lib",
+            "psapi.lib",
             "runtimeobject.lib",
             "schannel.lib",
             "secur32.lib",
-            "Shell32.lib",
-            "User32.Lib",
-            "UserEnv.Lib",
-            "WS2_32.Lib",
+            "shell32.lib",
+            "user32.lib",
+            "userenv.lib",
+            "ws2_32.lib",
         ]
 
     print("Creating C extension modules...")
@@ -353,6 +377,54 @@ def _get_rustc_version() -> str:
         ) from e
 
 
+def _ensure_windows_python_import_lib() -> None:
+    """
+    Ensure that the *t* suffixed Python import library exists on Windows.
+
+    On some official CPython Windows builds the import library is named
+    ``pythonXY.lib`` (for example ``python313.lib``). However, when building
+    C-extensions ``distutils``/``setuptools`` may ask the MSVC linker for the
+    file ``pythonXYt.lib`` - note the additional *t* suffix. The *t* variant
+    historically referred to a *thread-safe* build but is no longer shipped.
+
+    When the file is missing the linker exits with
+    ``LINK : fatal error LNK1104: cannot open file 'pythonXYt.lib'`` which
+    breaks the CI build on Windows. To work around this we simply create a
+    copy of the existing import library with the expected name **before** the
+    extension build starts.
+
+    """
+    if not IS_WINDOWS:
+        return
+
+    try:
+        # The virtual environment as well as the base installation may both
+        # participate in the link search path.  Attempt the fix in both
+        # locations to maximise the chance of success.
+        candidate_roots = {Path(sys.base_prefix), Path(sys.prefix)}
+
+        # Example: for Python 3.13 -> '313'
+        major, minor, *_ = platform.python_version_tuple()
+        version_compact = f"{major}{minor}"
+
+        for root in candidate_roots:
+            libs_dir = root / "libs"
+            if not libs_dir.exists():
+                continue
+
+            src = libs_dir / f"python{version_compact}.lib"
+            dst = libs_dir / f"python{version_compact}t.lib"
+
+            if src.exists() and not dst.exists():
+                print(
+                    "Creating missing Windows import lib " f"{dst} (copying from {src})",
+                )
+                shutil.copyfile(src, dst)
+    except Exception as exc:  # pragma: no cover - defensive
+        # Never fail the build because of this helper, just show the warning
+        print(f"Warning: failed to create *t* suffixed Python import library: {exc}")
+
+
 def _strip_unneeded_symbols() -> None:
     try:
         print("Stripping unneeded symbols from binaries...")
@@ -372,10 +444,43 @@ def _strip_unneeded_symbols() -> None:
         raise RuntimeError(f"Error when stripping symbols.\n{e}") from e
 
 
+def show_rustanalyzer_settings() -> None:
+    """
+    Show appropriate vscode settings for the build.
+    """
+    import json
+
+    # Set environment variables
+    settings: dict[str, object] = {}
+    for key in [
+        "rust-analyzer.check.extraEnv",
+        "rust-analyzer.runnables.extraEnv",
+        "rust-analyzer.cargo.features",
+    ]:
+        settings[key] = {
+            "CC": os.environ["CC"],
+            "CXX": os.environ["CXX"],
+            "VIRTUAL_ENV": os.environ["VIRTUAL_ENV"],
+        }
+
+    # Set features
+    features = _set_feature_flags()
+    if features[0] == "--all-features":
+        settings["rust-analyzer.cargo.features"] = "all"
+        settings["rust-analyzer.check.features"] = "all"
+    else:
+        settings["rust-analyzer.cargo.features"] = features[1].split(",")
+        settings["rust-analyzer.check.features"] = features[1].split(",")
+
+    print("Set these rust analyzer settings in .vscode/settings.json")
+    print(json.dumps(settings, indent=2))
+
+
 def build() -> None:
     """
     Construct the extensions and distribution.
     """
+    _ensure_windows_python_import_lib()
     _build_rust_libs()
     _copy_rust_dylibs_to_project()
 
@@ -419,7 +524,7 @@ if __name__ == "__main__":
     print(f"Cython: {cython_compiler_version}")
     print(f"NumPy:  {np.__version__}")
 
-    print(f"\nRUST_TOOLCHAIN={RUST_TOOLCHAIN}")
+    print(f"\nRUSTUP_TOOLCHAIN={RUSTUP_TOOLCHAIN}")
     print(f"BUILD_MODE={BUILD_MODE}")
     print(f"BUILD_DIR={BUILD_DIR}")
     print(f"HIGH_PRECISION={HIGH_PRECISION}")
@@ -434,10 +539,16 @@ if __name__ == "__main__":
     print_env_var_if_exists("CFLAGS")
     print_env_var_if_exists("LDFLAGS")
     print_env_var_if_exists("LD_LIBRARY_PATH")
+    print_env_var_if_exists("PYO3_PYTHON")
+    print_env_var_if_exists("PYTHONHOME")
     print_env_var_if_exists("RUSTFLAGS")
+    print_env_var_if_exists("DRY_RUN")
 
-    print("\nStarting build...")
-    ts_start = dt.datetime.now(dt.UTC)
-    build()
-    print(f"Build time: {dt.datetime.now(dt.UTC) - ts_start}")
-    print("\033[32m" + "Build completed" + "\033[0m")
+    if DRY_RUN:
+        show_rustanalyzer_settings()
+    else:
+        print("\nStarting build...")
+        ts_start = dt.datetime.now(dt.UTC)
+        build()
+        print(f"Build time: {dt.datetime.now(dt.UTC) - ts_start}")
+        print("\033[32m" + "Build completed" + "\033[0m")
