@@ -30,12 +30,16 @@ use std::{
     time::Duration,
 };
 
+use aws_lc_rs::hmac;
 use base64::prelude::*;
-use nautilus_core::{python::IntoPyObjectNautilusExt, time::get_atomic_clock_realtime};
+use nautilus_common::logging::{log_task_started, log_task_stopped};
+#[cfg(feature = "python")]
+use nautilus_core::python::IntoPyObjectNautilusExt;
+use nautilus_core::{env::get_env_var, time::get_atomic_clock_realtime};
 use nautilus_model::identifiers::AccountId;
 use nautilus_network::socket::{SocketClient, SocketConfig, WriterCommand};
+#[cfg(feature = "python")]
 use pyo3::prelude::*;
-use ring::hmac;
 use tokio::task::JoinHandle;
 use tokio_tungstenite::tungstenite::stream::Mode;
 
@@ -44,15 +48,18 @@ use super::{
     parse::convert_to_order_status_report,
 };
 use crate::{
-    common::{consts::COINBASE_INTX, credential::get_env_var},
+    common::consts::COINBASE_INTX,
     fix::{
         messages::{fix_exec_type, fix_message_type, fix_tag},
         parse::convert_to_fill_report,
     },
 };
 
-#[pyclass(module = "nautilus_trader.core.nautilus_pyo3.adapters")]
-#[derive(Clone)]
+#[cfg_attr(
+    feature = "python",
+    pyo3::pyclass(module = "nautilus_trader.core.nautilus_pyo3.adapters")
+)]
+#[derive(Debug, Clone)]
 pub struct CoinbaseIntxFixClient {
     endpoint: String,
     api_key: String,
@@ -73,6 +80,10 @@ pub struct CoinbaseIntxFixClient {
 
 impl CoinbaseIntxFixClient {
     /// Creates a new [`CoinbaseIntxFixClient`] instance.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if required environment variables or parameters are missing.
     pub fn new(
         endpoint: Option<String>,
         api_key: Option<String>,
@@ -109,53 +120,77 @@ impl CoinbaseIntxFixClient {
 
     /// Creates a new authenticated [`CoinbaseIntxFixClient`] instance using
     /// environment variables and the default Coinbase International FIX drop copy endpoint.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if required environment variables are not set.
     pub fn from_env() -> anyhow::Result<Self> {
         Self::new(None, None, None, None, None)
     }
 
     /// Returns the FIX endpoint being used by the client.
-    pub fn endpoint(&self) -> &str {
+    #[must_use]
+    pub const fn endpoint(&self) -> &str {
         self.endpoint.as_str()
     }
 
     /// Returns the public API key being used by the client.
-    pub fn api_key(&self) -> &str {
+    #[must_use]
+    pub const fn api_key(&self) -> &str {
         self.api_key.as_str()
     }
 
     /// Returns the Coinbase International portfolio ID being used by the client.
-    pub fn portfolio_id(&self) -> &str {
+    #[must_use]
+    pub const fn portfolio_id(&self) -> &str {
         self.portfolio_id.as_str()
     }
 
     /// Returns the sender company ID being used by the client.
-    pub fn sender_comp_id(&self) -> &str {
+    #[must_use]
+    pub const fn sender_comp_id(&self) -> &str {
         self.sender_comp_id.as_str()
     }
 
     /// Returns the target company ID being used by the client.
-    pub fn target_comp_id(&self) -> &str {
+    #[must_use]
+    pub const fn target_comp_id(&self) -> &str {
         self.target_comp_id.as_str()
     }
 
     /// Checks if the client is connected.
+    #[must_use]
     pub fn is_connected(&self) -> bool {
         self.connected.load(Ordering::SeqCst)
     }
 
     /// Checks if the client is logged on.
+    #[must_use]
     pub fn is_logged_on(&self) -> bool {
         self.logged_on.load(Ordering::SeqCst)
     }
 
     /// Connects to the Coinbase International FIX Drop Copy endpoint.
-    pub async fn connect(&mut self, handler: PyObject) -> anyhow::Result<()> {
+    ///
+    /// # Panics
+    ///
+    /// Panics if time calculation or unwrap logic inside fails during logon retry setup.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if network connection or FIX logon fails.
+    pub async fn connect(
+        &mut self,
+        #[cfg(feature = "python")] handler: PyObject,
+        #[cfg(not(feature = "python"))] _handler: (),
+    ) -> anyhow::Result<()> {
         let config = SocketConfig {
             url: self.endpoint.clone(),
             mode: Mode::Tls,
             suffix: vec![FIX_DELIMITER],
+            #[cfg(feature = "python")]
             py_handler: None, // Using handler from arg (TODO: refactor this config pattern)
-            heartbeat: None,  // Using FIX heartbeats
+            heartbeat: None, // Using FIX heartbeats
             reconnect_timeout_ms: Some(10000),
             reconnect_delay_initial_ms: Some(5000),
             reconnect_delay_max_ms: Some(30000),
@@ -210,6 +245,7 @@ impl CoinbaseIntxFixClient {
                                     match convert_to_order_status_report(
                                         &message, account_id, ts_init,
                                     ) {
+                                        #[cfg(feature = "python")]
                                         Ok(report) => Python::with_gil(|py| {
                                             call_python(
                                                 py,
@@ -217,6 +253,12 @@ impl CoinbaseIntxFixClient {
                                                 report.into_py_any_unwrap(py),
                                             );
                                         }),
+                                        #[cfg(not(feature = "python"))]
+                                        Ok(_report) => {
+                                            tracing::debug!(
+                                                "Order status report handled (Python disabled)"
+                                            );
+                                        }
                                         Err(e) => {
                                             tracing::error!(
                                                 "Failed to parse FIX execution report: {e}"
@@ -229,6 +271,7 @@ impl CoinbaseIntxFixClient {
                                     let clock = get_atomic_clock_realtime(); // TODO: Optimize
                                     let ts_init = clock.get_time_ns();
                                     match convert_to_fill_report(&message, account_id, ts_init) {
+                                        #[cfg(feature = "python")]
                                         Ok(report) => Python::with_gil(|py| {
                                             call_python(
                                                 py,
@@ -236,6 +279,12 @@ impl CoinbaseIntxFixClient {
                                                 report.into_py_any_unwrap(py),
                                             );
                                         }),
+                                        #[cfg(not(feature = "python"))]
+                                        Ok(_report) => {
+                                            tracing::debug!(
+                                                "Fill report handled (Python disabled)"
+                                            );
+                                        }
                                         Err(e) => {
                                             tracing::error!(
                                                 "Failed to parse FIX execution report: {e}"
@@ -258,11 +307,21 @@ impl CoinbaseIntxFixClient {
             }
         });
 
-        let socket =
-            match SocketClient::connect(config, Some(handle_message), None, None, None).await {
-                Ok(socket) => socket,
-                Err(e) => anyhow::bail!("Failed to connect to FIX endpoint: {e:?}"),
-            };
+        let socket = match SocketClient::connect(
+            config,
+            Some(handle_message),
+            #[cfg(feature = "python")]
+            None,
+            #[cfg(feature = "python")]
+            None,
+            #[cfg(feature = "python")]
+            None,
+        )
+        .await
+        {
+            Ok(socket) => socket,
+            Err(e) => anyhow::bail!("Failed to connect to FIX endpoint: {e:?}"),
+        };
 
         let writer_tx = socket.writer_tx.clone();
 
@@ -277,9 +336,11 @@ impl CoinbaseIntxFixClient {
         let client_clone = self.clone();
 
         self.processing_task = Some(Arc::new(tokio::spawn(async move {
-            tracing::debug!("Started task 'maintain FIX connection'");
+            log_task_started("maintain-fix-connection");
 
-            let mut last_logon_attempt = std::time::Instant::now() - Duration::from_secs(10);
+            let mut last_logon_attempt = std::time::Instant::now()
+                .checked_sub(Duration::from_secs(10))
+                .unwrap();
 
             loop {
                 tokio::time::sleep(Duration::from_millis(100)).await;
@@ -305,7 +366,9 @@ impl CoinbaseIntxFixClient {
         let target_comp_id = self.target_comp_id.clone();
 
         self.heartbeat_task = Some(Arc::new(tokio::spawn(async move {
-            tracing::debug!("Started task 'FIX heartbeat' at {heartbeat_secs}s intervals");
+            log_task_started("heartbeat");
+            tracing::debug!("Heartbeat at {heartbeat_secs}s intervals");
+
             let interval = Duration::from_secs(heartbeat_secs);
 
             loop {
@@ -331,19 +394,23 @@ impl CoinbaseIntxFixClient {
                 tokio::time::sleep(interval).await;
             }
 
-            tracing::debug!("Stopped task 'FIX heartbeat'");
+            log_task_stopped("heartbeat");
         })));
 
         Ok(())
     }
 
     /// Closes the connection.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if logout or socket closure fails.
     pub async fn close(&mut self) -> anyhow::Result<()> {
         // Send logout message if connected
-        if self.is_logged_on() {
-            if let Err(e) = self.send_logout("Normal logout").await {
-                tracing::warn!("Failed to send logout message: {e}");
-            }
+        if self.is_logged_on()
+            && let Err(e) = self.send_logout("Normal logout").await
+        {
+            tracing::warn!("Failed to send logout message: {e}");
         }
 
         // Close socket
@@ -390,9 +457,9 @@ impl CoinbaseIntxFixClient {
             .decode(&self.api_secret)
             .map_err(|e| anyhow::anyhow!("Invalid base64 secret key: {e}"))?;
 
-        let hmac_key = hmac::Key::new(hmac::HMAC_SHA256, &decoded_secret);
-        let signature = hmac::sign(&hmac_key, message.as_bytes());
-        let encoded_signature = BASE64_STANDARD.encode(signature);
+        let key = hmac::Key::new(hmac::HMAC_SHA256, &decoded_secret);
+        let tag = hmac::sign(&key, message.as_bytes());
+        let encoded_signature = BASE64_STANDARD.encode(tag.as_ref());
 
         let logon_msg = FixMessage::create_logon(
             1, // Always use 1 for new logon with reset
@@ -409,7 +476,7 @@ impl CoinbaseIntxFixClient {
             tracing::info!("Logging on...");
 
             match socket.send_bytes(logon_msg.to_bytes()).await {
-                Ok(_) => tracing::debug!("Sent logon message"),
+                Ok(()) => tracing::debug!("Sent logon message"),
                 Err(e) => tracing::error!("Error on logon: {e}"),
             }
         } else {
@@ -449,7 +516,7 @@ impl CoinbaseIntxFixClient {
 
         if let Some(socket) = &self.socket {
             match socket.send_bytes(logout_msg.to_bytes()).await {
-                Ok(_) => tracing::debug!("Sent logout message"),
+                Ok(()) => tracing::debug!("Sent logout message"),
                 Err(e) => tracing::error!("Error on logout: {e}"),
             }
         } else {
@@ -461,6 +528,7 @@ impl CoinbaseIntxFixClient {
 }
 
 // Can't be moved to core because we don't want to depend on tracing there
+#[cfg(feature = "python")]
 pub fn call_python(py: Python, callback: &PyObject, py_obj: PyObject) {
     if let Err(e) = callback.call1(py, (py_obj,)) {
         tracing::error!("Error calling Python: {e}");
