@@ -24,8 +24,10 @@ use std::{
 
 use chrono::Utc;
 use futures_util::{Stream, StreamExt};
-use nautilus_common::runtime::get_runtime;
-use nautilus_core::{consts::NAUTILUS_USER_AGENT, time::get_atomic_clock_realtime};
+use nautilus_common::{logging::log_task_stopped, runtime::get_runtime};
+use nautilus_core::{
+    consts::NAUTILUS_USER_AGENT, env::get_env_var, time::get_atomic_clock_realtime,
+};
 use nautilus_model::{
     data::{BarType, Data, OrderBookDeltas_API},
     identifiers::InstrumentId,
@@ -48,15 +50,13 @@ use super::{
 };
 use crate::{
     common::{
-        consts::COINBASE_INTX_WS_URL,
-        credential::{Credential, get_env_var},
-        parse::bar_spec_as_coinbase_channel,
+        consts::COINBASE_INTX_WS_URL, credential::Credential, parse::bar_spec_as_coinbase_channel,
     },
     websocket::parse::{parse_instrument_any, parse_trade_msg},
 };
 
 /// Provides a WebSocket client for connecting to [Coinbase International](https://www.coinbase.com/en/international-exchange).
-#[derive(Clone)]
+#[derive(Debug, Clone)]
 #[cfg_attr(
     feature = "python",
     pyo3::pyclass(module = "nautilus_trader.core.nautilus_pyo3.adapters")
@@ -80,6 +80,10 @@ impl Default for CoinbaseIntxWebSocketClient {
 
 impl CoinbaseIntxWebSocketClient {
     /// Creates a new [`CoinbaseIntxWebSocketClient`] instance.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if required environment variables are missing or invalid.
     pub fn new(
         url: Option<String>,
         api_key: Option<String>,
@@ -110,21 +114,28 @@ impl CoinbaseIntxWebSocketClient {
 
     /// Creates a new authenticated [`CoinbaseIntxWebSocketClient`] using environment variables and
     /// the default Coinbase International production websocket url.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if required environment variables are missing or invalid.
     pub fn from_env() -> anyhow::Result<Self> {
         Self::new(None, None, None, None, None)
     }
 
     /// Returns the websocket url being used by the client.
-    pub fn url(&self) -> &str {
+    #[must_use]
+    pub const fn url(&self) -> &str {
         self.url.as_str()
     }
 
     /// Returns the public API key being used by the client.
+    #[must_use]
     pub fn api_key(&self) -> &str {
         self.credential.api_key.as_str()
     }
 
     /// Returns a value indicating whether the client is active.
+    #[must_use]
     pub fn is_active(&self) -> bool {
         match &self.inner {
             Some(inner) => inner.is_active(),
@@ -133,6 +144,7 @@ impl CoinbaseIntxWebSocketClient {
     }
 
     /// Returns a value indicating whether the client is closed.
+    #[must_use]
     pub fn is_closed(&self) -> bool {
         match &self.inner {
             Some(inner) => inner.is_closed(),
@@ -141,6 +153,10 @@ impl CoinbaseIntxWebSocketClient {
     }
 
     /// Connects the client to the server and caches the given instruments.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the WebSocket connection or initial subscription fails.
     pub async fn connect(&mut self, instruments: Vec<InstrumentAny>) -> anyhow::Result<()> {
         let client = self.clone();
         let post_reconnect = Arc::new(move || {
@@ -151,9 +167,16 @@ impl CoinbaseIntxWebSocketClient {
         let config = WebSocketConfig {
             url: self.url.clone(),
             headers: vec![(USER_AGENT.to_string(), NAUTILUS_USER_AGENT.to_string())],
+            #[cfg(feature = "python")]
+            handler: Consumer::Python(None),
+            #[cfg(not(feature = "python"))]
+            handler: {
+                let (consumer, _rx) = Consumer::rust_consumer();
+                consumer
+            },
             heartbeat: self.heartbeat,
             heartbeat_msg: None,
-            handler: Consumer::Python(None),
+            #[cfg(feature = "python")]
             ping_handler: None,
             reconnect_timeout_ms: Some(5_000),
             reconnect_delay_initial_ms: None, // Use default
@@ -190,8 +213,8 @@ impl CoinbaseIntxWebSocketClient {
     ///
     /// # Panics
     ///
-    /// This function panics:
-    /// - If the websocket is not connected.
+    /// This function panics if:
+    /// - The websocket is not connected.
     /// - If `stream_data` has already been called somewhere else (stream receiver is then taken).
     pub fn stream(&mut self) -> impl Stream<Item = NautilusWsMessage> + 'static {
         let rx = self
@@ -207,6 +230,10 @@ impl CoinbaseIntxWebSocketClient {
     }
 
     /// Closes the client.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the WebSocket fails to close properly.
     pub async fn close(&mut self) -> Result<(), Error> {
         tracing::debug!("Closing");
         self.signal.store(true, Ordering::Relaxed);
@@ -234,6 +261,10 @@ impl CoinbaseIntxWebSocketClient {
     }
 
     /// Subscribes to the given channels and product IDs.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the subscription message cannot be sent.
     async fn subscribe(
         &self,
         channels: Vec<CoinbaseIntxWsChannel>,
@@ -269,7 +300,9 @@ impl CoinbaseIntxWebSocketClient {
             .map_err(|e| CoinbaseIntxWsError::JsonError(e.to_string()))?;
 
         if let Some(inner) = &self.inner {
-            inner.send_text(json_txt, None).await;
+            if let Err(err) = inner.send_text(json_txt, None).await {
+                tracing::error!("Error sending message: {err:?}");
+            }
         } else {
             return Err(CoinbaseIntxWsError::ClientError(
                 "Cannot send message: not connected".to_string(),
@@ -319,7 +352,9 @@ impl CoinbaseIntxWebSocketClient {
             .map_err(|e| CoinbaseIntxWsError::JsonError(e.to_string()))?;
 
         if let Some(inner) = &self.inner {
-            inner.send_text(json_txt, None).await;
+            if let Err(err) = inner.send_text(json_txt, None).await {
+                tracing::error!("Error sending message: {err:?}");
+            }
         } else {
             return Err(CoinbaseIntxWsError::ClientError(
                 "Cannot send message: not connected".to_string(),
@@ -347,6 +382,11 @@ impl CoinbaseIntxWebSocketClient {
     }
 
     /// Subscribes to instrument definition updates for the given instrument IDs.
+    /// Subscribes to instrument updates for the specified instruments.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the subscription fails.
     pub async fn subscribe_instruments(
         &self,
         instrument_ids: Vec<InstrumentId>,
@@ -357,6 +397,11 @@ impl CoinbaseIntxWebSocketClient {
     }
 
     /// Subscribes to funding message streams for the given instrument IDs.
+    /// Subscribes to funding rate updates for the specified instruments.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the subscription fails.
     pub async fn subscribe_funding(
         &self,
         instrument_ids: Vec<InstrumentId>,
@@ -367,6 +412,11 @@ impl CoinbaseIntxWebSocketClient {
     }
 
     /// Subscribes to risk message streams for the given instrument IDs.
+    /// Subscribes to risk updates for the specified instruments.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the subscription fails.
     pub async fn subscribe_risk(
         &self,
         instrument_ids: Vec<InstrumentId>,
@@ -377,6 +427,11 @@ impl CoinbaseIntxWebSocketClient {
     }
 
     /// Subscribes to order book (level 2) streams for the given instrument IDs.
+    /// Subscribes to order book snapshots and updates for the specified instruments.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the subscription fails.
     pub async fn subscribe_order_book(
         &self,
         instrument_ids: Vec<InstrumentId>,
@@ -387,6 +442,11 @@ impl CoinbaseIntxWebSocketClient {
     }
 
     /// Subscribes to quote (level 1) streams for the given instrument IDs.
+    /// Subscribes to top-of-book quote updates for the specified instruments.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the subscription fails.
     pub async fn subscribe_quotes(
         &self,
         instrument_ids: Vec<InstrumentId>,
@@ -397,6 +457,11 @@ impl CoinbaseIntxWebSocketClient {
     }
 
     /// Subscribes to trade (match) streams for the given instrument IDs.
+    /// Subscribes to trade updates for the specified instruments.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the subscription fails.
     pub async fn subscribe_trades(
         &self,
         instrument_ids: Vec<InstrumentId>,
@@ -407,6 +472,11 @@ impl CoinbaseIntxWebSocketClient {
     }
 
     /// Subscribes to risk streams (for mark prices) for the given instrument IDs.
+    /// Subscribes to mark price updates for the specified instruments.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the subscription fails.
     pub async fn subscribe_mark_prices(
         &self,
         instrument_ids: Vec<InstrumentId>,
@@ -417,6 +487,11 @@ impl CoinbaseIntxWebSocketClient {
     }
 
     /// Subscribes to risk streams (for index prices) for the given instrument IDs.
+    /// Subscribes to index price updates for the specified instruments.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the subscription fails.
     pub async fn subscribe_index_prices(
         &self,
         instrument_ids: Vec<InstrumentId>,
@@ -427,6 +502,11 @@ impl CoinbaseIntxWebSocketClient {
     }
 
     /// Subscribes to bar (candle) streams for the given instrument IDs.
+    /// Subscribes to candlestick bar updates for the specified bar type.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the subscription fails.
     pub async fn subscribe_bars(&self, bar_type: BarType) -> Result<(), CoinbaseIntxWsError> {
         let channel = bar_spec_as_coinbase_channel(bar_type.spec())
             .map_err(|e| CoinbaseIntxWsError::ClientError(e.to_string()))?;
@@ -435,6 +515,11 @@ impl CoinbaseIntxWebSocketClient {
     }
 
     /// Unsubscribes from instrument definition streams for the given instrument IDs.
+    /// Unsubscribes from instrument updates for the specified instruments.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the unsubscription fails.
     pub async fn unsubscribe_instruments(
         &self,
         instrument_ids: Vec<InstrumentId>,
@@ -445,6 +530,11 @@ impl CoinbaseIntxWebSocketClient {
     }
 
     /// Unsubscribes from risk message streams for the given instrument IDs.
+    /// Unsubscribes from risk updates for the specified instruments.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the unsubscription fails.
     pub async fn unsubscribe_risk(
         &self,
         instrument_ids: Vec<InstrumentId>,
@@ -455,6 +545,11 @@ impl CoinbaseIntxWebSocketClient {
     }
 
     /// Unsubscribes from funding message streams for the given instrument IDs.
+    /// Unsubscribes from funding updates for the specified instruments.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the unsubscription fails.
     pub async fn unsubscribe_funding(
         &self,
         instrument_ids: Vec<InstrumentId>,
@@ -465,6 +560,11 @@ impl CoinbaseIntxWebSocketClient {
     }
 
     /// Unsubscribes from order book (level 2) streams for the given instrument IDs.
+    /// Unsubscribes from order book updates for the specified instruments.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the unsubscription fails.
     pub async fn unsubscribe_order_book(
         &self,
         instrument_ids: Vec<InstrumentId>,
@@ -475,6 +575,11 @@ impl CoinbaseIntxWebSocketClient {
     }
 
     /// Unsubscribes from quote (level 1) streams for the given instrument IDs.
+    /// Unsubscribes from quote updates for the specified instruments.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the unsubscription fails.
     pub async fn unsubscribe_quotes(
         &self,
         instrument_ids: Vec<InstrumentId>,
@@ -485,6 +590,11 @@ impl CoinbaseIntxWebSocketClient {
     }
 
     /// Unsubscribes from trade (match) streams for the given instrument IDs.
+    /// Unsubscribes from trade updates for the specified instruments.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the unsubscription fails.
     pub async fn unsubscribe_trades(
         &self,
         instrument_ids: Vec<InstrumentId>,
@@ -495,6 +605,11 @@ impl CoinbaseIntxWebSocketClient {
     }
 
     /// Unsubscribes from risk streams (for mark prices) for the given instrument IDs.
+    /// Unsubscribes from mark price updates for the specified instruments.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the unsubscription fails.
     pub async fn unsubscribe_mark_prices(
         &self,
         instrument_ids: Vec<InstrumentId>,
@@ -505,6 +620,11 @@ impl CoinbaseIntxWebSocketClient {
     }
 
     /// Unsubscribes from risk streams (for index prices) for the given instrument IDs.
+    /// Unsubscribes from index price updates for the specified instruments.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the unsubscription fails.
     pub async fn unsubscribe_index_prices(
         &self,
         instrument_ids: Vec<InstrumentId>,
@@ -515,6 +635,11 @@ impl CoinbaseIntxWebSocketClient {
     }
 
     /// Unsubscribes from bar (candle) streams for the given instrument IDs.
+    /// Unsubscribes from bar updates for the specified bar type.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the unsubscription fails.
     pub async fn unsubscribe_bars(&self, bar_type: BarType) -> Result<(), CoinbaseIntxWsError> {
         let channel = bar_spec_as_coinbase_channel(bar_type.spec())
             .map_err(|e| CoinbaseIntxWsError::ClientError(e.to_string()))?;
@@ -607,7 +732,7 @@ impl CoinbaseIntxFeedHandler {
             }
         }
 
-        tracing::debug!("Stopped message streaming");
+        log_task_stopped("message-streaming");
         None
     }
 }
@@ -681,10 +806,9 @@ impl CoinbaseIntxWsMessageHandler {
                                 return None;
                             }
                         }
-                    } else {
-                        tracing::error!("No instrument found for {}", msg.product_id);
-                        return None;
                     }
+                    tracing::error!("No instrument found for {}", msg.product_id);
+                    return None;
                 }
                 CoinbaseIntxWsMessage::BookUpdate(msg) => {
                     if let Some(inst) = self.instruments.get(&msg.product_id) {
@@ -782,9 +906,8 @@ impl CoinbaseIntxWsMessageHandler {
                             }
                             (None, None) => continue,
                         };
-                    } else {
-                        tracing::error!("No instrument found for {}", msg.product_id);
                     }
+                    tracing::error!("No instrument found for {}", msg.product_id);
                 }
                 CoinbaseIntxWsMessage::CandleSnapshot(msg) => {
                     if let Some(inst) = self.instruments.get(&msg.product_id) {
