@@ -97,6 +97,9 @@ pub const fn parse_aggressor_side(c: c_char) -> AggressorSide {
     }
 }
 
+/// # Errors
+///
+/// Returns an error if `c` is not a valid `BookAction` character.
 pub fn parse_book_action(c: c_char) -> anyhow::Result<BookAction> {
     match c as u8 as char {
         'A' => Ok(BookAction::Add),
@@ -108,6 +111,9 @@ pub fn parse_book_action(c: c_char) -> anyhow::Result<BookAction> {
     }
 }
 
+/// # Errors
+///
+/// Returns an error if `c` is not a valid `OptionKind` character.
 pub fn parse_option_kind(c: c_char) -> anyhow::Result<OptionKind> {
     match c as u8 as char {
         'C' => Ok(OptionKind::Call),
@@ -129,6 +135,9 @@ fn parse_currency_or_usd_default(value: Result<&str, impl std::error::Error>) ->
     }
 }
 
+/// # Errors
+///
+/// Returns an error if `value` has fewer than 3 characters.
 pub fn parse_cfi_iso10926(
     value: &str,
 ) -> anyhow::Result<(Option<AssetClass>, Option<InstrumentClass>)> {
@@ -165,6 +174,9 @@ pub fn parse_cfi_iso10926(
 }
 
 // https://databento.com/docs/schemas-and-data-formats/status#types-of-status-reasons
+/// # Errors
+///
+/// Returns an error if `value` is an invalid status reason code.
 pub fn parse_status_reason(value: u16) -> anyhow::Result<Option<Ustr>> {
     let value_str = match value {
         0 => return Ok(None),
@@ -207,6 +219,9 @@ pub fn parse_status_reason(value: u16) -> anyhow::Result<Option<Ustr>> {
     Ok(Some(Ustr::from(value_str)))
 }
 
+/// # Errors
+///
+/// Returns an error if `value` is an invalid status trading event code.
 pub fn parse_status_trading_event(value: u16) -> anyhow::Result<Option<Ustr>> {
     let value_str = match value {
         0 => return Ok(None),
@@ -252,9 +267,9 @@ pub fn decode_optional_price(value: i64, precision: u8) -> Option<Price> {
 
 /// Decodes a quantity from the given optional value, expressed in standard whole-number units.
 #[must_use]
-pub fn decode_optional_quantity(value: i32) -> Option<Quantity> {
+pub fn decode_optional_quantity(value: i64) -> Option<Quantity> {
     match value {
-        i32::MAX => None,
+        i64::MAX => None,
         _ => Some(Quantity::from(value)),
     }
 }
@@ -277,241 +292,34 @@ pub fn decode_lot_size(value: i32) -> Quantity {
     }
 }
 
-pub fn decode_equity_v1(
-    msg: &dbn::compat::InstrumentDefMsgV1,
-    instrument_id: InstrumentId,
-    ts_init: UnixNanos,
-) -> anyhow::Result<Equity> {
-    let currency = parse_currency_or_usd_default(msg.currency());
-    let price_increment = decode_price_increment(msg.min_price_increment, currency.precision);
-    let lot_size = decode_lot_size(msg.min_lot_size_round_lot);
-    let ts_event = UnixNanos::from(msg.ts_recv); // More accurate and reliable timestamp
-
-    Equity::new_checked(
-        instrument_id,
-        instrument_id.symbol,
-        None, // No ISIN available yet
-        currency,
-        price_increment.precision,
-        price_increment,
-        Some(lot_size),
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        ts_event,
-        ts_init,
-    )
-}
-
-pub fn decode_futures_contract_v1(
-    msg: &dbn::compat::InstrumentDefMsgV1,
-    instrument_id: InstrumentId,
-    ts_init: UnixNanos,
-) -> anyhow::Result<FuturesContract> {
-    let currency = parse_currency_or_usd_default(msg.currency());
-    let exchange = Ustr::from(msg.exchange()?);
-    let underlying = Ustr::from(msg.asset()?);
-    let (asset_class, _) = parse_cfi_iso10926(msg.cfi()?)?;
-    let price_increment = decode_price_increment(msg.min_price_increment, currency.precision);
-    let multiplier = decode_multiplier(msg.unit_of_measure_qty);
-    let lot_size = decode_lot_size(msg.min_lot_size_round_lot);
-    let ts_event = UnixNanos::from(msg.ts_recv); // More accurate and reliable timestamp
-
-    FuturesContract::new_checked(
-        instrument_id,
-        instrument_id.symbol,
-        asset_class.unwrap_or(AssetClass::Commodity),
-        Some(exchange),
-        underlying,
-        msg.activation.into(),
-        msg.expiration.into(),
-        currency,
-        price_increment.precision,
-        price_increment,
-        multiplier,
-        lot_size,
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        ts_event,
-        ts_init,
-    )
-}
-
-pub fn decode_futures_spread_v1(
-    msg: &dbn::compat::InstrumentDefMsgV1,
-    instrument_id: InstrumentId,
-    ts_init: UnixNanos,
-) -> anyhow::Result<FuturesSpread> {
-    let exchange = Ustr::from(msg.exchange()?);
-    let underlying = Ustr::from(msg.asset()?);
-    let (asset_class, _) = parse_cfi_iso10926(msg.cfi()?)?;
-    let strategy_type = Ustr::from(msg.secsubtype()?);
-    let currency = parse_currency_or_usd_default(msg.currency());
-    let price_increment = decode_price_increment(msg.min_price_increment, currency.precision);
-    let multiplier = decode_multiplier(msg.unit_of_measure_qty);
-    let lot_size = decode_lot_size(msg.min_lot_size_round_lot);
-    let ts_event = UnixNanos::from(msg.ts_recv); // More accurate and reliable timestamp
-
-    FuturesSpread::new_checked(
-        instrument_id,
-        instrument_id.symbol,
-        asset_class.unwrap_or(AssetClass::Commodity),
-        Some(exchange),
-        underlying,
-        strategy_type,
-        msg.activation.into(),
-        msg.expiration.into(),
-        currency,
-        price_increment.precision,
-        price_increment,
-        multiplier,
-        lot_size,
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        ts_event,
-        ts_init,
-    )
-}
-
-pub fn decode_option_contract_v1(
-    msg: &dbn::compat::InstrumentDefMsgV1,
-    instrument_id: InstrumentId,
-    ts_init: UnixNanos,
-) -> anyhow::Result<OptionContract> {
-    let currency = parse_currency_or_usd_default(msg.currency());
-    let strike_price_currency = parse_currency_or_usd_default(msg.strike_price_currency());
-    let exchange = Ustr::from(msg.exchange()?);
-    let underlying = Ustr::from(msg.underlying()?);
-    let asset_class_opt = if instrument_id.venue.as_str() == "OPRA" {
-        Some(AssetClass::Equity)
-    } else {
-        let (asset_class, _) = parse_cfi_iso10926(msg.cfi()?)?;
-        asset_class
-    };
-    let option_kind = parse_option_kind(msg.instrument_class)?;
-    let strike_price = Price::from_raw(
-        decode_raw_price_i64(msg.strike_price),
-        strike_price_currency.precision,
-    );
-    let price_increment = decode_price_increment(msg.min_price_increment, currency.precision);
-    let multiplier = decode_multiplier(msg.unit_of_measure_qty);
-    let lot_size = decode_lot_size(msg.min_lot_size_round_lot);
-    let ts_event = UnixNanos::from(msg.ts_recv); // More accurate and reliable timestamp
-
-    OptionContract::new_checked(
-        instrument_id,
-        instrument_id.symbol,
-        asset_class_opt.unwrap_or(AssetClass::Commodity),
-        Some(exchange),
-        underlying,
-        option_kind,
-        strike_price,
-        currency,
-        msg.activation.into(),
-        msg.expiration.into(),
-        price_increment.precision,
-        price_increment,
-        multiplier,
-        lot_size,
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        ts_event,
-        ts_init,
-    )
-}
-
-pub fn decode_option_spread_v1(
-    msg: &dbn::compat::InstrumentDefMsgV1,
-    instrument_id: InstrumentId,
-    ts_init: UnixNanos,
-) -> anyhow::Result<OptionSpread> {
-    let currency = parse_currency_or_usd_default(msg.currency());
-    let exchange = Ustr::from(msg.exchange()?);
-    let underlying = Ustr::from(msg.underlying()?);
-    let asset_class_opt = if instrument_id.venue.as_str() == "OPRA" {
-        Some(AssetClass::Equity)
-    } else {
-        let (asset_class, _) = parse_cfi_iso10926(msg.cfi()?)?;
-        asset_class
-    };
-    let strategy_type = Ustr::from(msg.secsubtype()?);
-    let price_increment = decode_price_increment(msg.min_price_increment, currency.precision);
-    let multiplier = decode_multiplier(msg.unit_of_measure_qty);
-    let lot_size = decode_lot_size(msg.min_lot_size_round_lot);
-    let ts_event = UnixNanos::from(msg.ts_recv); // More accurate and reliable timestamp
-
-    OptionSpread::new_checked(
-        instrument_id,
-        instrument_id.symbol,
-        asset_class_opt.unwrap_or(AssetClass::Commodity),
-        Some(exchange),
-        underlying,
-        strategy_type,
-        msg.activation.into(),
-        msg.expiration.into(),
-        currency,
-        price_increment.precision,
-        price_increment,
-        multiplier,
-        lot_size,
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        None, // TBD
-        ts_event,
-        ts_init,
-    )
-}
-
 #[must_use]
 fn is_trade_msg(order_side: OrderSide, action: c_char) -> bool {
     order_side == OrderSide::NoOrderSide || action as u8 as char == 'T'
 }
 
+/// # Errors
+///
+/// Returns an error if decoding the MBO message fails.
 pub fn decode_mbo_msg(
     msg: &dbn::MboMsg,
     instrument_id: InstrumentId,
     price_precision: u8,
-    ts_init: UnixNanos,
+    ts_init: Option<UnixNanos>,
     include_trades: bool,
 ) -> anyhow::Result<(Option<OrderBookDelta>, Option<TradeTick>)> {
     let side = parse_order_side(msg.side);
     if is_trade_msg(side, msg.action) {
         if include_trades {
+            let ts_event = msg.ts_recv.into();
+            let ts_init = ts_init.unwrap_or(ts_event);
+
             let trade = TradeTick::new(
                 instrument_id,
                 Price::from_raw(decode_raw_price_i64(msg.price), price_precision),
                 Quantity::from(msg.size),
                 parse_aggressor_side(msg.side),
                 TradeId::new(itoa::Buffer::new().format(msg.sequence)),
-                msg.ts_recv.into(),
+                ts_event,
                 ts_init,
             );
             return Ok((None, Some(trade)));
@@ -526,6 +334,8 @@ pub fn decode_mbo_msg(
         Quantity::from(msg.size),
         msg.order_id,
     );
+    let ts_event = msg.ts_recv.into();
+    let ts_init = ts_init.unwrap_or(ts_event);
 
     let delta = OrderBookDelta::new(
         instrument_id,
@@ -533,46 +343,58 @@ pub fn decode_mbo_msg(
         order,
         msg.flags.raw(),
         msg.sequence.into(),
-        msg.ts_recv.into(),
+        ts_event,
         ts_init,
     );
 
     Ok((Some(delta), None))
 }
 
+/// # Errors
+///
+/// Returns an error if decoding the Trade message fails.
 pub fn decode_trade_msg(
     msg: &dbn::TradeMsg,
     instrument_id: InstrumentId,
     price_precision: u8,
-    ts_init: UnixNanos,
+    ts_init: Option<UnixNanos>,
 ) -> anyhow::Result<TradeTick> {
+    let ts_event = msg.ts_recv.into();
+    let ts_init = ts_init.unwrap_or(ts_event);
+
     let trade = TradeTick::new(
         instrument_id,
         Price::from_raw(decode_raw_price_i64(msg.price), price_precision),
         Quantity::from(msg.size),
         parse_aggressor_side(msg.side),
         TradeId::new(itoa::Buffer::new().format(msg.sequence)),
-        msg.ts_recv.into(),
+        ts_event,
         ts_init,
     );
 
     Ok(trade)
 }
 
+/// # Errors
+///
+/// Returns an error if decoding the TBBO message fails.
 pub fn decode_tbbo_msg(
     msg: &dbn::TbboMsg,
     instrument_id: InstrumentId,
     price_precision: u8,
-    ts_init: UnixNanos,
+    ts_init: Option<UnixNanos>,
 ) -> anyhow::Result<(QuoteTick, TradeTick)> {
     let top_level = &msg.levels[0];
+    let ts_event = msg.ts_recv.into();
+    let ts_init = ts_init.unwrap_or(ts_event);
+
     let quote = QuoteTick::new(
         instrument_id,
         Price::from_raw(decode_raw_price_i64(top_level.bid_px), price_precision),
         Price::from_raw(decode_raw_price_i64(top_level.ask_px), price_precision),
         Quantity::from(top_level.bid_sz),
         Quantity::from(top_level.ask_sz),
-        msg.ts_recv.into(),
+        ts_event,
         ts_init,
     );
 
@@ -582,28 +404,34 @@ pub fn decode_tbbo_msg(
         Quantity::from(msg.size),
         parse_aggressor_side(msg.side),
         TradeId::new(itoa::Buffer::new().format(msg.sequence)),
-        msg.ts_recv.into(),
+        ts_event,
         ts_init,
     );
 
     Ok((quote, trade))
 }
 
+/// # Errors
+///
+/// Returns an error if decoding the MBP1 message fails.
 pub fn decode_mbp1_msg(
     msg: &dbn::Mbp1Msg,
     instrument_id: InstrumentId,
     price_precision: u8,
-    ts_init: UnixNanos,
+    ts_init: Option<UnixNanos>,
     include_trades: bool,
 ) -> anyhow::Result<(QuoteTick, Option<TradeTick>)> {
     let top_level = &msg.levels[0];
+    let ts_event = msg.ts_recv.into();
+    let ts_init = ts_init.unwrap_or(ts_event);
+
     let quote = QuoteTick::new(
         instrument_id,
         Price::from_raw(decode_raw_price_i64(top_level.bid_px), price_precision),
         Price::from_raw(decode_raw_price_i64(top_level.ask_px), price_precision),
         Quantity::from(top_level.bid_sz),
         Quantity::from(top_level.ask_sz),
-        msg.ts_recv.into(),
+        ts_event,
         ts_init,
     );
 
@@ -614,7 +442,7 @@ pub fn decode_mbp1_msg(
             Quantity::from(msg.size),
             parse_aggressor_side(msg.side),
             TradeId::new(itoa::Buffer::new().format(msg.sequence)),
-            msg.ts_recv.into(),
+            ts_event,
             ts_init,
         ))
     } else {
@@ -624,31 +452,44 @@ pub fn decode_mbp1_msg(
     Ok((quote, maybe_trade))
 }
 
+/// # Errors
+///
+/// Returns an error if decoding the BBO message fails.
 pub fn decode_bbo_msg(
     msg: &dbn::BboMsg,
     instrument_id: InstrumentId,
     price_precision: u8,
-    ts_init: UnixNanos,
+    ts_init: Option<UnixNanos>,
 ) -> anyhow::Result<QuoteTick> {
     let top_level = &msg.levels[0];
+    let ts_event = msg.ts_recv.into();
+    let ts_init = ts_init.unwrap_or(ts_event);
+
     let quote = QuoteTick::new(
         instrument_id,
         Price::from_raw(decode_raw_price_i64(top_level.bid_px), price_precision),
         Price::from_raw(decode_raw_price_i64(top_level.ask_px), price_precision),
         Quantity::from(top_level.bid_sz),
         Quantity::from(top_level.ask_sz),
-        msg.ts_recv.into(),
+        ts_event,
         ts_init,
     );
 
     Ok(quote)
 }
 
+/// # Errors
+///
+/// Returns an error if decoding the MBP10 message fails.
+///
+/// # Panics
+///
+/// Panics if the number of levels in `msg.levels` is not exactly `DEPTH10_LEN`.
 pub fn decode_mbp10_msg(
     msg: &dbn::Mbp10Msg,
     instrument_id: InstrumentId,
     price_precision: u8,
-    ts_init: UnixNanos,
+    ts_init: Option<UnixNanos>,
 ) -> anyhow::Result<OrderBookDepth10> {
     let mut bids = Vec::with_capacity(DEPTH10_LEN);
     let mut asks = Vec::with_capacity(DEPTH10_LEN);
@@ -680,6 +521,8 @@ pub fn decode_mbp10_msg(
     let asks: [BookOrder; DEPTH10_LEN] = asks.try_into().expect("`asks` length != 10");
     let bid_counts: [u32; DEPTH10_LEN] = bid_counts.try_into().expect("`bid_counts` length != 10");
     let ask_counts: [u32; DEPTH10_LEN] = ask_counts.try_into().expect("`ask_counts` length != 10");
+    let ts_event = msg.ts_recv.into();
+    let ts_init = ts_init.unwrap_or(ts_event);
 
     let depth = OrderBookDepth10::new(
         instrument_id,
@@ -689,13 +532,16 @@ pub fn decode_mbp10_msg(
         ask_counts,
         msg.flags.raw(),
         msg.sequence.into(),
-        msg.ts_recv.into(),
+        ts_event,
         ts_init,
     );
 
     Ok(depth)
 }
 
+/// # Errors
+///
+/// Returns an error if `rtype` is not a supported bar aggregation.
 pub fn decode_bar_type(
     msg: &dbn::OhlcvMsg,
     instrument_id: InstrumentId,
@@ -726,6 +572,9 @@ pub fn decode_bar_type(
     Ok(bar_type)
 }
 
+/// # Errors
+///
+/// Returns an error if `rtype` is not a supported bar aggregation.
 pub fn decode_ts_event_adjustment(msg: &dbn::OhlcvMsg) -> anyhow::Result<UnixNanos> {
     let adjustment = match msg.hd.rtype {
         32 => {
@@ -753,18 +602,30 @@ pub fn decode_ts_event_adjustment(msg: &dbn::OhlcvMsg) -> anyhow::Result<UnixNan
     Ok(adjustment.into())
 }
 
+/// # Errors
+///
+/// Returns an error if decoding the OHLCV message fails.
 pub fn decode_ohlcv_msg(
     msg: &dbn::OhlcvMsg,
     instrument_id: InstrumentId,
     price_precision: u8,
-    ts_init: UnixNanos,
+    ts_init: Option<UnixNanos>,
+    timestamp_on_close: bool,
 ) -> anyhow::Result<Bar> {
     let bar_type = decode_bar_type(msg, instrument_id)?;
     let ts_event_adjustment = decode_ts_event_adjustment(msg)?;
 
-    // Adjust `ts_event` from open to close of bar
-    let ts_event = UnixNanos::from(msg.hd.ts_event);
-    let ts_init = cmp::max(ts_init, ts_event) + ts_event_adjustment;
+    let ts_event_raw = msg.hd.ts_event.into();
+    let ts_init_raw = ts_init.unwrap_or(ts_event_raw);
+
+    let (ts_event, ts_init) = if timestamp_on_close {
+        // Both ts_event and ts_init are set to close time
+        let ts_close = cmp::max(ts_init_raw, ts_event_raw) + ts_event_adjustment;
+        (ts_close, ts_close)
+    } else {
+        // Both ts_event and ts_init are set to open time
+        (ts_event_raw, ts_event_raw)
+    };
 
     let bar = Bar::new(
         bar_type,
@@ -780,15 +641,25 @@ pub fn decode_ohlcv_msg(
     Ok(bar)
 }
 
+/// # Errors
+///
+/// Returns an error if decoding the status message fails.
+///
+/// # Panics
+///
+/// Panics if `msg.action` is not a valid `MarketStatusAction`.
 pub fn decode_status_msg(
     msg: &dbn::StatusMsg,
     instrument_id: InstrumentId,
-    ts_init: UnixNanos,
+    ts_init: Option<UnixNanos>,
 ) -> anyhow::Result<InstrumentStatus> {
+    let ts_event = msg.hd.ts_event.into();
+    let ts_init = ts_init.unwrap_or(ts_event);
+
     let status = InstrumentStatus::new(
         instrument_id,
         MarketStatusAction::from_u16(msg.action).expect("Invalid `MarketStatusAction`"),
-        msg.hd.ts_event.into(),
+        ts_event,
         ts_init,
         parse_status_reason(msg.reason)?,
         parse_status_trading_event(msg.trading_event)?,
@@ -800,19 +671,29 @@ pub fn decode_status_msg(
     Ok(status)
 }
 
+/// # Errors
+///
+/// Returns an error if decoding the record type fails or encounters unsupported message.
 pub fn decode_record(
     record: &dbn::RecordRef,
     instrument_id: InstrumentId,
     price_precision: u8,
     ts_init: Option<UnixNanos>,
     include_trades: bool,
+    bars_timestamp_on_close: bool,
 ) -> anyhow::Result<(Option<Data>, Option<Data>)> {
     // We don't handle `TbboMsg` here as Nautilus separates this schema
     // into quotes and trades when loading, and the live client will
     // never subscribe to `tbbo`.
     let result = if let Some(msg) = record.get::<dbn::MboMsg>() {
         let ts_init = determine_timestamp(ts_init, msg.ts_recv.into());
-        let result = decode_mbo_msg(msg, instrument_id, price_precision, ts_init, include_trades)?;
+        let result = decode_mbo_msg(
+            msg,
+            instrument_id,
+            price_precision,
+            Some(ts_init),
+            include_trades,
+        )?;
         match result {
             (Some(delta), None) => (Some(Data::Delta(delta)), None),
             (None, Some(trade)) => (Some(Data::Trade(trade)), None),
@@ -821,30 +702,42 @@ pub fn decode_record(
         }
     } else if let Some(msg) = record.get::<dbn::TradeMsg>() {
         let ts_init = determine_timestamp(ts_init, msg.ts_recv.into());
-        let trade = decode_trade_msg(msg, instrument_id, price_precision, ts_init)?;
+        let trade = decode_trade_msg(msg, instrument_id, price_precision, Some(ts_init))?;
         (Some(Data::Trade(trade)), None)
     } else if let Some(msg) = record.get::<dbn::Mbp1Msg>() {
         let ts_init = determine_timestamp(ts_init, msg.ts_recv.into());
-        let result = decode_mbp1_msg(msg, instrument_id, price_precision, ts_init, include_trades)?;
+        let result = decode_mbp1_msg(
+            msg,
+            instrument_id,
+            price_precision,
+            Some(ts_init),
+            include_trades,
+        )?;
         match result {
             (quote, None) => (Some(Data::Quote(quote)), None),
             (quote, Some(trade)) => (Some(Data::Quote(quote)), Some(Data::Trade(trade))),
         }
     } else if let Some(msg) = record.get::<dbn::Bbo1SMsg>() {
         let ts_init = determine_timestamp(ts_init, msg.ts_recv.into());
-        let quote = decode_bbo_msg(msg, instrument_id, price_precision, ts_init)?;
+        let quote = decode_bbo_msg(msg, instrument_id, price_precision, Some(ts_init))?;
         (Some(Data::Quote(quote)), None)
     } else if let Some(msg) = record.get::<dbn::Bbo1MMsg>() {
         let ts_init = determine_timestamp(ts_init, msg.ts_recv.into());
-        let quote = decode_bbo_msg(msg, instrument_id, price_precision, ts_init)?;
+        let quote = decode_bbo_msg(msg, instrument_id, price_precision, Some(ts_init))?;
         (Some(Data::Quote(quote)), None)
     } else if let Some(msg) = record.get::<dbn::Mbp10Msg>() {
         let ts_init = determine_timestamp(ts_init, msg.ts_recv.into());
-        let depth = decode_mbp10_msg(msg, instrument_id, price_precision, ts_init)?;
+        let depth = decode_mbp10_msg(msg, instrument_id, price_precision, Some(ts_init))?;
         (Some(Data::from(depth)), None)
     } else if let Some(msg) = record.get::<dbn::OhlcvMsg>() {
         let ts_init = determine_timestamp(ts_init, msg.hd.ts_event.into());
-        let bar = decode_ohlcv_msg(msg, instrument_id, price_precision, ts_init)?;
+        let bar = decode_ohlcv_msg(
+            msg,
+            instrument_id,
+            price_precision,
+            Some(ts_init),
+            bars_timestamp_on_close,
+        )?;
         (Some(Data::Bar(bar)), None)
     } else {
         anyhow::bail!("DBN message type is not currently supported")
@@ -860,50 +753,13 @@ const fn determine_timestamp(ts_init: Option<UnixNanos>, msg_timestamp: UnixNano
     }
 }
 
-pub fn decode_instrument_def_msg_v1(
-    msg: &dbn::compat::InstrumentDefMsgV1,
-    instrument_id: InstrumentId,
-    ts_init: UnixNanos,
-) -> anyhow::Result<InstrumentAny> {
-    match msg.instrument_class as u8 as char {
-        'K' => Ok(InstrumentAny::Equity(decode_equity_v1(
-            msg,
-            instrument_id,
-            ts_init,
-        )?)),
-        'F' => Ok(InstrumentAny::FuturesContract(decode_futures_contract_v1(
-            msg,
-            instrument_id,
-            ts_init,
-        )?)),
-        'S' => Ok(InstrumentAny::FuturesSpread(decode_futures_spread_v1(
-            msg,
-            instrument_id,
-            ts_init,
-        )?)),
-        'C' | 'P' => Ok(InstrumentAny::OptionContract(decode_option_contract_v1(
-            msg,
-            instrument_id,
-            ts_init,
-        )?)),
-        'T' | 'M' => Ok(InstrumentAny::OptionSpread(decode_option_spread_v1(
-            msg,
-            instrument_id,
-            ts_init,
-        )?)),
-        'B' => anyhow::bail!("Unsupported `instrument_class` 'B' (Bond)"),
-        'X' => anyhow::bail!("Unsupported `instrument_class` 'X' (FX spot)"),
-        _ => anyhow::bail!(
-            "Unsupported `instrument_class` '{}'",
-            msg.instrument_class as u8 as char
-        ),
-    }
-}
-
+/// # Errors
+///
+/// Returns an error if decoding the `InstrumentDefMsg` fails.
 pub fn decode_instrument_def_msg(
     msg: &dbn::InstrumentDefMsg,
     instrument_id: InstrumentId,
-    ts_init: UnixNanos,
+    ts_init: Option<UnixNanos>,
 ) -> anyhow::Result<InstrumentAny> {
     match msg.instrument_class as u8 as char {
         'K' => Ok(InstrumentAny::Equity(decode_equity(
@@ -940,15 +796,19 @@ pub fn decode_instrument_def_msg(
     }
 }
 
+/// # Errors
+///
+/// Returns an error if parsing or constructing `Equity` fails.
 pub fn decode_equity(
     msg: &dbn::InstrumentDefMsg,
     instrument_id: InstrumentId,
-    ts_init: UnixNanos,
+    ts_init: Option<UnixNanos>,
 ) -> anyhow::Result<Equity> {
     let currency = parse_currency_or_usd_default(msg.currency());
     let price_increment = decode_price_increment(msg.min_price_increment, currency.precision);
     let lot_size = decode_lot_size(msg.min_lot_size_round_lot);
     let ts_event = UnixNanos::from(msg.ts_recv); // More accurate and reliable timestamp
+    let ts_init = ts_init.unwrap_or(ts_event);
 
     Ok(Equity::new(
         instrument_id,
@@ -971,10 +831,13 @@ pub fn decode_equity(
     ))
 }
 
+/// # Errors
+///
+/// Returns an error if parsing or constructing `FuturesContract` fails.
 pub fn decode_futures_contract(
     msg: &dbn::InstrumentDefMsg,
     instrument_id: InstrumentId,
-    ts_init: UnixNanos,
+    ts_init: Option<UnixNanos>,
 ) -> anyhow::Result<FuturesContract> {
     let currency = parse_currency_or_usd_default(msg.currency());
     let exchange = Ustr::from(msg.exchange()?);
@@ -984,6 +847,7 @@ pub fn decode_futures_contract(
     let multiplier = decode_multiplier(msg.unit_of_measure_qty);
     let lot_size = decode_lot_size(msg.min_lot_size_round_lot);
     let ts_event = UnixNanos::from(msg.ts_recv); // More accurate and reliable timestamp
+    let ts_init = ts_init.unwrap_or(ts_event);
 
     FuturesContract::new_checked(
         instrument_id,
@@ -1011,10 +875,13 @@ pub fn decode_futures_contract(
     )
 }
 
+/// # Errors
+///
+/// Returns an error if parsing or constructing `FuturesSpread` fails.
 pub fn decode_futures_spread(
     msg: &dbn::InstrumentDefMsg,
     instrument_id: InstrumentId,
-    ts_init: UnixNanos,
+    ts_init: Option<UnixNanos>,
 ) -> anyhow::Result<FuturesSpread> {
     let exchange = Ustr::from(msg.exchange()?);
     let underlying = Ustr::from(msg.asset()?);
@@ -1025,6 +892,7 @@ pub fn decode_futures_spread(
     let multiplier = decode_multiplier(msg.unit_of_measure_qty);
     let lot_size = decode_lot_size(msg.min_lot_size_round_lot);
     let ts_event = UnixNanos::from(msg.ts_recv); // More accurate and reliable timestamp
+    let ts_init = ts_init.unwrap_or(ts_event);
 
     FuturesSpread::new_checked(
         instrument_id,
@@ -1053,10 +921,13 @@ pub fn decode_futures_spread(
     )
 }
 
+/// # Errors
+///
+/// Returns an error if parsing or constructing `OptionContract` fails.
 pub fn decode_option_contract(
     msg: &dbn::InstrumentDefMsg,
     instrument_id: InstrumentId,
-    ts_init: UnixNanos,
+    ts_init: Option<UnixNanos>,
 ) -> anyhow::Result<OptionContract> {
     let currency = parse_currency_or_usd_default(msg.currency());
     let strike_price_currency = parse_currency_or_usd_default(msg.strike_price_currency());
@@ -1077,6 +948,7 @@ pub fn decode_option_contract(
     let multiplier = decode_multiplier(msg.unit_of_measure_qty);
     let lot_size = decode_lot_size(msg.min_lot_size_round_lot);
     let ts_event = UnixNanos::from(msg.ts_recv); // More accurate and reliable timestamp
+    let ts_init = ts_init.unwrap_or(ts_event);
 
     OptionContract::new_checked(
         instrument_id,
@@ -1106,10 +978,13 @@ pub fn decode_option_contract(
     )
 }
 
+/// # Errors
+///
+/// Returns an error if parsing or constructing `OptionSpread` fails.
 pub fn decode_option_spread(
     msg: &dbn::InstrumentDefMsg,
     instrument_id: InstrumentId,
-    ts_init: UnixNanos,
+    ts_init: Option<UnixNanos>,
 ) -> anyhow::Result<OptionSpread> {
     let exchange = Ustr::from(msg.exchange()?);
     let underlying = Ustr::from(msg.underlying()?);
@@ -1124,7 +999,8 @@ pub fn decode_option_spread(
     let price_increment = decode_price_increment(msg.min_price_increment, currency.precision);
     let multiplier = decode_multiplier(msg.unit_of_measure_qty);
     let lot_size = decode_lot_size(msg.min_lot_size_round_lot);
-    let ts_event = UnixNanos::from(msg.ts_recv); // More accurate and reliable timestamp
+    let ts_event = msg.ts_recv.into(); // More accurate and reliable timestamp
+    let ts_init = ts_init.unwrap_or(ts_event);
 
     OptionSpread::new_checked(
         instrument_id,
@@ -1153,12 +1029,18 @@ pub fn decode_option_spread(
     )
 }
 
+/// # Errors
+///
+/// Returns an error if constructing `DatabentoImbalance` fails.
 pub fn decode_imbalance_msg(
     msg: &dbn::ImbalanceMsg,
     instrument_id: InstrumentId,
     price_precision: u8,
-    ts_init: UnixNanos,
+    ts_init: Option<UnixNanos>,
 ) -> anyhow::Result<DatabentoImbalance> {
+    let ts_event = msg.ts_recv.into();
+    let ts_init = ts_init.unwrap_or(ts_event);
+
     DatabentoImbalance::new(
         instrument_id,
         Price::from_raw(decode_raw_price_i64(msg.ref_price), price_precision),
@@ -1175,21 +1057,30 @@ pub fn decode_imbalance_msg(
         parse_order_side(msg.side),
         msg.significant_imbalance as c_char,
         msg.hd.ts_event.into(),
-        msg.ts_recv.into(),
+        ts_event,
         ts_init,
     )
 }
 
+/// # Errors
+///
+/// Returns an error if constructing `DatabentoStatistics` fails.
+///
+/// # Panics
+///
+/// Panics if `msg.stat_type` or `msg.update_action` is not a valid enum variant.
 pub fn decode_statistics_msg(
     msg: &dbn::StatMsg,
     instrument_id: InstrumentId,
     price_precision: u8,
-    ts_init: UnixNanos,
+    ts_init: Option<UnixNanos>,
 ) -> anyhow::Result<DatabentoStatistics> {
     let stat_type = DatabentoStatisticType::from_u8(msg.stat_type as u8)
         .expect("Invalid value for `stat_type`");
     let update_action = DatabentoStatisticUpdateAction::from_u8(msg.update_action)
         .expect("Invalid value for `update_action`");
+    let ts_event = msg.ts_recv.into();
+    let ts_init = ts_init.unwrap_or(ts_event);
 
     DatabentoStatistics::new(
         instrument_id,
@@ -1203,7 +1094,7 @@ pub fn decode_statistics_msg(
         msg.ts_ref.into(),
         msg.ts_in_delta,
         msg.hd.ts_event.into(),
-        msg.ts_recv.into(),
+        ts_event,
         ts_init,
     )
 }
@@ -1327,10 +1218,10 @@ mod tests {
     }
 
     #[rstest]
-    #[case(i32::MAX, None)] // None for i32::MAX
+    #[case(i64::MAX, None)] // None for i32::MAX
     #[case(0, Some(Quantity::new(0.0, 0)))] // 0 is valid quantity
     #[case(10, Some(Quantity::new(10.0, 0)))] // Arbitrary valid quantity
-    fn test_decode_optional_quantity(#[case] value: i32, #[case] expected: Option<Quantity>) {
+    fn test_decode_optional_quantity(#[case] value: i64, #[case] expected: Option<Quantity>) {
         let actual = decode_optional_quantity(value);
         assert_eq!(actual, expected);
     }
@@ -1344,7 +1235,7 @@ mod tests {
         let msg = dbn_stream.next().unwrap().unwrap();
 
         let instrument_id = InstrumentId::from("ESM4.GLBX");
-        let (delta, _) = decode_mbo_msg(msg, instrument_id, 2, 0.into(), false).unwrap();
+        let (delta, _) = decode_mbo_msg(msg, instrument_id, 2, Some(0.into()), false).unwrap();
         let delta = delta.unwrap();
 
         assert_eq!(delta.instrument_id, instrument_id);
@@ -1369,7 +1260,7 @@ mod tests {
         let msg = dbn_stream.next().unwrap().unwrap();
 
         let instrument_id = InstrumentId::from("ESM4.GLBX");
-        let (quote, _) = decode_mbp1_msg(msg, instrument_id, 2, 0.into(), false).unwrap();
+        let (quote, _) = decode_mbp1_msg(msg, instrument_id, 2, Some(0.into()), false).unwrap();
 
         assert_eq!(quote.instrument_id, instrument_id);
         assert_eq!(quote.bid_price, Price::from("3720.25"));
@@ -1390,7 +1281,7 @@ mod tests {
         let msg = dbn_stream.next().unwrap().unwrap();
 
         let instrument_id = InstrumentId::from("ESM4.GLBX");
-        let quote = decode_bbo_msg(msg, instrument_id, 2, 0.into()).unwrap();
+        let quote = decode_bbo_msg(msg, instrument_id, 2, Some(0.into())).unwrap();
 
         assert_eq!(quote.instrument_id, instrument_id);
         assert_eq!(quote.bid_price, Price::from("5199.50"));
@@ -1411,7 +1302,7 @@ mod tests {
         let msg = dbn_stream.next().unwrap().unwrap();
 
         let instrument_id = InstrumentId::from("ESM4.GLBX");
-        let quote = decode_bbo_msg(msg, instrument_id, 2, 0.into()).unwrap();
+        let quote = decode_bbo_msg(msg, instrument_id, 2, Some(0.into())).unwrap();
 
         assert_eq!(quote.instrument_id, instrument_id);
         assert_eq!(quote.bid_price, Price::from("5199.50"));
@@ -1432,7 +1323,7 @@ mod tests {
         let msg = dbn_stream.next().unwrap().unwrap();
 
         let instrument_id = InstrumentId::from("ESM4.GLBX");
-        let depth10 = decode_mbp10_msg(msg, instrument_id, 2, 0.into()).unwrap();
+        let depth10 = decode_mbp10_msg(msg, instrument_id, 2, Some(0.into())).unwrap();
 
         assert_eq!(depth10.instrument_id, instrument_id);
         assert_eq!(depth10.bids.len(), 10);
@@ -1455,7 +1346,7 @@ mod tests {
         let msg = dbn_stream.next().unwrap().unwrap();
 
         let instrument_id = InstrumentId::from("ESM4.GLBX");
-        let trade = decode_trade_msg(msg, instrument_id, 2, 0.into()).unwrap();
+        let trade = decode_trade_msg(msg, instrument_id, 2, Some(0.into())).unwrap();
 
         assert_eq!(trade.instrument_id, instrument_id);
         assert_eq!(trade.price, Price::from("3720.25"));
@@ -1476,7 +1367,7 @@ mod tests {
         let msg = dbn_stream.next().unwrap().unwrap();
 
         let instrument_id = InstrumentId::from("ESM4.GLBX");
-        let (quote, trade) = decode_tbbo_msg(msg, instrument_id, 2, 0.into()).unwrap();
+        let (quote, trade) = decode_tbbo_msg(msg, instrument_id, 2, Some(0.into())).unwrap();
 
         assert_eq!(quote.instrument_id, instrument_id);
         assert_eq!(quote.bid_price, Price::from("3720.25"));
@@ -1507,7 +1398,7 @@ mod tests {
         let msg = dbn_stream.next().unwrap().unwrap();
 
         let instrument_id = InstrumentId::from("ESM4.GLBX");
-        let bar = decode_ohlcv_msg(msg, instrument_id, 2, 0.into()).unwrap();
+        let bar = decode_ohlcv_msg(msg, instrument_id, 2, Some(0.into()), true).unwrap();
 
         assert_eq!(
             bar.bar_type,
@@ -1530,22 +1421,7 @@ mod tests {
         let msg = dbn_stream.next().unwrap().unwrap();
 
         let instrument_id = InstrumentId::from("ESM4.GLBX");
-        let result = decode_instrument_def_msg(msg, instrument_id, 0.into());
-
-        assert!(result.is_ok());
-        assert_eq!(result.unwrap().multiplier(), Quantity::from(1));
-    }
-
-    #[rstest]
-    fn test_decode_definition_v1_msg() {
-        let path = test_data_path().join("test_data.definition.v1.dbn.zst");
-        let mut dbn_stream = Decoder::from_zstd_file(path)
-            .unwrap()
-            .decode_stream::<dbn::compat::InstrumentDefMsgV1>();
-        let msg = dbn_stream.next().unwrap().unwrap();
-
-        let instrument_id = InstrumentId::from("ESM4.GLBX");
-        let result = decode_instrument_def_msg_v1(msg, instrument_id, 0.into());
+        let result = decode_instrument_def_msg(msg, instrument_id, Some(0.into()));
 
         assert!(result.is_ok());
         assert_eq!(result.unwrap().multiplier(), Quantity::from(1));
@@ -1560,7 +1436,7 @@ mod tests {
         let msg = dbn_stream.next().unwrap().unwrap();
 
         let instrument_id = InstrumentId::from("ESM4.GLBX");
-        let status = decode_status_msg(msg, instrument_id, 0.into()).unwrap();
+        let status = decode_status_msg(msg, instrument_id, Some(0.into())).unwrap();
 
         assert_eq!(status.instrument_id, instrument_id);
         assert_eq!(status.action, MarketStatusAction::Trading);
@@ -1582,7 +1458,7 @@ mod tests {
         let msg = dbn_stream.next().unwrap().unwrap();
 
         let instrument_id = InstrumentId::from("ESM4.GLBX");
-        let imbalance = decode_imbalance_msg(msg, instrument_id, 2, 0.into()).unwrap();
+        let imbalance = decode_imbalance_msg(msg, instrument_id, 2, Some(0.into())).unwrap();
 
         assert_eq!(imbalance.instrument_id, instrument_id);
         assert_eq!(imbalance.ref_price, Price::from("229.43"));
@@ -1606,7 +1482,7 @@ mod tests {
         let msg = dbn_stream.next().unwrap().unwrap();
 
         let instrument_id = InstrumentId::from("ESM4.GLBX");
-        let statistics = decode_statistics_msg(msg, instrument_id, 2, 0.into()).unwrap();
+        let statistics = decode_statistics_msg(msg, instrument_id, 2, Some(0.into())).unwrap();
 
         assert_eq!(statistics.instrument_id, instrument_id);
         assert_eq!(statistics.stat_type, DatabentoStatisticType::LowestOffer);
