@@ -13,14 +13,16 @@
 //  limitations under the License.
 // -------------------------------------------------------------------------------------------------
 
+//! Python bindings for the Databento live client.
+
 use std::{
-    collections::HashMap,
     fs,
     path::PathBuf,
     str::FromStr,
     sync::{Arc, RwLock},
 };
 
+use ahash::AHashMap;
 use databento::{dbn, live::Subscription};
 use indexmap::IndexMap;
 use nautilus_core::python::{IntoPyObjectNautilusExt, to_pyruntime_err, to_pyvalue_err};
@@ -53,8 +55,9 @@ pub struct DatabentoLiveClient {
     cmd_rx: Option<tokio::sync::mpsc::UnboundedReceiver<LiveCommand>>,
     buffer_size: usize,
     publisher_venue_map: IndexMap<u16, Venue>,
-    symbol_venue_map: Arc<RwLock<HashMap<Symbol, Venue>>>,
+    symbol_venue_map: Arc<RwLock<AHashMap<Symbol, Venue>>>,
     use_exchange_as_venue: bool,
+    bars_timestamp_on_close: bool,
 }
 
 impl DatabentoLiveClient {
@@ -77,11 +80,12 @@ impl DatabentoLiveClient {
                     let py_obj = data_to_pycapsule(py, data);
                     call_python(py, &callback, py_obj);
                 }),
-                LiveMessage::Instrument(data) => Python::with_gil(|py| {
-                    let py_obj =
-                        instrument_any_to_pyobject(py, data).expect("Failed creating instrument");
-                    call_python(py, &callback, py_obj);
-                }),
+                LiveMessage::Instrument(data) => {
+                    Python::with_gil(|py| match instrument_any_to_pyobject(py, data) {
+                        Ok(py_obj) => call_python(py, &callback, py_obj),
+                        Err(e) => tracing::error!("Failed creating instrument: {e}"),
+                    });
+                }
                 LiveMessage::Status(data) => Python::with_gil(|py| {
                     let py_obj = data.into_py_any_unwrap(py);
                     call_python(py, &callback_pyo3, py_obj);
@@ -127,14 +131,18 @@ fn call_python(py: Python, callback: &PyObject, py_obj: PyObject) {
 
 #[pymethods]
 impl DatabentoLiveClient {
+    /// # Errors
+    ///
+    /// Returns a `PyErr` if reading or parsing the publishers file fails.
     #[new]
     pub fn py_new(
         key: String,
         dataset: String,
         publishers_filepath: PathBuf,
         use_exchange_as_venue: bool,
+        bars_timestamp_on_close: Option<bool>,
     ) -> PyResult<Self> {
-        let publishers_json = fs::read_to_string(publishers_filepath)?;
+        let publishers_json = fs::read_to_string(publishers_filepath).map_err(to_pyvalue_err)?;
         let publishers_vec: Vec<DatabentoPublisher> =
             serde_json::from_str(&publishers_json).map_err(to_pyvalue_err)?;
         let publisher_venue_map = publishers_vec
@@ -156,8 +164,9 @@ impl DatabentoLiveClient {
             is_running: false,
             is_closed: false,
             publisher_venue_map,
-            symbol_venue_map: Arc::new(RwLock::new(HashMap::new())),
+            symbol_venue_map: Arc::new(RwLock::new(AHashMap::new())),
             use_exchange_as_venue,
+            bars_timestamp_on_close: bars_timestamp_on_close.unwrap_or(true),
         })
     }
 
@@ -180,14 +189,20 @@ impl DatabentoLiveClient {
         start: Option<u64>,
         snapshot: Option<bool>,
     ) -> PyResult<()> {
-        let mut symbol_venue_map = self.symbol_venue_map.write().unwrap();
+        let mut symbol_venue_map = self
+            .symbol_venue_map
+            .write()
+            .map_err(|e| to_pyruntime_err(format!("symbol_venue_map lock poisoned: {e}")))?;
         let symbols: Vec<String> = instrument_ids
             .iter()
             .map(|instrument_id| {
                 instrument_id_to_symbol_string(*instrument_id, &mut symbol_venue_map)
             })
             .collect();
-        let stype_in = infer_symbology_type(symbols.first().unwrap());
+        let first_symbol = symbols
+            .first()
+            .ok_or_else(|| to_pyvalue_err("No symbols provided"))?;
+        let stype_in = infer_symbology_type(first_symbol);
         let symbols: Vec<&str> = symbols.iter().map(String::as_str).collect();
         check_consistent_symbology(symbols.as_slice()).map_err(to_pyvalue_err)?;
         let mut sub = Subscription::builder()
@@ -229,7 +244,10 @@ impl DatabentoLiveClient {
         // Consume the receiver
         // SAFETY: We guard the client from being started more than once with the
         // `is_running` flag, so here it is safe to unwrap the command receiver.
-        let cmd_rx = self.cmd_rx.take().unwrap();
+        let cmd_rx = self
+            .cmd_rx
+            .take()
+            .ok_or_else(|| to_pyruntime_err("Command receiver already taken"))?;
 
         let mut feed_handler = DatabentoFeedHandler::new(
             self.key.clone(),
@@ -239,6 +257,7 @@ impl DatabentoLiveClient {
             self.publisher_venue_map.clone(),
             self.symbol_venue_map.clone(),
             self.use_exchange_as_venue,
+            self.bars_timestamp_on_close,
         );
 
         self.send_command(LiveCommand::Start)?;
