@@ -13,13 +13,10 @@
 //  limitations under the License.
 // -------------------------------------------------------------------------------------------------
 
-use std::collections::HashMap;
-
 use ahash::AHashMap;
 use databento::dbn::{self, PitSymbolMap, SType};
 use dbn::{Publisher, Record};
 use indexmap::IndexMap;
-use nautilus_core::correctness::check_slice_not_empty;
 use nautilus_model::identifiers::{InstrumentId, Symbol, Venue};
 
 use super::types::PublisherId;
@@ -39,17 +36,24 @@ impl MetadataCache {
         }
     }
 
+    /// # Errors
+    ///
+    /// Returns an error if metadata for the given `date` cannot be retrieved.
     pub fn symbol_map_for_date(&mut self, date: time::Date) -> dbn::Result<&PitSymbolMap> {
-        Ok(self
-            .date_metadata_map
-            .entry(date)
-            .or_insert_with(|| self.metadata.symbol_map_for_date(date).unwrap()))
+        if !self.date_metadata_map.contains_key(&date) {
+            let map = self.metadata.symbol_map_for_date(date)?;
+            self.date_metadata_map.insert(date, map);
+        }
+
+        self.date_metadata_map
+            .get(&date)
+            .ok_or_else(|| dbn::Error::decode(format!("metadata cache missing for date {date}")))
     }
 }
 
 pub fn instrument_id_to_symbol_string(
     instrument_id: InstrumentId,
-    symbol_venue_map: &mut HashMap<Symbol, Venue>,
+    symbol_venue_map: &mut AHashMap<Symbol, Venue>,
 ) -> String {
     symbol_venue_map
         .entry(instrument_id.symbol)
@@ -57,27 +61,43 @@ pub fn instrument_id_to_symbol_string(
     instrument_id.symbol.to_string()
 }
 
+/// # Errors
+///
+/// Returns an error if mapping record to `InstrumentId` fails.
+///
+/// # Panics
+///
+/// Panics if the raw symbol from metadata cannot be converted into a `Symbol`.
 pub fn decode_nautilus_instrument_id(
     record: &dbn::RecordRef,
     metadata: &mut MetadataCache,
     publisher_venue_map: &IndexMap<PublisherId, Venue>,
-    symbol_venue_map: &HashMap<Symbol, Venue>,
+    symbol_venue_map: &AHashMap<Symbol, Venue>,
 ) -> anyhow::Result<InstrumentId> {
-    let publisher = record.publisher().expect("Invalid `publisher` for record");
+    let publisher = record
+        .publisher()
+        .map_err(|e| anyhow::anyhow!("Invalid `publisher` for record: {e}"))?;
     let publisher_id = publisher as PublisherId;
     let venue = publisher_venue_map
         .get(&publisher_id)
         .ok_or_else(|| anyhow::anyhow!("`Venue` not found for `publisher_id` {publisher_id}"))?;
     let mut instrument_id = get_nautilus_instrument_id_for_record(record, metadata, *venue)?;
-    if publisher == Publisher::GlbxMdp3Glbx {
-        if let Some(venue) = symbol_venue_map.get(&instrument_id.symbol) {
-            instrument_id.venue = *venue;
-        }
+    if publisher == Publisher::GlbxMdp3Glbx
+        && let Some(venue) = symbol_venue_map.get(&instrument_id.symbol)
+    {
+        instrument_id.venue = *venue;
     }
 
     Ok(instrument_id)
 }
 
+/// # Errors
+///
+/// Returns an error if mapping record to `InstrumentId` fails or timestamp overflow occurs.
+///
+/// # Panics
+///
+/// Panics if the raw symbol from metadata cannot be converted into a `Symbol`.
 pub fn get_nautilus_instrument_id_for_record(
     record: &dbn::RecordRef,
     metadata: &mut MetadataCache,
@@ -112,7 +132,7 @@ pub fn get_nautilus_instrument_id_for_record(
     let duration = time::Duration::nanoseconds(nanoseconds as i64);
     let datetime = time::OffsetDateTime::UNIX_EPOCH
         .checked_add(duration)
-        .unwrap(); // SAFETY: Relying on correctness of record timestamps
+        .ok_or_else(|| anyhow::anyhow!("Timestamp overflow for record"))?;
     let date = datetime.date();
     let symbol_map = metadata.symbol_map_for_date(date)?;
     let raw_symbol = symbol_map
@@ -142,11 +162,14 @@ pub fn infer_symbology_type(symbol: &str) -> SType {
     SType::RawSymbol
 }
 
+/// # Errors
+///
+/// Returns an error if `symbols` is empty or symbols have inconsistent symbology types.
 pub fn check_consistent_symbology(symbols: &[&str]) -> anyhow::Result<()> {
-    check_slice_not_empty(symbols, stringify!(symbols)).unwrap();
-
-    // SAFETY: We checked len so know there must be at least one symbol
-    let first_symbol = symbols.first().unwrap();
+    if symbols.is_empty() {
+        anyhow::bail!("No symbols provided");
+    }
+    let first_symbol = symbols[0];
     let first_stype = infer_symbology_type(first_symbol);
 
     for symbol in symbols {
@@ -194,10 +217,32 @@ mod tests {
     }
 
     #[rstest]
-    #[should_panic]
     fn test_check_consistent_symbology_when_empty_symbols() {
         let symbols: Vec<&str> = vec![];
-        let _ = check_consistent_symbology(&symbols);
+        assert!(check_consistent_symbology(&symbols).is_err());
+    }
+
+    #[rstest]
+    fn test_instrument_id_to_symbol_string_updates_map() {
+        use nautilus_model::identifiers::Venue;
+        let symbol = Symbol::from("TEST");
+        let venue = Venue::from("XNAS");
+        let instrument_id = InstrumentId::new(symbol, venue);
+        let mut map: AHashMap<Symbol, Venue> = AHashMap::new();
+
+        // First call should insert the mapping
+        let sym_str = instrument_id_to_symbol_string(instrument_id, &mut map);
+        assert_eq!(sym_str, "TEST");
+        assert_eq!(map.get(&Symbol::from("TEST")), Some(&Venue::from("XNAS")));
+
+        // Call again with same symbol but different venue should not override existing
+        let other = Venue::from("XLON");
+        let inst2 = InstrumentId::new(Symbol::from("TEST"), other);
+        let sym_str2 = instrument_id_to_symbol_string(inst2, &mut map);
+        assert_eq!(sym_str2, "TEST");
+
+        // Venue remains the original
+        assert_eq!(map.get(&Symbol::from("TEST")), Some(&Venue::from("XNAS")));
     }
 
     #[rstest]
