@@ -18,7 +18,20 @@ use serde::{Deserialize, Serialize};
 use strum::{AsRefStr, Display, EnumIter, EnumString, FromRepr};
 use ustr::Ustr;
 
-#[derive(Debug, Clone, PartialEq, Eq, Serialize, Deserialize, Display, FromRepr, EnumString)]
+#[derive(
+    Debug,
+    Clone,
+    PartialEq,
+    Eq,
+    Hash,
+    Serialize,
+    Deserialize,
+    Display,
+    AsRefStr,
+    EnumIter,
+    EnumString,
+    FromRepr,
+)]
 #[strum(ascii_case_insensitive)]
 #[strum(serialize_all = "lowercase")]
 #[serde(rename_all = "lowercase")]
@@ -31,7 +44,20 @@ pub enum InstrumentType {
     Combo,
 }
 
-#[derive(Debug, Clone, PartialEq, Eq, Serialize, Deserialize, Display, FromRepr, EnumString)]
+#[derive(
+    Debug,
+    Clone,
+    PartialEq,
+    Eq,
+    Hash,
+    Serialize,
+    Deserialize,
+    Display,
+    AsRefStr,
+    EnumIter,
+    EnumString,
+    FromRepr,
+)]
 #[serde(rename_all = "lowercase")]
 /// The type of option.
 pub enum OptionType {
@@ -40,7 +66,20 @@ pub enum OptionType {
 }
 
 /// The aggressor side of the trade.
-#[derive(Debug, Clone, PartialEq, Eq, Serialize, Deserialize, Display, FromRepr, EnumString)]
+#[derive(
+    Debug,
+    Clone,
+    PartialEq,
+    Eq,
+    Hash,
+    Serialize,
+    Deserialize,
+    Display,
+    AsRefStr,
+    EnumIter,
+    EnumString,
+    FromRepr,
+)]
 #[serde(rename_all = "lowercase")]
 pub enum TradeSide {
     Buy,
@@ -50,7 +89,20 @@ pub enum TradeSide {
 
 /// The bar kind.
 #[allow(missing_docs)]
-#[derive(Debug, Clone, PartialEq, Eq, Serialize, Deserialize, Display, FromRepr, EnumString)]
+#[derive(
+    Debug,
+    Clone,
+    PartialEq,
+    Eq,
+    Hash,
+    Serialize,
+    Deserialize,
+    Display,
+    AsRefStr,
+    EnumIter,
+    EnumString,
+    FromRepr,
+)]
 #[serde(rename_all = "lowercase")]
 pub enum BarKind {
     Time,
@@ -82,6 +134,7 @@ pub enum Exchange {
     Binance,
     BinanceDelivery,
     BinanceDex,
+    BinanceEuropeanOptions,
     BinanceFutures,
     BinanceJersey,
     BinanceOptions,
@@ -89,6 +142,8 @@ pub enum Exchange {
     Bitfinex,
     BitfinexDerivatives,
     Bitflyer,
+    Bitget,
+    BitgetFutures,
     Bitmex,
     Bitnomial,
     Bitstamp,
@@ -97,6 +152,7 @@ pub enum Exchange {
     BybitOptions,
     BybitSpot,
     Coinbase,
+    CoinbaseInternational,
     Coinflex,
     CryptoCom,
     CryptoComDerivatives,
@@ -104,6 +160,7 @@ pub enum Exchange {
     Delta,
     Deribit,
     Dydx,
+    DydxV4,
     Ftx,
     FtxUs,
     GateIo,
@@ -115,13 +172,17 @@ pub enum Exchange {
     HuobiDmLinearSwap,
     HuobiDmOptions,
     HuobiDmSwap,
+    Hyperliquid,
     Kraken,
+    KrakenFutures,
     Kucoin,
+    KucoinFutures,
     Mango,
     Okcoin,
     Okex,
     OkexFutures,
     OkexOptions,
+    OkexSpreads,
     OkexSwap,
     Phemex,
     Poloniex,
@@ -140,6 +201,7 @@ impl Exchange {
             "BINANCE" => vec![
                 Self::Binance,
                 Self::BinanceDex,
+                Self::BinanceEuropeanOptions,
                 Self::BinanceFutures,
                 Self::BinanceJersey,
                 Self::BinanceOptions,
@@ -147,6 +209,7 @@ impl Exchange {
             "BINANCE_DELIVERY" => vec![Self::BinanceDelivery],
             "BINANCE_US" => vec![Self::BinanceUs],
             "BITFINEX" => vec![Self::Bitfinex, Self::BitfinexDerivatives],
+            "BITGET" => vec![Self::Bitget, Self::BitgetFutures],
             "BITFLYER" => vec![Self::Bitflyer],
             "BITMEX" => vec![Self::Bitmex],
             "BITNOMIAL" => vec![Self::Bitnomial],
@@ -154,12 +217,14 @@ impl Exchange {
             "BLOCKCHAIN_COM" => vec![Self::BlockchainCom],
             "BYBIT" => vec![Self::Bybit, Self::BybitOptions, Self::BybitSpot],
             "COINBASE" => vec![Self::Coinbase],
+            "COINBASE_INTX" => vec![Self::CoinbaseInternational],
             "COINFLEX" => vec![Self::Coinflex],
             "CRYPTO_COM" => vec![Self::CryptoCom, Self::CryptoComDerivatives],
             "CRYPTOFACILITIES" => vec![Self::Cryptofacilities],
             "DELTA" => vec![Self::Delta],
             "DERIBIT" => vec![Self::Deribit],
             "DYDX" => vec![Self::Dydx],
+            "DYDX_V4" => vec![Self::DydxV4],
             "FTX" => vec![Self::Ftx, Self::FtxUs],
             "GATE_IO" => vec![Self::GateIo, Self::GateIoFutures],
             "GEMINI" => vec![Self::Gemini],
@@ -171,14 +236,16 @@ impl Exchange {
                 Self::HuobiDmOptions,
             ],
             "HUOBI_DELIVERY" => vec![Self::HuobiDmSwap],
-            "KRAKEN" => vec![Self::Kraken],
-            "KUCOIN" => vec![Self::Kucoin],
+            "HYPERLIQUID" => vec![Self::Hyperliquid],
+            "KRAKEN" => vec![Self::Kraken, Self::KrakenFutures],
+            "KUCOIN" => vec![Self::Kucoin, Self::KucoinFutures],
             "MANGO" => vec![Self::Mango],
             "OKCOIN" => vec![Self::Okcoin],
             "OKEX" => vec![
                 Self::Okex,
                 Self::OkexFutures,
                 Self::OkexOptions,
+                Self::OkexSpreads,
                 Self::OkexSwap,
             ],
             "PHEMEX" => vec![Self::Phemex],
@@ -198,6 +265,7 @@ impl Exchange {
             Self::Binance => "BINANCE",
             Self::BinanceDelivery => "BINANCE_DELIVERY",
             Self::BinanceDex => "BINANCE",
+            Self::BinanceEuropeanOptions => "BINANCE",
             Self::BinanceFutures => "BINANCE",
             Self::BinanceJersey => "BINANCE",
             Self::BinanceOptions => "BINANCE",
@@ -205,6 +273,8 @@ impl Exchange {
             Self::Bitfinex => "BITFINEX",
             Self::BitfinexDerivatives => "BITFINEX",
             Self::Bitflyer => "BITFLYER",
+            Self::Bitget => "BITGET",
+            Self::BitgetFutures => "BITGET",
             Self::Bitmex => "BITMEX",
             Self::Bitnomial => "BITNOMIAL",
             Self::Bitstamp => "BITSTAMP",
@@ -213,6 +283,7 @@ impl Exchange {
             Self::BybitOptions => "BYBIT",
             Self::BybitSpot => "BYBIT",
             Self::Coinbase => "COINBASE",
+            Self::CoinbaseInternational => "COINBASE_INTX",
             Self::Coinflex => "COINFLEX",
             Self::CryptoCom => "CRYPTO_COM",
             Self::CryptoComDerivatives => "CRYPTO_COM",
@@ -220,6 +291,7 @@ impl Exchange {
             Self::Delta => "DELTA",
             Self::Deribit => "DERIBIT",
             Self::Dydx => "DYDX",
+            Self::DydxV4 => "DYDX_V4",
             Self::Ftx => "FTX",
             Self::FtxUs => "FTX",
             Self::GateIo => "GATE_IO",
@@ -231,13 +303,17 @@ impl Exchange {
             Self::HuobiDmLinearSwap => "HUOBI",
             Self::HuobiDmOptions => "HUOBI",
             Self::HuobiDmSwap => "HUOBI_DELIVERY",
+            Self::Hyperliquid => "HYPERLIQUID",
             Self::Kraken => "KRAKEN",
+            Self::KrakenFutures => "KRAKEN",
             Self::Kucoin => "KUCOIN",
+            Self::KucoinFutures => "KUCOIN",
             Self::Mango => "MANGO",
             Self::Okcoin => "OKCOIN",
             Self::Okex => "OKEX",
             Self::OkexFutures => "OKEX",
             Self::OkexOptions => "OKEX",
+            Self::OkexSpreads => "OKEX",
             Self::OkexSwap => "OKEX",
             Self::Phemex => "PHEMEX",
             Self::Poloniex => "POLONIEX",
