@@ -21,15 +21,18 @@ pub mod enums;
 pub mod http;
 pub mod machine;
 
-use std::str::FromStr;
-
-use nautilus_core::python::to_pyvalue_err;
+use nautilus_core::python::enums::parse_enum;
 use pyo3::prelude::*;
 use ustr::Ustr;
 
 use super::enums::{Exchange, InstrumentType};
 use crate::parse::normalize_symbol_str;
 
+/// Normalize a symbol string for Tardis, returning a suffix-modified symbol.
+///
+/// # Errors
+///
+/// Returns a `PyErr` if the `exchange` or `instrument_type` cannot be parsed.
 #[pyfunction(name = "tardis_normalize_symbol_str")]
 #[pyo3(signature = (symbol, exchange, instrument_type, is_inverse=None))]
 pub fn py_tardis_normalize_symbol_str(
@@ -39,13 +42,14 @@ pub fn py_tardis_normalize_symbol_str(
     is_inverse: Option<bool>,
 ) -> PyResult<String> {
     let symbol = Ustr::from(&symbol);
-    let exchange = Exchange::from_str(&exchange).map_err(to_pyvalue_err)?;
-    let instrument_type = InstrumentType::from_str(&instrument_type).map_err(to_pyvalue_err)?;
+    let exchange: Exchange = parse_enum(&exchange, stringify!(exchange))?;
+    let instrument_type: InstrumentType =
+        parse_enum(&instrument_type, stringify!(instrument_type))?;
 
     Ok(normalize_symbol_str(symbol, &exchange, &instrument_type, is_inverse).to_string())
 }
 
-/// Loaded as nautilus_pyo3.tardis
+/// Loaded as `nautilus_pyo3.tardis`.
 ///
 /// # Errors
 ///
