@@ -168,7 +168,7 @@ impl PortfolioAnalyzer {
         }
     }
 
-    /// Records a trade's `PnL`.
+    /// Records a trade's PnL.
     pub fn add_trade(&mut self, position_id: &PositionId, pnl: &Money) {
         let currency = pnl.currency;
         let entry = self.realized_pnls.entry(currency).or_default();
@@ -183,7 +183,7 @@ impl PortfolioAnalyzer {
             .or_insert(value);
     }
 
-    /// Retrieves realized `PnLs` for a specific currency.
+    /// Retrieves realized PnLs for a specific currency.
     #[must_use]
     pub fn realized_pnls(&self, currency: Option<&Currency>) -> Option<Vec<(PositionId, f64)>> {
         if self.realized_pnls.is_empty() {
@@ -193,7 +193,14 @@ impl PortfolioAnalyzer {
         self.realized_pnls.get(currency).cloned()
     }
 
-    /// Calculates total `PnL` including unrealized `PnL` if provided.
+    /// Calculates total PnL including unrealized PnL if provided.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if:
+    /// - No currency is specified in a multi-currency portfolio.
+    /// - The specified currency is not found in account balances.
+    /// - The unrealized PnL currency does not match the specified currency.
     pub fn total_pnl(
         &self,
         currency: Option<&Currency>,
@@ -207,10 +214,10 @@ impl PortfolioAnalyzer {
             .or_else(|| self.account_balances.keys().next())
             .ok_or("Currency not specified for multi-currency portfolio")?;
 
-        if let Some(unrealized_pnl) = unrealized_pnl {
-            if unrealized_pnl.currency != *currency {
-                return Err("Unrealized PnL currency does not match specified currency");
-            }
+        if let Some(unrealized_pnl) = unrealized_pnl
+            && unrealized_pnl.currency != *currency
+        {
+            return Err("Unrealized PnL currency does not match specified currency");
         }
 
         let account_balance = self
@@ -228,7 +235,14 @@ impl PortfolioAnalyzer {
         Ok((account_balance.as_f64() - account_balance_starting.as_f64()) + unrealized_pnl_f64)
     }
 
-    /// Calculates total `PnL` as a percentage of starting balance.
+    /// Calculates total PnL as a percentage of starting balance.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if:
+    /// - No currency is specified in a multi-currency portfolio.
+    /// - The specified currency is not found in account balances.
+    /// - The unrealized PnL currency does not match the specified currency.
     pub fn total_pnl_percentage(
         &self,
         currency: Option<&Currency>,
@@ -242,10 +256,10 @@ impl PortfolioAnalyzer {
             .or_else(|| self.account_balances.keys().next())
             .ok_or("Currency not specified for multi-currency portfolio")?;
 
-        if let Some(unrealized_pnl) = unrealized_pnl {
-            if unrealized_pnl.currency != *currency {
-                return Err("Unrealized PnL currency does not match specified currency");
-            }
+        if let Some(unrealized_pnl) = unrealized_pnl
+            && unrealized_pnl.currency != *currency
+        {
+            return Err("Unrealized PnL currency does not match specified currency");
         }
 
         let account_balance = self
@@ -272,6 +286,14 @@ impl PortfolioAnalyzer {
     }
 
     /// Gets all PnL-related performance statistics.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if PnL calculations fail, for example due to:
+    ///
+    /// - No currency specified for a multi-currency portfolio.
+    /// - Unrealized PnL currency not matching the specified currency.
+    /// - Specified currency not found in account balances.
     pub fn get_performance_stats_pnls(
         &self,
         currency: Option<&Currency>,
@@ -337,7 +359,11 @@ impl PortfolioAnalyzer {
         self.statistics.keys().map(String::len).max().unwrap_or(0)
     }
 
-    /// Gets formatted `PnL` statistics as strings.
+    /// Gets formatted PnL statistics as strings.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if PnL statistics calculation fails.
     pub fn get_stats_pnls_formatted(
         &self,
         currency: Option<&Currency>,
@@ -415,10 +441,10 @@ mod tests {
     }
 
     impl MockStatistic {
-        fn new(name: &str) -> Arc<dyn PortfolioStatistic<Item = f64> + Send + Sync> {
-            Arc::new(Self {
+        fn new(name: &str) -> Self {
+            Self {
                 name: name.to_string(),
-            })
+            }
         }
     }
 
@@ -580,12 +606,17 @@ mod tests {
         fn balance(&self, _: Option<Currency>) -> Option<&AccountBalance> {
             todo!()
         }
+
+        fn purge_account_events(&mut self, _: UnixNanos, _: u64) {
+            // MockAccount doesn't need purging
+        }
     }
 
     #[rstest]
     fn test_register_and_deregister_statistics() {
         let mut analyzer = PortfolioAnalyzer::new();
-        let stat = Arc::new(MockStatistic::new("test_stat"));
+        let stat: Arc<dyn PortfolioStatistic<Item = f64> + Send + Sync> =
+            Arc::new(MockStatistic::new("test_stat"));
 
         // Test registration
         analyzer.register_statistic(Arc::clone(&stat));
@@ -596,8 +627,10 @@ mod tests {
         assert!(analyzer.statistic("test_stat").is_none());
 
         // Test deregister all
-        let stat1 = Arc::new(MockStatistic::new("stat1"));
-        let stat2 = Arc::new(MockStatistic::new("stat2"));
+        let stat1: Arc<dyn PortfolioStatistic<Item = f64> + Send + Sync> =
+            Arc::new(MockStatistic::new("stat1"));
+        let stat2: Arc<dyn PortfolioStatistic<Item = f64> + Send + Sync> =
+            Arc::new(MockStatistic::new("stat2"));
         analyzer.register_statistic(Arc::clone(&stat1));
         analyzer.register_statistic(Arc::clone(&stat2));
         analyzer.deregister_statistics();
@@ -696,7 +729,8 @@ mod tests {
     fn test_performance_stats_calculation() {
         let mut analyzer = PortfolioAnalyzer::new();
         let currency = Currency::USD();
-        let stat = Arc::new(MockStatistic::new("test_stat"));
+        let stat: Arc<dyn PortfolioStatistic<Item = f64> + Send + Sync> =
+            Arc::new(MockStatistic::new("test_stat"));
         analyzer.register_statistic(Arc::clone(&stat));
 
         // Add some positions
@@ -739,7 +773,8 @@ mod tests {
     fn test_formatted_output() {
         let mut analyzer = PortfolioAnalyzer::new();
         let currency = Currency::USD();
-        let stat = Arc::new(MockStatistic::new("test_stat"));
+        let stat: Arc<dyn PortfolioStatistic<Item = f64> + Send + Sync> =
+            Arc::new(MockStatistic::new("test_stat"));
         analyzer.register_statistic(Arc::clone(&stat));
 
         let positions = vec![
