@@ -19,46 +19,224 @@
 
 use std::collections::HashMap;
 
-use nautilus_core::UnixNanos;
+use nautilus_common::{
+    cache::CacheConfig, enums::Environment, logging::logger::LoggerConfig,
+    msgbus::database::MessageBusConfig,
+};
+use nautilus_core::{UUID4, UnixNanos};
+use nautilus_data::engine::config::DataEngineConfig;
+use nautilus_execution::engine::config::ExecutionEngineConfig;
 use nautilus_model::{
     data::BarSpecification,
     enums::{AccountType, BookType, OmsType},
-    identifiers::{ClientId, InstrumentId},
+    identifiers::{ClientId, InstrumentId, TraderId},
     types::Currency,
 };
+use nautilus_persistence::config::StreamingConfig;
+use nautilus_portfolio::config::PortfolioConfig;
+use nautilus_risk::engine::config::RiskEngineConfig;
 use nautilus_system::config::NautilusKernelConfig;
 use ustr::Ustr;
 
 /// Configuration for ``BacktestEngine`` instances.
 #[derive(Debug, Clone)]
 pub struct BacktestEngineConfig {
-    /// The kernel configuration for the backtest engine.
-    pub kernel: NautilusKernelConfig,
+    /// The kernel environment context.
+    pub environment: Environment,
+    /// The trader ID for the node.
+    pub trader_id: TraderId,
+    /// If trading strategy state should be loaded from the database on start.
+    pub load_state: bool,
+    /// If trading strategy state should be saved to the database on stop.
+    pub save_state: bool,
+    /// The logging configuration for the kernel.
+    pub logging: LoggerConfig,
+    /// The unique instance identifier for the kernel.
+    pub instance_id: Option<UUID4>,
+    /// The timeout (seconds) for all clients to connect and initialize.
+    pub timeout_connection: u32,
+    /// The timeout (seconds) for execution state to reconcile.
+    pub timeout_reconciliation: u32,
+    /// The timeout (seconds) for portfolio to initialize margins and unrealized pnls.
+    pub timeout_portfolio: u32,
+    /// The timeout (seconds) for all engine clients to disconnect.
+    pub timeout_disconnection: u32,
+    /// The timeout (seconds) after stopping the node to await residual events before final shutdown.
+    pub timeout_post_stop: u32,
+    /// The timeout (seconds) to await pending tasks cancellation during shutdown.
+    pub timeout_shutdown: u32,
+    /// The cache configuration.
+    pub cache: Option<CacheConfig>,
+    /// The message bus configuration.
+    pub msgbus: Option<MessageBusConfig>,
+    /// The data engine configuration.
+    pub data_engine: Option<DataEngineConfig>,
+    /// The risk engine configuration.
+    pub risk_engine: Option<RiskEngineConfig>,
+    /// The execution engine configuration.
+    pub exec_engine: Option<ExecutionEngineConfig>,
+    /// The portfolio configuration.
+    pub portfolio: Option<PortfolioConfig>,
+    /// The configuration for streaming to feather files.
+    pub streaming: Option<StreamingConfig>,
     /// If logging should be bypassed.
-    bypass_logging: bool,
+    pub bypass_logging: bool,
     /// If post backtest performance analysis should be run.
-    run_analysis: bool,
+    pub run_analysis: bool,
 }
 
 impl BacktestEngineConfig {
     #[must_use]
+    #[allow(clippy::too_many_arguments)]
     pub fn new(
-        kernel: NautilusKernelConfig,
+        environment: Environment,
+        trader_id: TraderId,
+        load_state: Option<bool>,
+        save_state: Option<bool>,
         bypass_logging: Option<bool>,
         run_analysis: Option<bool>,
+        timeout_connection: Option<u32>,
+        timeout_reconciliation: Option<u32>,
+        timeout_portfolio: Option<u32>,
+        timeout_disconnection: Option<u32>,
+        timeout_post_stop: Option<u32>,
+        timeout_shutdown: Option<u32>,
+        logging: Option<LoggerConfig>,
+        instance_id: Option<UUID4>,
+        cache: Option<CacheConfig>,
+        msgbus: Option<MessageBusConfig>,
+        data_engine: Option<DataEngineConfig>,
+        risk_engine: Option<RiskEngineConfig>,
+        exec_engine: Option<ExecutionEngineConfig>,
+        portfolio: Option<PortfolioConfig>,
+        streaming: Option<StreamingConfig>,
     ) -> Self {
         Self {
-            kernel,
+            environment,
+            trader_id,
+            load_state: load_state.unwrap_or(false),
+            save_state: save_state.unwrap_or(false),
+            logging: logging.unwrap_or_default(),
+            instance_id,
+            timeout_connection: timeout_connection.unwrap_or(60),
+            timeout_reconciliation: timeout_reconciliation.unwrap_or(30),
+            timeout_portfolio: timeout_portfolio.unwrap_or(10),
+            timeout_disconnection: timeout_disconnection.unwrap_or(10),
+            timeout_post_stop: timeout_post_stop.unwrap_or(10),
+            timeout_shutdown: timeout_shutdown.unwrap_or(5),
+            cache,
+            msgbus,
+            data_engine,
+            risk_engine,
+            exec_engine,
+            portfolio,
+            streaming,
             bypass_logging: bypass_logging.unwrap_or(false),
             run_analysis: run_analysis.unwrap_or(true),
         }
     }
 }
 
+impl NautilusKernelConfig for BacktestEngineConfig {
+    fn environment(&self) -> Environment {
+        self.environment
+    }
+
+    fn trader_id(&self) -> TraderId {
+        self.trader_id
+    }
+
+    fn load_state(&self) -> bool {
+        self.load_state
+    }
+
+    fn save_state(&self) -> bool {
+        self.save_state
+    }
+
+    fn logging(&self) -> LoggerConfig {
+        self.logging.clone()
+    }
+
+    fn instance_id(&self) -> Option<UUID4> {
+        self.instance_id
+    }
+
+    fn timeout_connection(&self) -> u32 {
+        self.timeout_connection
+    }
+
+    fn timeout_reconciliation(&self) -> u32 {
+        self.timeout_reconciliation
+    }
+
+    fn timeout_portfolio(&self) -> u32 {
+        self.timeout_portfolio
+    }
+
+    fn timeout_disconnection(&self) -> u32 {
+        self.timeout_disconnection
+    }
+
+    fn timeout_post_stop(&self) -> u32 {
+        self.timeout_post_stop
+    }
+
+    fn timeout_shutdown(&self) -> u32 {
+        self.timeout_shutdown
+    }
+
+    fn cache(&self) -> Option<CacheConfig> {
+        self.cache.clone()
+    }
+
+    fn msgbus(&self) -> Option<MessageBusConfig> {
+        self.msgbus.clone()
+    }
+
+    fn data_engine(&self) -> Option<DataEngineConfig> {
+        self.data_engine.clone()
+    }
+
+    fn risk_engine(&self) -> Option<RiskEngineConfig> {
+        self.risk_engine.clone()
+    }
+
+    fn exec_engine(&self) -> Option<ExecutionEngineConfig> {
+        self.exec_engine.clone()
+    }
+
+    fn portfolio(&self) -> Option<PortfolioConfig> {
+        self.portfolio.clone()
+    }
+
+    fn streaming(&self) -> Option<StreamingConfig> {
+        self.streaming.clone()
+    }
+}
+
 impl Default for BacktestEngineConfig {
     fn default() -> Self {
         Self {
-            kernel: NautilusKernelConfig::default(),
+            environment: Environment::Backtest,
+            trader_id: TraderId::default(),
+            load_state: false,
+            save_state: false,
+            logging: LoggerConfig::default(),
+            instance_id: None,
+            timeout_connection: 60,
+            timeout_reconciliation: 30,
+            timeout_portfolio: 10,
+            timeout_disconnection: 10,
+            timeout_post_stop: 10,
+            timeout_shutdown: 5,
+            cache: None,
+            msgbus: None,
+            data_engine: None,
+            risk_engine: None,
+            exec_engine: None,
+            portfolio: None,
+            streaming: None,
             bypass_logging: false,
             run_analysis: true,
         }
