@@ -22,10 +22,11 @@
 use std::{
     cell::RefCell,
     collections::{BinaryHeap, HashMap, VecDeque},
+    fmt::Debug,
     rc::Rc,
 };
 
-use nautilus_common::{cache::Cache, clock::Clock};
+use nautilus_common::{cache::Cache, clock::Clock, messages::execution::TradingCommand};
 use nautilus_core::{
     UnixNanos,
     correctness::{FAILED, check_equal},
@@ -33,7 +34,6 @@ use nautilus_core::{
 use nautilus_execution::{
     client::ExecutionClient,
     matching_engine::{config::OrderMatchingEngineConfig, engine::OrderMatchingEngine},
-    messages::TradingCommand,
     models::{fee::FeeModelAny, fill::FillModel, latency::LatencyModel},
 };
 use nautilus_model::{
@@ -89,6 +89,21 @@ impl PartialOrd for InflightCommand {
     }
 }
 
+/// Simulated exchange venue for realistic trading execution during backtesting.
+///
+/// The `SimulatedExchange` provides a comprehensive simulation of a trading venue,
+/// including order matching engines, account management, and realistic execution
+/// models. It maintains order books, processes market data, and executes trades
+/// with configurable latency and fill models to accurately simulate real market
+/// conditions during backtesting.
+///
+/// Key features:
+/// - Multi-instrument order matching with realistic execution
+/// - Configurable fee, fill, and latency models
+/// - Support for various order types and execution options
+/// - Account balance and position management
+/// - Market data processing and order book maintenance
+/// - Simulation modules for custom venue behaviors
 pub struct SimulatedExchange {
     pub id: Venue,
     pub oms_type: OmsType,
@@ -121,8 +136,23 @@ pub struct SimulatedExchange {
     use_message_queue: bool,
 }
 
+impl Debug for SimulatedExchange {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct(stringify!(SimulatedExchange))
+            .field("id", &self.id)
+            .field("account_type", &self.account_type)
+            .finish()
+    }
+}
+
 impl SimulatedExchange {
     /// Creates a new [`SimulatedExchange`] instance.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if:
+    /// - `starting_balances` is empty.
+    /// - `base_currency` is `Some` but `starting_balances` contains multiple currencies.
     #[allow(clippy::too_many_arguments)]
     pub fn new(
         venue: Venue,
@@ -213,10 +243,19 @@ impl SimulatedExchange {
         self.generate_fresh_account_state();
     }
 
+    /// Adds an instrument to the simulated exchange and initializes its matching engine.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the exchange account type is `Cash` and the instrument is a `CryptoPerpetual` or `CryptoFuture`.
+    ///
+    /// # Panics
+    ///
+    /// Panics if the instrument cannot be added to the exchange.
     pub fn add_instrument(&mut self, instrument: InstrumentAny) -> anyhow::Result<()> {
         check_equal(
-            instrument.id().venue,
-            self.id,
+            &instrument.id().venue,
+            &self.id,
             "Venue of instrument id",
             "Venue of simulated exchange",
         )
@@ -349,6 +388,9 @@ impl SimulatedExchange {
             })
     }
 
+    /// # Panics
+    ///
+    /// Panics if retrieving the account from the execution client fails.
     #[must_use]
     pub fn get_account(&self) -> Option<AccountAny> {
         self.exec_client
@@ -356,6 +398,9 @@ impl SimulatedExchange {
             .map(|client| client.get_account().unwrap())
     }
 
+    /// # Panics
+    ///
+    /// Panics if generating account state fails during adjustment.
     pub fn adjust_account(&mut self, adjustment: Money) {
         if self.frozen_account {
             // Nothing to adjust
@@ -413,6 +458,9 @@ impl SimulatedExchange {
         }
     }
 
+    /// # Panics
+    ///
+    /// Panics if the command is invalid when generating inflight command.
     pub fn generate_inflight_command(&mut self, command: &TradingCommand) -> (UnixNanos, u32) {
         if let Some(latency_model) = &self.latency_model {
             let ts = match command {
@@ -442,6 +490,9 @@ impl SimulatedExchange {
         }
     }
 
+    /// # Panics
+    ///
+    /// Panics if adding a missing instrument during delta processing fails.
     pub fn process_order_book_delta(&mut self, delta: OrderBookDelta) {
         for module in &self.modules {
             module.pre_process(Data::Delta(delta));
@@ -470,6 +521,9 @@ impl SimulatedExchange {
         }
     }
 
+    /// # Panics
+    ///
+    /// Panics if adding a missing instrument during deltas processing fails.
     pub fn process_order_book_deltas(&mut self, deltas: OrderBookDeltas) {
         for module in &self.modules {
             module.pre_process(Data::Deltas(OrderBookDeltas_API::new(deltas.clone())));
@@ -498,6 +552,9 @@ impl SimulatedExchange {
         }
     }
 
+    /// # Panics
+    ///
+    /// Panics if adding a missing instrument during quote tick processing fails.
     pub fn process_quote_tick(&mut self, quote: &QuoteTick) {
         for module in &self.modules {
             module.pre_process(Data::Quote(quote.to_owned()));
@@ -526,6 +583,9 @@ impl SimulatedExchange {
         }
     }
 
+    /// # Panics
+    ///
+    /// Panics if adding a missing instrument during trade tick processing fails.
     pub fn process_trade_tick(&mut self, trade: &TradeTick) {
         for module in &self.modules {
             module.pre_process(Data::Trade(trade.to_owned()));
@@ -554,6 +614,9 @@ impl SimulatedExchange {
         }
     }
 
+    /// # Panics
+    ///
+    /// Panics if adding a missing instrument during bar processing fails.
     pub fn process_bar(&mut self, bar: Bar) {
         for module in &self.modules {
             module.pre_process(Data::Bar(bar));
@@ -582,6 +645,9 @@ impl SimulatedExchange {
         }
     }
 
+    /// # Panics
+    ///
+    /// Panics if adding a missing instrument during instrument status processing fails.
     pub fn process_instrument_status(&mut self, status: InstrumentStatus) {
         // TODO add module preprocessing
 
@@ -608,6 +674,9 @@ impl SimulatedExchange {
         }
     }
 
+    /// # Panics
+    ///
+    /// Panics if popping an inflight command fails during processing.
     pub fn process(&mut self, ts_now: UnixNanos) {
         // TODO implement correct clock fixed time setting self.clock.set_time(ts_now);
 
@@ -643,6 +712,9 @@ impl SimulatedExchange {
         log::info!("Resetting exchange state");
     }
 
+    /// # Panics
+    ///
+    /// Panics if execution client is uninitialized when processing trading command.
     pub fn process_trading_command(&mut self, command: TradingCommand) {
         if let Some(matching_engine) = self.matching_engines.get_mut(&command.instrument_id()) {
             let account_id = if let Some(exec_client) = &self.exec_client {
@@ -678,6 +750,9 @@ impl SimulatedExchange {
         }
     }
 
+    /// # Panics
+    ///
+    /// Panics if generating fresh account state fails.
     pub fn generate_fresh_account_state(&self) {
         let balances: Vec<AccountBalance> = self
             .starting_balances
@@ -718,19 +793,17 @@ mod tests {
     use nautilus_common::{
         cache::Cache,
         clock::TestClock,
+        messages::execution::{SubmitOrder, TradingCommand},
         msgbus::{
             self,
             stubs::{get_message_saving_handler, get_saved_messages},
         },
     };
     use nautilus_core::{AtomicTime, UUID4, UnixNanos};
-    use nautilus_execution::{
-        messages::{SubmitOrder, TradingCommand},
-        models::{
-            fee::{FeeModelAny, MakerTakerFeeModel},
-            fill::FillModel,
-            latency::LatencyModel,
-        },
+    use nautilus_execution::models::{
+        fee::{FeeModelAny, MakerTakerFeeModel},
+        fill::FillModel,
+        latency::LatencyModel,
     };
     use nautilus_model::{
         accounts::{AccountAny, MarginAccount},
@@ -752,7 +825,6 @@ mod tests {
         types::{AccountBalance, Currency, Money, Price, Quantity},
     };
     use rstest::rstest;
-    use ustr::Ustr;
 
     use crate::{
         exchange::{InflightCommand, SimulatedExchange},
@@ -804,7 +876,7 @@ mod tests {
             TraderId::default(),
             AccountId::default(),
             exchange.clone(),
-            cache.clone(),
+            cache,
             Rc::new(RefCell::new(clock)),
             None,
             None,
@@ -1202,7 +1274,7 @@ mod tests {
         let account_type = AccountType::Margin;
         let mut cache = Cache::default();
         let handler = get_message_saving_handler::<AccountState>(None);
-        msgbus::register(Ustr::from("Portfolio.update_account"), handler.clone());
+        msgbus::register("Portfolio.update_account".into(), handler.clone());
         let margin_account = MarginAccount::new(
             AccountState::new(
                 AccountId::from("SIM-001"),
@@ -1354,7 +1426,7 @@ mod tests {
         assert_eq!(exchange.borrow().inflight_queue.len(), 2);
         // First inflight command should have timestamp at 100 and 200 insert latency
         assert_eq!(
-            exchange.borrow().inflight_queue.iter().nth(0).unwrap().ts,
+            exchange.borrow().inflight_queue.iter().next().unwrap().ts,
             UnixNanos::from(300)
         );
         // Second inflight command should have timestamp at 150 and 200 insert latency
@@ -1368,7 +1440,7 @@ mod tests {
         assert_eq!(exchange.borrow().message_queue.len(), 0);
         assert_eq!(exchange.borrow().inflight_queue.len(), 1);
         assert_eq!(
-            exchange.borrow().inflight_queue.iter().nth(0).unwrap().ts,
+            exchange.borrow().inflight_queue.iter().next().unwrap().ts,
             UnixNanos::from(350)
         );
     }
