@@ -13,11 +13,29 @@
 //  limitations under the License.
 // -------------------------------------------------------------------------------------------------
 
+//! Backtest engine for [NautilusTrader](http://nautilustrader.io).
+//!
+//! The *backtest* crate provides a comprehensive event-driven backtesting framework that allows
+//! quantitative traders to test and validate trading strategies on historical data with high
+//! fidelity market simulation. The system replicates real market conditions including:
+//!
+//! - Event-driven backtesting engine with simulated exchanges.
+//! - Market data replay with configurable latency and fill models.
+//! - Order matching engines with realistic execution simulation.
+//! - Multi-venue and multi-asset backtesting capabilities.
+//! - Comprehensive configuration and state management.
+//! - Integration with live trading systems for seamless deployment.
+//!
+//! # Platform
+//!
 //! [NautilusTrader](http://nautilustrader.io) is an open-source, high-performance, production-grade
 //! algorithmic trading platform, providing quantitative traders with the ability to backtest
 //! portfolios of automated trading strategies on historical data with an event-driven engine,
 //! and also deploy those same strategies live, with no code changes.
 //!
+//! NautilusTrader's design, architecture, and implementation philosophy prioritizes software correctness and safety at the
+//! highest level, with the aim of supporting mission-critical, trading system backtesting and live deployment workloads.
+//!
 //! # Feature flags
 //!
 //! This crate provides feature flags to control source code inclusion during compilation,
@@ -29,12 +47,12 @@
 //! - `python`: Enables Python bindings from [PyO3](https://pyo3.rs).
 
 #![warn(rustc::all)]
+#![deny(unsafe_code)]
 #![deny(nonstandard_style)]
+#![deny(missing_debug_implementations)]
+#![deny(clippy::missing_errors_doc)]
+#![deny(clippy::missing_panics_doc)]
 #![deny(rustdoc::broken_intra_doc_links)]
-// #![deny(clippy::missing_errors_doc)]
-
-// Uncomment once we've added trivial `Debug` impls everywhere
-// #![warn(missing_debug_implementations)]
 
 pub mod accumulator;
 pub mod config;
@@ -43,7 +61,6 @@ pub mod engine;
 pub mod exchange;
 pub mod execution_client;
 pub mod modules;
-pub mod runner;
 
 #[cfg(feature = "ffi")]
 pub mod ffi;
