@@ -20,9 +20,9 @@ use nautilus_core::UnixNanos;
 use nautilus_model::{
     accounts::AccountAny,
     data::{Bar, MarkPriceUpdate, QuoteTick, TradeTick},
-    enums::{BookType, OmsType, OrderSide, OrderStatus, OrderType, PriceType},
+    enums::{BookType, OmsType, OrderSide, OrderStatus, OrderType, PositionSide, PriceType},
     events::{OrderAccepted, OrderEventAny, OrderRejected, OrderSubmitted},
-    identifiers::{AccountId, ClientOrderId, InstrumentId, PositionId, Venue},
+    identifiers::{AccountId, ClientOrderId, InstrumentId, PositionId, Symbol, Venue},
     instruments::{CurrencyPair, Instrument, InstrumentAny, SyntheticInstrument, stubs::*},
     orderbook::OrderBook,
     orders::{
@@ -267,6 +267,174 @@ fn test_order_when_accepted(mut cache: Cache, audusd_sim: CurrencyPair) {
     );
 }
 
+#[rstest]
+fn test_client_order_ids_filtering(mut cache: Cache) {
+    // Build a small deterministic universe: 2 venues × 3 instruments × 2 orders
+    let venue_a = Venue::from("VENUE-A");
+    let _venue_b = Venue::from("VENUE-B");
+
+    let mut generator = TestOrdersGenerator::new(OrderType::Limit);
+    generator.add_venue_and_total_instruments(venue_a, 3);
+    generator.add_venue_and_total_instruments(_venue_b, 3);
+    generator.set_orders_per_instrument(2);
+
+    let orders = generator.build();
+
+    let _instrument_a0 = InstrumentId::from("SYMBOL-0.VENUE-A");
+
+    // Sanity-check the generated volume: 2 × 3 × 2 = 12
+    assert_eq!(orders.len(), 12);
+
+    // Load into cache so indices are built on the fly
+    for order in &orders {
+        cache.add_order(order.clone(), None, None, false).unwrap();
+    }
+
+    // No filters – expect all orders
+    assert_eq!(cache.client_order_ids(None, None, None).len(), orders.len());
+
+    // Venue only
+    let expected_venue_a = orders
+        .iter()
+        .filter(|o| o.instrument_id().venue == venue_a)
+        .count();
+    assert_eq!(
+        cache.client_order_ids(Some(&venue_a), None, None).len(),
+        expected_venue_a
+    );
+
+    // Venue + instrument
+    let instrument_a0 = InstrumentId::from("SYMBOL-0.VENUE-A");
+    assert_eq!(
+        cache
+            .client_order_ids(Some(&venue_a), Some(&instrument_a0), None)
+            .len(),
+        orders
+            .iter()
+            .filter(|o| o.instrument_id() == instrument_a0)
+            .count()
+    );
+}
+
+#[rstest]
+fn test_position_ids_filtering(mut cache: Cache) {
+    let venue_a = Venue::from("VENUE-A");
+    let _venue_b = Venue::from("VENUE-B");
+
+    fn make_pair(id_str: &str) -> CurrencyPair {
+        CurrencyPair::new(
+            InstrumentId::from(id_str),
+            Symbol::from(id_str),
+            Currency::USD(),
+            Currency::EUR(),
+            2,
+            4,
+            Price::from("0.01"),
+            Quantity::from("0.0001"),
+            None,
+            None,
+            None,
+            None,
+            None,
+            None,
+            None,
+            None,
+            None,
+            None,
+            None,
+            UnixNanos::default(),
+            UnixNanos::default(),
+        )
+    }
+
+    // Build two open positions and one closed position across venues
+    let instr_a0 = make_pair("PAIR-0.VENUE-A");
+    let instr_b0 = make_pair("PAIR-0.VENUE-B");
+
+    let base_order = OrderTestBuilder::new(OrderType::Market)
+        .instrument_id(instr_a0.id)
+        .side(OrderSide::Buy)
+        .quantity(Quantity::from("1"))
+        .build();
+
+    let fill_a_event = TestOrderEventStubs::filled(
+        &base_order,
+        &InstrumentAny::CurrencyPair(instr_a0),
+        None,
+        Some(PositionId::new("POS-A")),
+        None,
+        None,
+        None,
+        None,
+        None,
+        None,
+    );
+    let fill_a = match fill_a_event {
+        OrderEventAny::Filled(f) => f,
+        _ => unreachable!(),
+    };
+    let pos_a = Position::new(&InstrumentAny::CurrencyPair(instr_a0), fill_a);
+
+    // Second open position on venue B
+    let order_b = OrderTestBuilder::new(OrderType::Market)
+        .instrument_id(instr_b0.id)
+        .side(OrderSide::Buy)
+        .quantity(Quantity::from("1"))
+        .build();
+
+    let fill_b_event = TestOrderEventStubs::filled(
+        &order_b,
+        &InstrumentAny::CurrencyPair(instr_b0),
+        None,
+        Some(PositionId::new("POS-B")),
+        None,
+        None,
+        None,
+        None,
+        None,
+        None,
+    );
+    let fill_b = match fill_b_event {
+        OrderEventAny::Filled(f) => f,
+        _ => unreachable!(),
+    };
+    let pos_b = Position::new(&InstrumentAny::CurrencyPair(instr_b0), fill_b);
+
+    // Closed position on venue A (side Flat + ts_closed)
+    let mut pos_closed = pos_a.clone();
+    pos_closed.id = PositionId::new("POS-C");
+    pos_closed.side = PositionSide::Flat;
+    pos_closed.ts_closed = Some(UnixNanos::from(1));
+
+    // Insert into cache
+    cache.add_position(pos_a.clone(), OmsType::Netting).unwrap();
+    cache.add_position(pos_b.clone(), OmsType::Netting).unwrap();
+    cache
+        .add_position(pos_closed.clone(), OmsType::Netting)
+        .unwrap();
+
+    // Assertions
+    assert_eq!(cache.position_ids(None, None, None).len(), 3);
+
+    // Venue filter
+    assert_eq!(cache.position_ids(Some(&venue_a), None, None).len(), 2);
+
+    // Venue + instrument filter
+    assert_eq!(
+        cache
+            .position_ids(Some(&venue_a), Some(&instr_a0.id), None)
+            .len(),
+        2 // open + closed on venue A instrument
+    );
+
+    // Open / closed separation
+    assert!(
+        cache
+            .position_open_ids(None, None, None)
+            .contains(&pos_a.id)
+    );
+}
+
 #[ignore = "Revisit on next pass"]
 #[rstest]
 fn test_order_when_filled(mut cache: Cache, audusd_sim: CurrencyPair) {
@@ -832,7 +1000,7 @@ fn test_purge_order() {
     let audusd_sim = audusd_sim();
     let audusd_sim = InstrumentAny::CurrencyPair(audusd_sim);
 
-    // Add an order to cache
+    // Create an order and fill to generate a position
     let order = OrderTestBuilder::new(OrderType::Limit)
         .instrument_id(audusd_sim.id())
         .side(OrderSide::Buy)
@@ -841,8 +1009,26 @@ fn test_purge_order() {
         .build();
 
     let client_order_id = order.client_order_id();
+
+    let filled = TestOrderEventStubs::filled(
+        &order,
+        &audusd_sim,
+        None,
+        Some(PositionId::new("P-123456")),
+        Some(Price::from("1.00001")),
+        None,
+        None,
+        None,
+        None,
+        None,
+    );
+
     cache.add_order(order, None, None, false).unwrap();
 
+    let position = Position::new(&audusd_sim, filled.into());
+    let position_id = position.id;
+    cache.add_position(position, OmsType::Netting).unwrap();
+
     // Verify the order exists
     assert!(cache.order_exists(&client_order_id));
     assert_eq!(cache.orders_total_count(None, None, None, None), 1);
@@ -853,6 +1039,8 @@ fn test_purge_order() {
     // Verify the order is gone
     assert!(!cache.order_exists(&client_order_id));
     assert_eq!(cache.orders_total_count(None, None, None, None), 0);
+    // Verify associated order events were purged from the position
+    assert_eq!(cache.position(&position_id).unwrap().event_count(), 0);
 }
 
 #[rstest]
