@@ -27,6 +27,7 @@ use nautilus_core::{
         string::{cstr_as_str, str_to_cstr},
     },
 };
+#[cfg(feature = "python")]
 use pyo3::{ffi, prelude::*};
 
 use super::timer::TimeEventHandler;
@@ -45,6 +46,7 @@ use crate::{
 /// having to manually access the underlying `TestClock` instance.
 #[repr(C)]
 #[allow(non_camel_case_types)]
+#[derive(Debug)]
 pub struct TestClock_API(Box<TestClock>);
 
 impl Deref for TestClock_API {
@@ -71,9 +73,16 @@ pub extern "C" fn test_clock_drop(clock: TestClock_API) {
     drop(clock); // Memory freed here
 }
 
+/// Registers the default callback handler for TestClock.
+///
 /// # Safety
 ///
-/// - Assumes `callback_ptr` is a valid `PyCallable` pointer.
+/// Assumes `callback_ptr` is a valid `PyCallable` pointer.
+///
+/// # Panics
+///
+/// Panics if the `callback_ptr` is null or represents the Python `None` object.
+#[cfg(feature = "python")]
 #[unsafe(no_mangle)]
 pub unsafe extern "C" fn test_clock_register_default_handler(
     clock: &mut TestClock_API,
@@ -127,8 +136,14 @@ pub extern "C" fn test_clock_timer_count(clock: &mut TestClock_API) -> usize {
 
 /// # Safety
 ///
-/// - Assumes `name_ptr` is a valid C string pointer.
-/// - Assumes `callback_ptr` is a valid `PyCallable` pointer.
+/// This function assumes:
+/// - `name_ptr` is a valid C string pointer.
+/// - `callback_ptr` is a valid `PyCallable` pointer.
+///
+/// # Panics
+///
+/// Panics if `callback_ptr` is null or if setting the timer fails.
+#[cfg(feature = "python")]
 #[unsafe(no_mangle)]
 pub unsafe extern "C" fn test_clock_set_time_alert(
     clock: &mut TestClock_API,
@@ -155,8 +170,14 @@ pub unsafe extern "C" fn test_clock_set_time_alert(
 
 /// # Safety
 ///
-/// - Assumes `name_ptr` is a valid C string pointer.
-/// - Assumes `callback_ptr` is a valid `PyCallable` pointer.
+/// This function assumes:
+/// - `name_ptr` is a valid C string pointer.
+/// - `callback_ptr` is a valid `PyCallable` pointer.
+///
+/// # Panics
+///
+/// Panics if `callback_ptr` is null or represents the Python `None` object.
+#[cfg(feature = "python")]
 #[unsafe(no_mangle)]
 pub unsafe extern "C" fn test_clock_set_timer(
     clock: &mut TestClock_API,
@@ -166,14 +187,13 @@ pub unsafe extern "C" fn test_clock_set_timer(
     stop_time_ns: UnixNanos,
     callback_ptr: *mut ffi::PyObject,
     allow_past: u8,
+    fire_immediately: u8,
 ) {
     assert!(!callback_ptr.is_null());
 
     let name = unsafe { cstr_as_str(name_ptr) };
-    let stop_time_ns = match stop_time_ns.into() {
-        0 => None,
-        _ => Some(stop_time_ns),
-    };
+    let start_time_ns = (start_time_ns != 0).then_some(start_time_ns);
+    let stop_time_ns = (stop_time_ns != 0).then_some(stop_time_ns);
     let callback = if callback_ptr == unsafe { ffi::Py_None() } {
         None
     } else {
@@ -190,13 +210,14 @@ pub unsafe extern "C" fn test_clock_set_timer(
             stop_time_ns,
             callback,
             Some(allow_past != 0),
+            Some(fire_immediately != 0),
         )
         .expect(FAILED);
 }
 
 /// # Safety
 ///
-/// - Assumes `set_time` is a correct `uint8_t` of either 0 or 1.
+/// Assumes `set_time` is a correct `uint8_t` of either 0 or 1.
 #[unsafe(no_mangle)]
 pub unsafe extern "C" fn test_clock_advance_time(
     clock: &mut TestClock_API,
@@ -225,19 +246,19 @@ pub extern "C" fn vec_time_event_handlers_drop(v: CVec) {
 
 /// # Safety
 ///
-/// - Assumes `name_ptr` is a valid C string pointer.
+/// Assumes `name_ptr` is a valid C string pointer.
 #[unsafe(no_mangle)]
 pub unsafe extern "C" fn test_clock_next_time(
     clock: &mut TestClock_API,
     name_ptr: *const c_char,
 ) -> UnixNanos {
     let name = unsafe { cstr_as_str(name_ptr) };
-    clock.next_time_ns(name)
+    clock.next_time_ns(name).unwrap_or_default()
 }
 
 /// # Safety
 ///
-/// - Assumes `name_ptr` is a valid C string pointer.
+/// Assumes `name_ptr` is a valid C string pointer.
 #[unsafe(no_mangle)]
 pub unsafe extern "C" fn test_clock_cancel_timer(
     clock: &mut TestClock_API,
@@ -263,6 +284,7 @@ pub extern "C" fn test_clock_cancel_timers(clock: &mut TestClock_API) {
 /// both mutable and immutable access.
 #[repr(C)]
 #[allow(non_camel_case_types)]
+#[derive(Debug)]
 pub struct LiveClock_API(Box<LiveClock>);
 
 impl Deref for LiveClock_API {
@@ -281,7 +303,8 @@ impl DerefMut for LiveClock_API {
 
 #[unsafe(no_mangle)]
 pub extern "C" fn live_clock_new() -> LiveClock_API {
-    LiveClock_API(Box::default())
+    // Initialize a live clock without a time event sender
+    LiveClock_API(Box::new(LiveClock::new(None)))
 }
 
 #[unsafe(no_mangle)]
@@ -291,7 +314,12 @@ pub extern "C" fn live_clock_drop(clock: LiveClock_API) {
 
 /// # Safety
 ///
-/// - Assumes `callback_ptr` is a valid `PyCallable` pointer.
+/// Assumes `callback_ptr` is a valid `PyCallable` pointer.
+///
+/// # Panics
+///
+/// Panics if `callback_ptr` is null or represents the Python `None` object.
+#[cfg(feature = "python")]
 #[unsafe(no_mangle)]
 pub unsafe extern "C" fn live_clock_register_default_handler(
     clock: &mut LiveClock_API,
@@ -340,14 +368,16 @@ pub extern "C" fn live_clock_timer_count(clock: &mut LiveClock_API) -> usize {
 
 /// # Safety
 ///
-/// - Assumes `name_ptr` is a valid C string pointer.
-/// - Assumes `callback_ptr` is a valid `PyCallable` pointer.
+/// This function assumes:
+/// - `name_ptr` is a valid C string pointer.
+/// - `callback_ptr` is a valid `PyCallable` pointer.
 ///
 /// # Panics
 ///
-/// This function panics:
-/// - If `name` is not a valid string.
-/// - If `callback_ptr` is NULL and no default callback has been assigned on the clock.
+/// This function panics if:
+/// - `name` is not a valid string.
+/// - `callback_ptr` is NULL and no default callback has been assigned on the clock.
+#[cfg(feature = "python")]
 #[unsafe(no_mangle)]
 pub unsafe extern "C" fn live_clock_set_time_alert(
     clock: &mut LiveClock_API,
@@ -374,14 +404,16 @@ pub unsafe extern "C" fn live_clock_set_time_alert(
 
 /// # Safety
 ///
-/// - Assumes `name_ptr` is a valid C string pointer.
-/// - Assumes `callback_ptr` is a valid `PyCallable` pointer.
+/// This function assumes:
+/// - `name_ptr` is a valid C string pointer.
+/// - `callback_ptr` is a valid `PyCallable` pointer.
 ///
 /// # Panics
 ///
-/// This function panics:
-/// - If `name` is not a valid string.
-/// - If `callback_ptr` is NULL and no default callback has been assigned on the clock.
+/// This function panics if:
+/// - `name` is not a valid string.
+/// - `callback_ptr` is NULL and no default callback has been assigned on the clock.
+#[cfg(feature = "python")]
 #[unsafe(no_mangle)]
 pub unsafe extern "C" fn live_clock_set_timer(
     clock: &mut LiveClock_API,
@@ -391,15 +423,13 @@ pub unsafe extern "C" fn live_clock_set_timer(
     stop_time_ns: UnixNanos,
     callback_ptr: *mut ffi::PyObject,
     allow_past: u8,
+    fire_immediately: u8,
 ) {
     assert!(!callback_ptr.is_null());
 
     let name = unsafe { cstr_as_str(name_ptr) };
-    let stop_time_ns = match stop_time_ns.into() {
-        0 => None,
-        _ => Some(stop_time_ns),
-    };
-
+    let start_time_ns = (start_time_ns != 0).then_some(start_time_ns);
+    let stop_time_ns = (stop_time_ns != 0).then_some(stop_time_ns);
     let callback = if callback_ptr == unsafe { ffi::Py_None() } {
         None
     } else {
@@ -416,25 +446,26 @@ pub unsafe extern "C" fn live_clock_set_timer(
             stop_time_ns,
             callback,
             Some(allow_past != 0),
+            Some(fire_immediately != 0),
         )
         .expect(FAILED);
 }
 
 /// # Safety
 ///
-/// - Assumes `name_ptr` is a valid C string pointer.
+/// Assumes `name_ptr` is a valid C string pointer.
 #[unsafe(no_mangle)]
 pub unsafe extern "C" fn live_clock_next_time(
     clock: &mut LiveClock_API,
     name_ptr: *const c_char,
 ) -> UnixNanos {
     let name = unsafe { cstr_as_str(name_ptr) };
-    clock.next_time_ns(name)
+    clock.next_time_ns(name).unwrap_or_default()
 }
 
 /// # Safety
 ///
-/// - Assumes `name_ptr` is a valid C string pointer.
+/// Assumes `name_ptr` is a valid C string pointer.
 #[unsafe(no_mangle)]
 pub unsafe extern "C" fn live_clock_cancel_timer(
     clock: &mut LiveClock_API,
