@@ -30,9 +30,8 @@ use nautilus_model::identifiers::TraderId;
 use crate::{
     enums::{LogColor, LogLevel},
     logging::{
-        self, headers,
+        headers,
         logger::{self, LogGuard, LoggerConfig},
-        logging_set_bypass, map_log_level_to_filter, parse_component_levels,
         writer::FileWriterConfig,
     },
 };
@@ -47,6 +46,7 @@ use crate::{
 /// having to manually access the underlying `LogGuard` instance.
 #[repr(C)]
 #[allow(non_camel_case_types)]
+#[derive(Debug)]
 pub struct LogGuard_API(Box<LogGuard>);
 
 impl Deref for LogGuard_API {
@@ -72,13 +72,18 @@ impl DerefMut for LogGuard_API {
 ///
 /// # Safety
 ///
-/// Should only be called once during an applications run, ideally at the
+/// Should only be called once during an application's run, ideally at the
 /// beginning of the run.
 ///
-/// - Assume `directory_ptr` is either NULL or a valid C string pointer.
-/// - Assume `file_name_ptr` is either NULL or a valid C string pointer.
-/// - Assume `file_format_ptr` is either NULL or a valid C string pointer.
-/// - Assume `component_level_ptr` is either NULL or a valid C string pointer.
+/// This function assumes:
+/// - `directory_ptr` is either NULL or a valid C string pointer.
+/// - `file_name_ptr` is either NULL or a valid C string pointer.
+/// - `file_format_ptr` is either NULL or a valid C string pointer.
+/// - `component_level_ptr` is either NULL or a valid C string pointer.
+///
+/// # Panics
+///
+/// Panics if initializing the Rust logger fails.
 #[unsafe(no_mangle)]
 pub unsafe extern "C" fn logging_init(
     trader_id: TraderId,
@@ -95,11 +100,11 @@ pub unsafe extern "C" fn logging_init(
     max_file_size: u64,
     max_backup_count: u32,
 ) -> LogGuard_API {
-    let level_stdout = map_log_level_to_filter(level_stdout);
-    let level_file = map_log_level_to_filter(level_file);
+    let level_stdout = crate::logging::map_log_level_to_filter(level_stdout);
+    let level_file = crate::logging::map_log_level_to_filter(level_file);
 
     let component_levels_json = unsafe { optional_bytes_to_json(component_levels_ptr) };
-    let component_levels = parse_component_levels(component_levels_json);
+    let component_levels = crate::logging::parse_component_levels(component_levels_json);
 
     let config = LoggerConfig::new(
         level_stdout,
@@ -116,21 +121,18 @@ pub unsafe extern "C" fn logging_init(
         None
     };
 
-    let directory =
-        unsafe { optional_cstr_to_str(directory_ptr).map(std::string::ToString::to_string) };
-    let file_name =
-        unsafe { optional_cstr_to_str(file_name_ptr).map(std::string::ToString::to_string) };
-    let file_format =
-        unsafe { optional_cstr_to_str(file_format_ptr).map(std::string::ToString::to_string) };
+    let directory = unsafe { optional_cstr_to_str(directory_ptr).map(ToString::to_string) };
+    let file_name = unsafe { optional_cstr_to_str(file_name_ptr).map(ToString::to_string) };
+    let file_format = unsafe { optional_cstr_to_str(file_format_ptr).map(ToString::to_string) };
 
     let file_config = FileWriterConfig::new(directory, file_name, file_format, file_rotate);
 
     if u8_as_bool(is_bypassed) {
-        logging_set_bypass();
+        crate::logging::logging_set_bypass();
     }
 
     LogGuard_API(Box::new(
-        logging::init_logging(trader_id, instance_id, config, file_config).unwrap(),
+        crate::logging::init_logging(trader_id, instance_id, config, file_config).unwrap(),
     ))
 }
 
@@ -138,8 +140,9 @@ pub unsafe extern "C" fn logging_init(
 ///
 /// # Safety
 ///
-/// - Assumes `component_ptr` is a valid C string pointer.
-/// - Assumes `message_ptr` is a valid C string pointer.
+/// This function assumes:
+/// - `component_ptr` is a valid C string pointer.
+/// - `message_ptr` is a valid C string pointer.
 #[unsafe(no_mangle)]
 pub unsafe extern "C" fn logger_log(
     level: LogLevel,
@@ -157,8 +160,9 @@ pub unsafe extern "C" fn logger_log(
 ///
 /// # Safety
 ///
-/// - Assumes `machine_id_ptr` is a valid C string pointer.
-/// - Assumes `component_ptr` is a valid C string pointer.
+/// This function assumes:
+/// - `machine_id_ptr` is a valid C string pointer.
+/// - `component_ptr` is a valid C string pointer.
 #[unsafe(no_mangle)]
 pub unsafe extern "C" fn logging_log_header(
     trader_id: TraderId,
@@ -175,7 +179,7 @@ pub unsafe extern "C" fn logging_log_header(
 ///
 /// # Safety
 ///
-/// - Assumes `component_ptr` is a valid C string pointer.
+/// Assumes `component_ptr` is a valid C string pointer.
 #[unsafe(no_mangle)]
 pub unsafe extern "C" fn logging_log_sysinfo(component_ptr: *const c_char) {
     let component = unsafe { cstr_to_ustr(component_ptr) };
@@ -184,6 +188,48 @@ pub unsafe extern "C" fn logging_log_sysinfo(component_ptr: *const c_char) {
 
 /// Flushes global logger buffers of any records.
 #[unsafe(no_mangle)]
+pub extern "C" fn logger_flush() {
+    log::logger().flush();
+}
+
+/// Flushes global logger buffers of any records and then drops the logger.
+#[unsafe(no_mangle)]
 pub extern "C" fn logger_drop(log_guard: LogGuard_API) {
     drop(log_guard);
 }
+// FFI wrappers for logger control
+
+#[unsafe(no_mangle)]
+pub extern "C" fn logging_is_initialized() -> u8 {
+    u8::from(crate::logging::logging_is_initialized())
+}
+
+#[unsafe(no_mangle)]
+pub extern "C" fn logging_set_bypass() {
+    crate::logging::logging_set_bypass();
+}
+
+#[unsafe(no_mangle)]
+pub extern "C" fn logging_shutdown() {
+    crate::logging::logging_shutdown();
+}
+
+#[unsafe(no_mangle)]
+pub extern "C" fn logging_is_colored() -> u8 {
+    u8::from(crate::logging::logging_is_colored())
+}
+
+#[unsafe(no_mangle)]
+pub extern "C" fn logging_clock_set_realtime_mode() {
+    crate::logging::logging_clock_set_realtime_mode();
+}
+
+#[unsafe(no_mangle)]
+pub extern "C" fn logging_clock_set_static_mode() {
+    crate::logging::logging_clock_set_static_mode();
+}
+
+#[unsafe(no_mangle)]
+pub extern "C" fn logging_clock_set_static_time(time_ns: u64) {
+    crate::logging::logging_clock_set_static_time(time_ns);
+}
