@@ -26,7 +26,6 @@ use nautilus_model::{
     instruments::Instrument,
     position::Position,
 };
-use ustr::Ustr;
 
 use crate::{cache::Cache, clock::Clock, msgbus};
 
@@ -45,6 +44,7 @@ use crate::{cache::Cache, clock::Clock, msgbus};
 ///
 /// Also note that for ease of implementation we consider that american options (for stock options for example) are european for the computation of greeks.
 #[allow(dead_code)]
+#[derive(Debug)]
 pub struct GreeksCalculator {
     cache: Rc<RefCell<Cache>>,
     clock: Rc<RefCell<dyn Clock>>,
@@ -62,6 +62,14 @@ impl GreeksCalculator {
     /// - Apply shocks to the spot value of the instrument's underlying, implied volatility or time to expiry.
     /// - Compute percent greeks.
     /// - Compute beta-weighted delta and gamma with respect to an index.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the instrument definition is not found or greeks calculation fails.
+    ///
+    /// # Panics
+    ///
+    /// Panics if the instrument has no underlying identifier.
     #[allow(clippy::too_many_arguments)]
     pub fn instrument_greeks(
         &self,
@@ -240,12 +248,12 @@ impl GreeksCalculator {
 
             // Publishing greeks on the message bus if requested
             if publish_greeks {
-                let topic_str = format!(
+                let topic = format!(
                     "data.GreeksData.instrument_id={}",
                     instrument_id.symbol.as_str()
-                );
-                let topic = Ustr::from(topic_str.as_str());
-                msgbus::publish(&topic, &greeks_data.clone().unwrap());
+                )
+                .into();
+                msgbus::publish(topic, &greeks_data.clone().unwrap());
             }
         }
 
@@ -393,6 +401,10 @@ impl GreeksCalculator {
     /// - Apply shocks to the spot value of an instrument's underlying, implied volatility or time to expiry.
     /// - Compute percent greeks.
     /// - Compute beta-weighted delta and gamma with respect to an index.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if any underlying greeks calculation fails.
     #[allow(clippy::too_many_arguments)]
     pub fn portfolio_greeks(
         &self,
@@ -489,8 +501,7 @@ impl GreeksCalculator {
     where
         F: Fn(GreeksData) + 'static + Send + Sync,
     {
-        let topic_str = format!("data.GreeksData.instrument_id={}*", underlying);
-        let topic = Ustr::from(topic_str.as_str());
+        let pattern = format!("data.GreeksData.instrument_id={underlying}*").into();
 
         if let Some(custom_handler) = handler {
             let handler = msgbus::handler::TypedMessageHandler::with_any(
@@ -501,7 +512,7 @@ impl GreeksCalculator {
                 },
             );
             msgbus::subscribe(
-                topic.as_str(),
+                pattern,
                 msgbus::handler::ShareableMessageHandler(Rc::new(handler)),
                 None,
             );
@@ -516,7 +527,7 @@ impl GreeksCalculator {
                 },
             );
             msgbus::subscribe(
-                topic.as_str(),
+                pattern,
                 msgbus::handler::ShareableMessageHandler(Rc::new(default_handler)),
                 None,
             );
