@@ -13,11 +13,22 @@
 //  limitations under the License.
 // -------------------------------------------------------------------------------------------------
 
+//! Common componentry for [NautilusTrader](http://nautilustrader.io).
+//!
+//! The *common* crate provides shared components and utilities that form the system foundation for
+//! NautilusTrader applications. This includes the actor system, message bus, caching layer, and other
+//! essential services.
+//!
+//! # Platform
+//!
 //! [NautilusTrader](http://nautilustrader.io) is an open-source, high-performance, production-grade
 //! algorithmic trading platform, providing quantitative traders with the ability to backtest
 //! portfolios of automated trading strategies on historical data with an event-driven engine,
 //! and also deploy those same strategies live, with no code changes.
 //!
+//! NautilusTrader's design, architecture, and implementation philosophy prioritizes software correctness and safety at the
+//! highest level, with the aim of supporting mission-critical, trading system backtesting and live deployment workloads.
+//!
 //! # Feature flags
 //!
 //! This crate provides feature flags to control source code inclusion during compilation,
@@ -28,13 +39,15 @@
 //! - `ffi`: Enables the C foreign function interface (FFI) from [cbindgen](https://github.com/mozilla/cbindgen).
 //! - `python`: Enables Python bindings from [PyO3](https://pyo3.rs).
 //! - `stubs`: Enables type stubs for use in testing scenarios.
-#![warn(rustc::all)]
-#![deny(nonstandard_style)]
-#![deny(rustdoc::broken_intra_doc_links)]
-// #![deny(clippy::missing_errors_doc)]
+//! - `defi`: Enables DeFi (Decentralized Finance) support.
 
-// Uncomment once we've added trivial `Debug` impls everywhere
-// #![warn(missing_debug_implementations)]
+#![warn(rustc::all)]
+#![deny(unsafe_code)]
+#![deny(nonstandard_style)]
+#![deny(missing_debug_implementations)]
+#![deny(clippy::missing_errors_doc)]
+#![deny(clippy::missing_panics_doc)]
+#![deny(rustdoc::broken_intra_doc_links)]
 
 pub mod actor;
 pub mod cache;
