@@ -18,7 +18,7 @@ use std::{
     env,
     fmt::Display,
     str::FromStr,
-    sync::{atomic::Ordering, mpsc::SendError},
+    sync::{OnceLock, atomic::Ordering, mpsc::SendError},
 };
 
 use indexmap::IndexMap;
@@ -44,6 +44,9 @@ use crate::{
 
 const LOGGING: &str = "logging";
 
+/// Global log sender which allows multiple log guards per process.
+static LOGGER_TX: OnceLock<std::sync::mpsc::Sender<LogEvent>> = OnceLock::new();
+
 #[cfg_attr(
     feature = "python",
     pyo3::pyclass(module = "nautilus_trader.core.nautilus_pyo3.common")
@@ -69,7 +72,7 @@ impl Default for LoggerConfig {
             stdout_level: LevelFilter::Info,
             fileout_level: LevelFilter::Off,
             component_level: HashMap::new(),
-            is_colored: false,
+            is_colored: true,
             print_config: false,
         }
     }
@@ -94,6 +97,9 @@ impl LoggerConfig {
         }
     }
 
+    /// # Errors
+    ///
+    /// Returns an error if the spec string is invalid.
     pub fn from_spec(spec: &str) -> anyhow::Result<Self> {
         let mut config = Self::default();
         for kv in spec.split(';') {
@@ -153,11 +159,14 @@ pub struct Logger {
 }
 
 /// Represents a type of log event.
+#[derive(Debug)]
 pub enum LogEvent {
     /// A log line event.
     Log(LogLine),
     /// A command to flush all logger buffers.
     Flush,
+    /// A command to close the logger.
+    Close,
 }
 
 /// Represents a log event which includes a message.
@@ -187,6 +196,7 @@ impl Display for LogLine {
 /// of it, such as plain string, colored string, and JSON. It also caches the
 /// results for repeated calls, optimizing performance when the same message
 /// needs to be logged multiple times in different formats.
+#[derive(Clone, Debug)]
 pub struct LogLineWrapper {
     /// The underlying log line that contains the log data.
     line: LogLine,
@@ -251,6 +261,9 @@ impl LogLineWrapper {
     /// This method serializes the log line and its associated metadata
     /// (timestamp, trader ID, etc.) into a JSON string format. This is useful
     /// for structured logging or when logs need to be stored in a JSON format.
+    /// # Panics
+    ///
+    /// Panics if serialization of the log event to JSON fails.
     #[must_use]
     pub fn get_json(&self) -> String {
         let json_string =
@@ -325,6 +338,11 @@ impl Log for Logger {
 
 #[allow(clippy::too_many_arguments)]
 impl Logger {
+    /// Initializes the logger based on the `NAUTILUS_LOG` environment variable.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if reading the environment variable or parsing the configuration fails.
     pub fn init_with_env(
         trader_id: TraderId,
         instance_id: UUID4,
@@ -343,6 +361,11 @@ impl Logger {
     /// let file_config = FileWriterConfig::default();
     /// let log_guard = Logger::init_with_config(trader_id, instance_id, config, file_config);
     /// ```
+    /// Initializes the logger with the given `LoggerConfig` and `FileWriterConfig`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the logger fails to register or initialize the background thread.
     pub fn init_with_config(
         trader_id: TraderId,
         instance_id: UUID4,
@@ -351,46 +374,42 @@ impl Logger {
     ) -> anyhow::Result<LogGuard> {
         let (tx, rx) = std::sync::mpsc::channel::<LogEvent>();
 
+        let logger_tx = tx.clone();
         let logger = Self {
-            tx,
+            tx: logger_tx,
             config: config.clone(),
         };
 
+        set_boxed_logger(Box::new(logger))?;
+
+        LOGGER_TX.set(tx.clone()).ok(); // Intended as a future feature: not yet used
+
         let print_config = config.print_config;
         if print_config {
             println!("STATIC_MAX_LEVEL={STATIC_MAX_LEVEL}");
             println!("Logger initialized with {config:?} {file_config:?}");
         }
 
-        let handle: Option<std::thread::JoinHandle<()>>;
-        match set_boxed_logger(Box::new(logger)) {
-            Ok(()) => {
-                handle = Some(
-                    std::thread::Builder::new()
-                        .name(LOGGING.to_string())
-                        .spawn(move || {
-                            Self::handle_messages(
-                                trader_id.to_string(),
-                                instance_id.to_string(),
-                                config,
-                                file_config,
-                                rx,
-                            );
-                        })?,
+        let handle = std::thread::Builder::new()
+            .name(LOGGING.to_string())
+            .spawn(move || {
+                Self::handle_messages(
+                    trader_id.to_string(),
+                    instance_id.to_string(),
+                    config,
+                    file_config,
+                    rx,
                 );
+            })?;
 
-                let max_level = log::LevelFilter::Trace;
-                set_max_level(max_level);
-                if print_config {
-                    println!("Logger set as `log` implementation with max level {max_level}");
-                }
-            }
-            Err(e) => {
-                anyhow::bail!("Cannot initialize logger because of error: {e}");
-            }
+        let max_level = log::LevelFilter::Trace;
+        set_max_level(max_level);
+
+        if print_config {
+            println!("Logger set as `log` implementation with max level {max_level}");
         }
 
-        Ok(LogGuard::new(handle))
+        Ok(LogGuard::new(Some(handle), Some(tx)))
     }
 
     fn handle_messages(
@@ -403,7 +422,7 @@ impl Logger {
         let LoggerConfig {
             stdout_level,
             fileout_level,
-            ref component_level,
+            component_level,
             is_colored,
             print_config: _,
         } = config;
@@ -418,21 +437,19 @@ impl Logger {
         let mut file_writer_opt = if fileout_level == LevelFilter::Off {
             None
         } else {
-            FileWriter::new(trader_id, instance_id, file_config, fileout_level)
+            FileWriter::new(
+                trader_id.clone(),
+                instance_id.clone(),
+                file_config.clone(),
+                fileout_level,
+            )
         };
 
         // Continue to receive and handle log events until channel is hung up
         while let Ok(event) = rx.recv() {
             match event {
-                LogEvent::Flush => {
-                    break;
-                }
                 LogEvent::Log(line) => {
-                    let component_level = component_level.get(&line.component);
-
-                    // Check if the component exists in level_filters,
-                    // and if its level is greater than event.level.
-                    if let Some(&filter_level) = component_level {
+                    if let Some(&filter_level) = component_level.get(&line.component) {
                         if line.level > filter_level {
                             continue;
                         }
@@ -456,16 +473,35 @@ impl Logger {
                         }
                     }
 
-                    if let Some(ref mut writer) = file_writer_opt {
-                        if writer.enabled(&wrapper.line) {
-                            if writer.json_format {
-                                writer.write(&wrapper.get_json());
+                    if let Some(ref mut file_writer) = file_writer_opt {
+                        if file_writer.enabled(&wrapper.line) {
+                            if file_writer.json_format {
+                                file_writer.write(&wrapper.get_json());
                             } else {
-                                writer.write(wrapper.get_string());
+                                file_writer.write(wrapper.get_string());
                             }
                         }
                     }
                 }
+                LogEvent::Flush => {
+                    stdout_writer.flush();
+                    stderr_writer.flush();
+
+                    if let Some(ref mut file_writer) = file_writer_opt {
+                        file_writer.flush();
+                    }
+                }
+                LogEvent::Close => {
+                    // Final flush
+                    stdout_writer.flush();
+                    stderr_writer.flush();
+
+                    if let Some(ref mut file_writer) = file_writer_opt {
+                        file_writer.flush();
+                    }
+
+                    break;
+                }
             }
         }
     }
@@ -501,29 +537,41 @@ pub fn log<T: AsRef<str>>(level: LogLevel, color: LogColor, component: Ustr, mes
 #[derive(Debug)]
 pub struct LogGuard {
     handle: Option<std::thread::JoinHandle<()>>,
+    tx: Option<std::sync::mpsc::Sender<LogEvent>>,
 }
 
 impl LogGuard {
     /// Creates a new [`LogGuard`] instance.
     #[must_use]
-    pub const fn new(handle: Option<std::thread::JoinHandle<()>>) -> Self {
-        Self { handle }
+    pub const fn new(
+        handle: Option<std::thread::JoinHandle<()>>,
+        tx: Option<std::sync::mpsc::Sender<LogEvent>>,
+    ) -> Self {
+        Self { handle, tx }
     }
 }
 
 impl Default for LogGuard {
     /// Creates a new default [`LogGuard`] instance.
     fn default() -> Self {
-        Self::new(None)
+        Self::new(None, None)
     }
 }
 
 impl Drop for LogGuard {
     fn drop(&mut self) {
-        log::logger().flush();
-        if let Some(handle) = self.handle.take() {
-            handle.join().expect("Error joining logging handle");
+        // Dropping a `LogGuard` should not shutdown the global logger when
+        // other parts of the process may still need it. Flush any buffered messages
+        // so that the caller’s logs are persisted, but we leave the logger thread
+        // running for the remainder of the process lifetime.
+
+        if let Some(tx) = self.tx.take() {
+            let _ = tx.send(LogEvent::Flush);
         }
+
+        // Drop the thread handle (if we own it) without joining to keep the
+        // global logger alive for the remainder of the process.
+        self.handle.take();
     }
 }
 
@@ -596,7 +644,7 @@ mod tests {
                 stdout_level: LevelFilter::Warn,
                 fileout_level: LevelFilter::Error,
                 component_level: HashMap::new(),
-                is_colored: false,
+                is_colored: true,
                 print_config: true,
             }
         );
@@ -639,7 +687,7 @@ mod tests {
                     .filter_map(Result::ok)
                     .any(|entry| entry.path().is_file())
             },
-            Duration::from_secs(2),
+            Duration::from_secs(3),
         );
 
         drop(log_guard); // Ensure log buffers are flushed
@@ -657,7 +705,7 @@ mod tests {
                     std::fs::read_to_string(log_file_path).expect("Error while reading log file");
                 !log_contents.is_empty()
             },
-            Duration::from_secs(2),
+            Duration::from_secs(3),
         );
 
         assert_eq!(
@@ -767,7 +815,7 @@ mod tests {
                     false
                 }
             },
-            Duration::from_secs(2),
+            Duration::from_secs(3),
         );
 
         assert_eq!(
@@ -813,7 +861,7 @@ mod tests {
         let files: Vec<_> = std::fs::read_dir(&dir_path)
             .expect("Failed to read directory")
             .filter_map(Result::ok)
-            .filter(|entry| entry.path().extension().map_or(false, |ext| ext == "log"))
+            .filter(|entry| entry.path().extension().is_some_and(|ext| ext == "log"))
             .collect();
 
         // We should have multiple files due to rotation
@@ -830,7 +878,7 @@ mod tests {
         let files: Vec<_> = std::fs::read_dir(&dir_path)
             .expect("Failed to read directory")
             .filter_map(Result::ok)
-            .filter(|entry| entry.path().extension().map_or(false, |ext| ext == "log"))
+            .filter(|entry| entry.path().extension().is_some_and(|ext| ext == "log"))
             .collect();
 
         // We should have multiple files due to rotation
@@ -850,7 +898,7 @@ mod tests {
         let files: Vec<_> = std::fs::read_dir(&dir_path)
             .expect("Failed to read directory")
             .filter_map(Result::ok)
-            .filter(|entry| entry.path().extension().map_or(false, |ext| ext == "log"))
+            .filter(|entry| entry.path().extension().is_some_and(|ext| ext == "log"))
             .collect();
 
         // We should have at most max_backups + 1 files (current file + backups)
