@@ -17,6 +17,7 @@
 
 pub mod headers;
 pub mod logger;
+pub mod macros;
 pub mod writer;
 
 use std::{
@@ -27,6 +28,8 @@ use std::{
 };
 
 use log::LevelFilter;
+// Re-exports
+pub use macros::{log_debug, log_error, log_info, log_trace, log_warn};
 use nautilus_core::{UUID4, time::get_atomic_clock_static};
 use nautilus_model::identifiers::TraderId;
 use tracing_subscriber::EnvFilter;
@@ -39,7 +42,7 @@ use self::{
 use crate::enums::LogLevel;
 
 pub const RECV: &str = "<--";
-pub const SENT: &str = "-->";
+pub const SEND: &str = "-->";
 pub const CMD: &str = "[CMD]";
 pub const EVT: &str = "[EVT]";
 pub const DOC: &str = "[DOC]";
@@ -53,44 +56,39 @@ static LOGGING_REALTIME: AtomicBool = AtomicBool::new(true);
 static LOGGING_COLORED: AtomicBool = AtomicBool::new(true);
 
 /// Returns whether the core logger is enabled.
-#[unsafe(no_mangle)]
-pub extern "C" fn logging_is_initialized() -> u8 {
-    u8::from(LOGGING_INITIALIZED.load(Ordering::Relaxed))
+pub fn logging_is_initialized() -> bool {
+    LOGGING_INITIALIZED.load(Ordering::Relaxed)
 }
 
-/// Sets the logging system to bypass mode.
-#[unsafe(no_mangle)]
-pub extern "C" fn logging_set_bypass() {
+/// Sets the logging subsystem to bypass mode.
+pub fn logging_set_bypass() {
     LOGGING_BYPASSED.store(true, Ordering::Relaxed);
 }
 
-/// Shuts down the logging system.
-#[unsafe(no_mangle)]
-pub extern "C" fn logging_shutdown() {
-    todo!()
+/// Shuts down the logging subsystem.
+pub fn logging_shutdown() {
+    // Flush any buffered logs and mark logging as uninitialized
+    log::logger().flush();
+    LOGGING_INITIALIZED.store(false, Ordering::Relaxed);
 }
 
 /// Returns whether the core logger is using ANSI colors.
-#[unsafe(no_mangle)]
-pub extern "C" fn logging_is_colored() -> u8 {
-    u8::from(LOGGING_COLORED.load(Ordering::Relaxed))
+pub fn logging_is_colored() -> bool {
+    LOGGING_COLORED.load(Ordering::Relaxed)
 }
 
 /// Sets the global logging clock to real-time mode.
-#[unsafe(no_mangle)]
-pub extern "C" fn logging_clock_set_realtime_mode() {
+pub fn logging_clock_set_realtime_mode() {
     LOGGING_REALTIME.store(true, Ordering::Relaxed);
 }
 
 /// Sets the global logging clock to static mode.
-#[unsafe(no_mangle)]
-pub extern "C" fn logging_clock_set_static_mode() {
+pub fn logging_clock_set_static_mode() {
     LOGGING_REALTIME.store(false, Ordering::Relaxed);
 }
 
 /// Sets the global logging clock static time with the given UNIX timestamp (nanoseconds).
-#[unsafe(no_mangle)]
-pub extern "C" fn logging_clock_set_static_time(time_ns: u64) {
+pub fn logging_clock_set_static_time(time_ns: u64) {
     let clock = get_atomic_clock_static();
     clock.set_time(time_ns.into());
 }
@@ -135,6 +133,15 @@ pub fn init_tracing() -> anyhow::Result<()> {
 ///
 /// Should only be called once during an applications run, ideally at the
 /// beginning of the run.
+/// Initialize logging.
+///
+/// Logging should be used for Python and sync Rust logic which is most of
+/// the components in the `nautilus_trader` package.
+/// Logging can be configured via the `NAUTILUS_LOG` environment variable.
+///
+/// # Errors
+///
+/// Returns an error if the logging subsystem fails to initialize.
 pub fn init_logging(
     trader_id: TraderId,
     instance_id: UUID4,
@@ -158,6 +165,11 @@ pub const fn map_log_level_to_filter(log_level: LogLevel) -> LevelFilter {
     }
 }
 
+/// Parses a string into a [`LevelFilter`].
+///
+/// # Panics
+///
+/// Panics if the provided string is not a valid `LevelFilter`.
 #[must_use]
 pub fn parse_level_filter_str(s: &str) -> LevelFilter {
     let mut log_level_str = s.to_string().to_uppercase();
@@ -169,6 +181,11 @@ pub fn parse_level_filter_str(s: &str) -> LevelFilter {
 }
 
 #[must_use]
+/// Parses component-specific log levels from a JSON value map.
+///
+/// # Panics
+///
+/// Panics if a JSON value in the map is not a string representing a log level.
 pub fn parse_component_levels(
     original_map: Option<HashMap<String, serde_json::Value>>,
 ) -> HashMap<Ustr, LevelFilter> {
@@ -177,11 +194,40 @@ pub fn parse_component_levels(
             let mut new_map = HashMap::new();
             for (key, value) in map {
                 let ustr_key = Ustr::from(&key);
-                let value = parse_level_filter_str(value.as_str().unwrap());
-                new_map.insert(ustr_key, value);
+                // Expect the JSON value to be a string representing a log level
+                let s = value
+                    .as_str()
+                    .expect("Invalid component log level: expected string");
+                let lvl = parse_level_filter_str(s);
+                new_map.insert(ustr_key, lvl);
             }
             new_map
         }
         None => HashMap::new(),
     }
 }
+
+/// Logs that a task has started using `tracing::debug!`.
+pub fn log_task_started(task_name: &str) {
+    tracing::debug!("Started task '{task_name}'");
+}
+
+/// Logs that a task has stopped using `tracing::debug!`.
+pub fn log_task_stopped(task_name: &str) {
+    tracing::debug!("Stopped task '{task_name}'");
+}
+
+/// Logs that a task is being awaited using `tracing::debug!`.
+pub fn log_task_awaiting(task_name: &str) {
+    tracing::debug!("Awaiting task '{task_name}'");
+}
+
+/// Logs that a task was aborted using `tracing::debug!`.
+pub fn log_task_aborted(task_name: &str) {
+    tracing::debug!("Aborted task '{task_name}'");
+}
+
+/// Logs that there was an error in a task `tracing::error!`.
+pub fn log_task_error(task_name: &str, e: &anyhow::Error) {
+    tracing::error!("Error in task '{task_name}': {e}");
+}
