@@ -16,6 +16,7 @@
 use std::{
     any::Any,
     cell::RefCell,
+    fmt::Debug,
     rc::Rc,
     sync::{
         Arc,
@@ -35,6 +36,14 @@ pub struct StubMessageHandler {
     callback: Arc<dyn Fn(Message) + Send>,
 }
 
+impl Debug for StubMessageHandler {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct(stringify!(StubMessageHandler))
+            .field("id", &self.id)
+            .finish()
+    }
+}
+
 impl MessageHandler for StubMessageHandler {
     fn id(&self) -> Ustr {
         self.id
@@ -65,6 +74,7 @@ pub fn get_stub_shareable_handler(id: Option<Ustr>) -> ShareableMessageHandler {
 }
 
 // Stub message handler which checks if handle was called
+#[derive(Debug)]
 pub struct CallCheckMessageHandler {
     id: Ustr,
     called: Arc<AtomicBool>,
@@ -103,6 +113,11 @@ pub fn get_call_check_shareable_handler(id: Option<Ustr>) -> ShareableMessageHan
     }))
 }
 
+/// Returns whether the given `CallCheckMessageHandler` has been invoked at least once.
+///
+/// # Panics
+///
+/// Panics if the provided `handler` is not a `CallCheckMessageHandler`.
 #[must_use]
 pub fn check_handler_was_called(call_check_handler: ShareableMessageHandler) -> bool {
     call_check_handler
@@ -133,6 +148,11 @@ impl<T: Clone + 'static> MessageHandler for MessageSavingHandler<T> {
         self.id
     }
 
+    /// Handles an incoming message by saving it.
+    ///
+    /// # Panics
+    ///
+    /// Panics if the provided `message` is not of the expected type `T`.
     fn handle(&self, message: &dyn Any) {
         let mut messages = self.messages.borrow_mut();
         match message.downcast_ref::<T>() {
@@ -158,6 +178,11 @@ pub fn get_message_saving_handler<T: Clone + 'static>(id: Option<Ustr>) -> Share
     }))
 }
 
+/// Retrieves the messages saved by a [`MessageSavingHandler`].
+///
+/// # Panics
+///
+/// Panics if the provided `handler` is not a `MessageSavingHandler<T>`.
 #[must_use]
 pub fn get_saved_messages<T: Clone + 'static>(handler: ShareableMessageHandler) -> Vec<T> {
     handler
