@@ -33,8 +33,10 @@ use crate::{
 #[allow(non_camel_case_types)]
 #[pyo3::pyclass(
     module = "nautilus_trader.core.nautilus_pyo3.common",
-    name = "TestClock"
+    name = "TestClock",
+    unsendable
 )]
+#[derive(Debug)]
 pub struct TestClock_Py(Box<TestClock>);
 
 #[pymethods]
@@ -79,30 +81,33 @@ impl TestClock_Py {
             .map_err(to_pyvalue_err)
     }
 
-    #[pyo3(signature = (name, interval_ns, start_time_ns, stop_time_ns=None, callback=None, allow_past=None))]
+    #[allow(clippy::too_many_arguments)]
+    #[pyo3(signature = (name, interval_ns, start_time_ns, stop_time_ns=None, callback=None, allow_past=None, fire_immediately=None))]
     fn set_timer_ns(
         &mut self,
         name: &str,
         interval_ns: u64,
-        start_time_ns: u64,
+        start_time_ns: Option<u64>,
         stop_time_ns: Option<u64>,
         callback: Option<PyObject>,
         allow_past: Option<bool>,
+        fire_immediately: Option<bool>,
     ) -> PyResult<()> {
         self.0
             .set_timer_ns(
                 name,
                 interval_ns,
-                start_time_ns.into(),
+                start_time_ns.map(UnixNanos::from),
                 stop_time_ns.map(UnixNanos::from),
                 callback.map(TimeEventCallback::from),
                 allow_past,
+                fire_immediately,
             )
             .map_err(to_pyvalue_err)
     }
 
-    fn next_time_ns(&self, name: &str) -> u64 {
-        *self.0.next_time_ns(name)
+    fn next_time_ns(&self, name: &str) -> Option<u64> {
+        self.0.next_time_ns(name).map(|n| n.as_u64())
     }
 
     fn cancel_timer(&mut self, name: &str) {
@@ -125,8 +130,10 @@ impl TestClock_Py {
 #[allow(non_camel_case_types)]
 #[pyo3::pyclass(
     module = "nautilus_trader.core.nautilus_pyo3.common",
-    name = "LiveClock"
+    name = "LiveClock",
+    unsendable
 )]
+#[derive(Debug)]
 pub struct LiveClock_Py(Box<LiveClock>);
 
 #[pymethods]
@@ -159,30 +166,33 @@ impl LiveClock_Py {
             .map_err(to_pyvalue_err)
     }
 
-    #[pyo3(signature = (name, interval_ns, start_time_ns, stop_time_ns=None, callback=None, allow_past=None))]
+    #[allow(clippy::too_many_arguments)]
+    #[pyo3(signature = (name, interval_ns, start_time_ns, stop_time_ns=None, callback=None, allow_past=None, fire_immediately=None))]
     fn set_timer_ns(
         &mut self,
         name: &str,
         interval_ns: u64,
-        start_time_ns: u64,
+        start_time_ns: Option<u64>,
         stop_time_ns: Option<u64>,
         callback: Option<PyObject>,
         allow_past: Option<bool>,
+        fire_immediately: Option<bool>,
     ) -> PyResult<()> {
         self.0
             .set_timer_ns(
                 name,
                 interval_ns,
-                start_time_ns.into(),
+                start_time_ns.map(UnixNanos::from),
                 stop_time_ns.map(UnixNanos::from),
                 callback.map(TimeEventCallback::from),
                 allow_past,
+                fire_immediately,
             )
             .map_err(to_pyvalue_err)
     }
 
-    fn next_time_ns(&self, name: &str) -> u64 {
-        *self.0.next_time_ns(name)
+    fn next_time_ns(&self, name: &str) -> Option<u64> {
+        self.0.next_time_ns(name).map(|t| t.as_u64())
     }
 
     fn cancel_timer(&mut self, name: &str) {
@@ -232,7 +242,7 @@ mod tests {
 
             let timer_name = "TEST_TIME1";
             test_clock
-                .set_timer_ns(timer_name, 10, 0.into(), None, None, None)
+                .set_timer_ns(timer_name, 10, None, None, None, None, None)
                 .unwrap();
 
             assert_eq!(test_clock.timer_names(), [timer_name]);
@@ -250,7 +260,7 @@ mod tests {
 
             let timer_name = "TEST_TIME1";
             test_clock
-                .set_timer_ns(timer_name, 10, 0.into(), None, None, None)
+                .set_timer_ns(timer_name, 10, None, None, None, None, None)
                 .unwrap();
             test_clock.cancel_timer(timer_name);
 
@@ -269,7 +279,7 @@ mod tests {
 
             let timer_name = "TEST_TIME1";
             test_clock
-                .set_timer_ns(timer_name, 10, 0.into(), None, None, None)
+                .set_timer_ns(timer_name, 10, None, None, None, None, None)
                 .unwrap();
             test_clock.cancel_timers();
 
@@ -291,10 +301,11 @@ mod tests {
                 .set_timer_ns(
                     timer_name,
                     1,
-                    1.into(),
+                    Some(UnixNanos::from(1)),
                     Some(UnixNanos::from(3)),
                     None,
                     None,
+                    None,
                 )
                 .unwrap();
             test_clock.advance_time(2.into(), true);
@@ -316,10 +327,11 @@ mod tests {
                 .set_timer_ns(
                     "TEST_TIME1",
                     2,
-                    0.into(),
+                    None,
                     Some(UnixNanos::from(3)),
                     None,
                     None,
+                    None,
                 )
                 .unwrap();
             test_clock.advance_time(3.into(), true);
@@ -342,10 +354,11 @@ mod tests {
                 .set_timer_ns(
                     "TEST_TIME1",
                     2,
-                    0.into(),
+                    None,
                     Some(UnixNanos::from(3)),
                     None,
                     None,
+                    None,
                 )
                 .unwrap();
             test_clock.advance_time(3.into(), false);
