@@ -15,14 +15,6 @@
 
 //! Real-time and test timers for use with `Clock` implementations.
 
-#[rustfmt::skip]
-#[cfg(feature = "clock_v2")]
-use std::collections::BinaryHeap;
-
-#[rustfmt::skip]
-#[cfg(feature = "clock_v2")]
-use tokio::sync::Mutex;
-
 use std::{
     cmp::Ordering,
     fmt::{Debug, Display},
@@ -48,13 +40,13 @@ use tokio::{
 };
 use ustr::Ustr;
 
-use crate::runtime::get_runtime;
+use crate::{runner::TimeEventSender, runtime::get_runtime};
 
 /// Creates a valid nanoseconds interval that is guaranteed to be positive.
 ///
 /// # Panics
 ///
-/// This function panics if `interval_ns` is zero.
+/// Panics if `interval_ns` is zero.
 #[must_use]
 pub fn create_valid_interval(interval_ns: u64) -> NonZeroU64 {
     NonZeroU64::new(std::cmp::max(interval_ns, 1)).expect("`interval_ns` must be positive")
@@ -78,7 +70,7 @@ pub struct TimeEvent {
     pub event_id: UUID4,
     /// UNIX timestamp (nanoseconds) when the event occurred.
     pub ts_event: UnixNanos,
-    /// UNIX timestamp (nanoseconds) when the instance was initialized.
+    /// UNIX timestamp (nanoseconds) when the instance was created.
     pub ts_init: UnixNanos,
 }
 
@@ -101,7 +93,7 @@ impl TimeEvent {
     ///
     /// # Safety
     ///
-    /// - Assumes `name` is a valid string.
+    /// Assumes `name` is a valid string.
     #[must_use]
     pub const fn new(name: Ustr, event_id: UUID4, ts_event: UnixNanos, ts_init: UnixNanos) -> Self {
         Self {
@@ -149,6 +141,11 @@ impl Debug for TimeEventCallback {
 }
 
 impl TimeEventCallback {
+    /// Invokes the callback for the given `TimeEvent`.
+    ///
+    /// # Panics
+    ///
+    /// Panics if the underlying Python callback invocation fails (e.g., raises an exception).
     pub fn call(&self, event: TimeEvent) {
         match self {
             #[cfg(feature = "python")]
@@ -175,8 +172,15 @@ impl From<PyObject> for TimeEventCallback {
     }
 }
 
-// SAFETY: Message handlers cannot be sent across thread boundaries
+// TimeEventCallback supports both single-threaded and async use cases:
+// - Python variant uses Arc<PyObject> for cross-thread compatibility with Python's GIL
+// - Rust variant uses Rc<dyn Fn(TimeEvent)> for efficient single-threaded callbacks
+// SAFETY: The async timer tasks only use Python callbacks, and Rust callbacks are never
+// sent across thread boundaries in practice. This unsafe implementation allows the enum
+// to be moved into async tasks while maintaining the efficient Rc for single-threaded use.
+#[allow(unsafe_code)]
 unsafe impl Send for TimeEventCallback {}
+#[allow(unsafe_code)]
 unsafe impl Sync for TimeEventCallback {}
 
 #[repr(C)]
@@ -199,6 +203,11 @@ impl TimeEventHandlerV2 {
         Self { event, callback }
     }
 
+    /// Executes the handler by invoking its callback for the associated event.
+    ///
+    /// # Panics
+    ///
+    /// Panics if the underlying callback invocation fails (e.g., a Python callback raises an exception).
     pub fn run(self) {
         let Self { event, callback } = self;
         callback.call(event);
@@ -239,6 +248,8 @@ pub struct TestTimer {
     pub start_time_ns: UnixNanos,
     /// The optional stop time of the timer in UNIX nanoseconds.
     pub stop_time_ns: Option<UnixNanos>,
+    /// If the timer should fire immediately at start time.
+    pub fire_immediately: bool,
     next_time_ns: UnixNanos,
     is_expired: bool,
 }
@@ -248,22 +259,30 @@ impl TestTimer {
     ///
     /// # Panics
     ///
-    /// This function panics if `name` is not a valid string.
+    /// Panics if `name` is not a valid string.
     #[must_use]
     pub fn new(
         name: Ustr,
         interval_ns: NonZeroU64,
         start_time_ns: UnixNanos,
         stop_time_ns: Option<UnixNanos>,
+        fire_immediately: bool,
     ) -> Self {
         check_valid_string(name, stringify!(name)).expect(FAILED);
 
+        let next_time_ns = if fire_immediately {
+            start_time_ns
+        } else {
+            start_time_ns + interval_ns.get()
+        };
+
         Self {
             name,
             interval_ns,
             start_time_ns,
             stop_time_ns,
-            next_time_ns: start_time_ns + interval_ns.get(),
+            fire_immediately,
+            next_time_ns,
             is_expired: false,
         }
     }
@@ -296,9 +315,12 @@ impl TestTimer {
     ///
     /// This allows testing of multiple time intervals within a single step.
     pub fn advance(&mut self, to_time_ns: UnixNanos) -> impl Iterator<Item = TimeEvent> + '_ {
-        let advances = to_time_ns
-            .saturating_sub(self.next_time_ns.as_u64() - self.interval_ns.get())
-            / self.interval_ns.get();
+        // Calculate how many events should fire up to and including to_time_ns
+        let advances = if self.next_time_ns <= to_time_ns {
+            (to_time_ns.as_u64() - self.next_time_ns.as_u64()) / self.interval_ns.get() + 1
+        } else {
+            0
+        };
         self.take(advances as usize).map(|(event, _)| event)
     }
 
@@ -317,6 +339,14 @@ impl Iterator for TestTimer {
         if self.is_expired {
             None
         } else {
+            // Check if current event would exceed stop time before creating the event
+            if let Some(stop_time_ns) = self.stop_time_ns {
+                if self.next_time_ns > stop_time_ns {
+                    self.is_expired = true;
+                    return None;
+                }
+            }
+
             let item = (
                 TimeEvent {
                     name: self.name,
@@ -327,9 +357,9 @@ impl Iterator for TestTimer {
                 self.next_time_ns,
             );
 
-            // If current next event time has exceeded stop time, then expire timer
+            // Check if we should expire after this event (for repeating timers at stop boundary)
             if let Some(stop_time_ns) = self.stop_time_ns {
-                if self.next_time_ns >= stop_time_ns {
+                if self.next_time_ns == stop_time_ns {
                     self.is_expired = true;
                 }
             }
@@ -355,11 +385,12 @@ pub struct LiveTimer {
     pub start_time_ns: UnixNanos,
     /// The optional stop time of the timer in UNIX nanoseconds.
     pub stop_time_ns: Option<UnixNanos>,
+    /// If the timer should fire immediately at start time.
+    pub fire_immediately: bool,
     next_time_ns: Arc<AtomicU64>,
     callback: TimeEventCallback,
     task_handle: Option<JoinHandle<()>>,
-    #[cfg(feature = "clock_v2")]
-    heap: Arc<Mutex<BinaryHeap<TimeEvent>>>,
+    sender: Option<Arc<dyn TimeEventSender>>,
 }
 
 impl LiveTimer {
@@ -367,57 +398,38 @@ impl LiveTimer {
     ///
     /// # Panics
     ///
-    /// This function panics if `name` is not a valid string.
+    /// Panics if `name` is not a valid string.
+    #[allow(clippy::too_many_arguments)]
     #[must_use]
-    #[cfg(not(feature = "clock_v2"))]
     pub fn new(
         name: Ustr,
         interval_ns: NonZeroU64,
         start_time_ns: UnixNanos,
         stop_time_ns: Option<UnixNanos>,
         callback: TimeEventCallback,
+        fire_immediately: bool,
+        sender: Option<Arc<dyn TimeEventSender>>,
     ) -> Self {
         check_valid_string(name, stringify!(name)).expect(FAILED);
 
+        let next_time_ns = if fire_immediately {
+            start_time_ns.as_u64()
+        } else {
+            start_time_ns.as_u64() + interval_ns.get()
+        };
+
         log::debug!("Creating timer '{name}'");
+
         Self {
             name,
             interval_ns,
             start_time_ns,
             stop_time_ns,
-            next_time_ns: Arc::new(AtomicU64::new(start_time_ns.as_u64() + interval_ns.get())),
+            fire_immediately,
+            next_time_ns: Arc::new(AtomicU64::new(next_time_ns)),
             callback,
             task_handle: None,
-        }
-    }
-
-    /// Creates a new [`LiveTimer`] instance.
-    ///
-    /// # Panics
-    ///
-    /// This function panics if `name` is not a valid string.
-    #[must_use]
-    #[cfg(feature = "clock_v2")]
-    pub fn new(
-        name: Ustr,
-        interval_ns: NonZeroU64,
-        start_time_ns: UnixNanos,
-        stop_time_ns: Option<UnixNanos>,
-        callback: TimeEventCallback,
-        heap: Arc<Mutex<BinaryHeap<TimeEvent>>>,
-    ) -> Self {
-        check_valid_string(name, stringify!(name)).expect(FAILED);
-
-        log::debug!("Creating timer '{name}'");
-        Self {
-            name,
-            interval_ns,
-            start_time_ns,
-            stop_time_ns,
-            next_time_ns: Arc::new(AtomicU64::new(start_time_ns.as_u64() + interval_ns.get())),
-            callback,
-            heap,
-            task_handle: None,
+            sender,
         }
     }
 
@@ -444,6 +456,10 @@ impl LiveTimer {
     ///
     /// Time events will begin triggering at the specified intervals.
     /// The generated events are handled by the provided callback function.
+    ///
+    /// # Panics
+    ///
+    /// Panics if Rust-based callback system active and no time event sender has been set.
     #[allow(unused_variables)] // callback is used
     pub fn start(&mut self) {
         let event_name = self.name;
@@ -459,9 +475,7 @@ impl LiveTimer {
         let mut next_time_ns = self.next_time_ns.load(atomic::Ordering::SeqCst);
         if next_time_ns <= now_ns {
             log::warn!(
-                "Timer '{}' alert time {} was in the past, adjusted to current time for immediate fire",
-                event_name,
-                next_time_ns,
+                "Timer '{event_name}' alert time {next_time_ns} was in the past, adjusted to current time for immediate fire"
             );
             next_time_ns = now_ns.into();
             self.next_time_ns
@@ -472,8 +486,7 @@ impl LiveTimer {
         let mut next_time_ns = UnixNanos::from(floor_to_nearest_microsecond(next_time_ns));
         let next_time_atomic = self.next_time_ns.clone();
 
-        #[cfg(feature = "clock_v2")]
-        let heap = self.heap.clone();
+        let sender = self.sender.clone();
 
         let rt = get_runtime();
         let handle = rt.spawn(async move {
@@ -493,21 +506,20 @@ impl LiveTimer {
                 timer.tick().await;
                 let now_ns = clock.get_time_ns();
 
-                #[cfg(feature = "python")]
-                {
-                    match callback {
-                        TimeEventCallback::Python(ref callback) => {
-                            call_python_with_time_event(event_name, next_time_ns, now_ns, callback);
-                        }
-                        // Note: Clock v1 style path should not be called with Rust callback
-                        TimeEventCallback::Rust(_) => {}
-                    }
-                }
+                let event = TimeEvent::new(event_name, UUID4::new(), next_time_ns, now_ns);
 
-                #[cfg(feature = "clock_v2")]
-                {
-                    let event = TimeEvent::new(event_name, UUID4::new(), next_time_ns, now_ns);
-                    heap.lock().await.push(event);
+                match callback {
+                    #[cfg(feature = "python")]
+                    TimeEventCallback::Python(ref callback) => {
+                        call_python_with_time_event(event, callback);
+                    }
+                    TimeEventCallback::Rust(_) => {
+                        let sender = sender
+                            .as_ref()
+                            .expect("timer event sender was unset for Rust callback system");
+                        let handler = TimeEventHandlerV2::new(event, callback.clone());
+                        sender.send(handler);
+                    }
                 }
 
                 // Prepare next time interval
@@ -538,18 +550,12 @@ impl LiveTimer {
 }
 
 #[cfg(feature = "python")]
-fn call_python_with_time_event(
-    name: Ustr,
-    ts_event: UnixNanos,
-    ts_init: UnixNanos,
-    callback: &PyObject,
-) {
+fn call_python_with_time_event(event: TimeEvent, callback: &PyObject) {
     use nautilus_core::python::IntoPyObjectNautilusExt;
     use pyo3::types::PyCapsule;
 
     Python::with_gil(|py| {
         // Create new time event
-        let event = TimeEvent::new(name, UUID4::new(), ts_event, ts_init);
         let capsule: PyObject = PyCapsule::new(py, event, None)
             .expect("Error creating `PyCapsule`")
             .into_py_any_unwrap(py);
@@ -566,13 +572,13 @@ fn call_python_with_time_event(
 ////////////////////////////////////////////////////////////////////////////////
 #[cfg(test)]
 mod tests {
-    use std::num::NonZeroU64;
+    use std::{num::NonZeroU64, rc::Rc};
 
     use nautilus_core::UnixNanos;
     use rstest::*;
     use ustr::Ustr;
 
-    use super::{TestTimer, TimeEvent};
+    use super::{LiveTimer, TestTimer, TimeEvent, TimeEventCallback};
 
     #[rstest]
     fn test_test_timer_pop_event() {
@@ -581,6 +587,7 @@ mod tests {
             NonZeroU64::new(1).unwrap(),
             UnixNanos::from(1),
             None,
+            false,
         );
 
         assert!(timer.next().is_some());
@@ -596,6 +603,7 @@ mod tests {
             NonZeroU64::new(5).unwrap(),
             UnixNanos::default(),
             None,
+            false,
         );
         let _: Vec<TimeEvent> = timer.advance(UnixNanos::from(1)).collect();
         let _: Vec<TimeEvent> = timer.advance(UnixNanos::from(2)).collect();
@@ -612,6 +620,7 @@ mod tests {
             NonZeroU64::new(1).unwrap(),
             UnixNanos::default(),
             None,
+            false,
         );
         assert_eq!(timer.advance(UnixNanos::from(1)).count(), 1);
         assert!(!timer.is_expired);
@@ -624,6 +633,7 @@ mod tests {
             NonZeroU64::new(1).unwrap(),
             UnixNanos::default(),
             Some(UnixNanos::from(2)),
+            false,
         );
         assert_eq!(timer.advance(UnixNanos::from(2)).count(), 2);
         assert!(timer.is_expired);
@@ -636,6 +646,7 @@ mod tests {
             NonZeroU64::new(1).unwrap(),
             UnixNanos::default(),
             Some(UnixNanos::from(5)),
+            false,
         );
         assert_eq!(timer.advance(UnixNanos::from(5)).count(), 5);
         assert!(timer.is_expired);
@@ -648,6 +659,7 @@ mod tests {
             NonZeroU64::new(1).unwrap(),
             UnixNanos::default(),
             Some(UnixNanos::from(5)),
+            false,
         );
         assert_eq!(timer.advance(UnixNanos::from(10)).count(), 5);
         assert!(timer.is_expired);
@@ -660,6 +672,7 @@ mod tests {
             NonZeroU64::new(5).unwrap(),
             UnixNanos::from(0),
             None,
+            false,
         );
         let events: Vec<TimeEvent> = timer.advance(UnixNanos::from(5)).collect();
         assert_eq!(events.len(), 1, "Expected one event at the 5 ns boundary");
@@ -667,4 +680,265 @@ mod tests {
         let events: Vec<TimeEvent> = timer.advance(UnixNanos::from(10)).collect();
         assert_eq!(events.len(), 1, "Expected one event at the 10 ns boundary");
     }
+
+    #[rstest]
+    fn test_test_timer_fire_immediately_true() {
+        let mut timer = TestTimer::new(
+            Ustr::from("TEST_TIMER"),
+            NonZeroU64::new(5).unwrap(),
+            UnixNanos::from(10),
+            None,
+            true, // fire_immediately = true
+        );
+
+        // With fire_immediately=true, next_time_ns should be start_time_ns
+        assert_eq!(timer.next_time_ns(), UnixNanos::from(10));
+
+        // Advance to start time should produce an event
+        let events: Vec<TimeEvent> = timer.advance(UnixNanos::from(10)).collect();
+        assert_eq!(events.len(), 1);
+        assert_eq!(events[0].ts_event, UnixNanos::from(10));
+
+        // Next event should be at start_time + interval
+        assert_eq!(timer.next_time_ns(), UnixNanos::from(15));
+    }
+
+    #[rstest]
+    fn test_test_timer_fire_immediately_false() {
+        let mut timer = TestTimer::new(
+            Ustr::from("TEST_TIMER"),
+            NonZeroU64::new(5).unwrap(),
+            UnixNanos::from(10),
+            None,
+            false, // fire_immediately = false
+        );
+
+        // With fire_immediately=false, next_time_ns should be start_time_ns + interval
+        assert_eq!(timer.next_time_ns(), UnixNanos::from(15));
+
+        // Advance to start time should produce no events
+        let events: Vec<TimeEvent> = timer.advance(UnixNanos::from(10)).collect();
+        assert_eq!(events.len(), 0);
+
+        // Advance to first interval should produce an event
+        let events: Vec<TimeEvent> = timer.advance(UnixNanos::from(15)).collect();
+        assert_eq!(events.len(), 1);
+        assert_eq!(events[0].ts_event, UnixNanos::from(15));
+    }
+
+    #[rstest]
+    fn test_live_timer_fire_immediately_field() {
+        let timer = LiveTimer::new(
+            Ustr::from("TEST_TIMER"),
+            NonZeroU64::new(1000).unwrap(),
+            UnixNanos::from(100),
+            None,
+            TimeEventCallback::Rust(Rc::new(|_| {})),
+            true, // fire_immediately = true
+            None, // time_event_sender
+        );
+
+        // Verify the field is set correctly
+        assert!(timer.fire_immediately);
+
+        // With fire_immediately=true, next_time_ns should be start_time_ns
+        assert_eq!(timer.next_time_ns(), UnixNanos::from(100));
+    }
+
+    #[rstest]
+    fn test_live_timer_fire_immediately_false_field() {
+        let timer = LiveTimer::new(
+            Ustr::from("TEST_TIMER"),
+            NonZeroU64::new(1000).unwrap(),
+            UnixNanos::from(100),
+            None,
+            TimeEventCallback::Rust(Rc::new(|_| {})),
+            false, // fire_immediately = false
+            None,  // time_event_sender
+        );
+
+        // Verify the field is set correctly
+        assert!(!timer.fire_immediately);
+
+        // With fire_immediately=false, next_time_ns should be start_time_ns + interval
+        assert_eq!(timer.next_time_ns(), UnixNanos::from(1100));
+    }
+
+    ////////////////////////////////////////////////////////////////////////////////
+    // Property-based testing
+    ////////////////////////////////////////////////////////////////////////////////
+
+    use proptest::prelude::*;
+
+    #[derive(Clone, Debug)]
+    enum TimerOperation {
+        AdvanceTime(u64),
+        Cancel,
+    }
+
+    fn timer_operation_strategy() -> impl Strategy<Value = TimerOperation> {
+        prop_oneof![
+            8 => prop::num::u64::ANY.prop_map(|v| TimerOperation::AdvanceTime(v % 1000 + 1)),
+            2 => Just(TimerOperation::Cancel),
+        ]
+    }
+
+    fn timer_config_strategy() -> impl Strategy<Value = (u64, u64, Option<u64>, bool)> {
+        (
+            1u64..=100u64,                    // interval_ns (1-100)
+            0u64..=50u64,                     // start_time_ns (0-50)
+            prop::option::of(51u64..=200u64), // stop_time_ns (51-200 or None)
+            prop::bool::ANY,                  // fire_immediately
+        )
+    }
+
+    fn timer_test_strategy()
+    -> impl Strategy<Value = (Vec<TimerOperation>, (u64, u64, Option<u64>, bool))> {
+        (
+            prop::collection::vec(timer_operation_strategy(), 5..=50),
+            timer_config_strategy(),
+        )
+    }
+
+    fn test_timer_with_operations(
+        operations: Vec<TimerOperation>,
+        (interval_ns, start_time_ns, stop_time_ns, fire_immediately): (u64, u64, Option<u64>, bool),
+    ) {
+        let mut timer = TestTimer::new(
+            Ustr::from("PROP_TEST_TIMER"),
+            NonZeroU64::new(interval_ns).unwrap(),
+            UnixNanos::from(start_time_ns),
+            stop_time_ns.map(UnixNanos::from),
+            fire_immediately,
+        );
+
+        let mut current_time = start_time_ns;
+
+        for operation in operations {
+            if timer.is_expired() {
+                break;
+            }
+
+            match operation {
+                TimerOperation::AdvanceTime(delta) => {
+                    let to_time = current_time + delta;
+                    let events: Vec<TimeEvent> = timer.advance(UnixNanos::from(to_time)).collect();
+                    current_time = to_time;
+
+                    // Verify event ordering and timing
+                    for (i, event) in events.iter().enumerate() {
+                        // Event timestamps should be in order
+                        if i > 0 {
+                            assert!(
+                                event.ts_event >= events[i - 1].ts_event,
+                                "Events should be in chronological order"
+                            );
+                        }
+
+                        // Event timestamp should be within reasonable bounds
+                        assert!(
+                            event.ts_event.as_u64() >= start_time_ns,
+                            "Event timestamp should not be before start time"
+                        );
+
+                        assert!(
+                            event.ts_event.as_u64() <= to_time,
+                            "Event timestamp should not be after advance time"
+                        );
+
+                        // If there's a stop time, event should not exceed it
+                        if let Some(stop_time_ns) = stop_time_ns {
+                            assert!(
+                                event.ts_event.as_u64() <= stop_time_ns,
+                                "Event timestamp should not exceed stop time"
+                            );
+                        }
+                    }
+                }
+                TimerOperation::Cancel => {
+                    timer.cancel();
+                    assert!(timer.is_expired(), "Timer should be expired after cancel");
+                }
+            }
+
+            // Timer invariants
+            if !timer.is_expired() {
+                // Next time should be properly spaced
+                let expected_interval_multiple = if fire_immediately {
+                    timer.next_time_ns().as_u64() >= start_time_ns
+                } else {
+                    timer.next_time_ns().as_u64() >= start_time_ns + interval_ns
+                };
+                assert!(
+                    expected_interval_multiple,
+                    "Next time should respect interval spacing"
+                );
+
+                // If timer has stop time, check if it should be considered logically expired
+                // Note: Timer only becomes actually expired when advance() or next() is called
+                if let Some(stop_time_ns) = stop_time_ns {
+                    if timer.next_time_ns().as_u64() > stop_time_ns {
+                        // The timer should expire on the next advance/iteration
+                        let mut test_timer = timer;
+                        let events: Vec<TimeEvent> = test_timer
+                            .advance(UnixNanos::from(stop_time_ns + 1))
+                            .collect();
+                        assert!(
+                            events.is_empty() || test_timer.is_expired(),
+                            "Timer should not generate events beyond stop time"
+                        );
+                    }
+                }
+            }
+        }
+
+        // Final consistency check: if timer is not expired and we haven't hit stop time,
+        // advancing far enough should eventually expire it
+        if !timer.is_expired() && stop_time_ns.is_some() {
+            let events: Vec<TimeEvent> = timer
+                .advance(UnixNanos::from(stop_time_ns.unwrap() + 1000))
+                .collect();
+            assert!(
+                timer.is_expired() || events.is_empty(),
+                "Timer should eventually expire or stop generating events"
+            );
+        }
+    }
+
+    proptest! {
+        #[test]
+        fn prop_timer_advance_operations((operations, config) in timer_test_strategy()) {
+            test_timer_with_operations(operations, config);
+        }
+
+        #[test]
+        fn prop_timer_interval_consistency(
+            interval_ns in 1u64..=100u64,
+            start_time_ns in 0u64..=50u64,
+            fire_immediately in prop::bool::ANY,
+            advance_count in 1usize..=20usize,
+        ) {
+            let mut timer = TestTimer::new(
+                Ustr::from("CONSISTENCY_TEST"),
+                NonZeroU64::new(interval_ns).unwrap(),
+                UnixNanos::from(start_time_ns),
+                None, // No stop time for this test
+                fire_immediately,
+            );
+
+            let mut previous_event_time = if fire_immediately { start_time_ns } else { start_time_ns + interval_ns };
+
+            for _ in 0..advance_count {
+                let events: Vec<TimeEvent> = timer.advance(UnixNanos::from(previous_event_time)).collect();
+
+                if !events.is_empty() {
+                    // Should get exactly one event at the expected time
+                    prop_assert_eq!(events.len(), 1);
+                    prop_assert_eq!(events[0].ts_event.as_u64(), previous_event_time);
+                }
+
+                previous_event_time += interval_ns;
+            }
+        }
+    }
 }
