@@ -14,6 +14,7 @@
 // -------------------------------------------------------------------------------------------------
 
 //! Common data and time functions.
+use std::convert::TryFrom;
 
 use chrono::{DateTime, Datelike, NaiveDate, SecondsFormat, TimeDelta, Utc, Weekday};
 
@@ -41,44 +42,70 @@ pub const WEEKDAYS: [Weekday; 5] = [
 ];
 
 /// Converts seconds to nanoseconds (ns).
-#[unsafe(no_mangle)]
-pub extern "C" fn secs_to_nanos(secs: f64) -> u64 {
-    (secs * NANOSECONDS_IN_SECOND as f64) as u64
+///
+/// Casting f64 to u64 by truncating the fractional part is intentional for unit conversion,
+/// which may lose precision and drop negative values after clamping.
+#[allow(clippy::cast_possible_truncation, clippy::cast_sign_loss)]
+#[must_use]
+pub fn secs_to_nanos(secs: f64) -> u64 {
+    let nanos = secs * NANOSECONDS_IN_SECOND as f64;
+    nanos.max(0.0).trunc() as u64
 }
 
 /// Converts seconds to milliseconds (ms).
-#[unsafe(no_mangle)]
-pub extern "C" fn secs_to_millis(secs: f64) -> u64 {
-    (secs * MILLISECONDS_IN_SECOND as f64) as u64
+///
+/// Casting f64 to u64 by truncating the fractional part is intentional for unit conversion,
+/// which may lose precision and drop negative values after clamping.
+#[allow(clippy::cast_possible_truncation, clippy::cast_sign_loss)]
+#[must_use]
+pub fn secs_to_millis(secs: f64) -> u64 {
+    let millis = secs * MILLISECONDS_IN_SECOND as f64;
+    millis.max(0.0).trunc() as u64
 }
 
 /// Converts milliseconds (ms) to nanoseconds (ns).
-#[unsafe(no_mangle)]
-pub extern "C" fn millis_to_nanos(millis: f64) -> u64 {
-    (millis * NANOSECONDS_IN_MILLISECOND as f64) as u64
+///
+/// Casting f64 to u64 by truncating the fractional part is intentional for unit conversion,
+/// which may lose precision and drop negative values after clamping.
+#[allow(clippy::cast_possible_truncation, clippy::cast_sign_loss)]
+#[must_use]
+pub fn millis_to_nanos(millis: f64) -> u64 {
+    let nanos = millis * NANOSECONDS_IN_MILLISECOND as f64;
+    nanos.max(0.0).trunc() as u64
 }
 
 /// Converts microseconds (μs) to nanoseconds (ns).
-#[unsafe(no_mangle)]
-pub extern "C" fn micros_to_nanos(micros: f64) -> u64 {
-    (micros * NANOSECONDS_IN_MICROSECOND as f64) as u64
+///
+/// Casting f64 to u64 by truncating the fractional part is intentional for unit conversion,
+/// which may lose precision and drop negative values after clamping.
+#[allow(clippy::cast_possible_truncation, clippy::cast_sign_loss)]
+#[must_use]
+pub fn micros_to_nanos(micros: f64) -> u64 {
+    let nanos = micros * NANOSECONDS_IN_MICROSECOND as f64;
+    nanos.max(0.0).trunc() as u64
 }
 
 /// Converts nanoseconds (ns) to seconds.
-#[unsafe(no_mangle)]
-pub extern "C" fn nanos_to_secs(nanos: u64) -> f64 {
-    nanos as f64 / NANOSECONDS_IN_SECOND as f64
+///
+/// Casting u64 to f64 may lose precision for large values,
+/// but is acceptable when computing fractional seconds.
+#[allow(clippy::cast_precision_loss)]
+#[must_use]
+pub fn nanos_to_secs(nanos: u64) -> f64 {
+    let seconds = nanos / NANOSECONDS_IN_SECOND;
+    let rem_nanos = nanos % NANOSECONDS_IN_SECOND;
+    (seconds as f64) + (rem_nanos as f64) / (NANOSECONDS_IN_SECOND as f64)
 }
 
 /// Converts nanoseconds (ns) to milliseconds (ms).
-#[unsafe(no_mangle)]
-pub const extern "C" fn nanos_to_millis(nanos: u64) -> u64 {
+#[must_use]
+pub const fn nanos_to_millis(nanos: u64) -> u64 {
     nanos / NANOSECONDS_IN_MILLISECOND
 }
 
 /// Converts nanoseconds (ns) to microseconds (μs).
-#[unsafe(no_mangle)]
-pub const extern "C" fn nanos_to_micros(nanos: u64) -> u64 {
+#[must_use]
+pub const fn nanos_to_micros(nanos: u64) -> u64 {
     nanos / NANOSECONDS_IN_MICROSECOND
 }
 
@@ -90,6 +117,55 @@ pub fn unix_nanos_to_iso8601(unix_nanos: UnixNanos) -> String {
     datetime.to_rfc3339_opts(SecondsFormat::Nanos, true)
 }
 
+/// Converts an ISO 8601 (RFC 3339) format string to UNIX nanoseconds timestamp.
+///
+/// This function accepts various ISO 8601 formats including:
+/// - Full RFC 3339 with nanosecond precision: "2024-02-10T14:58:43.456789Z"
+/// - RFC 3339 without fractional seconds: "2024-02-10T14:58:43Z"
+/// - Simple date format: "2024-02-10" (interpreted as midnight UTC)
+///
+/// # Parameters
+///
+/// - `date_string`: The ISO 8601 formatted date string to parse
+///
+/// # Returns
+///
+/// Returns `Ok(UnixNanos)` if the string is successfully parsed, or an error if the format
+/// is invalid or the timestamp is out of range.
+///
+/// # Errors
+///
+/// Returns an error if:
+/// - The string format is not a valid ISO 8601 format
+/// - The timestamp is out of range for `UnixNanos`
+/// - The date/time values are invalid
+///
+/// # Examples
+///
+/// ```rust
+/// use nautilus_core::datetime::iso8601_to_unix_nanos;
+/// use nautilus_core::UnixNanos;
+///
+/// // Full RFC 3339 format
+/// let nanos = iso8601_to_unix_nanos("2024-02-10T14:58:43.456789Z".to_string())?;
+/// assert_eq!(nanos, UnixNanos::from(1_707_577_123_456_789_000));
+///
+/// // Without fractional seconds
+/// let nanos = iso8601_to_unix_nanos("2024-02-10T14:58:43Z".to_string())?;
+/// assert_eq!(nanos, UnixNanos::from(1_707_577_123_000_000_000));
+///
+/// // Simple date format (midnight UTC)
+/// let nanos = iso8601_to_unix_nanos("2024-02-10".to_string())?;
+/// assert_eq!(nanos, UnixNanos::from(1_707_523_200_000_000_000));
+/// # Ok::<(), anyhow::Error>(())
+/// ```
+#[inline]
+pub fn iso8601_to_unix_nanos(date_string: String) -> anyhow::Result<UnixNanos> {
+    date_string
+        .parse::<UnixNanos>()
+        .map_err(|e| anyhow::anyhow!("Failed to parse ISO 8601 string '{}': {}", date_string, e))
+}
+
 /// Converts a UNIX nanoseconds timestamp to an ISO 8601 (RFC 3339) format string
 /// with millisecond precision.
 #[inline]
@@ -129,12 +205,14 @@ pub fn last_weekday_nanos(year: i32, month: u32, day: u32) -> anyhow::Result<Uni
         .and_hms_nano_opt(0, 0, 0, 0)
         .ok_or_else(|| anyhow::anyhow!("Failed `and_hms_nano_opt`"))?;
 
-    Ok(UnixNanos::from(
-        unix_timestamp_ns
-            .and_utc()
-            .timestamp_nanos_opt()
-            .ok_or_else(|| anyhow::anyhow!("Failed `timestamp_nanos_opt`"))? as u64,
-    ))
+    // Convert timestamp nanos safely from i64 to u64
+    let raw_ns = unix_timestamp_ns
+        .and_utc()
+        .timestamp_nanos_opt()
+        .ok_or_else(|| anyhow::anyhow!("Failed `timestamp_nanos_opt`"))?;
+    let ns_u64 =
+        u64::try_from(raw_ns).map_err(|_| anyhow::anyhow!("Negative timestamp: {raw_ns}"))?;
+    Ok(UnixNanos::from(ns_u64))
 }
 
 /// Check whether the given UNIX nanoseconds timestamp is within the last 24 hours.
@@ -146,7 +224,10 @@ pub fn is_within_last_24_hours(timestamp_ns: UnixNanos) -> anyhow::Result<bool>
     let timestamp_ns = timestamp_ns.as_u64();
     let seconds = timestamp_ns / NANOSECONDS_IN_SECOND;
     let nanoseconds = (timestamp_ns % NANOSECONDS_IN_SECOND) as u32;
-    let timestamp = DateTime::from_timestamp(seconds as i64, nanoseconds)
+    // Convert seconds to i64 safely
+    let secs_i64 = i64::try_from(seconds)
+        .map_err(|_| anyhow::anyhow!("Timestamp seconds overflow: {seconds}"))?;
+    let timestamp = DateTime::from_timestamp(secs_i64, nanoseconds)
         .ok_or_else(|| anyhow::anyhow!("Invalid timestamp {timestamp_ns}"))?;
     let now = Utc::now();
 
@@ -154,47 +235,77 @@ pub fn is_within_last_24_hours(timestamp_ns: UnixNanos) -> anyhow::Result<bool>
 }
 
 /// Subtract `n` months from a chrono `DateTime<Utc>`.
-#[must_use]
-pub fn subtract_n_months(datetime: DateTime<Utc>, n: u32) -> DateTime<Utc> {
-    datetime
-        .checked_sub_months(chrono::Months::new(n))
-        .expect("Failed to subtract months")
+///
+/// # Errors
+///
+/// Returns an error if the resulting date would be invalid or out of range.
+pub fn subtract_n_months(datetime: DateTime<Utc>, n: u32) -> anyhow::Result<DateTime<Utc>> {
+    match datetime.checked_sub_months(chrono::Months::new(n)) {
+        Some(result) => Ok(result),
+        None => anyhow::bail!("Failed to subtract {n} months from {datetime}"),
+    }
 }
 
 /// Add `n` months to a chrono `DateTime<Utc>`.
-#[must_use]
-pub fn add_n_months(datetime: DateTime<Utc>, n: u32) -> DateTime<Utc> {
-    datetime
-        .checked_add_months(chrono::Months::new(n))
-        .expect("Failed to add months")
+///
+/// # Errors
+///
+/// Returns an error if the resulting date would be invalid or out of range.
+pub fn add_n_months(datetime: DateTime<Utc>, n: u32) -> anyhow::Result<DateTime<Utc>> {
+    match datetime.checked_add_months(chrono::Months::new(n)) {
+        Some(result) => Ok(result),
+        None => anyhow::bail!("Failed to add {n} months to {datetime}"),
+    }
 }
 
 /// Subtract `n` months from a given UNIX nanoseconds timestamp.
-#[must_use]
-pub fn subtract_n_months_nanos(unix_nanos: UnixNanos, n: u32) -> UnixNanos {
+///
+/// # Errors
+///
+/// Returns an error if the resulting timestamp is out of range or invalid.
+pub fn subtract_n_months_nanos(unix_nanos: UnixNanos, n: u32) -> anyhow::Result<UnixNanos> {
     let datetime = unix_nanos.to_datetime_utc();
-    (subtract_n_months(datetime, n)
-        .timestamp_nanos_opt()
-        .expect("Months should be within 584 years") as u64)
-        .into()
+    let result = subtract_n_months(datetime, n)?;
+    let timestamp = match result.timestamp_nanos_opt() {
+        Some(ts) => ts,
+        None => anyhow::bail!("Timestamp out of range after subtracting {n} months"),
+    };
+
+    if timestamp < 0 {
+        anyhow::bail!("Negative timestamp not allowed");
+    }
+
+    Ok(UnixNanos::from(timestamp as u64))
 }
 
 /// Add `n` months to a given UNIX nanoseconds timestamp.
-#[must_use]
-pub fn add_n_months_nanos(unix_nanos: UnixNanos, n: u32) -> UnixNanos {
-    let date = unix_nanos.to_datetime_utc();
-    (add_n_months(date, n)
-        .timestamp_nanos_opt()
-        .expect("Months should be within 584 years") as u64)
-        .into()
+///
+/// # Errors
+///
+/// Returns an error if the resulting timestamp is out of range or invalid.
+pub fn add_n_months_nanos(unix_nanos: UnixNanos, n: u32) -> anyhow::Result<UnixNanos> {
+    let datetime = unix_nanos.to_datetime_utc();
+    let result = add_n_months(datetime, n)?;
+    let timestamp = match result.timestamp_nanos_opt() {
+        Some(ts) => ts,
+        None => anyhow::bail!("Timestamp out of range after adding {n} months"),
+    };
+
+    if timestamp < 0 {
+        anyhow::bail!("Negative timestamp not allowed");
+    }
+
+    Ok(UnixNanos::from(timestamp as u64))
 }
 
 /// Returns the last valid day of `(year, month)`.
 #[must_use]
 pub const fn last_day_of_month(year: i32, month: u32) -> u32 {
-    // E.g., for February, check leap year logic
+    // Validate month range 1-12
+    assert!(month >= 1 && month <= 12, "`month` must be in 1..=12");
+
+    // February leap-year logic
     match month {
-        1 => 31,
         2 => {
             if is_leap_year(year) {
                 29
@@ -202,17 +313,8 @@ pub const fn last_day_of_month(year: i32, month: u32) -> u32 {
                 28
             }
         }
-        3 => 31,
-        4 => 30,
-        5 => 31,
-        6 => 30,
-        7 => 31,
-        8 => 31,
-        9 => 30,
-        10 => 31,
-        11 => 30,
-        12 => 31,
-        _ => 31, // fallback
+        4 | 6 | 9 | 11 => 30,
+        _ => 31, // January, March, May, July, August, October, December
     }
 }
 
@@ -226,6 +328,7 @@ pub const fn is_leap_year(year: i32) -> bool {
 // Tests
 ////////////////////////////////////////////////////////////////////////////////
 #[cfg(test)]
+#[allow(clippy::float_cmp)]
 mod tests {
     use chrono::{DateTime, TimeDelta, TimeZone, Utc};
     use rstest::rstest;
@@ -258,6 +361,12 @@ mod tests {
         assert_eq!(result, expected);
     }
 
+    #[rstest]
+    #[should_panic(expected = "`month` must be in 1..=12")]
+    fn test_last_day_of_month_invalid_month() {
+        let _ = last_day_of_month(2024, 0);
+    }
+
     #[rstest]
     #[case(0.0, 0)]
     #[case(1.0, 1_000_000)]
@@ -395,7 +504,7 @@ mod tests {
         #[case] months: u32,
         #[case] expected: DateTime<Utc>,
     ) {
-        let result = subtract_n_months(input, months);
+        let result = subtract_n_months(input, months).unwrap();
         assert_eq!(result, expected);
     }
 
@@ -409,7 +518,7 @@ mod tests {
         #[case] months: u32,
         #[case] expected: DateTime<Utc>,
     ) {
-        let result = add_n_months(input, months);
+        let result = add_n_months(input, months).unwrap();
         assert_eq!(result, expected);
     }
 
@@ -432,4 +541,36 @@ mod tests {
         let result = is_leap_year(year);
         assert_eq!(result, expected);
     }
+
+    #[rstest]
+    #[case("1970-01-01T00:00:00.000000000Z", 0)] // Unix epoch
+    #[case("1970-01-01T00:00:00.000000001Z", 1)] // 1 nanosecond
+    #[case("1970-01-01T00:00:00.001000000Z", 1_000_000)] // 1 millisecond
+    #[case("1970-01-01T00:00:01.000000000Z", 1_000_000_000)] // 1 second
+    #[case("2023-12-18T00:00:00.000000000Z", 1_702_857_600_000_000_000)] // Specific date
+    #[case("2024-02-10T14:58:43.456789Z", 1_707_577_123_456_789_000)] // RFC3339 with fractions
+    #[case("2024-02-10T14:58:43Z", 1_707_577_123_000_000_000)] // RFC3339 without fractions
+    #[case("2024-02-10", 1_707_523_200_000_000_000)] // Simple date format
+    fn test_iso8601_to_unix_nanos(#[case] input: &str, #[case] expected: u64) {
+        let result = iso8601_to_unix_nanos(input.to_string()).unwrap();
+        assert_eq!(result.as_u64(), expected);
+    }
+
+    #[rstest]
+    #[case("invalid-date")] // Invalid format
+    #[case("2024-02-30")] // Invalid date
+    #[case("2024-13-01")] // Invalid month
+    #[case("not a timestamp")] // Random string
+    fn test_iso8601_to_unix_nanos_invalid(#[case] input: &str) {
+        let result = iso8601_to_unix_nanos(input.to_string());
+        assert!(result.is_err());
+    }
+
+    #[rstest]
+    fn test_iso8601_roundtrip() {
+        let original_nanos = UnixNanos::from(1_707_577_123_456_789_000);
+        let iso8601_string = unix_nanos_to_iso8601(original_nanos);
+        let parsed_nanos = iso8601_to_unix_nanos(iso8601_string).unwrap();
+        assert_eq!(parsed_nanos, original_nanos);
+    }
 }
