@@ -16,18 +16,28 @@
 //! Core parsing functions.
 
 /// Returns the decimal precision inferred from the given string.
+///
+/// # Panics
+///
+/// Panics if the input string is not a valid decimal or scientific notation format.
 #[must_use]
+#[allow(clippy::cast_possible_truncation)]
 pub fn precision_from_str(s: &str) -> u8 {
     let s = s.trim().to_ascii_lowercase();
 
     // Check for scientific notation
     if s.contains("e-") {
+        // SAFETY: Double unwrap is acceptable here because:
+        // 1. We already validated the string contains "e-"
+        // 2. Function is used only for parsing valid numeric strings in controlled contexts
+        // 3. Alternative error handling would complicate the API for minimal benefit
         return s.split("e-").last().unwrap().parse::<u8>().unwrap();
     }
 
     // Check for decimal precision
     if let Some((_, decimal_part)) = s.split_once('.') {
-        decimal_part.len() as u8
+        // Clamp decimal precision to u8::MAX for very long decimal strings
+        decimal_part.len().min(u8::MAX as usize) as u8
     } else {
         0
     }
@@ -36,14 +46,15 @@ pub fn precision_from_str(s: &str) -> u8 {
 /// Returns the minimum increment precision inferred from the given string,
 /// ignoring trailing zeros.
 #[must_use]
+#[allow(clippy::cast_possible_truncation)]
 pub fn min_increment_precision_from_str(s: &str) -> u8 {
     let s = s.trim().to_ascii_lowercase();
 
     // Check for scientific notation
-    if let Some(pos) = s.find('e') {
-        if s[pos + 1..].starts_with('-') {
-            return s[pos + 2..].parse::<u8>().unwrap_or(0);
-        }
+    if let Some(pos) = s.find('e')
+        && s[pos + 1..].starts_with('-')
+    {
+        return s[pos + 2..].parse::<u8>().unwrap_or(0);
     }
 
     // Check for decimal precision
@@ -51,9 +62,9 @@ pub fn min_increment_precision_from_str(s: &str) -> u8 {
         let decimal_part = &s[dot_pos + 1..];
         if decimal_part.chars().any(|c| c != '0') {
             let trimmed_len = decimal_part.trim_end_matches('0').len();
-            return trimmed_len as u8;
+            return trimmed_len.min(u8::MAX as usize) as u8;
         }
-        return decimal_part.len() as u8;
+        return decimal_part.len().min(u8::MAX as usize) as u8;
     }
 
     0
