@@ -13,14 +13,27 @@
 //  limitations under the License.
 // -------------------------------------------------------------------------------------------------
 
+//! Cryptographic utilities and security functions for [NautilusTrader](http://nautilustrader.io).
+//!
+//! The *cryptography* crate provides essential cryptographic primitives and security utilities
+//! required for secure communication with trading venues and data providers. This includes
+//! digital signing, TLS configuration, and cryptographic provider management:
+//!
+//! - HMAC-based message authentication and signing.
+//! - Digital signatures using RSA and Ed25519 algorithms.
+//! - TLS client configuration with platform certificate verification.
+//! - Cryptographic provider management and initialization.
+//! - Secure encoding and decoding utilities.
+//!
+//! # Platform
+//!
 //! [NautilusTrader](http://nautilustrader.io) is an open-source, high-performance, production-grade
 //! algorithmic trading platform, providing quantitative traders with the ability to backtest
 //! portfolios of automated trading strategies on historical data with an event-driven engine,
 //! and also deploy those same strategies live, with no code changes.
 //!
-//! The platform is modularly designed to work with *adapters*, enabling connectivity to trading venues
-//! and data providers by translating their raw APIs into a unified interface and normalized domain
-//! model.
+//! NautilusTrader's design, architecture, and implementation philosophy prioritizes software correctness and safety at the
+//! highest level, with the aim of supporting mission-critical, trading system backtesting and live deployment workloads.
 //!
 //! # Feature flags
 //!
@@ -35,6 +48,8 @@
 #![deny(unsafe_code)]
 #![deny(nonstandard_style)]
 #![deny(missing_debug_implementations)]
+#![deny(clippy::missing_errors_doc)]
+#![deny(clippy::missing_panics_doc)]
 #![deny(rustdoc::broken_intra_doc_links)]
 
 pub mod providers;
