@@ -14,8 +14,11 @@
 // -------------------------------------------------------------------------------------------------
 
 //! Bar aggregation machinery.
+//!
+//! Defines the `BarAggregator` trait and core aggregation types (tick, volume, value, time),
+//! along with the `BarBuilder` and `BarAggregatorCore` helpers for constructing bars.
 
-use std::{cell::RefCell, ops::Add, rc::Rc};
+use std::{any::Any, cell::RefCell, fmt::Debug, ops::Add, rc::Rc};
 
 use chrono::TimeDelta;
 use nautilus_common::{
@@ -36,13 +39,18 @@ use nautilus_model::{
     types::{Price, Quantity, fixed::FIXED_SCALAR, quantity::QuantityRaw},
 };
 
-pub trait BarAggregator {
+/// Trait for aggregating incoming price and trade events into time-, tick-, volume-, or value-based bars.
+///
+/// Implementors receive updates and produce completed bars via handlers, with support for partial and batch updates.
+pub trait BarAggregator: Any + Debug {
     /// The [`BarType`] to be aggregated.
     fn bar_type(&self) -> BarType;
     /// If the aggregator is running and will receive data from the message bus.
     fn is_running(&self) -> bool;
     fn set_await_partial(&mut self, value: bool);
+    /// Enables or disables awaiting a partial bar before full aggregation.
     fn set_is_running(&mut self, value: bool);
+    /// Sets the running state of the aggregator (receiving updates when `true`).
     /// Updates the aggregator  with the given price and size.
     fn update(&mut self, price: Price, size: Quantity, ts_event: UnixNanos);
     /// Updates the aggregator with the given quote.
@@ -69,13 +77,32 @@ pub trait BarAggregator {
         }
     }
     fn update_bar(&mut self, bar: Bar, volume: Quantity, ts_init: UnixNanos);
+    /// Incorporates an existing bar and its volume into aggregation at the given init timestamp.
     fn start_batch_update(&mut self, handler: Box<dyn FnMut(Bar)>, time_ns: UnixNanos);
+    /// Starts batch mode, sending bars to the supplied handler for the given time context.
     fn stop_batch_update(&mut self);
+    /// Stops batch mode and restores the standard bar handler.
     fn await_partial(&self) -> bool;
+    /// Returns `true` if awaiting a partial bar before processing updates.
+    /// Sets the initial values for a partially completed bar.
     fn set_partial(&mut self, partial_bar: Bar);
+    /// Stop the aggregator, e.g., cancel timers. Default is no-op.
+    fn stop(&mut self) {}
+}
+
+impl dyn BarAggregator {
+    /// Returns a reference to this aggregator as `Any` for downcasting.
+    pub fn as_any(&self) -> &dyn Any {
+        self
+    }
+    /// Returns a mutable reference to this aggregator as `Any` for downcasting.
+    pub fn as_any_mut(&mut self) -> &mut dyn Any {
+        self
+    }
 }
 
 /// Provides a generic bar builder for aggregation.
+#[derive(Debug)]
 pub struct BarBuilder {
     bar_type: BarType,
     price_precision: u8,
@@ -97,14 +124,14 @@ impl BarBuilder {
     ///
     /// # Panics
     ///
-    /// This function panics:
-    /// - If `instrument.id` is not equal to the `bar_type.instrument_id`.
-    /// - If `bar_type.aggregation_source` is not equal to `AggregationSource::Internal`.
+    /// This function panics if:
+    /// - `instrument.id` is not equal to the `bar_type.instrument_id`.
+    /// - `bar_type.aggregation_source` is not equal to `AggregationSource::Internal`.
     #[must_use]
     pub fn new(bar_type: BarType, price_precision: u8, size_precision: u8) -> Self {
         correctness::check_equal(
-            bar_type.aggregation_source(),
-            AggregationSource::Internal,
+            &bar_type.aggregation_source(),
+            &AggregationSource::Internal,
             "bar_type.aggregation_source",
             "AggregationSource::Internal",
         )
@@ -128,6 +155,10 @@ impl BarBuilder {
     }
 
     /// Set the initial values for a partially completed bar.
+    ///
+    /// # Panics
+    ///
+    /// Panics if internal values for `high` or `low` are unexpectedly missing.
     pub fn set_partial(&mut self, partial_bar: Bar) {
         if self.partial_set {
             return; // Already updated
@@ -157,7 +188,11 @@ impl BarBuilder {
         self.initialized = true;
     }
 
-    /// Update the bar builder.
+    /// Updates the builder state with the given price, size, and event timestamp.
+    ///
+    /// # Panics
+    ///
+    /// Panics if `high` or `low` values are unexpectedly `None` when updating.
     pub fn update(&mut self, price: Price, size: Quantity, ts_event: UnixNanos) {
         if ts_event < self.ts_last {
             return; // Not applicable
@@ -183,6 +218,11 @@ impl BarBuilder {
         self.ts_last = ts_event;
     }
 
+    /// Updates the builder state with a completed bar, its volume, and the bar init timestamp.
+    ///
+    /// # Panics
+    ///
+    /// Panics if `high` or `low` values are unexpectedly `None` when updating.
     pub fn update_bar(&mut self, bar: Bar, volume: Quantity, ts_init: UnixNanos) {
         if ts_init < self.ts_last {
             return; // Not applicable
@@ -224,7 +264,11 @@ impl BarBuilder {
         self.build(self.ts_last, self.ts_last)
     }
 
-    /// Return the aggregated bar with the given closing timestamp, and reset.
+    /// Returns the aggregated bar for the given timestamps, then resets the builder.
+    ///
+    /// # Panics
+    ///
+    /// Panics if `open`, `high`, `low`, or `close` values are `None` when building the bar.
     pub fn build(&mut self, ts_event: UnixNanos, ts_init: UnixNanos) -> Bar {
         if self.open.is_none() {
             self.open = self.last_close;
@@ -233,16 +277,16 @@ impl BarBuilder {
             self.close = self.last_close;
         }
 
-        if let (Some(close), Some(low)) = (self.close, self.low) {
-            if close < low {
-                self.low = Some(close);
-            }
+        if let (Some(close), Some(low)) = (self.close, self.low)
+            && close < low
+        {
+            self.low = Some(close);
         }
 
-        if let (Some(close), Some(high)) = (self.close, self.high) {
-            if close > high {
-                self.high = Some(close);
-            }
+        if let (Some(close), Some(high)) = (self.close, self.high)
+            && close > high
+        {
+            self.high = Some(close);
         }
 
         // SAFETY: The open was checked, so we can assume all prices are Some
@@ -278,6 +322,18 @@ where
     batch_mode: bool,
 }
 
+impl<H: FnMut(Bar)> Debug for BarAggregatorCore<H> {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct(stringify!(BarAggregatorCore))
+            .field("bar_type", &self.bar_type)
+            .field("builder", &self.builder)
+            .field("await_partial", &self.await_partial)
+            .field("is_running", &self.is_running)
+            .field("batch_mode", &self.batch_mode)
+            .finish()
+    }
+}
+
 impl<H> BarAggregatorCore<H>
 where
     H: FnMut(Bar),
@@ -286,9 +342,9 @@ where
     ///
     /// # Panics
     ///
-    /// This function panics:
-    /// - If `instrument.id` is not equal to the `bar_type.instrument_id`.
-    /// - If `bar_type.aggregation_source` is not equal to `AggregationSource::Internal`.
+    /// This function panics if:
+    /// - `instrument.id` is not equal to the `bar_type.instrument_id`.
+    /// - `bar_type.aggregation_source` is not equal to `AggregationSource::Internal`.
     pub fn new(
         bar_type: BarType,
         price_precision: u8,
@@ -308,19 +364,22 @@ where
         }
     }
 
+    /// Sets whether to await a partial bar before processing new updates.
     pub const fn set_await_partial(&mut self, value: bool) {
         self.await_partial = value;
     }
 
+    /// Sets the running state of the aggregator (receives updates when `true`).
     pub const fn set_is_running(&mut self, value: bool) {
         self.is_running = value;
     }
 
+    /// Returns `true` if the aggregator is awaiting a partial bar to complete before aggregation.
     pub const fn await_partial(&self) -> bool {
         self.await_partial
     }
 
-    /// Set the initial values for a partially completed bar.
+    /// Initializes builder state with a partially completed bar.
     pub fn set_partial(&mut self, partial_bar: Bar) {
         self.builder.set_partial(partial_bar);
     }
@@ -346,11 +405,13 @@ where
         }
     }
 
+    /// Enables batch update mode, sending bars to the provided handler instead of immediate dispatch.
     pub fn start_batch_update(&mut self, handler: Box<dyn FnMut(Bar)>) {
         self.batch_mode = true;
         self.batch_handler = Some(handler);
     }
 
+    /// Disables batch update mode and restores the original bar handler.
     pub fn stop_batch_update(&mut self) {
         self.batch_mode = false;
 
@@ -372,6 +433,15 @@ where
     cum_value: f64,
 }
 
+impl<H: FnMut(Bar)> Debug for TickBarAggregator<H> {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct(stringify!(TickBarAggregator))
+            .field("core", &self.core)
+            .field("cum_value", &self.cum_value)
+            .finish()
+    }
+}
+
 impl<H> TickBarAggregator<H>
 where
     H: FnMut(Bar),
@@ -380,9 +450,9 @@ where
     ///
     /// # Panics
     ///
-    /// This function panics:
-    /// - If `instrument.id` is not equal to the `bar_type.instrument_id`.
-    /// - If `bar_type.aggregation_source` is not equal to `AggregationSource::Internal`.
+    /// This function panics if:
+    /// - `instrument.id` is not equal to the `bar_type.instrument_id`.
+    /// - `bar_type.aggregation_source` is not equal to `AggregationSource::Internal`.
     pub fn new(
         bar_type: BarType,
         price_precision: u8,
@@ -405,7 +475,7 @@ where
 
 impl<H> BarAggregator for TickBarAggregator<H>
 where
-    H: FnMut(Bar),
+    H: FnMut(Bar) + 'static,
 {
     fn bar_type(&self) -> BarType {
         self.core.bar_type
@@ -490,6 +560,14 @@ where
     core: BarAggregatorCore<H>,
 }
 
+impl<H: FnMut(Bar)> Debug for VolumeBarAggregator<H> {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct(stringify!(VolumeBarAggregator))
+            .field("core", &self.core)
+            .finish()
+    }
+}
+
 impl<H> VolumeBarAggregator<H>
 where
     H: FnMut(Bar),
@@ -498,9 +576,9 @@ where
     ///
     /// # Panics
     ///
-    /// This function panics:
-    /// - If `instrument.id` is not equal to the `bar_type.instrument_id`.
-    /// - If `bar_type.aggregation_source` is not equal to `AggregationSource::Internal`.
+    /// This function panics if:
+    /// - `instrument.id` is not equal to the `bar_type.instrument_id`.
+    /// - `bar_type.aggregation_source` is not equal to `AggregationSource::Internal`.
     pub fn new(
         bar_type: BarType,
         price_precision: u8,
@@ -522,7 +600,7 @@ where
 
 impl<H> BarAggregator for VolumeBarAggregator<H>
 where
-    H: FnMut(Bar),
+    H: FnMut(Bar) + 'static,
 {
     fn bar_type(&self) -> BarType {
         self.core.bar_type
@@ -624,6 +702,15 @@ where
     cum_value: f64,
 }
 
+impl<H: FnMut(Bar)> Debug for ValueBarAggregator<H> {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct(stringify!(ValueBarAggregator))
+            .field("core", &self.core)
+            .field("cum_value", &self.cum_value)
+            .finish()
+    }
+}
+
 impl<H> ValueBarAggregator<H>
 where
     H: FnMut(Bar),
@@ -632,9 +719,9 @@ where
     ///
     /// # Panics
     ///
-    /// This function panics:
-    /// - If `instrument.id` is not equal to the `bar_type.instrument_id`.
-    /// - If `bar_type.aggregation_source` is not equal to `AggregationSource::Internal`.
+    /// This function panics if:
+    /// - `instrument.id` is not equal to the `bar_type.instrument_id`.
+    /// - `bar_type.aggregation_source` is not equal to `AggregationSource::Internal`.
     pub fn new(
         bar_type: BarType,
         price_precision: u8,
@@ -663,7 +750,7 @@ where
 
 impl<H> BarAggregator for ValueBarAggregator<H>
 where
-    H: FnMut(Bar),
+    H: FnMut(Bar) + 'static,
 {
     fn bar_type(&self) -> BarType {
         self.core.bar_type
@@ -773,20 +860,42 @@ where
     timer_name: String,
     interval_ns: UnixNanos,
     next_close_ns: UnixNanos,
-    composite_bar_build_delay: i64,
-    add_delay: bool,
+    bar_build_delay: u64,
     batch_open_ns: UnixNanos,
     batch_next_close_ns: UnixNanos,
-    time_bars_origin: Option<TimeDelta>,
+    time_bars_origin_offset: Option<TimeDelta>,
     skip_first_non_full_bar: bool,
 }
 
-#[derive(Clone)]
+impl<H: FnMut(Bar)> Debug for TimeBarAggregator<H> {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct(stringify!(TimeBarAggregator))
+            .field("core", &self.core)
+            .field("build_with_no_updates", &self.build_with_no_updates)
+            .field("timestamp_on_close", &self.timestamp_on_close)
+            .field("is_left_open", &self.is_left_open)
+            .field("timer_name", &self.timer_name)
+            .field("interval_ns", &self.interval_ns)
+            .field("bar_build_delay", &self.bar_build_delay)
+            .field("skip_first_non_full_bar", &self.skip_first_non_full_bar)
+            .finish()
+    }
+}
+
+#[derive(Clone, Debug)]
+/// Callback wrapper for time-based bar aggregation events.
+///
+/// This struct provides a bridge between timer events and time bar aggregation,
+/// allowing bars to be automatically built and emitted at regular time intervals.
+/// It holds a reference to a `TimeBarAggregator` and triggers bar creation when
+/// timer events occur.
 pub struct NewBarCallback<H: FnMut(Bar)> {
     aggregator: Rc<RefCell<TimeBarAggregator<H>>>,
 }
 
 impl<H: FnMut(Bar)> NewBarCallback<H> {
+    /// Creates a new callback that invokes the time bar aggregator on timer events.
+    #[must_use]
     pub const fn new(aggregator: Rc<RefCell<TimeBarAggregator<H>>>) -> Self {
         Self { aggregator }
     }
@@ -808,9 +917,9 @@ where
     ///
     /// # Panics
     ///
-    /// This function panics:
-    /// - If `instrument.id` is not equal to the `bar_type.instrument_id`.
-    /// - If `bar_type.aggregation_source` is not equal to `AggregationSource::Internal`.
+    /// This function panics if:
+    /// - `instrument.id` is not equal to the `bar_type.instrument_id`.
+    /// - `bar_type.aggregation_source` is not equal to `AggregationSource::Internal`.
     #[allow(clippy::too_many_arguments)]
     pub fn new(
         bar_type: BarType,
@@ -822,8 +931,8 @@ where
         build_with_no_updates: bool,
         timestamp_on_close: bool,
         interval_type: BarIntervalType,
-        time_bars_origin: Option<TimeDelta>,
-        composite_bar_build_delay: i64,
+        time_bars_origin_offset: Option<TimeDelta>,
+        bar_build_delay: u64,
         skip_first_non_full_bar: bool,
     ) -> Self {
         let is_left_open = match interval_type {
@@ -831,9 +940,6 @@ where
             BarIntervalType::RightOpen => false,
         };
 
-        let add_delay = bar_type.is_composite()
-            && bar_type.composite().aggregation_source() == AggregationSource::Internal;
-
         let core = BarAggregatorCore::new(
             bar_type.standard(),
             price_precision,
@@ -854,34 +960,40 @@ where
             timer_name: bar_type.to_string(),
             interval_ns: get_bar_interval_ns(&bar_type),
             next_close_ns: UnixNanos::default(),
-            composite_bar_build_delay,
-            add_delay,
+            bar_build_delay,
             batch_open_ns: UnixNanos::default(),
             batch_next_close_ns: UnixNanos::default(),
-            time_bars_origin,
+            time_bars_origin_offset,
             skip_first_non_full_bar,
         }
     }
 
-    /// Starts the time bar aggregator.
+    /// Starts the time bar aggregator, scheduling periodic bar builds on the clock.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if setting up the underlying clock timer fails.
+    ///
+    /// # Panics
+    ///
+    /// Panics if the underlying clock timer registration fails.
     pub fn start(&mut self, callback: NewBarCallback<H>) -> anyhow::Result<()> {
         let now = self.clock.borrow().utc_now();
-        let mut start_time = get_time_bar_start(now, &self.bar_type(), self.time_bars_origin);
+        let mut start_time =
+            get_time_bar_start(now, &self.bar_type(), self.time_bars_origin_offset);
 
         if start_time == now {
             self.skip_first_non_full_bar = false;
         }
 
-        if self.add_delay {
-            start_time += TimeDelta::microseconds(self.composite_bar_build_delay);
-        }
+        start_time += TimeDelta::microseconds(self.bar_build_delay as i64);
 
         let spec = &self.bar_type().spec();
         let start_time_ns = UnixNanos::from(start_time);
 
         if spec.aggregation == BarAggregation::Month {
             let step = spec.step.get() as u32;
-            let alert_time_ns = add_n_months_nanos(start_time_ns, step);
+            let alert_time_ns = add_n_months_nanos(start_time_ns, step).expect(FAILED);
 
             self.clock
                 .borrow_mut()
@@ -893,10 +1005,11 @@ where
                 .set_timer_ns(
                     &self.timer_name,
                     self.interval_ns.as_u64(),
-                    start_time_ns,
+                    Some(start_time_ns),
                     None,
                     Some(callback.into()),
                     None,
+                    None,
                 )
                 .expect(FAILED);
         }
@@ -910,22 +1023,28 @@ where
         self.clock.borrow_mut().cancel_timer(&self.timer_name);
     }
 
+    /// Starts batch time for bar aggregation.
+    ///
+    /// # Panics
+    ///
+    /// Panics if month arithmetic operations fail for monthly aggregation intervals.
     pub fn start_batch_time(&mut self, time_ns: UnixNanos) {
         let spec = self.bar_type().spec();
         self.core.batch_mode = true;
 
         let time = time_ns.to_datetime_utc();
-        let start_time = get_time_bar_start(time, &self.bar_type(), self.time_bars_origin);
+        let start_time = get_time_bar_start(time, &self.bar_type(), self.time_bars_origin_offset);
         self.batch_open_ns = UnixNanos::from(start_time);
 
         if spec.aggregation == BarAggregation::Month {
             let step = spec.step.get() as u32;
 
             if self.batch_open_ns == time_ns {
-                self.batch_open_ns = subtract_n_months_nanos(self.batch_open_ns, step);
+                self.batch_open_ns =
+                    subtract_n_months_nanos(self.batch_open_ns, step).expect(FAILED);
             }
 
-            self.batch_next_close_ns = add_n_months_nanos(self.batch_open_ns, step);
+            self.batch_next_close_ns = add_n_months_nanos(self.batch_open_ns, step).expect(FAILED);
         } else {
             if self.batch_open_ns == time_ns {
                 self.batch_open_ns -= self.interval_ns;
@@ -980,10 +1099,12 @@ where
             // Ensure batch times are coherent with last builder update
             if self.bar_type().spec().aggregation == BarAggregation::Month {
                 while self.batch_next_close_ns < time_ns {
-                    self.batch_next_close_ns = add_n_months_nanos(self.batch_next_close_ns, step);
+                    self.batch_next_close_ns =
+                        add_n_months_nanos(self.batch_next_close_ns, step).expect(FAILED);
                 }
 
-                self.batch_open_ns = subtract_n_months_nanos(self.batch_next_close_ns, step);
+                self.batch_open_ns =
+                    subtract_n_months_nanos(self.batch_next_close_ns, step).expect(FAILED);
             } else {
                 while self.batch_next_close_ns < time_ns {
                     self.batch_next_close_ns += self.interval_ns;
@@ -999,7 +1120,8 @@ where
             self.batch_open_ns = self.batch_next_close_ns;
 
             if self.bar_type().spec().aggregation == BarAggregation::Month {
-                self.batch_next_close_ns = add_n_months_nanos(self.batch_next_close_ns, step);
+                self.batch_next_close_ns =
+                    add_n_months_nanos(self.batch_next_close_ns, step).expect(FAILED);
             } else {
                 self.batch_next_close_ns += self.interval_ns;
             }
@@ -1030,7 +1152,7 @@ where
 
         if self.bar_type().spec().aggregation == BarAggregation::Month {
             let step = self.bar_type().spec().step.get() as u32;
-            let next_alert_ns = add_n_months_nanos(ts_init, step);
+            let next_alert_ns = add_n_months_nanos(ts_init, step).expect(FAILED);
 
             self.clock
                 .borrow_mut()
@@ -1039,7 +1161,11 @@ where
 
             self.next_close_ns = next_alert_ns;
         } else {
-            self.next_close_ns = self.clock.borrow().next_time_ns(&self.timer_name);
+            self.next_close_ns = self
+                .clock
+                .borrow()
+                .next_time_ns(&self.timer_name)
+                .unwrap_or_default();
         }
     }
 }
@@ -1067,6 +1193,10 @@ where
     fn await_partial(&self) -> bool {
         self.core.await_partial()
     }
+    /// Stop time-based aggregator by cancelling its timer.
+    fn stop(&mut self) {
+        Self::stop(self);
+    }
 
     fn update(&mut self, price: Price, size: Quantity, ts_event: UnixNanos) {
         if self.batch_next_close_ns != UnixNanos::default() {
@@ -1817,8 +1947,8 @@ mod tests {
             true,  // build_with_no_updates
             false, // timestamp_on_close
             BarIntervalType::LeftOpen,
-            None,  // time_bars_origin
-            15,    // composite_bar_build_delay
+            None,  // time_bars_origin_offset
+            15,    // bar_build_delay
             false, // skip_first_non_full_bar
         );
 
