@@ -13,11 +13,29 @@
 //  limitations under the License.
 // -------------------------------------------------------------------------------------------------
 
+//! Data engine and market data processing for [NautilusTrader](http://nautilustrader.io).
+//!
+//! The *data* crate provides a comprehensive framework for handling market data ingestion,
+//! processing, and aggregation within the NautilusTrader ecosystem. This includes real-time
+//! data streaming, historical data management, and various aggregation methodologies:
+//!
+//! - High-performance data engine for orchestrating data operations.
+//! - Data client infrastructure for connecting to market data providers.
+//! - Bar aggregation machinery supporting tick, volume, value, and time-based aggregation.
+//! - Order book management and delta processing capabilities.
+//! - Subscription management and data request handling.
+//! - Configurable data routing and processing pipelines.
+//!
+//! # Platform
+//!
 //! [NautilusTrader](http://nautilustrader.io) is an open-source, high-performance, production-grade
 //! algorithmic trading platform, providing quantitative traders with the ability to backtest
 //! portfolios of automated trading strategies on historical data with an event-driven engine,
 //! and also deploy those same strategies live, with no code changes.
 //!
+//! NautilusTrader's design, architecture, and implementation philosophy prioritizes software correctness and safety at the
+//! highest level, with the aim of supporting mission-critical, trading system backtesting and live deployment workloads.
+//!
 //! # Feature flags
 //!
 //! This crate provides feature flags to control source code inclusion during compilation,
@@ -27,17 +45,20 @@
 //!
 //! - `ffi`: Enables the C foreign function interface (FFI) from [cbindgen](https://github.com/mozilla/cbindgen).
 //! - `python`: Enables Python bindings from [PyO3](https://pyo3.rs).
+//! - `high-precision`: Enables [high-precision mode](https://nautilustrader.io/docs/nightly/getting_started/installation#precision-mode) to use 128-bit value types.
+//! - `defi`: Enables DeFi (Decentralized Finance) support.
 
 #![warn(rustc::all)]
 #![deny(unsafe_code)]
 #![deny(nonstandard_style)]
+#![deny(missing_debug_implementations)]
+#![deny(clippy::missing_errors_doc)]
+#![deny(clippy::missing_panics_doc)]
 #![deny(rustdoc::broken_intra_doc_links)]
-// #![deny(clippy::missing_errors_doc)]
-
-// Uncomment once we've added trivial debug impls everywhere
-// #![deny(missing_debug_implementations)]
 
 pub mod aggregation;
 pub mod client;
 pub mod engine;
-pub mod mocks;
+
+// Re-exports
+pub use client::{DataClient, DataClientAdapter};
