@@ -19,13 +19,9 @@
 #![allow(dead_code)]
 #![allow(unused_variables)]
 
-use std::{any::Any, cell::RefCell, rc::Rc};
+use std::{any::Any, cell::RefCell, fmt::Debug, rc::Rc};
 
-use nautilus_common::{
-    cache::Cache,
-    clock::Clock,
-    msgbus::{self},
-};
+use nautilus_common::{cache::Cache, clock::Clock, msgbus};
 use nautilus_core::{UUID4, UnixNanos};
 use nautilus_model::{
     accounts::AccountAny,
@@ -39,15 +35,16 @@ use nautilus_model::{
         AccountId, ClientId, ClientOrderId, InstrumentId, PositionId, StrategyId, TradeId,
         TraderId, Venue, VenueOrderId,
     },
+    reports::{ExecutionMassStatus, FillReport, OrderStatusReport, PositionStatusReport},
     types::{AccountBalance, Currency, MarginBalance, Money, Price, Quantity},
 };
-use ustr::Ustr;
-
-use crate::reports::{
-    fill::FillReport, mass_status::ExecutionMassStatus, order::OrderStatusReport,
-    position::PositionStatusReport,
-};
 
+/// Base implementation for execution clients providing common functionality.
+///
+/// This struct provides the foundation for all execution clients, handling
+/// account state generation, order event creation, and message routing.
+/// Execution clients can inherit this base functionality and extend it
+/// with venue-specific implementations.
 pub struct BaseExecutionClient {
     pub trader_id: TraderId,
     pub client_id: ClientId,
@@ -61,7 +58,16 @@ pub struct BaseExecutionClient {
     cache: Rc<RefCell<Cache>>,
 }
 
+impl Debug for BaseExecutionClient {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct(stringify!(BaseExecutionClient))
+            .field("client_id", &self.client_id)
+            .finish()
+    }
+}
+
 impl BaseExecutionClient {
+    /// Creates a new [`BaseExecutionClient`] instance.
     #[allow(clippy::too_many_arguments)]
     pub const fn new(
         trader_id: TraderId,
@@ -88,19 +94,27 @@ impl BaseExecutionClient {
         }
     }
 
+    /// Sets the connection status of the execution client.
     pub const fn set_connected(&mut self, is_connected: bool) {
         self.is_connected = is_connected;
     }
 
+    /// Sets the account identifier for the execution client.
     pub const fn set_account_id(&mut self, account_id: AccountId) {
         self.account_id = account_id;
     }
 
     #[must_use]
+    /// Returns the account associated with this execution client.
     pub fn get_account(&self) -> Option<AccountAny> {
         self.cache.borrow().account(&self.account_id).cloned()
     }
 
+    /// Generates and publishes the account state event.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if constructing or sending the account state fails.
     pub fn generate_account_state(
         &self,
         balances: Vec<AccountBalance>,
@@ -256,12 +270,12 @@ impl BaseExecutionClient {
         if !venue_order_id_modified {
             let cache = self.cache.as_ref().borrow();
             let existing_order_result = cache.venue_order_id(&client_order_id);
-            if let Some(existing_order) = existing_order_result {
-                if *existing_order != venue_order_id {
-                    log::error!(
-                        "Existing venue order id {existing_order} does not match provided venue order id {venue_order_id}"
-                    );
-                }
+            if let Some(existing_order) = existing_order_result
+                && *existing_order != venue_order_id
+            {
+                log::error!(
+                    "Existing venue order id {existing_order} does not match provided venue order id {venue_order_id}"
+                );
             }
         }
 
@@ -400,32 +414,32 @@ impl BaseExecutionClient {
     }
 
     fn send_account_state(&self, account_state: AccountState) {
-        let endpoint = Ustr::from("Portfolio.update_account");
-        msgbus::send(&endpoint, &account_state as &dyn Any);
+        let endpoint = "Portfolio.update_account".into();
+        msgbus::send_any(endpoint, &account_state as &dyn Any);
     }
 
     fn send_order_event(&self, event: OrderEventAny) {
-        let endpoint = Ustr::from("ExecEngine.process");
-        msgbus::send(&endpoint, &event as &dyn Any);
+        let endpoint = "ExecEngine.process".into();
+        msgbus::send_any(endpoint, &event as &dyn Any);
     }
 
     fn send_mass_status_report(&self, report: ExecutionMassStatus) {
-        let endpoint = Ustr::from("ExecEngine.reconcile_mass_status");
-        msgbus::send(&endpoint, &report as &dyn Any);
+        let endpoint = "ExecEngine.reconcile_mass_status".into();
+        msgbus::send_any(endpoint, &report as &dyn Any);
     }
 
     fn send_order_status_report(&self, report: OrderStatusReport) {
-        let endpoint = Ustr::from("ExecEngine.reconcile_report");
-        msgbus::send(&endpoint, &report as &dyn Any);
+        let endpoint = "ExecEngine.reconcile_report".into();
+        msgbus::send_any(endpoint, &report as &dyn Any);
     }
 
     fn send_fill_report(&self, report: FillReport) {
-        let endpoint = Ustr::from("ExecEngine.reconcile_report");
-        msgbus::send(&endpoint, &report as &dyn Any);
+        let endpoint = "ExecEngine.reconcile_report".into();
+        msgbus::send_any(endpoint, &report as &dyn Any);
     }
 
     fn send_position_report(&self, report: PositionStatusReport) {
-        let endpoint = Ustr::from("ExecEngine.reconcile_report");
-        msgbus::send(&endpoint, &report as &dyn Any);
+        let endpoint = "ExecEngine.reconcile_report".into();
+        msgbus::send_any(endpoint, &report as &dyn Any);
     }
 }
