@@ -25,6 +25,7 @@ pub mod config;
 use std::{
     cell::{RefCell, RefMut},
     collections::{HashMap, HashSet},
+    fmt::Debug,
     rc::Rc,
     time::SystemTime,
 };
@@ -35,6 +36,10 @@ use nautilus_common::{
     clock::Clock,
     generators::position_id::PositionIdGenerator,
     logging::{CMD, EVT, RECV},
+    messages::execution::{
+        BatchCancelOrders, CancelAllOrders, CancelOrder, ModifyOrder, QueryOrder, SubmitOrder,
+        SubmitOrderList, TradingCommand,
+    },
     msgbus::{
         self, get_message_bus,
         switchboard::{self},
@@ -55,14 +60,14 @@ use nautilus_model::{
     types::{Money, Price, Quantity},
 };
 
-use crate::{
-    client::ExecutionClient,
-    messages::{
-        BatchCancelOrders, CancelAllOrders, CancelOrder, ModifyOrder, QueryOrder, SubmitOrder,
-        SubmitOrderList, TradingCommand,
-    },
-};
+use crate::client::ExecutionClient;
 
+/// Central execution engine responsible for orchestrating order routing and execution.
+///
+/// The execution engine manages the entire order lifecycle from submission to completion,
+/// handling routing to appropriate execution clients, position management, and event
+/// processing. It supports multiple execution venues through registered clients and
+/// provides sophisticated order management capabilities.
 pub struct ExecutionEngine {
     clock: Rc<RefCell<dyn Clock>>,
     cache: Rc<RefCell<Cache>>,
@@ -75,7 +80,16 @@ pub struct ExecutionEngine {
     config: ExecutionEngineConfig,
 }
 
+impl Debug for ExecutionEngine {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct(stringify!(ExecutionEngine))
+            .field("client_count", &self.clients.len())
+            .finish()
+    }
+}
+
 impl ExecutionEngine {
+    /// Creates a new [`ExecutionEngine`] instance.
     pub fn new(
         clock: Rc<RefCell<dyn Clock>>,
         cache: Rc<RefCell<Cache>>,
@@ -96,37 +110,48 @@ impl ExecutionEngine {
     }
 
     #[must_use]
+    /// Returns the position ID count for the specified strategy.
     pub fn position_id_count(&self, strategy_id: StrategyId) -> usize {
         self.pos_id_generator.count(strategy_id)
     }
 
     #[must_use]
+    /// Checks the integrity of cached execution data.
     pub fn check_integrity(&self) -> bool {
         self.cache.borrow_mut().check_integrity()
     }
 
     #[must_use]
+    /// Returns true if all registered execution clients are connected.
     pub fn check_connected(&self) -> bool {
         self.clients.values().all(|c| c.is_connected())
     }
 
     #[must_use]
+    /// Returns true if all registered execution clients are disconnected.
     pub fn check_disconnected(&self) -> bool {
         self.clients.values().all(|c| !c.is_connected())
     }
 
     #[must_use]
+    /// Checks for residual positions and orders in the cache.
     pub fn check_residuals(&self) -> bool {
         self.cache.borrow().check_residuals()
     }
 
     #[must_use]
+    /// Returns the set of instruments that have external order claims.
     pub fn get_external_order_claims_instruments(&self) -> HashSet<InstrumentId> {
         self.external_order_claims.keys().copied().collect()
     }
 
     // -- REGISTRATION ----------------------------------------------------------------------------
 
+    /// Registers a new execution client.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if a client with the same ID is already registered.
     pub fn register_client(&mut self, client: Rc<dyn ExecutionClient>) -> anyhow::Result<()> {
         if self.clients.contains_key(&client.client_id()) {
             anyhow::bail!("Client already registered with ID {}", client.client_id());
@@ -140,16 +165,23 @@ impl ExecutionEngine {
         Ok(())
     }
 
+    /// Registers a default execution client for fallback routing.
     pub fn register_default_client(&mut self, client: Rc<dyn ExecutionClient>) {
         log::info!("Registered default client {}", client.client_id());
         self.default_client = Some(client);
     }
 
     #[must_use]
+    /// Returns the execution client registered with the given ID.
     pub fn get_client(&self, client_id: &ClientId) -> Option<Rc<dyn ExecutionClient>> {
         self.clients.get(client_id).cloned()
     }
 
+    /// Sets routing for a specific venue to a given client ID.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the client ID is not registered.
     pub fn register_venue_routing(
         &mut self,
         client_id: ClientId,
@@ -169,6 +201,9 @@ impl ExecutionEngine {
     //     todo!();
     // }
 
+    /// # Errors
+    ///
+    /// Returns an error if no client is registered with the given ID.
     pub fn deregister_client(&mut self, client_id: ClientId) -> anyhow::Result<()> {
         if self.clients.remove(&client_id).is_some() {
             // Remove from routing map if present
@@ -184,6 +219,11 @@ impl ExecutionEngine {
     // -- COMMANDS --------------------------------------------------------------------------------
 
     #[allow(clippy::await_holding_refcell_ref)]
+    /// Loads persistent state into cache and rebuilds indices.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if any cache operation fails.
     pub async fn load_cache(&mut self) -> anyhow::Result<()> {
         let ts = SystemTime::now();
 
@@ -219,21 +259,24 @@ impl ExecutionEngine {
         Ok(())
     }
 
+    /// Flushes the database to persist all cached data.
     pub fn flush_db(&self) {
         self.cache.borrow_mut().flush_db();
     }
 
+    /// Processes an order event, updating internal state and routing as needed.
     pub fn process(&mut self, event: &OrderEventAny) {
         self.handle_event(event);
     }
 
-    pub fn execute(&self, command: TradingCommand) {
+    /// Executes a trading command by routing it to the appropriate execution client.
+    pub fn execute(&self, command: &TradingCommand) {
         self.execute_command(command);
     }
 
     // -- COMMAND HANDLERS ------------------------------------------------------------------------
 
-    fn execute_command(&self, command: TradingCommand) {
+    fn execute_command(&self, command: &TradingCommand) {
         if self.config.debug {
             log::debug!("{RECV}{CMD} {command:?}");
         }
@@ -269,8 +312,8 @@ impl ExecutionEngine {
         }
     }
 
-    fn handle_submit_order(&self, client: Rc<dyn ExecutionClient>, command: SubmitOrder) {
-        let mut order = command.order.clone();
+    fn handle_submit_order(&self, client: Rc<dyn ExecutionClient>, cmd: &SubmitOrder) {
+        let mut order = cmd.order.clone();
         let client_order_id = order.client_order_id();
         let instrument_id = order.instrument_id();
 
@@ -279,12 +322,9 @@ impl ExecutionEngine {
             // Add order to cache in a separate scope to drop the mutable borrow
             {
                 let mut cache = self.cache.borrow_mut();
-                if let Err(e) = cache.add_order(
-                    order.clone(),
-                    command.position_id,
-                    Some(command.client_id),
-                    true,
-                ) {
+                if let Err(e) =
+                    cache.add_order(order.clone(), cmd.position_id, Some(cmd.client_id), true)
+                {
                     log::error!("Error adding order to cache: {e}");
                     return;
                 }
@@ -302,7 +342,7 @@ impl ExecutionEngine {
                 instrument.clone()
             } else {
                 log::error!(
-                    "Cannot handle submit order: no instrument found for {instrument_id}, {command}",
+                    "Cannot handle submit order: no instrument found for {instrument_id}, {cmd}",
                 );
                 return;
             }
@@ -330,33 +370,25 @@ impl ExecutionEngine {
         }
 
         // Send the order to the execution client
-        // TODO: Avoid this clone
-        if let Err(e) = client.submit_order(command.clone()) {
+        if let Err(e) = client.submit_order(cmd) {
             log::error!("Error submitting order to client: {e}");
             self.deny_order(
-                &command.order,
+                &cmd.order,
                 &format!("failed-to-submit-order-to-client: {e}"),
             );
         }
     }
 
-    fn handle_submit_order_list(
-        &self,
-        client: Rc<dyn ExecutionClient>,
-        mut command: SubmitOrderList,
-    ) {
-        let orders = command.order_list.orders.clone();
+    fn handle_submit_order_list(&self, client: Rc<dyn ExecutionClient>, cmd: &SubmitOrderList) {
+        let orders = cmd.order_list.orders.clone();
 
         // Cache orders
         let mut cache = self.cache.borrow_mut();
         for order in &orders {
             if !cache.order_exists(&order.client_order_id()) {
-                if let Err(e) = cache.add_order(
-                    order.clone(),
-                    command.position_id,
-                    Some(command.client_id),
-                    true,
-                ) {
+                if let Err(e) =
+                    cache.add_order(order.clone(), cmd.position_id, Some(cmd.client_id), true)
+                {
                     log::error!("Error adding order to cache: {e}");
                     return;
                 }
@@ -370,50 +402,51 @@ impl ExecutionEngine {
 
         // Get instrument from cache
         let cache = self.cache.borrow();
-        let instrument = if let Some(instrument) = cache.instrument(&command.instrument_id) {
+        let instrument = if let Some(instrument) = cache.instrument(&cmd.instrument_id) {
             instrument
         } else {
             log::error!(
-                "Cannot handle submit order list: no instrument found for {}, {command}",
-                command.instrument_id,
+                "Cannot handle submit order list: no instrument found for {}, {cmd}",
+                cmd.instrument_id,
             );
             return;
         };
 
         // Check if converting quote quantity
-        if !instrument.is_inverse() && command.order_list.orders[0].is_quote_quantity() {
+        if !instrument.is_inverse() && cmd.order_list.orders[0].is_quote_quantity() {
             let mut quote_qty = None;
-            let mut last_px = None;
+            let mut _last_px = None;
 
-            for order in &mut command.order_list.orders {
+            for order in &cmd.order_list.orders {
                 if !order.is_quote_quantity() {
                     continue; // Base quantity already set
                 }
 
                 if Some(order.quantity()) != quote_qty {
-                    last_px =
+                    _last_px =
                         self.last_px_for_conversion(&order.instrument_id(), order.order_side());
                     quote_qty = Some(order.quantity());
                 }
 
-                if let Some(px) = last_px {
-                    let base_qty = instrument.get_base_quantity(order.quantity(), px);
-                    self.set_order_base_qty(order, base_qty);
-                } else {
-                    for order in &command.order_list.orders {
-                        self.deny_order(
-                            order,
-                            &format!("no-price-to-convert-quote-qty {}", order.instrument_id()),
-                        );
-                    }
-                    return; // Denied
-                }
+                // TODO: Pull order out of cache to modify
+                // if let Some(px) = last_px {
+                //     let base_qty = instrument.get_base_quantity(order.quantity(), px);
+                //     self.set_order_base_qty(order, base_qty);
+                // } else {
+                //     for order in &cmd.order_list.orders {
+                //         self.deny_order(
+                //             order,
+                //             &format!("no-price-to-convert-quote-qty {}", order.instrument_id()),
+                //         );
+                //     }
+                //     return; // Denied
+                // }
             }
         }
 
         if self.config.manage_own_order_books {
-            let mut own_book = self.get_or_init_own_order_book(&command.instrument_id);
-            for order in &command.order_list.orders {
+            let mut own_book = self.get_or_init_own_order_book(&cmd.instrument_id);
+            for order in &cmd.order_list.orders {
                 if should_handle_own_book_order(order) {
                     own_book.add(order.to_own_book_order());
                 }
@@ -421,7 +454,7 @@ impl ExecutionEngine {
         }
 
         // Send to execution client
-        if let Err(e) = client.submit_order_list(command) {
+        if let Err(e) = client.submit_order_list(cmd) {
             log::error!("Error submitting order list to client: {e}");
             for order in &orders {
                 self.deny_order(
@@ -432,36 +465,32 @@ impl ExecutionEngine {
         }
     }
 
-    fn handle_modify_order(&self, client: Rc<dyn ExecutionClient>, command: ModifyOrder) {
-        if let Err(e) = client.modify_order(command) {
+    fn handle_modify_order(&self, client: Rc<dyn ExecutionClient>, cmd: &ModifyOrder) {
+        if let Err(e) = client.modify_order(cmd) {
             log::error!("Error modifying order: {e}");
         }
     }
 
-    fn handle_cancel_order(&self, client: Rc<dyn ExecutionClient>, command: CancelOrder) {
-        if let Err(e) = client.cancel_order(command) {
+    fn handle_cancel_order(&self, client: Rc<dyn ExecutionClient>, cmd: &CancelOrder) {
+        if let Err(e) = client.cancel_order(cmd) {
             log::error!("Error canceling order: {e}");
         }
     }
 
-    fn handle_cancel_all_orders(&self, client: Rc<dyn ExecutionClient>, command: CancelAllOrders) {
-        if let Err(e) = client.cancel_all_orders(command) {
+    fn handle_cancel_all_orders(&self, client: Rc<dyn ExecutionClient>, cmd: &CancelAllOrders) {
+        if let Err(e) = client.cancel_all_orders(cmd) {
             log::error!("Error canceling all orders: {e}");
         }
     }
 
-    fn handle_batch_cancel_orders(
-        &self,
-        client: Rc<dyn ExecutionClient>,
-        command: BatchCancelOrders,
-    ) {
-        if let Err(e) = client.batch_cancel_orders(command) {
+    fn handle_batch_cancel_orders(&self, client: Rc<dyn ExecutionClient>, cmd: &BatchCancelOrders) {
+        if let Err(e) = client.batch_cancel_orders(cmd) {
             log::error!("Error batch canceling orders: {e}");
         }
     }
 
-    fn handle_query_order(&self, client: Rc<dyn ExecutionClient>, command: QueryOrder) {
-        if let Err(e) = client.query_order(command) {
+    fn handle_query_order(&self, client: Rc<dyn ExecutionClient>, cmd: &QueryOrder) {
+        if let Err(e) = client.query_order(cmd) {
             log::error!("Error querying order: {e}");
         }
     }
@@ -471,16 +500,16 @@ impl ExecutionEngine {
             log::debug!("Creating order state snapshot for {order}");
         }
 
-        if self.cache.borrow().has_backing() {
-            if let Err(e) = self.cache.borrow().snapshot_order_state(order) {
-                log::error!("Failed to snapshot order state: {e}");
-                return;
-            }
+        if self.cache.borrow().has_backing()
+            && let Err(e) = self.cache.borrow().snapshot_order_state(order)
+        {
+            log::error!("Failed to snapshot order state: {e}");
+            return;
         }
 
         if get_message_bus().borrow().has_backing {
             let topic = switchboard::get_order_snapshots_topic(order.client_order_id());
-            msgbus::publish(&topic, order);
+            msgbus::publish(topic, order);
         }
     }
 
@@ -495,7 +524,7 @@ impl ExecutionEngine {
         // }
 
         let topic = switchboard::get_positions_snapshots_topic(position.id);
-        msgbus::publish(&topic, position);
+        msgbus::publish(topic, position);
     }
 
     // -- EVENT HANDLERS --------------------------------------------------------------------------
@@ -552,18 +581,18 @@ impl ExecutionEngine {
 
         drop(cache);
         match event {
-            OrderEventAny::Filled(order_filled) => {
-                let oms_type = self.determine_oms_type(order_filled);
-                let position_id = self.determine_position_id(*order_filled, oms_type);
+            OrderEventAny::Filled(fill) => {
+                let oms_type = self.determine_oms_type(fill);
+                let position_id = self.determine_position_id(*fill, oms_type);
 
                 // Create a new fill with the determined position ID
-                let mut order_filled = *order_filled;
-                if order_filled.position_id.is_none() {
-                    order_filled.position_id = Some(position_id);
+                let mut fill = *fill;
+                if fill.position_id.is_none() {
+                    fill.position_id = Some(position_id);
                 }
 
-                self.apply_event_to_order(&mut order, OrderEventAny::Filled(order_filled));
-                self.handle_order_fill(&order, order_filled, oms_type);
+                self.apply_event_to_order(&mut order, OrderEventAny::Filled(fill));
+                self.handle_order_fill(&order, fill, oms_type);
             }
             _ => {
                 self.apply_event_to_order(&mut order, event.clone());
@@ -578,10 +607,10 @@ impl ExecutionEngine {
         }
 
         // Use native venue OMS
-        if let Some(client_id) = self.routing_map.get(&fill.instrument_id.venue) {
-            if let Some(client) = self.clients.get(client_id) {
-                return client.oms_type();
-            }
+        if let Some(client_id) = self.routing_map.get(&fill.instrument_id.venue)
+            && let Some(client) = self.clients.get(client_id)
+        {
+            return client.oms_type();
         }
 
         if let Some(client) = &self.default_client {
@@ -663,7 +692,7 @@ impl ExecutionEngine {
         }
 
         let topic = switchboard::get_event_orders_topic(event.strategy_id());
-        msgbus::publish(&topic, order);
+        msgbus::publish(topic, order);
 
         if self.config.snapshot_orders {
             self.create_order_state_snapshot(order);
@@ -714,18 +743,18 @@ impl ExecutionEngine {
             for client_order_id in order.linked_order_ids().unwrap_or_default() {
                 let mut cache = self.cache.borrow_mut();
                 let contingent_order = cache.mut_order(client_order_id);
-                if let Some(contingent_order) = contingent_order {
-                    if contingent_order.position_id().is_none() {
-                        contingent_order.set_position_id(Some(position_id));
+                if let Some(contingent_order) = contingent_order
+                    && contingent_order.position_id().is_none()
+                {
+                    contingent_order.set_position_id(Some(position_id));
 
-                        if let Err(e) = self.cache.borrow_mut().add_position_id(
-                            &position_id,
-                            &contingent_order.instrument_id().venue,
-                            &contingent_order.client_order_id(),
-                            &contingent_order.strategy_id(),
-                        ) {
-                            log::error!("Failed to add position ID: {e}");
-                        }
+                    if let Err(e) = self.cache.borrow_mut().add_position_id(
+                        &position_id,
+                        &contingent_order.instrument_id().venue,
+                        &contingent_order.client_order_id(),
+                        &contingent_order.strategy_id(),
+                    ) {
+                        log::error!("Failed to add position ID: {e}");
                     }
                 }
             }
@@ -760,7 +789,7 @@ impl ExecutionEngine {
         let ts_init = self.clock.borrow().timestamp_ns();
         let event = PositionOpened::create(&position, &fill, UUID4::new(), ts_init);
         let topic = switchboard::get_event_positions_topic(event.strategy_id);
-        msgbus::publish(&topic, &event);
+        msgbus::publish(topic, &event);
 
         Ok(position)
     }
@@ -782,10 +811,10 @@ impl ExecutionEngine {
 
         if position.is_closed() {
             let event = PositionClosed::create(position, &fill, UUID4::new(), ts_init);
-            msgbus::publish(&topic, &event);
+            msgbus::publish(topic, &event);
         } else {
             let event = PositionChanged::create(position, &fill, UUID4::new(), ts_init);
-            msgbus::publish(&topic, &event);
+            msgbus::publish(topic, &event);
         }
     }
 
@@ -896,13 +925,12 @@ impl ExecutionEngine {
             commission2,
         );
 
-        if oms_type == OmsType::Hedging {
-            if let Some(position_id) = fill.position_id {
-                if position_id.is_virtual() {
-                    log::warn!("Closing position {fill_split1:?}");
-                    log::warn!("Flipping position {fill_split2:?}");
-                }
-            }
+        if oms_type == OmsType::Hedging
+            && let Some(position_id) = fill.position_id
+            && position_id.is_virtual()
+        {
+            log::warn!("Closing position {fill_split1:?}");
+            log::warn!("Flipping position {fill_split2:?}");
         }
 
         // Open flipped position
@@ -1045,14 +1073,14 @@ impl ExecutionEngine {
         }
 
         let topic = switchboard::get_event_orders_topic(order.strategy_id());
-        msgbus::publish(&topic, &denied);
+        msgbus::publish(topic, &denied);
 
         if self.config.snapshot_orders {
             self.create_order_state_snapshot(&order);
         }
     }
 
-    fn get_or_init_own_order_book(&self, instrument_id: &InstrumentId) -> RefMut<OwnOrderBook> {
+    fn get_or_init_own_order_book(&self, instrument_id: &InstrumentId) -> RefMut<'_, OwnOrderBook> {
         let mut cache = self.cache.borrow_mut();
         if cache.own_order_book_mut(instrument_id).is_none() {
             let own_book = OwnOrderBook::new(*instrument_id);
