@@ -34,7 +34,7 @@ use crate::matching_core::handlers::{
 };
 
 /// A generic order matching core.
-#[derive(Clone)]
+#[derive(Clone, Debug)]
 pub struct OrderMatchingCore {
     /// The instrument ID for the matching core.
     pub instrument_id: InstrumentId,
@@ -115,12 +115,12 @@ impl OrderMatchingCore {
     }
 
     #[must_use]
-    pub fn get_orders_bid(&self) -> &[PassiveOrderAny] {
+    pub const fn get_orders_bid(&self) -> &[PassiveOrderAny] {
         self.orders_bid.as_slice()
     }
 
     #[must_use]
-    pub fn get_orders_ask(&self) -> &[PassiveOrderAny] {
+    pub const fn get_orders_ask(&self) -> &[PassiveOrderAny] {
         self.orders_ask.as_slice()
     }
 
@@ -167,6 +167,11 @@ impl OrderMatchingCore {
         self.orders_ask.clear();
     }
 
+    /// Adds a passive order to the matching core.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`OrderError::NotFound`] if the order cannot be added.
     pub fn add_order(&mut self, order: PassiveOrderAny) -> Result<(), OrderError> {
         match order.order_side_specified() {
             OrderSideSpecified::Buy => {
@@ -180,6 +185,11 @@ impl OrderMatchingCore {
         }
     }
 
+    /// Deletes a passive order from the matching core.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`OrderError::NotFound`] if the order is not present.
     pub fn delete_order(&mut self, order: &PassiveOrderAny) -> Result<(), OrderError> {
         match order.order_side_specified() {
             OrderSideSpecified::Buy => {
@@ -238,16 +248,22 @@ impl OrderMatchingCore {
     }
 
     pub fn match_limit_order(&mut self, order: &LimitOrderAny) {
-        if self.is_limit_matched(order.order_side_specified(), order.limit_px()) {
-            if let Some(handler) = &mut self.fill_limit_order {
-                handler
-                    .0
-                    .fill_limit_order(&mut OrderAny::from(order.clone()));
-            }
+        if self.is_limit_matched(order.order_side_specified(), order.limit_px())
+            && let Some(handler) = &mut self.fill_limit_order
+        {
+            handler
+                .0
+                .fill_limit_order(&mut OrderAny::from(order.clone()));
         }
     }
 
     pub fn match_stop_order(&mut self, order: &StopOrderAny) {
+        match order {
+            StopOrderAny::TrailingStopMarket(o) if !o.is_activated => return,
+            StopOrderAny::TrailingStopLimit(o) if !o.is_activated => return,
+            _ => {}
+        }
+
         if self.is_stop_matched(order.order_side_specified(), order.stop_px()) {
             if let Some(handler) = &mut self.trigger_stop_order {
                 handler
