@@ -34,6 +34,7 @@ use crate::{
     models::{fee::FeeModelAny, fill::FillModel},
 };
 
+#[derive(Debug)]
 pub struct OrderEngineAdapter {
     engine: Rc<RefCell<OrderMatchingEngine>>,
 }
@@ -103,12 +104,12 @@ impl OrderEngineAdapter {
     }
 
     #[must_use]
-    pub fn get_engine(&self) -> Ref<OrderMatchingEngine> {
+    pub fn get_engine(&self) -> Ref<'_, OrderMatchingEngine> {
         self.engine.borrow()
     }
 
     #[must_use]
-    pub fn get_engine_mut(&self) -> RefMut<OrderMatchingEngine> {
+    pub fn get_engine_mut(&self) -> RefMut<'_, OrderMatchingEngine> {
         self.engine.borrow_mut()
     }
 }
