@@ -22,6 +22,7 @@ use std::{
     cell::RefCell,
     cmp::min,
     collections::HashMap,
+    fmt::Debug,
     ops::{Add, Sub},
     rc::Rc,
 };
@@ -30,7 +31,8 @@ use chrono::TimeDelta;
 use nautilus_common::{
     cache::Cache,
     clock::Clock,
-    msgbus::{self},
+    messages::execution::{BatchCancelOrders, CancelAllOrders, CancelOrder, ModifyOrder},
+    msgbus,
 };
 use nautilus_core::{UUID4, UnixNanos};
 use nautilus_model::{
@@ -59,7 +61,6 @@ use ustr::Ustr;
 use crate::{
     matching_core::OrderMatchingCore,
     matching_engine::{config::OrderMatchingEngineConfig, ids_generator::IdsGenerator},
-    messages::{BatchCancelOrders, CancelAllOrders, CancelOrder, ModifyOrder},
     models::{
         fee::{FeeModel, FeeModelAny},
         fill::FillModel,
@@ -103,7 +104,17 @@ pub struct OrderMatchingEngine {
     ids_generator: IdsGenerator,
 }
 
+impl Debug for OrderMatchingEngine {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct(stringify!(OrderMatchingEngine))
+            .field("venue", &self.venue)
+            .field("instrument", &self.instrument.id())
+            .finish()
+    }
+}
+
 impl OrderMatchingEngine {
+    /// Creates a new [`OrderMatchingEngine`] instance.
     #[allow(clippy::too_many_arguments)]
     pub fn new(
         instrument: InstrumentAny,
@@ -162,6 +173,11 @@ impl OrderMatchingEngine {
         }
     }
 
+    /// Resets the matching engine to its initial state.
+    ///
+    /// Clears the order book, execution state, cached data, and resets all
+    /// internal components. This is typically used for backtesting scenarios
+    /// where the engine needs to be reset between test runs.
     pub fn reset(&mut self) {
         self.book.clear(0, UnixNanos::default());
         self.execution_bar_types.clear();
@@ -177,36 +193,43 @@ impl OrderMatchingEngine {
         log::info!("Reset {}", self.instrument.id());
     }
 
+    /// Sets the fill model for the matching engine.
     pub const fn set_fill_model(&mut self, fill_model: FillModel) {
         self.fill_model = fill_model;
     }
 
     #[must_use]
+    /// Returns the best bid price from the order book.
     pub fn best_bid_price(&self) -> Option<Price> {
         self.book.best_bid_price()
     }
 
     #[must_use]
+    /// Returns the best ask price from the order book.
     pub fn best_ask_price(&self) -> Option<Price> {
         self.book.best_ask_price()
     }
 
     #[must_use]
+    /// Returns a reference to the internal order book.
     pub const fn get_book(&self) -> &OrderBook {
         &self.book
     }
 
     #[must_use]
-    pub fn get_open_bid_orders(&self) -> &[PassiveOrderAny] {
+    /// Returns all open bid orders managed by the matching core.
+    pub const fn get_open_bid_orders(&self) -> &[PassiveOrderAny] {
         self.core.get_orders_bid()
     }
 
     #[must_use]
-    pub fn get_open_ask_orders(&self) -> &[PassiveOrderAny] {
+    /// Returns all open ask orders managed by the matching core.
+    pub const fn get_open_ask_orders(&self) -> &[PassiveOrderAny] {
         self.core.get_orders_ask()
     }
 
     #[must_use]
+    /// Returns all open orders from both bid and ask sides.
     pub fn get_open_orders(&self) -> Vec<PassiveOrderAny> {
         // Get orders from both open bid orders and open ask orders
         let mut orders = Vec::new();
@@ -216,6 +239,7 @@ impl OrderMatchingEngine {
     }
 
     #[must_use]
+    /// Returns true if an order with the given client order ID exists in the matching engine.
     pub fn order_exists(&self, client_order_id: ClientOrderId) -> bool {
         self.core.order_exists(client_order_id)
     }
@@ -243,6 +267,9 @@ impl OrderMatchingEngine {
         self.iterate(deltas.ts_event);
     }
 
+    /// # Panics
+    ///
+    /// Panics if updating the order book with the quote tick fails.
     pub fn process_quote_tick(&mut self, quote: &QuoteTick) {
         log::debug!("Processing {quote}");
 
@@ -253,6 +280,9 @@ impl OrderMatchingEngine {
         self.iterate(quote.ts_event);
     }
 
+    /// # Panics
+    ///
+    /// Panics if the bar type configuration is missing a time delta.
     pub fn process_bar(&mut self, bar: &Bar) {
         log::debug!("Processing {bar}");
 
@@ -441,6 +471,9 @@ impl OrderMatchingEngine {
         self.last_bar_ask = None;
     }
 
+    /// # Panics
+    ///
+    /// Panics if updating the order book with the trade tick fails.
     pub fn process_trade_tick(&mut self, trade: &TradeTick) {
         log::debug!("Processing {trade}");
 
@@ -479,6 +512,9 @@ impl OrderMatchingEngine {
 
     // -- TRADING COMMANDS ------------------------------------------------------------------------
 
+    /// # Panics
+    ///
+    /// Panics if the instrument activation timestamp is missing.
     #[allow(clippy::needless_return)]
     pub fn process_order(&mut self, order: &mut OrderAny, account_id: AccountId) {
         // Enter the scope where you will borrow a cache
@@ -495,33 +531,33 @@ impl OrderMatchingEngine {
 
             // Check for instrument expiration or activation
             if EXPIRING_INSTRUMENT_TYPES.contains(&self.instrument.instrument_class()) {
-                if let Some(activation_ns) = self.instrument.activation_ns() {
-                    if self.clock.borrow().timestamp_ns() < activation_ns {
-                        self.generate_order_rejected(
-                            order,
-                            format!(
-                                "Contract {} is not yet active, activation {}",
-                                self.instrument.id(),
-                                self.instrument.activation_ns().unwrap()
-                            )
-                            .into(),
-                        );
-                        return;
-                    }
+                if let Some(activation_ns) = self.instrument.activation_ns()
+                    && self.clock.borrow().timestamp_ns() < activation_ns
+                {
+                    self.generate_order_rejected(
+                        order,
+                        format!(
+                            "Contract {} is not yet active, activation {}",
+                            self.instrument.id(),
+                            self.instrument.activation_ns().unwrap()
+                        )
+                        .into(),
+                    );
+                    return;
                 }
-                if let Some(expiration_ns) = self.instrument.expiration_ns() {
-                    if self.clock.borrow().timestamp_ns() >= expiration_ns {
-                        self.generate_order_rejected(
-                            order,
-                            format!(
-                                "Contract {} has expired, expiration {}",
-                                self.instrument.id(),
-                                self.instrument.expiration_ns().unwrap()
-                            )
-                            .into(),
-                        );
-                        return;
-                    }
+                if let Some(expiration_ns) = self.instrument.expiration_ns()
+                    && self.clock.borrow().timestamp_ns() >= expiration_ns
+                {
+                    self.generate_order_rejected(
+                        order,
+                        format!(
+                            "Contract {} has expired, expiration {}",
+                            self.instrument.id(),
+                            self.instrument.expiration_ns().unwrap()
+                        )
+                        .into(),
+                    );
+                    return;
                 }
             }
 
@@ -596,9 +632,10 @@ impl OrderMatchingEngine {
             }
 
             // Check for valid order price precision
-            if let Some(price) = order.price() {
-                if price.precision != self.instrument.price_precision() {
-                    self.generate_order_rejected(
+            if let Some(price) = order.price()
+                && price.precision != self.instrument.price_precision()
+            {
+                self.generate_order_rejected(
                         order,
                         format!(
                             "Invalid order price precision for order {}, was {} when {} price precision is {}",
@@ -609,14 +646,14 @@ impl OrderMatchingEngine {
                         )
                             .into(),
                     );
-                    return;
-                }
+                return;
             }
 
             // Check for valid order trigger price precision
-            if let Some(trigger_price) = order.trigger_price() {
-                if trigger_price.precision != self.instrument.price_precision() {
-                    self.generate_order_rejected(
+            if let Some(trigger_price) = order.trigger_price()
+                && trigger_price.precision != self.instrument.price_precision()
+            {
+                self.generate_order_rejected(
                         order,
                         format!(
                             "Invalid order trigger price precision for order {}, was {} when {} price precision is {}",
@@ -627,8 +664,7 @@ impl OrderMatchingEngine {
                         )
                             .into(),
                     );
-                    return;
-                }
+                return;
             }
 
             // Get position if exists
@@ -1013,12 +1049,12 @@ impl OrderMatchingEngine {
     }
 
     fn process_trailing_stop_order(&mut self, order: &mut OrderAny) {
-        if let Some(trigger_price) = order.trigger_price() {
-            if self
+        if let Some(trigger_price) = order.trigger_price()
+            && self
                 .core
                 .is_stop_matched(order.order_side_specified(), trigger_price)
-            {
-                self.generate_order_rejected(
+        {
+            self.generate_order_rejected(
                     order,
                     format!(
                         "{} {} order trigger px of {} was in the market: bid={}, ask={}, but rejected because of configuration",
@@ -1033,8 +1069,7 @@ impl OrderMatchingEngine {
                             .map_or_else(|| "None".to_string(), |p| p.to_string())
                     ).into(),
                 );
-                return;
-            }
+            return;
         }
 
         // Order is valid and accepted
@@ -1045,6 +1080,10 @@ impl OrderMatchingEngine {
 
     /// Iterate the matching engine by processing the bid and ask order sides
     /// and advancing time up to the given UNIX `timestamp_ns`.
+    ///
+    /// # Panics
+    ///
+    /// Panics if the best bid or ask price is unavailable when iterating.
     pub fn iterate(&mut self, timestamp_ns: UnixNanos) {
         // TODO implement correct clock fixed time setting self.clock.set_time(ts_now);
 
@@ -1067,33 +1106,119 @@ impl OrderMatchingEngine {
         self.iterate_orders(timestamp_ns, &orders_ask);
     }
 
+    fn maybe_activate_trailing_stop(
+        &mut self,
+        order: &mut OrderAny,
+        bid: Option<Price>,
+        ask: Option<Price>,
+    ) -> bool {
+        match order {
+            OrderAny::TrailingStopMarket(inner) => {
+                if inner.is_activated {
+                    return true;
+                }
+
+                if inner.activation_price.is_none() {
+                    let px = match inner.order_side() {
+                        OrderSide::Buy => ask,
+                        OrderSide::Sell => bid,
+                        _ => None,
+                    };
+                    if let Some(p) = px {
+                        inner.activation_price = Some(p);
+                        inner.set_activated();
+                        if let Err(e) = self.cache.borrow_mut().update_order(order) {
+                            log::error!("Failed to update order: {e}");
+                        }
+                        return true;
+                    }
+                    return false;
+                }
+
+                let activation_price = inner.activation_price.unwrap();
+                let hit = match inner.order_side() {
+                    OrderSide::Buy => ask.is_some_and(|a| a <= activation_price),
+                    OrderSide::Sell => bid.is_some_and(|b| b >= activation_price),
+                    _ => false,
+                };
+                if hit {
+                    inner.set_activated();
+                    if let Err(e) = self.cache.borrow_mut().update_order(order) {
+                        log::error!("Failed to update order: {e}");
+                    }
+                }
+                hit
+            }
+            OrderAny::TrailingStopLimit(inner) => {
+                if inner.is_activated {
+                    return true;
+                }
+
+                if inner.activation_price.is_none() {
+                    let px = match inner.order_side() {
+                        OrderSide::Buy => ask,
+                        OrderSide::Sell => bid,
+                        _ => None,
+                    };
+                    if let Some(p) = px {
+                        inner.activation_price = Some(p);
+                        inner.set_activated();
+                        if let Err(e) = self.cache.borrow_mut().update_order(order) {
+                            log::error!("Failed to update order: {e}");
+                        }
+                        return true;
+                    }
+                    return false;
+                }
+
+                let activation_price = inner.activation_price.unwrap();
+                let hit = match inner.order_side() {
+                    OrderSide::Buy => ask.is_some_and(|a| a <= activation_price),
+                    OrderSide::Sell => bid.is_some_and(|b| b >= activation_price),
+                    _ => false,
+                };
+                if hit {
+                    inner.set_activated();
+                    if let Err(e) = self.cache.borrow_mut().update_order(order) {
+                        log::error!("Failed to update order: {e}");
+                    }
+                }
+                hit
+            }
+            _ => true,
+        }
+    }
+
     fn iterate_orders(&mut self, timestamp_ns: UnixNanos, orders: &[PassiveOrderAny]) {
         for order in orders {
             if order.is_closed() {
                 continue;
             }
 
-            // Check expiration
-            if self.config.support_gtd_orders {
-                if let Some(expire_time) = order.expire_time() {
-                    if timestamp_ns >= expire_time {
-                        // SAFTEY: We know this order is in the core
-                        self.core.delete_order(order).unwrap();
-                        self.cached_filled_qty.remove(&order.client_order_id());
-                        self.expire_order(order);
-                    }
-                }
+            if self.config.support_gtd_orders
+                && order
+                    .expire_time()
+                    .is_some_and(|expire_timestamp_ns| timestamp_ns >= expire_timestamp_ns)
+            {
+                let _ = self.core.delete_order(order);
+                self.cached_filled_qty.remove(&order.client_order_id());
+                self.expire_order(order);
+                continue;
             }
 
-            // Manage trailing stop
-            if let PassiveOrderAny::Stop(o) = order {
-                if let PassiveOrderAny::Stop(
-                    StopOrderAny::TrailingStopMarket(_) | StopOrderAny::TrailingStopLimit(_),
-                ) = order
-                {
-                    let mut order = OrderAny::from(o.to_owned());
-                    self.update_trailing_stop_order(&mut order);
+            if matches!(
+                order,
+                PassiveOrderAny::Stop(
+                    StopOrderAny::TrailingStopMarket(_) | StopOrderAny::TrailingStopLimit(_)
+                )
+            ) {
+                let mut any = OrderAny::from(order.clone());
+
+                if !self.maybe_activate_trailing_stop(&mut any, self.core.bid, self.core.ask) {
+                    continue;
                 }
+
+                self.update_trailing_stop_order(&mut any);
             }
 
             // Move market back to targets
@@ -1101,11 +1226,15 @@ impl OrderMatchingEngine {
                 self.core.bid = Some(target_bid);
                 self.target_bid = None;
             }
-            if let Some(target_ask) = self.target_ask {
+            if let Some(target_bid) = self.target_bid.take() {
+                self.core.bid = Some(target_bid);
+                self.target_bid = None;
+            }
+            if let Some(target_ask) = self.target_ask.take() {
                 self.core.ask = Some(target_ask);
                 self.target_ask = None;
             }
-            if let Some(target_last) = self.target_last {
+            if let Some(target_last) = self.target_last.take() {
                 self.core.last = Some(target_last);
                 self.target_last = None;
             }
@@ -1234,17 +1363,17 @@ impl OrderMatchingEngine {
     }
 
     pub fn fill_market_order(&mut self, order: &mut OrderAny) {
-        if let Some(filled_qty) = self.cached_filled_qty.get(&order.client_order_id()) {
-            if filled_qty >= &order.quantity() {
-                log::info!(
-                    "Ignoring fill as already filled pending application of events: {:?}, {:?}, {:?}, {:?}",
-                    filled_qty,
-                    order.quantity(),
-                    order.filled_qty(),
-                    order.quantity()
-                );
-                return;
-            }
+        if let Some(filled_qty) = self.cached_filled_qty.get(&order.client_order_id())
+            && filled_qty >= &order.quantity()
+        {
+            log::info!(
+                "Ignoring fill as already filled pending application of events: {:?}, {:?}, {:?}, {:?}",
+                filled_qty,
+                order.quantity(),
+                order.filled_qty(),
+                order.quantity()
+            );
+            return;
         }
 
         let venue_position_id = self.ids_generator.get_position_id(order, Some(true));
@@ -1269,6 +1398,9 @@ impl OrderMatchingEngine {
         self.apply_fills(order, fills, LiquiditySide::Taker, None, position);
     }
 
+    /// # Panics
+    ///
+    /// Panics if the order has no price, or if fill price or quantity precision mismatches occur.
     pub fn fill_limit_order(&mut self, order: &mut OrderAny) {
         match order.price() {
             Some(order_price) => {
@@ -1410,21 +1542,21 @@ impl OrderMatchingEngine {
             }
 
             // Check reduce only order
-            if self.config.use_reduce_only && order.is_reduce_only() {
-                if let Some(position) = &position {
-                    if *fill_qty > position.quantity {
-                        if position.quantity == Quantity::zero(position.quantity.precision) {
-                            // Done
-                            return;
-                        }
-
-                        // Adjust fill to honor reduce only execution (fill remaining position size only)
-                        let adjusted_fill_qty =
-                            Quantity::from_raw(position.quantity.raw, fill_qty.precision);
-
-                        self.generate_order_updated(order, adjusted_fill_qty, None, None);
-                    }
+            if self.config.use_reduce_only
+                && order.is_reduce_only()
+                && let Some(position) = &position
+                && *fill_qty > position.quantity
+            {
+                if position.quantity == Quantity::zero(position.quantity.precision) {
+                    // Done
+                    return;
                 }
+
+                // Adjust fill to honor reduce only execution (fill remaining position size only)
+                let adjusted_fill_qty =
+                    Quantity::from_raw(position.quantity.raw, fill_qty.precision);
+
+                self.generate_order_updated(order, adjusted_fill_qty, None, None);
             }
 
             if fill_qty.is_zero() {
@@ -1462,7 +1594,10 @@ impl OrderMatchingEngine {
             && self.book_type == BookType::L1_MBP
             && matches!(
                 order.order_type(),
-                OrderType::Market | OrderType::MarketIfTouched | OrderType::StopMarket
+                OrderType::Market
+                    | OrderType::MarketIfTouched
+                    | OrderType::StopMarket
+                    | OrderType::TrailingStopMarket
             )
         {
             // Exhausted simulated book volume (continue aggressive filling into next level)
@@ -1907,6 +2042,8 @@ impl OrderMatchingEngine {
     fn update_trailing_stop_order(&mut self, order: &mut OrderAny) {
         let (new_trigger_price, new_price) = trailing_stop_calculate(
             self.instrument.price_increment(),
+            order.trigger_price(),
+            order.activation_price(),
             order,
             self.core.bid,
             self.core.ask,
@@ -2120,7 +2257,7 @@ impl OrderMatchingEngine {
             ts_now,
             false,
         ));
-        msgbus::send(&Ustr::from("ExecEngine.process"), &event as &dyn Any);
+        msgbus::send_any("ExecEngine.process".into(), &event as &dyn Any);
     }
 
     fn generate_order_accepted(&self, order: &mut OrderAny, venue_order_id: VenueOrderId) {
@@ -2140,7 +2277,7 @@ impl OrderMatchingEngine {
             ts_now,
             false,
         ));
-        msgbus::send(&Ustr::from("ExecEngine.process"), &event as &dyn Any);
+        msgbus::send_any("ExecEngine.process".into(), &event as &dyn Any);
 
         // TODO remove this when execution engine msgbus handlers are correctly set
         order.apply(event).expect("Failed to apply order event");
@@ -2171,7 +2308,7 @@ impl OrderMatchingEngine {
             venue_order_id,
             account_id,
         ));
-        msgbus::send(&Ustr::from("ExecEngine.process"), &event as &dyn Any);
+        msgbus::send_any("ExecEngine.process".into(), &event as &dyn Any);
     }
 
     #[allow(clippy::too_many_arguments)]
@@ -2199,7 +2336,7 @@ impl OrderMatchingEngine {
             Some(venue_order_id),
             Some(account_id),
         ));
-        msgbus::send(&Ustr::from("ExecEngine.process"), &event as &dyn Any);
+        msgbus::send_any("ExecEngine.process".into(), &event as &dyn Any);
     }
 
     fn generate_order_updated(
@@ -2225,7 +2362,7 @@ impl OrderMatchingEngine {
             price,
             trigger_price,
         ));
-        msgbus::send(&Ustr::from("ExecEngine.process"), &event as &dyn Any);
+        msgbus::send_any("ExecEngine.process".into(), &event as &dyn Any);
 
         // TODO remove this when execution engine msgbus handlers are correctly set
         order.apply(event).expect("Failed to apply order event");
@@ -2245,7 +2382,7 @@ impl OrderMatchingEngine {
             Some(venue_order_id),
             order.account_id(),
         ));
-        msgbus::send(&Ustr::from("ExecEngine.process"), &event as &dyn Any);
+        msgbus::send_any("ExecEngine.process".into(), &event as &dyn Any);
     }
 
     fn generate_order_triggered(&self, order: &OrderAny) {
@@ -2262,7 +2399,7 @@ impl OrderMatchingEngine {
             order.venue_order_id(),
             order.account_id(),
         ));
-        msgbus::send(&Ustr::from("ExecEngine.process"), &event as &dyn Any);
+        msgbus::send_any("ExecEngine.process".into(), &event as &dyn Any);
     }
 
     fn generate_order_expired(&self, order: &OrderAny) {
@@ -2279,7 +2416,7 @@ impl OrderMatchingEngine {
             order.venue_order_id(),
             order.account_id(),
         ));
-        msgbus::send(&Ustr::from("ExecEngine.process"), &event as &dyn Any);
+        msgbus::send_any("ExecEngine.process".into(), &event as &dyn Any);
     }
 
     #[allow(clippy::too_many_arguments)]
@@ -2319,7 +2456,7 @@ impl OrderMatchingEngine {
             venue_position_id,
             Some(commission),
         ));
-        msgbus::send(&Ustr::from("ExecEngine.process"), &event as &dyn Any);
+        msgbus::send_any("ExecEngine.process".into(), &event as &dyn Any);
 
         // TODO remove this when execution engine msgbus handlers are correctly set
         order.apply(event).expect("Failed to apply order event");
