@@ -15,12 +15,13 @@
 
 use std::{any::Any, cell::RefCell, rc::Rc};
 
-use nautilus_common::msgbus::handler::MessageHandler;
+use nautilus_common::{messages::execution::TradingCommand, msgbus::handler::MessageHandler};
 use nautilus_model::events::OrderEventAny;
 use ustr::Ustr;
 
-use crate::{messages::TradingCommand, order_emulator::emulator::OrderEmulator};
+use super::emulator::OrderEmulator;
 
+#[derive(Debug)]
 pub struct OrderEmulatorExecuteHandler {
     pub id: Ustr,
     pub emulator: Rc<RefCell<OrderEmulator>>,
@@ -45,6 +46,7 @@ impl MessageHandler for OrderEmulatorExecuteHandler {
     }
 }
 
+#[derive(Debug)]
 pub struct OrderEmulatorOnEventHandler {
     pub id: Ustr,
     pub emulator: Rc<RefCell<OrderEmulator>>,
