@@ -13,13 +13,18 @@
 //  limitations under the License.
 // -------------------------------------------------------------------------------------------------
 
-use std::{cell::RefCell, collections::HashMap, rc::Rc};
+// Under development
+#![allow(dead_code)]
+#![allow(unused_variables)]
+
+use std::{cell::RefCell, collections::HashMap, fmt::Debug, rc::Rc};
 
 use nautilus_common::{
     cache::Cache,
     clock::Clock,
-    logging::{CMD, EVT, SENT},
-    msgbus::{self},
+    logging::{CMD, EVT, SEND},
+    messages::execution::{SubmitOrder, TradingCommand},
+    msgbus,
 };
 use nautilus_core::UUID4;
 use nautilus_model::{
@@ -31,67 +36,77 @@ use nautilus_model::{
     orders::{Order, OrderAny},
     types::Quantity,
 };
-use ustr::Ustr;
-
-use crate::messages::{
-    SubmitOrder, TradingCommand,
-    cancel::{CancelOrderHandler, CancelOrderHandlerAny},
-    modify::{ModifyOrderHandler, ModifyOrderHandlerAny},
-    submit::{SubmitOrderHandler, SubmitOrderHandlerAny},
-};
 
+/// Manages the lifecycle and state of orders with contingency handling.
+///
+/// The order manager is responsible for managing local order state, handling
+/// contingent orders (OTO, OCO, OUO), and coordinating with emulation and
+/// execution systems. It tracks order commands and manages complex order
+/// relationships for advanced order types.
 pub struct OrderManager {
     clock: Rc<RefCell<dyn Clock>>,
     cache: Rc<RefCell<Cache>>,
     active_local: bool,
-    submit_order_handler: Option<SubmitOrderHandlerAny>,
-    cancel_order_handler: Option<CancelOrderHandlerAny>,
-    modify_order_handler: Option<ModifyOrderHandlerAny>,
+    // submit_order_handler: Option<SubmitOrderHandlerAny>,
+    // cancel_order_handler: Option<CancelOrderHandlerAny>,
+    // modify_order_handler: Option<ModifyOrderHandlerAny>,
     submit_order_commands: HashMap<ClientOrderId, SubmitOrder>,
 }
 
+impl Debug for OrderManager {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct(stringify!(OrderManager))
+            .field("pending_commands", &self.submit_order_commands.len())
+            .finish()
+    }
+}
+
 impl OrderManager {
+    /// Creates a new [`OrderManager`] instance.
     pub fn new(
         clock: Rc<RefCell<dyn Clock>>,
         cache: Rc<RefCell<Cache>>,
         active_local: bool,
-        submit_order_handler: Option<SubmitOrderHandlerAny>,
-        cancel_order_handler: Option<CancelOrderHandlerAny>,
-        modify_order_handler: Option<ModifyOrderHandlerAny>,
+        // submit_order_handler: Option<SubmitOrderHandlerAny>,
+        // cancel_order_handler: Option<CancelOrderHandlerAny>,
+        // modify_order_handler: Option<ModifyOrderHandlerAny>,
     ) -> Self {
         Self {
             clock,
             cache,
             active_local,
-            submit_order_handler,
-            cancel_order_handler,
-            modify_order_handler,
+            // submit_order_handler,
+            // cancel_order_handler,
+            // modify_order_handler,
             submit_order_commands: HashMap::new(),
         }
     }
 
-    pub fn set_submit_order_handler(&mut self, handler: SubmitOrderHandlerAny) {
-        self.submit_order_handler = Some(handler);
-    }
-
-    pub fn set_cancel_order_handler(&mut self, handler: CancelOrderHandlerAny) {
-        self.cancel_order_handler = Some(handler);
-    }
-
-    pub fn set_modify_order_handler(&mut self, handler: ModifyOrderHandlerAny) {
-        self.modify_order_handler = Some(handler);
-    }
+    // pub fn set_submit_order_handler(&mut self, handler: SubmitOrderHandlerAny) {
+    //     self.submit_order_handler = Some(handler);
+    // }
+    //
+    // pub fn set_cancel_order_handler(&mut self, handler: CancelOrderHandlerAny) {
+    //     self.cancel_order_handler = Some(handler);
+    // }
+    //
+    // pub fn set_modify_order_handler(&mut self, handler: ModifyOrderHandlerAny) {
+    //     self.modify_order_handler = Some(handler);
+    // }
 
     #[must_use]
+    /// Returns a copy of all cached submit order commands.
     pub fn get_submit_order_commands(&self) -> HashMap<ClientOrderId, SubmitOrder> {
         self.submit_order_commands.clone()
     }
 
+    /// Caches a submit order command for later processing.
     pub fn cache_submit_order_command(&mut self, command: SubmitOrder) {
         self.submit_order_commands
             .insert(command.order.client_order_id(), command);
     }
 
+    /// Removes and returns a cached submit order command.
     pub fn pop_submit_order_command(
         &mut self,
         client_order_id: ClientOrderId,
@@ -99,10 +114,12 @@ impl OrderManager {
         self.submit_order_commands.remove(&client_order_id)
     }
 
+    /// Resets the order manager by clearing all cached commands.
     pub fn reset(&mut self) {
         self.submit_order_commands.clear();
     }
 
+    /// Cancels an order if it's not already pending cancellation or closed.
     pub fn cancel_order(&mut self, order: &OrderAny) {
         if self
             .cache
@@ -119,17 +136,21 @@ impl OrderManager {
 
         self.submit_order_commands.remove(&order.client_order_id());
 
-        if let Some(handler) = &self.cancel_order_handler {
-            handler.handle_cancel_order(order);
-        }
+        // if let Some(handler) = &self.cancel_order_handler {
+        //     handler.handle_cancel_order(order);
+        // }
     }
 
-    pub fn modify_order_quantity(&mut self, order: &mut OrderAny, new_quantity: Quantity) {
-        if let Some(handler) = &self.modify_order_handler {
-            handler.handle_modify_order(order, new_quantity);
-        }
+    /// Modifies the quantity of an existing order.
+    pub const fn modify_order_quantity(&mut self, order: &mut OrderAny, new_quantity: Quantity) {
+        // if let Some(handler) = &self.modify_order_handler {
+        //     handler.handle_modify_order(order, new_quantity);
+        // }
     }
 
+    /// # Errors
+    ///
+    /// Returns an error if creating a new submit order fails.
     pub fn create_new_submit_order(
         &mut self,
         order: &OrderAny,
@@ -164,19 +185,21 @@ impl OrderManager {
                 }
                 None => self.send_risk_command(TradingCommand::SubmitOrder(submit)),
             }
-        } else if let Some(handler) = &self.submit_order_handler {
-            handler.handle_submit_order(submit);
-        }
+        } // else if let Some(handler) = &self.submit_order_handler {
+        //     handler.handle_submit_order(submit);
+        // }
 
         Ok(())
     }
 
     #[must_use]
+    /// Returns true if the order manager should manage the given order.
     pub fn should_manage_order(&self, order: &OrderAny) -> bool {
         self.active_local && order.is_active_local()
     }
 
     // Event Handlers
+    /// Handles an order event by routing it to the appropriate handler method.
     pub fn handle_event(&mut self, event: OrderEventAny) {
         match event {
             OrderEventAny::Rejected(event) => self.handle_order_rejected(event),
@@ -188,6 +211,7 @@ impl OrderManager {
         }
     }
 
+    /// Handles an order rejected event and manages any contingent orders.
     pub fn handle_order_rejected(&mut self, rejected: OrderRejected) {
         let cloned_order = self
             .cache
@@ -256,6 +280,9 @@ impl OrderManager {
         }
     }
 
+    /// # Panics
+    ///
+    /// Panics if the OTO child order cannot be found for the given client order ID.
     pub fn handle_order_filled(&mut self, filled: OrderFilled) {
         let order = if let Some(order) = self.cache.borrow().order(&filled.client_order_id).cloned()
         {
@@ -327,19 +354,17 @@ impl OrderManager {
                         self.modify_order_quantity(&mut child_order, parent_filled_qty);
                     }
 
-                    if self.submit_order_handler.is_none() {
-                        return;
-                    }
+                    // if self.submit_order_handler.is_none() {
+                    //     return;
+                    // }
 
                     if !self
                         .submit_order_commands
                         .contains_key(&child_order.client_order_id())
-                    {
-                        if let Err(e) =
+                        && let Err(e) =
                             self.create_new_submit_order(&child_order, position_id, client_id)
-                        {
-                            log::error!("Failed to create new submit order: {e}");
-                        }
+                    {
+                        log::error!("Failed to create new submit order: {e}");
                     }
                 }
             }
@@ -377,6 +402,9 @@ impl OrderManager {
         }
     }
 
+    /// # Panics
+    ///
+    /// Panics if a contingent order cannot be found for the given client order ID.
     pub fn handle_contingencies(&mut self, order: OrderAny) {
         let (filled_qty, leaves_qty, is_spawn_active) =
             if let Some(exec_spawn_id) = order.exec_spawn_id() {
@@ -454,6 +482,9 @@ impl OrderManager {
         }
     }
 
+    /// # Panics
+    ///
+    /// Panics if an OCO contingent order cannot be found for the given client order ID.
     pub fn handle_contingencies_update(&mut self, order: OrderAny) {
         let quantity = match order.exec_spawn_id() {
             Some(exec_spawn_id) => {
@@ -497,14 +528,14 @@ impl OrderManager {
                 continue;
             }
 
-            if let Some(contingency_type) = order.contingency_type() {
-                if matches!(
+            if let Some(contingency_type) = order.contingency_type()
+                && matches!(
                     contingency_type,
                     ContingencyType::Oto | ContingencyType::Oco
-                ) && quantity != contingent_order.quantity()
-                {
-                    self.modify_order_quantity(&mut contingent_order, quantity);
-                }
+                )
+                && quantity != contingent_order.quantity()
+            {
+                self.modify_order_quantity(&mut contingent_order, quantity);
             }
         }
     }
@@ -515,38 +546,35 @@ impl OrderManager {
 
     // Message sending methods
     pub fn send_emulator_command(&self, command: TradingCommand) {
-        log::info!("{CMD}{SENT} {command}");
+        log::info!("{CMD}{SEND} {command}");
 
-        msgbus::send(&Ustr::from("OrderEmulator.execute"), &command);
+        msgbus::send_any("OrderEmulator.execute".into(), &command);
     }
 
     pub fn send_algo_command(&self, command: SubmitOrder, exec_algorithm_id: ExecAlgorithmId) {
-        log::info!("{CMD}{SENT} {command}");
+        log::info!("{CMD}{SEND} {command}");
 
         let endpoint = format!("{exec_algorithm_id}.execute");
-        msgbus::send(
-            &Ustr::from(&endpoint),
-            &TradingCommand::SubmitOrder(command),
-        );
+        msgbus::send_any(endpoint.into(), &TradingCommand::SubmitOrder(command));
     }
 
     pub fn send_risk_command(&self, command: TradingCommand) {
-        log::info!("{CMD}{SENT} {command}");
-        msgbus::send(&Ustr::from("RiskEngine.execute"), &command);
+        log::info!("{CMD}{SEND} {command}");
+        msgbus::send_any("RiskEngine.execute".into(), &command);
     }
 
     pub fn send_exec_command(&self, command: TradingCommand) {
-        log::info!("{CMD}{SENT} {command}");
-        msgbus::send(&Ustr::from("ExecEngine.execute"), &command);
+        log::info!("{CMD}{SEND} {command}");
+        msgbus::send_any("ExecEngine.execute".into(), &command);
     }
 
     pub fn send_risk_event(&self, event: OrderEventAny) {
-        log::info!("{EVT}{SENT} {event}");
-        msgbus::send(&Ustr::from("RiskEngine.process"), &event);
+        log::info!("{EVT}{SEND} {event}");
+        msgbus::send_any("RiskEngine.process".into(), &event);
     }
 
     pub fn send_exec_event(&self, event: OrderEventAny) {
-        log::info!("{EVT}{SENT} {event}");
-        msgbus::send(&Ustr::from("ExecEngine.process"), &event);
+        log::info!("{EVT}{SEND} {event}");
+        msgbus::send_any("ExecEngine.process".into(), &event);
     }
 }
