@@ -13,11 +13,31 @@
 //  limitations under the License.
 // -------------------------------------------------------------------------------------------------
 
+//! Database and messaging infrastructure for [NautilusTrader](http://nautilustrader.io).
+//!
+//! The *infrastructure* crate provides backend database implementations and message bus adapters
+//! that enable NautilusTrader to scale from development to production deployments. This includes
+//! enterprise-grade data persistence and messaging capabilities:
+//!
+//! - **Redis integration**: Cache database and message bus implementations using Redis.
+//! - **PostgreSQL integration**: SQL-based cache database with comprehensive data models.
+//! - **Connection management**: Robust connection handling with retry logic and health monitoring.
+//! - **Serialization options**: Support for JSON and MessagePack encoding formats.
+//! - **Python bindings**: PyO3 integration for seamless Python interoperability.
+//!
+//! The crate supports multiple database backends through feature flags, allowing users to choose
+//! the appropriate infrastructure components for their specific deployment requirements and scale.
+//!
+//! # Platform
+//!
 //! [NautilusTrader](http://nautilustrader.io) is an open-source, high-performance, production-grade
 //! algorithmic trading platform, providing quantitative traders with the ability to backtest
 //! portfolios of automated trading strategies on historical data with an event-driven engine,
 //! and also deploy those same strategies live, with no code changes.
 //!
+//! NautilusTrader's design, architecture, and implementation philosophy prioritizes software correctness and safety at the
+//! highest level, with the aim of supporting mission-critical, trading system backtesting and live deployment workloads.
+//!
 //! # Feature flags
 //!
 //! This crate provides feature flags to control source code inclusion during compilation,
@@ -32,8 +52,10 @@
 #![warn(rustc::all)]
 #![deny(unsafe_code)]
 #![deny(nonstandard_style)]
+#![deny(missing_debug_implementations)]
+#![deny(clippy::missing_errors_doc)]
+#![deny(clippy::missing_panics_doc)]
 #![deny(rustdoc::broken_intra_doc_links)]
-// #![deny(clippy::missing_errors_doc)]
 
 #[cfg(feature = "python")]
 pub mod python;
