@@ -15,6 +15,7 @@
 
 use std::{
     collections::{HashMap, VecDeque},
+    fmt::Debug,
     time::{Duration, Instant},
 };
 
@@ -26,6 +27,7 @@ use nautilus_common::{
     },
     custom::CustomData,
     enums::SerializationEncoding,
+    logging::{log_task_awaiting, log_task_started, log_task_stopped},
     runtime::get_runtime,
     signal::Signal,
 };
@@ -55,6 +57,7 @@ use crate::redis::{create_redis_connection, queries::DatabaseQueries};
 // Task and connection names
 const CACHE_READ: &str = "cache-read";
 const CACHE_WRITE: &str = "cache-write";
+const CACHE_PROCESS: &str = "cache-process";
 
 // Error constants
 const FAILED_TX_CHANNEL: &str = "Failed to send to channel";
@@ -92,6 +95,7 @@ pub enum DatabaseOperation {
     Insert,
     Update,
     Delete,
+    DeleteFromList,
     Close,
 }
 
@@ -109,7 +113,7 @@ pub struct DatabaseCommand {
 impl DatabaseCommand {
     /// Creates a new [`DatabaseCommand`] instance.
     #[must_use]
-    pub fn new(op_type: DatabaseOperation, key: String, payload: Option<Vec<Bytes>>) -> Self {
+    pub const fn new(op_type: DatabaseOperation, key: String, payload: Option<Vec<Bytes>>) -> Self {
         Self {
             op_type,
             key: Some(key),
@@ -119,7 +123,7 @@ impl DatabaseCommand {
 
     /// Initialize a `Close` database command, this is meant to close the database cache channel.
     #[must_use]
-    pub fn close() -> Self {
+    pub const fn close() -> Self {
         Self {
             op_type: DatabaseOperation::Close,
             key: None,
@@ -135,20 +139,35 @@ impl DatabaseCommand {
 pub struct RedisCacheDatabase {
     pub con: ConnectionManager,
     pub trader_id: TraderId,
-    encoding: SerializationEncoding,
-    handle: tokio::task::JoinHandle<()>,
-    trader_key: String,
+    pub trader_key: String,
+    pub encoding: SerializationEncoding,
     tx: tokio::sync::mpsc::UnboundedSender<DatabaseCommand>,
+    handle: tokio::task::JoinHandle<()>,
+}
+
+impl Debug for RedisCacheDatabase {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct(stringify!(RedisCacheDatabase))
+            .field("trader_id", &self.trader_id)
+            .field("encoding", &self.encoding)
+            .finish()
+    }
 }
 
 impl RedisCacheDatabase {
-    /// Creates a new [`RedisCacheDatabase`] instance.
-    // need to remove async from here
+    /// Creates a new [`RedisCacheDatabase`] instance for the given `trader_id`, `instance_id`, and `config`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if:
+    /// - The database configuration is missing in `config`.
+    /// - Establishing the Redis connection fails.
+    /// - The command processing task cannot be spawned.
     pub async fn new(
         trader_id: TraderId,
         instance_id: UUID4,
         config: CacheConfig,
-    ) -> anyhow::Result<RedisCacheDatabase> {
+    ) -> anyhow::Result<Self> {
         install_cryptographic_provider();
 
         let db_config = config
@@ -163,24 +182,26 @@ impl RedisCacheDatabase {
         let encoding = config.encoding;
         let handle = get_runtime().spawn(async move {
             if let Err(e) = process_commands(rx, trader_key_clone, config.clone()).await {
-                log::error!("Error in task '{CACHE_WRITE}': {e}");
+                log::error!("Error in task '{CACHE_PROCESS}': {e}");
             }
         });
 
-        Ok(RedisCacheDatabase {
+        Ok(Self {
+            con,
             trader_id,
             trader_key,
-            con,
+            encoding,
             tx,
             handle,
-            encoding,
         })
     }
 
-    pub fn get_encoding(&self) -> SerializationEncoding {
+    #[must_use]
+    pub const fn get_encoding(&self) -> SerializationEncoding {
         self.encoding
     }
 
+    #[must_use]
     pub fn get_trader_key(&self) -> &str {
         &self.trader_key
     }
@@ -189,13 +210,14 @@ impl RedisCacheDatabase {
         log::debug!("Closing");
 
         if let Err(e) = self.tx.send(DatabaseCommand::close()) {
-            log::debug!("Error sending close command: {e:?}")
+            log::debug!("Error sending close command: {e:?}");
         }
 
-        log::debug!("Awaiting task '{CACHE_WRITE}'");
+        log_task_awaiting(CACHE_PROCESS);
+
         tokio::task::block_in_place(|| {
             if let Err(e) = get_runtime().block_on(&mut self.handle) {
-                log::error!("Error awaiting task '{CACHE_WRITE}': {e:?}");
+                log::error!("Error awaiting task '{CACHE_PROCESS}': {e:?}");
             }
         });
 
@@ -211,39 +233,180 @@ impl RedisCacheDatabase {
         }
     }
 
+    /// Retrieves all keys matching the given `pattern` from Redis for this trader.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the underlying Redis scan operation fails.
     pub async fn keys(&mut self, pattern: &str) -> anyhow::Result<Vec<String>> {
         let pattern = format!("{}{REDIS_DELIMITER}{pattern}", self.trader_key);
         log::debug!("Querying keys: {pattern}");
         DatabaseQueries::scan_keys(&mut self.con, pattern).await
     }
 
+    /// Reads the value(s) associated with `key` for this trader from Redis.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the underlying Redis read operation fails.
     pub async fn read(&mut self, key: &str) -> anyhow::Result<Vec<Bytes>> {
         DatabaseQueries::read(&self.con, &self.trader_key, key).await
     }
 
+    /// Sends an insert command for `key` with optional `payload` to Redis via the background task.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the command cannot be sent to the background task channel.
     pub fn insert(&mut self, key: String, payload: Option<Vec<Bytes>>) -> anyhow::Result<()> {
         let op = DatabaseCommand::new(DatabaseOperation::Insert, key, payload);
         match self.tx.send(op) {
-            Ok(_) => Ok(()),
+            Ok(()) => Ok(()),
             Err(e) => anyhow::bail!("{FAILED_TX_CHANNEL}: {e}"),
         }
     }
 
+    /// Sends an update command for `key` with optional `payload` to Redis via the background task.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the command cannot be sent to the background task channel.
     pub fn update(&mut self, key: String, payload: Option<Vec<Bytes>>) -> anyhow::Result<()> {
         let op = DatabaseCommand::new(DatabaseOperation::Update, key, payload);
         match self.tx.send(op) {
-            Ok(_) => Ok(()),
+            Ok(()) => Ok(()),
             Err(e) => anyhow::bail!("{FAILED_TX_CHANNEL}: {e}"),
         }
     }
 
+    /// Sends a delete command for `key` with optional `payload` to Redis via the background task.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the command cannot be sent to the background task channel.
     pub fn delete(&mut self, key: String, payload: Option<Vec<Bytes>>) -> anyhow::Result<()> {
         let op = DatabaseCommand::new(DatabaseOperation::Delete, key, payload);
         match self.tx.send(op) {
-            Ok(_) => Ok(()),
+            Ok(()) => Ok(()),
             Err(e) => anyhow::bail!("{FAILED_TX_CHANNEL}: {e}"),
         }
     }
+
+    /// Delete the given order from the database with comprehensive index cleanup.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the command cannot be sent to the background task channel.
+    pub fn delete_order(&self, client_order_id: &ClientOrderId) -> anyhow::Result<()> {
+        let order_id_bytes = Bytes::from(client_order_id.to_string());
+
+        log::debug!("Deleting order: {client_order_id} from Redis");
+        log::debug!("Trader key: {}", self.trader_key);
+
+        // Delete the order itself
+        let key = format!("{ORDERS}{REDIS_DELIMITER}{client_order_id}");
+        log::debug!("Deleting order key: {key}");
+        let op = DatabaseCommand::new(DatabaseOperation::Delete, key, None);
+        self.tx
+            .send(op)
+            .map_err(|e| anyhow::anyhow!("Failed to send delete order command: {e}"))?;
+
+        // Delete from all order indexes
+        let index_keys = [
+            INDEX_ORDER_IDS,
+            INDEX_ORDERS,
+            INDEX_ORDERS_OPEN,
+            INDEX_ORDERS_CLOSED,
+            INDEX_ORDERS_EMULATED,
+            INDEX_ORDERS_INFLIGHT,
+        ];
+
+        for index_key in &index_keys {
+            let key = index_key.to_string();
+            log::debug!("Deleting from index: {key} (order_id: {client_order_id})");
+            let payload = vec![order_id_bytes.clone()];
+            let op = DatabaseCommand::new(DatabaseOperation::Delete, key, Some(payload));
+            self.tx
+                .send(op)
+                .map_err(|e| anyhow::anyhow!("Failed to send delete order index command: {e}"))?;
+        }
+
+        // Delete from hash indexes
+        let hash_indexes = [INDEX_ORDER_POSITION, INDEX_ORDER_CLIENT];
+        for index_key in &hash_indexes {
+            let key = index_key.to_string();
+            log::debug!("Deleting from hash index: {key} (order_id: {client_order_id})");
+            let payload = vec![order_id_bytes.clone()];
+            let op = DatabaseCommand::new(DatabaseOperation::Delete, key, Some(payload));
+            self.tx.send(op).map_err(|e| {
+                anyhow::anyhow!("Failed to send delete order hash index command: {e}")
+            })?;
+        }
+
+        log::debug!("Sent all delete commands for order: {client_order_id}");
+        Ok(())
+    }
+
+    /// Delete the given position from the database with comprehensive index cleanup.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the command cannot be sent to the background task channel.
+    pub fn delete_position(&self, position_id: &PositionId) -> anyhow::Result<()> {
+        let position_id_bytes = Bytes::from(position_id.to_string());
+
+        log::debug!("Deleting position: {position_id} from Redis");
+        log::debug!("Trader key: {}", self.trader_key);
+
+        // Delete the position itself
+        let key = format!("{POSITIONS}{REDIS_DELIMITER}{position_id}");
+        log::debug!("Deleting position key: {key}");
+        let op = DatabaseCommand::new(DatabaseOperation::Delete, key, None);
+        self.tx
+            .send(op)
+            .map_err(|e| anyhow::anyhow!("Failed to send delete position command: {e}"))?;
+
+        // Delete from all position indexes
+        let index_keys = [
+            INDEX_POSITIONS,
+            INDEX_POSITIONS_OPEN,
+            INDEX_POSITIONS_CLOSED,
+        ];
+
+        for index_key in &index_keys {
+            let key = index_key.to_string();
+            log::debug!("Deleting from index: {key} (position_id: {position_id})");
+            let payload = vec![position_id_bytes.clone()];
+            let op = DatabaseCommand::new(DatabaseOperation::Delete, key, Some(payload));
+            self.tx.send(op).map_err(|e| {
+                anyhow::anyhow!("Failed to send delete position index command: {e}")
+            })?;
+        }
+
+        log::debug!("Sent all delete commands for position: {position_id}");
+        Ok(())
+    }
+
+    /// Delete the given account event from the database.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the command cannot be sent to the background task channel.
+    pub fn delete_account_event(
+        &self,
+        account_id: &AccountId,
+        event_id: &str,
+    ) -> anyhow::Result<()> {
+        log::debug!("Deleting account event: {account_id}:{event_id}");
+        log::debug!("Trader key: {}", self.trader_key);
+
+        let key = format!("{ACCOUNTS}{REDIS_DELIMITER}{account_id}");
+        let payload = vec![Bytes::from(event_id.to_string())];
+        let op = DatabaseCommand::new(DatabaseOperation::DeleteFromList, key, Some(payload));
+        self.tx
+            .send(op)
+            .map_err(|e| anyhow::anyhow!("Failed to send delete account event command: {e}"))
+    }
 }
 
 async fn process_commands(
@@ -251,7 +414,7 @@ async fn process_commands(
     trader_key: String,
     config: CacheConfig,
 ) -> anyhow::Result<()> {
-    tracing::debug!("Starting cache processing");
+    log_task_started(CACHE_PROCESS);
 
     let db_config = config
         .database
@@ -269,20 +432,16 @@ async fn process_commands(
         if last_drain.elapsed() >= buffer_interval && !buffer.is_empty() {
             drain_buffer(&mut con, &trader_key, &mut buffer).await;
             last_drain = Instant::now();
-        } else {
-            match rx.recv().await {
-                Some(cmd) => {
-                    tracing::debug!("Received {cmd:?}");
-                    if let DatabaseOperation::Close = cmd.op_type {
-                        break;
-                    }
-                    buffer.push_back(cmd)
-                }
-                None => {
-                    tracing::debug!("Command channel closed");
-                    break;
-                }
+        } else if let Some(cmd) = rx.recv().await {
+            tracing::trace!("Received {cmd:?}");
+
+            if matches!(cmd.op_type, DatabaseOperation::Close) {
+                break;
             }
+            buffer.push_back(cmd);
+        } else {
+            tracing::debug!("Command channel closed");
+            break;
         }
     }
 
@@ -291,7 +450,7 @@ async fn process_commands(
         drain_buffer(&mut con, &trader_key, &mut buffer).await;
     }
 
-    tracing::debug!("Stopped cache processing");
+    log_task_stopped(CACHE_PROCESS);
     Ok(())
 }
 
@@ -304,12 +463,11 @@ async fn drain_buffer(
     pipe.atomic();
 
     for msg in buffer.drain(..) {
-        let key = match msg.key {
-            Some(key) => key,
-            None => {
-                log::error!("Null key found for message: {msg:?}");
-                continue;
-            }
+        let key = if let Some(key) = msg.key {
+            key
+        } else {
+            log::error!("Null key found for message: {msg:?}");
+            continue;
         };
         let collection = match get_collection_key(&key) {
             Ok(collection) => collection,
@@ -324,6 +482,7 @@ async fn drain_buffer(
         match msg.op_type {
             DatabaseOperation::Insert => {
                 if let Some(payload) = msg.payload {
+                    log::debug!("Processing INSERT for collection: {collection}, key: {key}");
                     if let Err(e) = insert(&mut pipe, collection, &key, payload) {
                         tracing::error!("{e}");
                     }
@@ -333,19 +492,37 @@ async fn drain_buffer(
             }
             DatabaseOperation::Update => {
                 if let Some(payload) = msg.payload {
+                    log::debug!("Processing UPDATE for collection: {collection}, key: {key}");
                     if let Err(e) = update(&mut pipe, collection, &key, payload) {
                         tracing::error!("{e}");
                     }
                 } else {
                     tracing::error!("Null `payload` for `update`");
-                };
+                }
             }
             DatabaseOperation::Delete => {
+                tracing::debug!(
+                    "Processing DELETE for collection: {}, key: {}, payload: {:?}",
+                    collection,
+                    key,
+                    msg.payload.as_ref().map(|p| p.len())
+                );
                 // `payload` can be `None` for a delete operation
                 if let Err(e) = delete(&mut pipe, collection, &key, msg.payload) {
                     tracing::error!("{e}");
                 }
             }
+            DatabaseOperation::DeleteFromList => {
+                log::debug!("Processing DELETE_FROM_LIST for collection: {collection}, key: {key}");
+                // For deleting specific items from Redis lists (TBD if this remains)
+                if let Some(payload) = &msg.payload {
+                    if let Err(e) = delete_from_list(&mut pipe, collection, &key, payload) {
+                        tracing::error!("{e}");
+                    }
+                } else {
+                    tracing::error!("Null `payload` for `delete_from_list`");
+                }
+            }
             DatabaseOperation::Close => panic!("Close command should not be drained"),
         }
     }
@@ -515,8 +692,27 @@ fn delete(
     key: &str,
     value: Option<Vec<Bytes>>,
 ) -> anyhow::Result<()> {
+    tracing::debug!(
+        "delete: collection={}, key={}, has_payload={}",
+        collection,
+        key,
+        value.is_some()
+    );
+
     match collection {
-        INDEX => remove_index(pipe, key, value),
+        INDEX => delete_from_index(pipe, key, value),
+        ORDERS => {
+            delete_string(pipe, key);
+            Ok(())
+        }
+        POSITIONS => {
+            delete_string(pipe, key);
+            Ok(())
+        }
+        ACCOUNTS => {
+            delete_string(pipe, key);
+            Ok(())
+        }
         ACTORS => {
             delete_string(pipe, key);
             Ok(())
@@ -529,11 +725,31 @@ fn delete(
     }
 }
 
-fn remove_index(pipe: &mut Pipeline, key: &str, value: Option<Vec<Bytes>>) -> anyhow::Result<()> {
+fn delete_from_index(
+    pipe: &mut Pipeline,
+    key: &str,
+    value: Option<Vec<Bytes>>,
+) -> anyhow::Result<()> {
     let value = value.ok_or_else(|| anyhow::anyhow!("Empty `payload` for `delete` '{key}'"))?;
     let index_key = get_index_key(key)?;
 
     match index_key {
+        INDEX_ORDER_IDS => {
+            remove_from_set(pipe, key, value[0].as_ref());
+            Ok(())
+        }
+        INDEX_ORDER_POSITION => {
+            remove_from_hash(pipe, key, value[0].as_ref());
+            Ok(())
+        }
+        INDEX_ORDER_CLIENT => {
+            remove_from_hash(pipe, key, value[0].as_ref());
+            Ok(())
+        }
+        INDEX_ORDERS => {
+            remove_from_set(pipe, key, value[0].as_ref());
+            Ok(())
+        }
         INDEX_ORDERS_OPEN => {
             remove_from_set(pipe, key, value[0].as_ref());
             Ok(())
@@ -550,6 +766,10 @@ fn remove_index(pipe: &mut Pipeline, key: &str, value: Option<Vec<Bytes>>) -> an
             remove_from_set(pipe, key, value[0].as_ref());
             Ok(())
         }
+        INDEX_POSITIONS => {
+            remove_from_set(pipe, key, value[0].as_ref());
+            Ok(())
+        }
         INDEX_POSITIONS_OPEN => {
             remove_from_set(pipe, key, value[0].as_ref());
             Ok(())
@@ -566,10 +786,66 @@ fn remove_from_set(pipe: &mut Pipeline, key: &str, member: &[u8]) {
     pipe.srem(key, member);
 }
 
+fn remove_from_hash(pipe: &mut Pipeline, key: &str, field: &[u8]) {
+    pipe.hdel(key, field);
+}
+
 fn delete_string(pipe: &mut Pipeline, key: &str) {
     pipe.del(key);
 }
 
+fn delete_from_list(
+    pipe: &mut Pipeline,
+    collection: &str,
+    key: &str,
+    payload: &[Bytes],
+) -> anyhow::Result<()> {
+    match collection {
+        ACCOUNTS => {
+            // payload[0] contains the event_id as a string
+            let event_id = std::str::from_utf8(&payload[0])?;
+
+            // The Python layer has already determined this event is safe to delete
+            // (it's not the last event). We can safely remove it from the Redis list.
+            // Since account events are stored as serialized objects, we need to find
+            // and remove items that contain the event_id within their serialized data.
+            let lua_script = r#"
+                local key = KEYS[1]
+                local event_id = ARGV[1]
+                local removed_count = 0
+
+                -- Check if the key exists first
+                if redis.call('EXISTS', key) == 0 then
+                    return 0  -- Nothing to delete
+                end
+
+                local items = redis.call('LRANGE', key, 0, -1)
+                redis.call('DEL', key)
+
+                for i, item in ipairs(items) do
+                    if not string.find(item, event_id, 1, true) then
+                        redis.call('RPUSH', key, item)
+                    else
+                        removed_count = removed_count + 1
+                    end
+                end
+
+                return removed_count
+            "#;
+
+            pipe.cmd("EVAL")
+                .arg(lua_script)
+                .arg(1)
+                .arg(key)
+                .arg(event_id);
+            Ok(())
+        }
+        _ => {
+            anyhow::bail!("Unsupported operation: `delete_from_list` for collection '{collection}'")
+        }
+    }
+}
+
 fn get_trader_key(trader_id: TraderId, instance_id: UUID4, config: &CacheConfig) -> String {
     let mut key = String::new();
 
@@ -604,9 +880,10 @@ fn get_index_key(key: &str) -> anyhow::Result<&str> {
 }
 
 #[allow(dead_code)] // Under development
+#[derive(Debug)]
 pub struct RedisCacheDatabaseAdapter {
     pub encoding: SerializationEncoding,
-    database: RedisCacheDatabase,
+    pub database: RedisCacheDatabase,
 }
 
 #[allow(dead_code)] // Under development
@@ -803,6 +1080,98 @@ impl CacheDatabaseAdapter for RedisCacheDatabaseAdapter {
         todo!()
     }
 
+    fn delete_order(&self, client_order_id: &ClientOrderId) -> anyhow::Result<()> {
+        let order_id_bytes = Bytes::from(client_order_id.to_string());
+
+        log::debug!("Deleting order: {client_order_id} from Redis");
+        log::debug!("Trader key: {}", self.database.trader_key);
+
+        // Delete the order itself
+        let key = format!("{ORDERS}{REDIS_DELIMITER}{client_order_id}");
+        log::debug!("Deleting order key: {key}");
+        let op = DatabaseCommand::new(DatabaseOperation::Delete, key, None);
+        self.database
+            .tx
+            .send(op)
+            .map_err(|e| anyhow::anyhow!("Failed to send delete order command: {e}"))?;
+
+        // Delete from all order indexes
+        let index_keys = [
+            INDEX_ORDER_IDS,
+            INDEX_ORDERS,
+            INDEX_ORDERS_OPEN,
+            INDEX_ORDERS_CLOSED,
+            INDEX_ORDERS_EMULATED,
+            INDEX_ORDERS_INFLIGHT,
+        ];
+
+        for index_key in &index_keys {
+            let key = index_key.to_string();
+            log::debug!("Deleting from index: {key} (order_id: {client_order_id})");
+            let payload = vec![order_id_bytes.clone()];
+            let op = DatabaseCommand::new(DatabaseOperation::Delete, key, Some(payload));
+            self.database
+                .tx
+                .send(op)
+                .map_err(|e| anyhow::anyhow!("Failed to send delete order index command: {e}"))?;
+        }
+
+        // Delete from hash indexes
+        let hash_indexes = [INDEX_ORDER_POSITION, INDEX_ORDER_CLIENT];
+        for index_key in &hash_indexes {
+            let key = index_key.to_string();
+            log::debug!("Deleting from hash index: {key} (order_id: {client_order_id})");
+            let payload = vec![order_id_bytes.clone()];
+            let op = DatabaseCommand::new(DatabaseOperation::Delete, key, Some(payload));
+            self.database.tx.send(op).map_err(|e| {
+                anyhow::anyhow!("Failed to send delete order hash index command: {e}")
+            })?;
+        }
+
+        log::debug!("Sent all delete commands for order: {client_order_id}");
+        Ok(())
+    }
+
+    fn delete_position(&self, position_id: &PositionId) -> anyhow::Result<()> {
+        let position_id_bytes = Bytes::from(position_id.to_string());
+
+        // Delete the position itself
+        let key = format!("{POSITIONS}{REDIS_DELIMITER}{position_id}");
+        let op = DatabaseCommand::new(DatabaseOperation::Delete, key, None);
+        self.database
+            .tx
+            .send(op)
+            .map_err(|e| anyhow::anyhow!("Failed to send delete position command: {e}"))?;
+
+        // Delete from all position indexes
+        let index_keys = [
+            INDEX_POSITIONS,
+            INDEX_POSITIONS_OPEN,
+            INDEX_POSITIONS_CLOSED,
+        ];
+
+        for index_key in &index_keys {
+            let key = index_key.to_string();
+            let payload = vec![position_id_bytes.clone()];
+            let op = DatabaseCommand::new(DatabaseOperation::Delete, key, Some(payload));
+            self.database.tx.send(op).map_err(|e| {
+                anyhow::anyhow!("Failed to send delete position index command: {e}")
+            })?;
+        }
+
+        Ok(())
+    }
+
+    fn delete_account_event(&self, account_id: &AccountId, event_id: &str) -> anyhow::Result<()> {
+        let key = format!("{ACCOUNTS}{REDIS_DELIMITER}{account_id}");
+        let payload = vec![Bytes::from(event_id.to_string())];
+        let op = DatabaseCommand::new(DatabaseOperation::DeleteFromList, key, Some(payload));
+        self.database
+            .tx
+            .send(op)
+            .map_err(|e| anyhow::anyhow!("Failed to send delete account event command: {e}"))
+    }
+
     fn add(&self, key: String, value: Bytes) -> anyhow::Result<()> {
         todo!()
     }
@@ -959,8 +1328,10 @@ mod tests {
     fn test_get_trader_key_with_prefix_and_instance_id() {
         let trader_id = TraderId::from("tester-123");
         let instance_id = UUID4::new();
-        let mut config = CacheConfig::default();
-        config.use_instance_id = true;
+        let config = CacheConfig {
+            use_instance_id: true,
+            ..Default::default()
+        };
 
         let key = get_trader_key(trader_id, instance_id, &config);
         assert!(key.starts_with("trader-tester-123:"));
