@@ -15,6 +15,7 @@
 
 use std::{
     collections::{HashMap, VecDeque},
+    fmt::Debug,
     sync::{
         Arc,
         atomic::{AtomicBool, Ordering},
@@ -25,9 +26,11 @@ use std::{
 use bytes::Bytes;
 use futures::stream::Stream;
 use nautilus_common::{
+    logging::{log_task_error, log_task_started, log_task_stopped},
     msgbus::{
-        BusMessage, CLOSE_TOPIC,
+        BusMessage,
         database::{DatabaseConfig, MessageBusConfig, MessageBusDatabaseAdapter},
+        switchboard::CLOSE_TOPIC,
     },
     runtime::get_runtime,
 };
@@ -37,8 +40,9 @@ use nautilus_core::{
 };
 use nautilus_cryptography::providers::install_cryptographic_provider;
 use nautilus_model::identifiers::TraderId;
-use redis::*;
+use redis::{AsyncCommands, streams};
 use streams::StreamReadOptions;
+use ustr::Ustr;
 
 use super::{REDIS_MINID, REDIS_XTRIM, await_handle};
 use crate::redis::{create_redis_connection, get_stream_key};
@@ -69,10 +73,25 @@ pub struct RedisMessageBusDatabase {
     heartbeat_signal: Arc<AtomicBool>,
 }
 
-impl MessageBusDatabaseAdapter for RedisMessageBusDatabase {
-    type DatabaseType = RedisMessageBusDatabase;
+impl Debug for RedisMessageBusDatabase {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct(stringify!(RedisMessageBusDatabase))
+            .field("trader_id", &self.trader_id)
+            .field("instance_id", &self.instance_id)
+            .finish()
+    }
+}
 
-    /// Creates a new [`RedisMessageBusDatabase`] instance.
+impl MessageBusDatabaseAdapter for RedisMessageBusDatabase {
+    type DatabaseType = Self;
+
+    /// Creates a new [`RedisMessageBusDatabase`] instance for the given `trader_id`, `instance_id`, and `config`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if:
+    /// - The database configuration is missing in `config`.
+    /// - Establishing the Redis connection for publishing fails.
     fn new(
         trader_id: TraderId,
         instance_id: UUID4,
@@ -91,14 +110,16 @@ impl MessageBusDatabaseAdapter for RedisMessageBusDatabase {
         // Create publish task (start the runtime here for now)
         let pub_handle = Some(get_runtime().spawn(async move {
             if let Err(e) = publish_messages(pub_rx, trader_id, instance_id, config_clone).await {
-                log::error!("Error in task '{MSGBUS_PUBLISH}': {e}");
-            };
+                log_task_error(MSGBUS_PUBLISH, &e);
+            }
         }));
 
         // Conditionally create stream task and channel if external streams configured
         let external_streams = config.external_streams.clone().unwrap_or_default();
         let stream_signal = Arc::new(AtomicBool::new(false));
-        let (stream_rx, stream_handle) = if !external_streams.is_empty() {
+        let (stream_rx, stream_handle) = if external_streams.is_empty() {
+            (None, None)
+        } else {
             let stream_signal_clone = stream_signal.clone();
             let (stream_tx, stream_rx) = tokio::sync::mpsc::channel::<BusMessage>(100_000);
             (
@@ -108,12 +129,10 @@ impl MessageBusDatabaseAdapter for RedisMessageBusDatabase {
                         stream_messages(stream_tx, db_config, external_streams, stream_signal_clone)
                             .await
                     {
-                        log::error!("Error in task '{MSGBUS_STREAM}': {e}");
+                        log_task_error(MSGBUS_STREAM, &e);
                     }
                 })),
             )
-        } else {
-            (None, None)
         };
 
         // Create heartbeat task
@@ -124,7 +143,7 @@ impl MessageBusDatabaseAdapter for RedisMessageBusDatabase {
             let pub_tx_clone = pub_tx.clone();
 
             Some(get_runtime().spawn(async move {
-                run_heartbeat(heartbeat_interval_secs, signal, pub_tx_clone).await
+                run_heartbeat(heartbeat_interval_secs, signal, pub_tx_clone).await;
             }))
         } else {
             None
@@ -149,8 +168,8 @@ impl MessageBusDatabaseAdapter for RedisMessageBusDatabase {
     }
 
     /// Publishes a message with the given `topic` and `payload`.
-    fn publish(&self, topic: String, payload: Bytes) {
-        let msg = BusMessage { topic, payload };
+    fn publish(&self, topic: Ustr, payload: Bytes) {
+        let msg = BusMessage::new(topic, payload);
         if let Err(e) = self.pub_tx.send(msg) {
             log::error!("Failed to send message: {e}");
         }
@@ -164,10 +183,8 @@ impl MessageBusDatabaseAdapter for RedisMessageBusDatabase {
         self.heartbeat_signal.store(true, Ordering::Relaxed);
 
         if !self.pub_tx.is_closed() {
-            let msg = BusMessage {
-                topic: CLOSE_TOPIC.to_string(),
-                payload: Bytes::new(), // Empty
-            };
+            let msg = BusMessage::new_close();
+
             if let Err(e) = self.pub_tx.send(msg) {
                 log::error!("Failed to send close message: {e:?}");
             }
@@ -185,7 +202,11 @@ impl MessageBusDatabaseAdapter for RedisMessageBusDatabase {
 }
 
 impl RedisMessageBusDatabase {
-    /// Gets the stream receiver for this instance.
+    /// Retrieves the Redis stream receiver for this message bus instance.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the stream receiver has already been taken.
     pub fn get_stream_receiver(
         &mut self,
     ) -> anyhow::Result<tokio::sync::mpsc::Receiver<BusMessage>> {
@@ -212,13 +233,21 @@ impl RedisMessageBusDatabase {
     }
 }
 
+/// Publishes messages received on `rx` to Redis streams for the given `trader_id` and `instance_id`, using `config`.
+///
+/// # Errors
+///
+/// Returns an error if:
+/// - The database configuration is missing in `config`.
+/// - Establishing the Redis connection fails.
+/// - Any Redis command fails during publishing.
 pub async fn publish_messages(
     mut rx: tokio::sync::mpsc::UnboundedReceiver<BusMessage>,
     trader_id: TraderId,
     instance_id: UUID4,
     config: MessageBusConfig,
 ) -> anyhow::Result<()> {
-    tracing::debug!("Starting message publishing");
+    log_task_started(MSGBUS_PUBLISH);
 
     let db_config = config
         .database
@@ -231,13 +260,13 @@ pub async fn publish_messages(
     let autotrim_duration = config
         .autotrim_mins
         .filter(|&mins| mins > 0)
-        .map(|mins| Duration::from_secs(mins as u64 * 60));
+        .map(|mins| Duration::from_secs(u64::from(mins) * 60));
     let mut last_trim_index: HashMap<String, usize> = HashMap::new();
 
     // Buffering
     let mut buffer: VecDeque<BusMessage> = VecDeque::new();
     let mut last_drain = Instant::now();
-    let buffer_interval = Duration::from_millis(config.buffer_interval_ms.unwrap_or(0) as u64);
+    let buffer_interval = Duration::from_millis(u64::from(config.buffer_interval_ms.unwrap_or(0)));
 
     loop {
         if last_drain.elapsed() >= buffer_interval && !buffer.is_empty() {
@@ -251,21 +280,16 @@ pub async fn publish_messages(
             )
             .await?;
             last_drain = Instant::now();
-        } else {
-            match rx.recv().await {
-                Some(msg) => {
-                    if msg.topic == CLOSE_TOPIC {
-                        tracing::debug!("Received close message");
-                        drop(rx);
-                        break;
-                    }
-                    buffer.push_back(msg);
-                }
-                None => {
-                    tracing::debug!("Channel hung up");
-                    break;
-                }
+        } else if let Some(msg) = rx.recv().await {
+            if msg.topic == CLOSE_TOPIC {
+                tracing::debug!("Received close message");
+                drop(rx);
+                break;
             }
+            buffer.push_back(msg);
+        } else {
+            tracing::debug!("Channel hung up");
+            break;
         }
     }
 
@@ -282,7 +306,7 @@ pub async fn publish_messages(
         .await?;
     }
 
-    tracing::debug!("Stopped message publishing");
+    log_task_stopped(MSGBUS_PUBLISH);
     Ok(())
 }
 
@@ -302,9 +326,10 @@ async fn drain_buffer(
             ("topic", msg.topic.as_ref()),
             ("payload", msg.payload.as_ref()),
         ];
-        let stream_key = match stream_per_topic {
-            true => format!("{stream_key}:{}", &msg.topic),
-            false => stream_key.to_string(),
+        let stream_key = if stream_per_topic {
+            format!("{stream_key}:{}", &msg.topic)
+        } else {
+            stream_key.to_string()
         };
         pipe.xadd(&stream_key, "*", &items);
 
@@ -342,13 +367,21 @@ async fn drain_buffer(
     pipe.query_async(conn).await.map_err(anyhow::Error::from)
 }
 
+/// Streams messages from Redis streams and sends them over the provided `tx` channel.
+///
+/// # Errors
+///
+/// Returns an error if:
+/// - Establishing the Redis connection fails.
+/// - Any Redis read operation fails.
 pub async fn stream_messages(
     tx: tokio::sync::mpsc::Sender<BusMessage>,
     config: DatabaseConfig,
     stream_keys: Vec<String>,
     stream_signal: Arc<AtomicBool>,
 ) -> anyhow::Result<()> {
-    tracing::info!("Starting message streaming");
+    log_task_started(MSGBUS_STREAM);
+
     let mut con = create_redis_connection(MSGBUS_STREAM, config).await?;
 
     let stream_keys = &stream_keys
@@ -378,9 +411,9 @@ pub async fn stream_messages(
                     // Timeout occurred: no messages received
                     continue;
                 }
-                for entry in stream_bulk.iter() {
-                    for (_stream_key, stream_msgs) in entry.iter() {
-                        for stream_msg in stream_msgs.iter() {
+                for entry in &stream_bulk {
+                    for stream_msgs in entry.values() {
+                        for stream_msg in stream_msgs {
                             for (id, array) in stream_msg {
                                 last_id.clear();
                                 last_id.push_str(id);
@@ -407,10 +440,18 @@ pub async fn stream_messages(
         }
     }
 
-    tracing::debug!("Stopped message streaming");
+    log_task_stopped(MSGBUS_STREAM);
     Ok(())
 }
 
+/// Decodes a Redis stream message value into a `BusMessage`.
+///
+/// # Errors
+///
+/// Returns an error if:
+/// - The incoming `stream_msg` is not an array.
+/// - The array has fewer than four elements (invalid format).
+/// - Parsing the topic or payload fails.
 fn decode_bus_message(stream_msg: &redis::Value) -> anyhow::Result<BusMessage> {
     if let redis::Value::Array(stream_msg) = stream_msg {
         if stream_msg.len() < 4 {
@@ -434,7 +475,7 @@ fn decode_bus_message(stream_msg: &redis::Value) -> anyhow::Result<BusMessage> {
             }
         };
 
-        Ok(BusMessage { topic, payload })
+        Ok(BusMessage::with_str_topic(topic, payload))
     } else {
         anyhow::bail!("Invalid stream message format: {stream_msg:?}")
     }
@@ -445,9 +486,10 @@ async fn run_heartbeat(
     signal: Arc<AtomicBool>,
     pub_tx: tokio::sync::mpsc::UnboundedSender<BusMessage>,
 ) {
-    tracing::debug!("Starting heartbeat at {heartbeat_interval_secs} second intervals");
+    log_task_started("heartbeat");
+    tracing::debug!("Heartbeat at {heartbeat_interval_secs} second intervals");
 
-    let heartbeat_interval = Duration::from_secs(heartbeat_interval_secs as u64);
+    let heartbeat_interval = Duration::from_secs(u64::from(heartbeat_interval_secs));
     let heartbeat_timer = tokio::time::interval(heartbeat_interval);
 
     let check_interval = Duration::from_millis(100);
@@ -474,14 +516,12 @@ async fn run_heartbeat(
         }
     }
 
-    tracing::debug!("Stopped heartbeat");
+    log_task_stopped("heartbeat");
 }
 
 fn create_heartbeat_msg() -> BusMessage {
-    BusMessage {
-        topic: HEARTBEAT_TOPIC.to_string(),
-        payload: Bytes::from(chrono::Utc::now().to_rfc3339().into_bytes()),
-    }
+    let payload = Bytes::from(chrono::Utc::now().to_rfc3339().into_bytes());
+    BusMessage::with_str_topic(HEARTBEAT_TOPIC, payload)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -600,8 +640,10 @@ mod serial_tests {
 
         let trader_id = TraderId::from("tester-001");
         let instance_id = UUID4::new();
-        let mut config = MessageBusConfig::default();
-        config.database = Some(DatabaseConfig::default());
+        let config = MessageBusConfig {
+            database: Some(DatabaseConfig::default()),
+            ..Default::default()
+        };
 
         let stream_key = get_stream_key(trader_id, instance_id, &config);
         let external_streams = vec![stream_key.clone()];
@@ -626,7 +668,7 @@ mod serial_tests {
         // Shutdown and cleanup
         rx.close();
         handle.await.unwrap();
-        flush_redis(&mut con).await.unwrap()
+        flush_redis(&mut con).await.unwrap();
     }
 
     #[rstest]
@@ -639,8 +681,10 @@ mod serial_tests {
 
         let trader_id = TraderId::from("tester-001");
         let instance_id = UUID4::new();
-        let mut config = MessageBusConfig::default();
-        config.database = Some(DatabaseConfig::default());
+        let config = MessageBusConfig {
+            database: Some(DatabaseConfig::default()),
+            ..Default::default()
+        };
 
         let stream_key = get_stream_key(trader_id, instance_id, &config);
         let external_streams = vec![stream_key.clone()];
@@ -648,7 +692,7 @@ mod serial_tests {
         let stream_signal_clone = stream_signal.clone();
 
         // Use a message ID in the future, as streaming begins
-        // around the timestamp the thread is spawned.
+        // around the timestamp the task is spawned.
         let clock = get_atomic_clock_realtime();
         let future_id = (clock.get_time_ms() + 1_000_000).to_string();
 
@@ -679,7 +723,7 @@ mod serial_tests {
 
         // Shutdown and cleanup
         handle.await.unwrap();
-        flush_redis(&mut con).await.unwrap()
+        flush_redis(&mut con).await.unwrap();
     }
 
     #[rstest]
@@ -690,8 +734,10 @@ mod serial_tests {
 
         let trader_id = TraderId::from("tester-001");
         let instance_id = UUID4::new();
-        let mut config = MessageBusConfig::default();
-        config.database = Some(DatabaseConfig::default());
+        let config = MessageBusConfig {
+            database: Some(DatabaseConfig::default()),
+            ..Default::default()
+        };
 
         let stream_key = get_stream_key(trader_id, instance_id, &config);
         let external_streams = vec![stream_key.clone()];
@@ -734,7 +780,7 @@ mod serial_tests {
         rx.close();
         stream_signal.store(true, Ordering::Relaxed);
         handle.await.unwrap();
-        flush_redis(&mut con).await.unwrap()
+        flush_redis(&mut con).await.unwrap();
     }
 
     #[rstest]
@@ -745,9 +791,11 @@ mod serial_tests {
 
         let trader_id = TraderId::from("tester-001");
         let instance_id = UUID4::new();
-        let mut config = MessageBusConfig::default();
-        config.database = Some(DatabaseConfig::default());
-        config.stream_per_topic = false;
+        let config = MessageBusConfig {
+            database: Some(DatabaseConfig::default()),
+            stream_per_topic: false,
+            ..Default::default()
+        };
         let stream_key = get_stream_key(trader_id, instance_id, &config);
 
         // Start the publish_messages task
@@ -758,10 +806,7 @@ mod serial_tests {
         });
 
         // Send a test message
-        let msg = BusMessage {
-            topic: "test_topic".to_string(),
-            payload: Bytes::from("test_payload"),
-        };
+        let msg = BusMessage::with_str_topic("test_topic", Bytes::from("test_payload"));
         tx.send(msg).unwrap();
 
         // Wait until the message is published to Redis
@@ -775,7 +820,7 @@ mod serial_tests {
                     !messages.is_empty()
                 }
             },
-            Duration::from_secs(2),
+            Duration::from_secs(3),
         )
         .await;
 
@@ -789,10 +834,7 @@ mod serial_tests {
         assert_eq!(decoded_message.payload, Bytes::from("test_payload"));
 
         // Stop publishing task
-        let msg = BusMessage {
-            topic: CLOSE_TOPIC.to_string(),
-            payload: Bytes::new(), // Empty
-        };
+        let msg = BusMessage::new_close();
         tx.send(msg).unwrap();
 
         // Shutdown and cleanup
@@ -805,8 +847,10 @@ mod serial_tests {
     async fn test_close() {
         let trader_id = TraderId::from("tester-001");
         let instance_id = UUID4::new();
-        let mut config = MessageBusConfig::default();
-        config.database = Some(DatabaseConfig::default());
+        let config = MessageBusConfig {
+            database: Some(DatabaseConfig::default()),
+            ..Default::default()
+        };
 
         let mut db = RedisMessageBusDatabase::new(trader_id, instance_id, config).unwrap();
 
