@@ -22,6 +22,7 @@ use bytes::Bytes;
 use nautilus_common::{
     cache::database::{CacheDatabaseAdapter, CacheMap},
     custom::CustomData,
+    logging::{log_task_awaiting, log_task_started, log_task_stopped},
     runtime::get_runtime,
     signal::Signal,
 };
@@ -49,6 +50,9 @@ use crate::sql::{
     queries::DatabaseQueries,
 };
 
+// Task and connection names
+const CACHE_PROCESS: &str = "cache-process";
+
 #[derive(Debug)]
 #[cfg_attr(
     feature = "python",
@@ -80,6 +84,15 @@ pub enum DatabaseQuery {
 }
 
 impl PostgresCacheDatabase {
+    /// Connects to the Postgres cache database using the provided connection parameters.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if establishing the database connection fails.
+    ///
+    /// # Panics
+    ///
+    /// Panics if the internal Postgres pool connection attempt (`connect_pg`) unwraps on error.
     pub async fn connect(
         host: Option<String>,
         port: Option<u16>,
@@ -94,16 +107,16 @@ impl PostgresCacheDatabase {
 
         // Spawn a task to handle messages
         let handle = tokio::spawn(async move {
-            PostgresCacheDatabase::process_commands(rx, pg_connect_options.clone().into()).await;
+            Self::process_commands(rx, pg_connect_options.clone().into()).await;
         });
-        Ok(PostgresCacheDatabase { pool, tx, handle })
+        Ok(Self { pool, tx, handle })
     }
 
     async fn process_commands(
         mut rx: tokio::sync::mpsc::UnboundedReceiver<DatabaseQuery>,
         pg_connect_options: PgConnectOptions,
     ) {
-        tracing::debug!("Starting cache processing");
+        log_task_started(CACHE_PROCESS);
 
         let pool = connect_pg(pg_connect_options).await.unwrap();
 
@@ -119,20 +132,15 @@ impl PostgresCacheDatabase {
             if last_drain.elapsed() >= buffer_interval && !buffer.is_empty() {
                 drain_buffer(&pool, &mut buffer).await;
                 last_drain = Instant::now();
-            } else {
-                match rx.recv().await {
-                    Some(msg) => {
-                        tracing::debug!("Received {msg:?}");
-                        match msg {
-                            DatabaseQuery::Close => break,
-                            _ => buffer.push_back(msg),
-                        }
-                    }
-                    None => {
-                        tracing::debug!("Command channel closed");
-                        break;
-                    }
+            } else if let Some(msg) = rx.recv().await {
+                tracing::debug!("Received {msg:?}");
+                match msg {
+                    DatabaseQuery::Close => break,
+                    _ => buffer.push_back(msg),
                 }
+            } else {
+                tracing::debug!("Command channel closed");
+                break;
             }
         }
 
@@ -141,10 +149,15 @@ impl PostgresCacheDatabase {
             drain_buffer(&pool, &mut buffer).await;
         }
 
-        tracing::debug!("Stopped cache processing");
+        log_task_stopped(CACHE_PROCESS);
     }
 }
 
+/// Retrieves a `PostgresCacheDatabase` using default connection options.
+///
+/// # Errors
+///
+/// Returns an error if connecting to the database or initializing the cache adapter fails.
 pub async fn get_pg_cache_database() -> anyhow::Result<PostgresCacheDatabase> {
     let connect_options = get_postgres_connect_options(None, None, None, None, None);
     Ok(PostgresCacheDatabase::connect(
@@ -166,6 +179,7 @@ impl CacheDatabaseAdapter for PostgresCacheDatabase {
         let (tx, rx) = std::sync::mpsc::channel();
 
         log::debug!("Closing connection pool");
+
         tokio::task::block_in_place(|| {
             get_runtime().block_on(async {
                 pool.close().await;
@@ -180,7 +194,8 @@ impl CacheDatabaseAdapter for PostgresCacheDatabase {
             log::error!("Error sending close: {e:?}");
         }
 
-        log::debug!("Awaiting task 'cache-write'"); // Naming tasks will soon be stablized
+        log_task_awaiting("cache-write");
+
         tokio::task::block_in_place(|| {
             if let Err(e) = get_runtime().block_on(&mut self.handle) {
                 log::error!("Error awaiting task 'cache-write': {e:?}");
@@ -525,6 +540,22 @@ impl CacheDatabaseAdapter for PostgresCacheDatabase {
         todo!()
     }
 
+    fn delete_order(&self, client_order_id: &ClientOrderId) -> anyhow::Result<()> {
+        anyhow::bail!(
+            "delete_order not implemented for PostgreSQL cache adapter: {client_order_id}"
+        )
+    }
+
+    fn delete_position(&self, position_id: &PositionId) -> anyhow::Result<()> {
+        anyhow::bail!("delete_position not implemented for PostgreSQL cache adapter: {position_id}")
+    }
+
+    fn delete_account_event(&self, account_id: &AccountId, event_id: &str) -> anyhow::Result<()> {
+        anyhow::bail!(
+            "delete_account_event not implemented for PostgreSQL cache adapter: {account_id}, {event_id}"
+        )
+    }
+
     fn add(&self, key: String, value: Bytes) -> anyhow::Result<()> {
         let query = DatabaseQuery::Add(key, value.into());
         self.tx
