@@ -52,6 +52,11 @@ use crate::sql::models::{
 pub struct DatabaseQueries;
 
 impl DatabaseQueries {
+    /// Truncates all tables in the cache database via the provided Postgres `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the TRUNCATE operation fails.
     pub async fn truncate(pool: &PgPool) -> anyhow::Result<()> {
         sqlx::query("SELECT truncate_all_tables()")
             .execute(pool)
@@ -60,6 +65,11 @@ impl DatabaseQueries {
             .map_err(|e| anyhow::anyhow!("Failed to truncate tables: {e}"))
     }
 
+    /// Inserts a raw key-value entry into the `general` table via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the INSERT operation fails.
     pub async fn add(pool: &PgPool, key: String, value: Vec<u8>) -> anyhow::Result<()> {
         sqlx::query("INSERT INTO general (id, value) VALUES ($1, $2)")
             .bind(key)
@@ -70,6 +80,11 @@ impl DatabaseQueries {
             .map_err(|e| anyhow::anyhow!("Failed to insert into general table: {e}"))
     }
 
+    /// Loads all entries from the `general` table via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SELECT operation fails.
     pub async fn load(pool: &PgPool) -> anyhow::Result<HashMap<String, Vec<u8>>> {
         sqlx::query_as::<_, GeneralRow>("SELECT * FROM general")
             .fetch_all(pool)
@@ -84,13 +99,18 @@ impl DatabaseQueries {
             .map_err(|e| anyhow::anyhow!("Failed to load general table: {e}"))
     }
 
+    /// Inserts or ignores a `Currency` row via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the INSERT operation fails.
     pub async fn add_currency(pool: &PgPool, currency: Currency) -> anyhow::Result<()> {
         sqlx::query(
             "INSERT INTO currency (id, precision, iso4217, name, currency_type) VALUES ($1, $2, $3, $4, $5::currency_type) ON CONFLICT (id) DO NOTHING"
         )
             .bind(currency.code.as_str())
-            .bind(currency.precision as i32)
-            .bind(currency.iso4217 as i32)
+            .bind(i32::from(currency.precision))
+            .bind(i32::from(currency.iso4217))
             .bind(currency.name.as_str())
             .bind(CurrencyTypeModel(currency.currency_type))
             .execute(pool)
@@ -99,6 +119,11 @@ impl DatabaseQueries {
             .map_err(|e| anyhow::anyhow!("Failed to insert into currency table: {e}"))
     }
 
+    /// Loads all `Currency` entries via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SELECT operation fails.
     pub async fn load_currencies(pool: &PgPool) -> anyhow::Result<Vec<Currency>> {
         sqlx::query_as::<_, CurrencyModel>("SELECT * FROM currency ORDER BY id ASC")
             .fetch_all(pool)
@@ -107,6 +132,11 @@ impl DatabaseQueries {
             .map_err(|e| anyhow::anyhow!("Failed to load currencies: {e}"))
     }
 
+    /// Loads a single `Currency` entry by `code` via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SELECT operation fails.
     pub async fn load_currency(pool: &PgPool, code: &str) -> anyhow::Result<Option<Currency>> {
         sqlx::query_as::<_, CurrencyModel>("SELECT * FROM currency WHERE id = $1")
             .bind(code)
@@ -116,6 +146,11 @@ impl DatabaseQueries {
             .map_err(|e| anyhow::anyhow!("Failed to load currency: {e}"))
     }
 
+    /// Inserts or updates an `InstrumentAny` entry via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the INSERT or UPDATE operation fails.
     pub async fn add_instrument(
         pool: &PgPool,
         kind: &str,
@@ -152,8 +187,8 @@ impl DatabaseQueries {
             .bind(instrument.strike_price().map(|x| x.to_string()))
             .bind(instrument.activation_ns().map(|x| x.to_string()))
             .bind(instrument.expiration_ns().map(|x| x.to_string()))
-            .bind(instrument.price_precision() as i32)
-            .bind(instrument.size_precision() as i32)
+            .bind(i32::from(instrument.price_precision()))
+            .bind(i32::from(instrument.size_precision()))
             .bind(instrument.price_increment().to_string())
             .bind(instrument.size_increment().to_string())
             .bind(instrument.maker_fee().to_string())
@@ -175,6 +210,11 @@ impl DatabaseQueries {
             .map_err(|e| anyhow::anyhow!(format!("Failed to insert item {} into instrument table: {:?}", instrument.id().to_string(), e)))
     }
 
+    /// Loads a single `InstrumentAny` entry by `instrument_id` via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SELECT operation fails.
     pub async fn load_instrument(
         pool: &PgPool,
         instrument_id: &InstrumentId,
@@ -189,6 +229,11 @@ impl DatabaseQueries {
             })
     }
 
+    /// Loads all `InstrumentAny` entries via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SELECT operation fails.
     pub async fn load_instruments(pool: &PgPool) -> anyhow::Result<Vec<InstrumentAny>> {
         sqlx::query_as::<_, InstrumentAnyModel>("SELECT * FROM instrument")
             .fetch_all(pool)
@@ -197,6 +242,15 @@ impl DatabaseQueries {
             .map_err(|e| anyhow::anyhow!("Failed to load instruments: {e}"))
     }
 
+    /// Inserts or updates an `OrderAny` entry via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SQL INSERT or UPDATE operation fails.
+    ///
+    /// # Panics
+    ///
+    /// Panics if the order initialization existence check unwraps `None` after awaiting.
     pub async fn add_order(
         pool: &PgPool,
         _kind: &str,
@@ -205,69 +259,76 @@ impl DatabaseQueries {
         client_id: Option<ClientId>,
     ) -> anyhow::Result<()> {
         if updated {
-            let exists =
-                DatabaseQueries::check_if_order_initialized_exists(pool, order.client_order_id())
-                    .await
-                    .unwrap();
-            if !exists {
-                panic!(
-                    "OrderInitialized event does not exist for order: {}",
-                    order.client_order_id()
-                );
-            }
+            let exists = Self::check_if_order_initialized_exists(pool, order.client_order_id())
+                .await
+                .unwrap();
+            assert!(
+                exists,
+                "OrderInitialized event does not exist for order: {}",
+                order.client_order_id()
+            );
         }
         match order.last_event().clone() {
             OrderEventAny::Accepted(event) => {
-                DatabaseQueries::add_order_event(pool, Box::new(event), client_id).await
+                Self::add_order_event(pool, Box::new(event), client_id).await
             }
             OrderEventAny::CancelRejected(event) => {
-                DatabaseQueries::add_order_event(pool, Box::new(event), client_id).await
+                Self::add_order_event(pool, Box::new(event), client_id).await
             }
             OrderEventAny::Canceled(event) => {
-                DatabaseQueries::add_order_event(pool, Box::new(event), client_id).await
+                Self::add_order_event(pool, Box::new(event), client_id).await
             }
             OrderEventAny::Denied(event) => {
-                DatabaseQueries::add_order_event(pool, Box::new(event), client_id).await
+                Self::add_order_event(pool, Box::new(event), client_id).await
             }
             OrderEventAny::Emulated(event) => {
-                DatabaseQueries::add_order_event(pool, Box::new(event), client_id).await
+                Self::add_order_event(pool, Box::new(event), client_id).await
             }
             OrderEventAny::Expired(event) => {
-                DatabaseQueries::add_order_event(pool, Box::new(event), client_id).await
+                Self::add_order_event(pool, Box::new(event), client_id).await
             }
             OrderEventAny::Filled(event) => {
-                DatabaseQueries::add_order_event(pool, Box::new(event), client_id).await
+                Self::add_order_event(pool, Box::new(event), client_id).await
             }
             OrderEventAny::Initialized(event) => {
-                DatabaseQueries::add_order_event(pool, Box::new(event), client_id).await
+                Self::add_order_event(pool, Box::new(event), client_id).await
             }
             OrderEventAny::ModifyRejected(event) => {
-                DatabaseQueries::add_order_event(pool, Box::new(event), client_id).await
+                Self::add_order_event(pool, Box::new(event), client_id).await
             }
             OrderEventAny::PendingCancel(event) => {
-                DatabaseQueries::add_order_event(pool, Box::new(event), client_id).await
+                Self::add_order_event(pool, Box::new(event), client_id).await
             }
             OrderEventAny::PendingUpdate(event) => {
-                DatabaseQueries::add_order_event(pool, Box::new(event), client_id).await
+                Self::add_order_event(pool, Box::new(event), client_id).await
             }
             OrderEventAny::Rejected(event) => {
-                DatabaseQueries::add_order_event(pool, Box::new(event), client_id).await
+                Self::add_order_event(pool, Box::new(event), client_id).await
             }
             OrderEventAny::Released(event) => {
-                DatabaseQueries::add_order_event(pool, Box::new(event), client_id).await
+                Self::add_order_event(pool, Box::new(event), client_id).await
             }
             OrderEventAny::Submitted(event) => {
-                DatabaseQueries::add_order_event(pool, Box::new(event), client_id).await
+                Self::add_order_event(pool, Box::new(event), client_id).await
             }
             OrderEventAny::Updated(event) => {
-                DatabaseQueries::add_order_event(pool, Box::new(event), client_id).await
+                Self::add_order_event(pool, Box::new(event), client_id).await
             }
             OrderEventAny::Triggered(event) => {
-                DatabaseQueries::add_order_event(pool, Box::new(event), client_id).await
+                Self::add_order_event(pool, Box::new(event), client_id).await
             }
         }
     }
 
+    /// Inserts an `OrderSnapshot` entry via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SQL INSERT operation fails.
+    ///
+    /// # Panics
+    ///
+    /// Panics if serialization of `snapshot.exec_algorithm_params` fails.
     pub async fn add_order_snapshot(pool: &PgPool, snapshot: OrderSnapshot) -> anyhow::Result<()> {
         let mut transaction = pool.begin().await?;
 
@@ -369,7 +430,7 @@ impl DatabaseQueries {
             .bind(snapshot.liquidity_side.map(|x| x.to_string()))
             .bind(snapshot.avg_px)
             .bind(snapshot.slippage)
-            .bind(snapshot.commissions.iter().map(|x| x.to_string()).collect::<Vec<String>>())
+            .bind(snapshot.commissions.iter().map(ToString::to_string).collect::<Vec<String>>())
             .bind(snapshot.status.to_string())
             .bind(snapshot.is_post_only)
             .bind(snapshot.is_reduce_only)
@@ -379,12 +440,12 @@ impl DatabaseQueries {
             .bind(snapshot.trigger_instrument_id.map(|x| x.to_string()))
             .bind(snapshot.contingency_type.map(|x| x.to_string()))
             .bind(snapshot.order_list_id.map(|x| x.to_string()))
-            .bind(snapshot.linked_order_ids.map(|x| x.iter().map(|x| x.to_string()).collect::<Vec<String>>()))
+            .bind(snapshot.linked_order_ids.map(|x| x.iter().map(ToString::to_string).collect::<Vec<String>>()))
             .bind(snapshot.parent_order_id.map(|x| x.to_string()))
             .bind(snapshot.exec_algorithm_id.map(|x| x.to_string()))
             .bind(snapshot.exec_algorithm_params.map(|x| serde_json::to_value(x).unwrap()))
             .bind(snapshot.exec_spawn_id.map(|x| x.to_string()))
-            .bind(snapshot.tags.map(|x| x.iter().map(|x| x.to_string()).collect::<Vec<String>>()))
+            .bind(snapshot.tags.map(|x| x.iter().map(ToString::to_string).collect::<Vec<String>>()))
             .bind(snapshot.init_id.to_string())
             .bind(snapshot.ts_init.to_string())
             .bind(snapshot.ts_last.to_string())
@@ -399,6 +460,11 @@ impl DatabaseQueries {
             .map_err(|e| anyhow::anyhow!("Failed to commit transaction: {e}"))
     }
 
+    /// Loads an `OrderSnapshot` entry by client order ID via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SQL SELECT or deserialization fails.
     pub async fn load_order_snapshot(
         pool: &PgPool,
         client_order_id: &ClientOrderId,
@@ -413,6 +479,11 @@ impl DatabaseQueries {
         .map_err(|e| anyhow::anyhow!("Failed to load order snapshot: {e}"))
     }
 
+    /// Inserts or updates a `PositionSnapshot` entry via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SQL INSERT or UPDATE operation fails, or if beginning the transaction fails.
     pub async fn add_position_snapshot(
         pool: &PgPool,
         snapshot: PositionSnapshot,
@@ -468,7 +539,7 @@ impl DatabaseQueries {
             .bind(snapshot.realized_return)
             .bind(snapshot.realized_pnl.map(|x| x.to_string()))
             .bind(snapshot.unrealized_pnl.map(|x| x.to_string()))
-            .bind(snapshot.commissions.iter().map(|x| x.to_string()).collect::<Vec<String>>())
+            .bind(snapshot.commissions.iter().map(ToString::to_string).collect::<Vec<String>>())
             .bind(snapshot.duration_ns.map(|x| x.to_string()))
             .bind(snapshot.ts_opened.to_string())
             .bind(snapshot.ts_closed.map(|x| x.to_string()))
@@ -484,6 +555,11 @@ impl DatabaseQueries {
             .map_err(|e| anyhow::anyhow!("Failed to commit transaction: {e}"))
     }
 
+    /// Loads a `PositionSnapshot` entry by `position_id` via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SQL SELECT or deserialization fails.
     pub async fn load_position_snapshot(
         pool: &PgPool,
         position_id: &PositionId,
@@ -496,6 +572,11 @@ impl DatabaseQueries {
             .map_err(|e| anyhow::anyhow!("Failed to load position snapshot: {e}"))
     }
 
+    /// Checks if an `OrderInitialized` event exists for the given `client_order_id` via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SQL SELECT operation fails.
     pub async fn check_if_order_initialized_exists(
         pool: &PgPool,
         client_order_id: ClientOrderId,
@@ -510,6 +591,11 @@ impl DatabaseQueries {
             .map_err(|e| anyhow::anyhow!("Failed to check if order initialized exists: {e}"))
     }
 
+    /// Checks if any account event exists for the given `account_id` via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SQL SELECT operation fails.
     pub async fn check_if_account_event_exists(
         pool: &PgPool,
         account_id: AccountId,
@@ -526,6 +612,11 @@ impl DatabaseQueries {
         .map_err(|e| anyhow::anyhow!("Failed to check if account event exists: {e}"))
     }
 
+    /// Inserts or updates an order event entry via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SQL INSERT or UPDATE operation fails.
     pub async fn add_order_event(
         pool: &PgPool,
         order_event: Box<dyn OrderEvent>,
@@ -563,24 +654,24 @@ impl DatabaseQueries {
 
         sqlx::query(r#"
             INSERT INTO "order_event" (
-                id, kind, client_order_id, order_type, order_side, trader_id, client_id, strategy_id, instrument_id, trade_id, currency, quantity, time_in_force, liquidity_side,
+                id, kind, client_order_id, order_type, order_side, trader_id, client_id, reason, strategy_id, instrument_id, trade_id, currency, quantity, time_in_force, liquidity_side,
                 post_only, reduce_only, quote_quantity, reconciliation, price, last_px, last_qty, trigger_price, trigger_type, limit_offset, trailing_offset,
                 trailing_offset_type, expire_time, display_qty, emulation_trigger, trigger_instrument_id, contingency_type,
                 order_list_id, linked_order_ids, parent_order_id,
                 exec_algorithm_id, exec_spawn_id, venue_order_id, account_id, position_id, commission, ts_event, ts_init, created_at, updated_at
             ) VALUES (
                 $1, $2, $3, $4, $5, $6, $7, $8, $9, $10, $11, $12, $13, $14, $15, $16, $17, $18, $19, $20,
-                $21, $22, $23, $24, $25::trailing_offset_type, $26, $27, $28, $29, $30, $31, $32, $33, $34,
-                $35, $36, $37, $38, $39, $40, $41, $42,  CURRENT_TIMESTAMP, CURRENT_TIMESTAMP
+                $21, $22, $23, $24, $25, $26::trailing_offset_type, $27, $28, $29, $30, $31, $32, $33, $34,
+                $35, $36, $37, $38, $39, $40, $41, $42, $43, CURRENT_TIMESTAMP, CURRENT_TIMESTAMP
             )
             ON CONFLICT (id)
             DO UPDATE
             SET
-                kind = $2, client_order_id = $3, order_type = $4, order_side=$5, trader_id = $6, client_id = $7, strategy_id = $8, instrument_id = $9, trade_id = $10, currency = $11,
-                quantity = $12, time_in_force = $13, liquidity_side = $14, post_only = $15, reduce_only = $16, quote_quantity = $17, reconciliation = $18, price = $19, last_px = $20,
-                last_qty = $21, trigger_price = $22, trigger_type = $23, limit_offset = $24, trailing_offset = $25, trailing_offset_type = $26, expire_time = $27, display_qty = $28,
-                emulation_trigger = $29, trigger_instrument_id = $30, contingency_type = $31, order_list_id = $32, linked_order_ids = $33, parent_order_id = $34, exec_algorithm_id = $35,
-                exec_spawn_id = $36, venue_order_id = $37, account_id = $38, position_id = $39, commission = $40, ts_event = $41, ts_init = $42, updated_at = CURRENT_TIMESTAMP
+                kind = $2, client_order_id = $3, order_type = $4, order_side=$5, trader_id = $6, client_id = $7, reason = $8, strategy_id = $9, instrument_id = $10, trade_id = $11, currency = $12,
+                quantity = $13, time_in_force = $14, liquidity_side = $15, post_only = $16, reduce_only = $17, quote_quantity = $18, reconciliation = $19, price = $20, last_px = $21,
+                last_qty = $22, trigger_price = $23, trigger_type = $24, limit_offset = $25, trailing_offset = $26, trailing_offset_type = $27, expire_time = $28, display_qty = $29,
+                emulation_trigger = $30, trigger_instrument_id = $31, contingency_type = $32, order_list_id = $33, linked_order_ids = $34, parent_order_id = $35, exec_algorithm_id = $36,
+                exec_spawn_id = $37, venue_order_id = $38, account_id = $39, position_id = $40, commission = $41, ts_event = $42, ts_init = $43, updated_at = CURRENT_TIMESTAMP
 
         "#)
             .bind(order_event.id().to_string())
@@ -590,6 +681,7 @@ impl DatabaseQueries {
             .bind(order_event.order_side().map(|x| x.to_string()))
             .bind(order_event.trader_id().to_string())
             .bind(client_id.map(|x| x.to_string()))
+            .bind(order_event.reason().map(|x| x.to_string()))
             .bind(order_event.strategy_id().to_string())
             .bind(order_event.instrument_id().to_string())
             .bind(order_event.trade_id().map(|x| x.to_string()))
@@ -615,7 +707,7 @@ impl DatabaseQueries {
             .bind(order_event.trigger_instrument_id().map(|x| x.to_string()))
             .bind(order_event.contingency_type().map(|x| x.to_string()))
             .bind(order_event.order_list_id().map(|x| x.to_string()))
-            .bind(order_event.linked_order_ids().map(|x| x.iter().map(|x| x.to_string()).collect::<Vec<String>>()))
+            .bind(order_event.linked_order_ids().map(|x| x.iter().map(ToString::to_string).collect::<Vec<String>>()))
             .bind(order_event.parent_order_id().map(|x| x.to_string()))
             .bind(order_event.exec_algorithm_id().map(|x| x.to_string()))
             .bind(order_event.exec_spawn_id().map(|x| x.to_string()))
@@ -635,6 +727,11 @@ impl DatabaseQueries {
             .map_err(|e| anyhow::anyhow!("Failed to commit transaction: {e}"))
     }
 
+    /// Loads all order events for a `client_order_id` via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SQL SELECT or deserialization fails.
     pub async fn load_order_events(
         pool: &PgPool,
         client_order_id: &ClientOrderId,
@@ -647,11 +744,20 @@ impl DatabaseQueries {
         .map_err(|e| anyhow::anyhow!("Failed to load order events: {e}"))
     }
 
+    /// Loads and assembles a complete `OrderAny` for a `client_order_id` via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if assembling events or SQL operations fail.
+    ///
+    /// # Panics
+    ///
+    /// Panics if assembling the order from events fails.
     pub async fn load_order(
         pool: &PgPool,
         client_order_id: &ClientOrderId,
     ) -> anyhow::Result<Option<OrderAny>> {
-        let order_events = DatabaseQueries::load_order_events(pool, client_order_id).await;
+        let order_events = Self::load_order_events(pool, client_order_id).await;
 
         match order_events {
             Ok(order_events) => {
@@ -665,6 +771,15 @@ impl DatabaseQueries {
         }
     }
 
+    /// Loads and assembles all `OrderAny` entries via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if loading events or SQL operations fail.
+    ///
+    /// # Panics
+    ///
+    /// Panics if loading or assembling any individual order fails.
     pub async fn load_orders(pool: &PgPool) -> anyhow::Result<Vec<OrderAny>> {
         let mut orders: Vec<OrderAny> = Vec::new();
         let client_order_ids: Vec<ClientOrderId> = sqlx::query(
@@ -681,7 +796,7 @@ impl DatabaseQueries {
         })
         .map_err(|e| anyhow::anyhow!("Failed to load order ids: {e}"))?;
         for id in client_order_ids {
-            let order = DatabaseQueries::load_order(pool, &id).await.unwrap();
+            let order = Self::load_order(pool, &id).await.unwrap();
             match order {
                 Some(order) => {
                     orders.push(order);
@@ -694,6 +809,15 @@ impl DatabaseQueries {
         Ok(orders)
     }
 
+    /// Inserts or updates an `AccountAny` entry via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SQL INSERT or UPDATE operation fails.
+    ///
+    /// # Panics
+    ///
+    /// Panics if checking for existing account event unwrap fails.
     pub async fn add_account(
         pool: &PgPool,
         kind: &str,
@@ -701,12 +825,14 @@ impl DatabaseQueries {
         account: Box<dyn Account>,
     ) -> anyhow::Result<()> {
         if updated {
-            let exists = DatabaseQueries::check_if_account_event_exists(pool, account.id())
+            let exists = Self::check_if_account_event_exists(pool, account.id())
                 .await
                 .unwrap();
-            if !exists {
-                panic!("Account event does not exist for account: {}", account.id());
-            }
+            assert!(
+                exists,
+                "Account event does not exist for account: {}",
+                account.id()
+            );
         }
 
         let mut transaction = pool.begin().await?;
@@ -754,6 +880,11 @@ impl DatabaseQueries {
             .map_err(|e| anyhow::anyhow!("Failed to commit add_account transaction: {e}"))
     }
 
+    /// Loads all account events for `account_id` via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SQL SELECT or deserialization fails.
     pub async fn load_account_events(
         pool: &PgPool,
         account_id: &AccountId,
@@ -768,11 +899,20 @@ impl DatabaseQueries {
         .map_err(|e| anyhow::anyhow!("Failed to load account events: {e}"))
     }
 
+    /// Loads and assembles a complete `AccountAny` for `account_id` via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if assembling events or SQL operations fail.
+    ///
+    /// # Panics
+    ///
+    /// Panics if assembling the account from events fails.
     pub async fn load_account(
         pool: &PgPool,
         account_id: &AccountId,
     ) -> anyhow::Result<Option<AccountAny>> {
-        let account_events = DatabaseQueries::load_account_events(pool, account_id).await;
+        let account_events = Self::load_account_events(pool, account_id).await;
         match account_events {
             Ok(account_events) => {
                 if account_events.is_empty() {
@@ -785,6 +925,15 @@ impl DatabaseQueries {
         }
     }
 
+    /// Loads and assembles all `AccountAny` entries via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if loading events or SQL operations fail.
+    ///
+    /// # Panics
+    ///
+    /// Panics if loading or assembling any individual account fails.
     pub async fn load_accounts(pool: &PgPool) -> anyhow::Result<Vec<AccountAny>> {
         let mut accounts: Vec<AccountAny> = Vec::new();
         let account_ids: Vec<AccountId> = sqlx::query(
@@ -801,7 +950,7 @@ impl DatabaseQueries {
         })
         .map_err(|e| anyhow::anyhow!("Failed to load account ids: {e}"))?;
         for id in account_ids {
-            let account = DatabaseQueries::load_account(pool, &id).await.unwrap();
+            let account = Self::load_account(pool, &id).await.unwrap();
             match account {
                 Some(account) => {
                     accounts.push(account);
@@ -814,6 +963,11 @@ impl DatabaseQueries {
         Ok(accounts)
     }
 
+    /// Inserts a `TradeTick` entry via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SQL INSERT operation fails.
     pub async fn add_trade(pool: &PgPool, trade: &TradeTick) -> anyhow::Result<()> {
         sqlx::query(r#"
             INSERT INTO "trade" (
@@ -841,6 +995,11 @@ impl DatabaseQueries {
             .map_err(|e| anyhow::anyhow!("Failed to insert into trade table: {e}"))
     }
 
+    /// Loads all `TradeTick` entries for `instrument_id` via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SQL SELECT or deserialization fails.
     pub async fn load_trades(
         pool: &PgPool,
         instrument_id: &InstrumentId,
@@ -855,6 +1014,11 @@ impl DatabaseQueries {
         .map_err(|e| anyhow::anyhow!("Failed to load trades: {e}"))
     }
 
+    /// Inserts a `QuoteTick` entry via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SQL INSERT operation fails.
     pub async fn add_quote(pool: &PgPool, quote: &QuoteTick) -> anyhow::Result<()> {
         sqlx::query(r#"
             INSERT INTO "quote" (
@@ -881,6 +1045,11 @@ impl DatabaseQueries {
             .map_err(|e| anyhow::anyhow!("Failed to insert into quote table: {e}"))
     }
 
+    /// Loads all `QuoteTick` entries for `instrument_id` via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SQL SELECT or deserialization fails.
     pub async fn load_quotes(
         pool: &PgPool,
         instrument_id: &InstrumentId,
@@ -895,8 +1064,13 @@ impl DatabaseQueries {
         .map_err(|e| anyhow::anyhow!("Failed to load quotes: {e}"))
     }
 
+    /// Inserts a `Bar` entry via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SQL INSERT operation fails.
     pub async fn add_bar(pool: &PgPool, bar: &Bar) -> anyhow::Result<()> {
-        println!("Adding bar: {:?}", bar);
+        println!("Adding bar: {bar:?}");
         sqlx::query(r#"
             INSERT INTO "bar" (
                 instrument_id, step, bar_aggregation, price_type, aggregation_source, open, high, low, close, volume, ts_event, ts_init, created_at, updated_at
@@ -927,6 +1101,11 @@ impl DatabaseQueries {
             .map_err(|e| anyhow::anyhow!("Failed to insert into bar table: {e}"))
     }
 
+    /// Loads all `Bar` entries for `instrument_id` via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SQL SELECT or deserialization fails.
     pub async fn load_bars(
         pool: &PgPool,
         instrument_id: &InstrumentId,
@@ -941,6 +1120,11 @@ impl DatabaseQueries {
         .map_err(|e| anyhow::anyhow!("Failed to load bars: {e}"))
     }
 
+    /// Loads all distinct client order IDs from order events via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SQL SELECT or iteration fails.
     pub async fn load_distinct_order_event_client_ids(
         pool: &PgPool,
     ) -> anyhow::Result<HashMap<ClientOrderId, ClientId>> {
@@ -962,6 +1146,11 @@ impl DatabaseQueries {
         Ok(map)
     }
 
+    /// Inserts a `Signal` entry via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SQL INSERT operation fails.
     pub async fn add_signal(pool: &PgPool, signal: &Signal) -> anyhow::Result<()> {
         sqlx::query(
             r#"
@@ -987,6 +1176,11 @@ impl DatabaseQueries {
         .map_err(|e| anyhow::anyhow!("Failed to insert into signal table: {e}"))
     }
 
+    /// Loads all `Signal` entries by `name` via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SQL SELECT or deserialization fails.
     pub async fn load_signals(pool: &PgPool, name: &str) -> anyhow::Result<Vec<Signal>> {
         sqlx::query_as::<_, SignalModel>(
             r#"SELECT * FROM "signal" WHERE name = $1 ORDER BY ts_init ASC"#,
@@ -998,6 +1192,11 @@ impl DatabaseQueries {
         .map_err(|e| anyhow::anyhow!("Failed to load signals: {e}"))
     }
 
+    /// Inserts a `CustomData` entry via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SQL INSERT operation fails.
     pub async fn add_custom_data(pool: &PgPool, data: &CustomData) -> anyhow::Result<()> {
         sqlx::query(
             r#"
@@ -1029,6 +1228,11 @@ impl DatabaseQueries {
         .map_err(|e| anyhow::anyhow!("Failed to insert into custom table: {e}"))
     }
 
+    /// Loads all `CustomData` entries of `data_type` via the provided `pool`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the SQL SELECT or deserialization fails.
     pub async fn load_custom_data(
         pool: &PgPool,
         data_type: &DataType,
