@@ -14,7 +14,8 @@
 // -------------------------------------------------------------------------------------------------
 
 #[cfg(test)]
-#[cfg(target_os = "linux")] // Databases only supported on Linux
+#[cfg(feature = "postgres")]
+#[cfg(target_os = "linux")] // Databases only tested and supported on Linux
 mod serial_tests {
     use std::{collections::HashSet, time::Duration};
 
@@ -74,7 +75,7 @@ mod serial_tests {
                 let result = pg_cache.load().unwrap();
                 result.keys().len() > 0
             },
-            Duration::from_secs(2),
+            Duration::from_secs(5),
         );
         let result = pg_cache.load().unwrap();
         assert_eq!(result.keys().len(), 1);
@@ -148,7 +149,7 @@ mod serial_tests {
                 let instruments = pg_cache.load_instruments().await.unwrap();
                 currencies.len() >= 6 && instruments.len() >= 7
             },
-            Duration::from_secs(2),
+            Duration::from_secs(5),
         )
         .await;
 
@@ -318,7 +319,7 @@ mod serial_tests {
                 pg_cache.load_currencies().await.unwrap().len() == 2
                     && pg_cache.load_instruments().await.unwrap().len() == 1
             },
-            Duration::from_secs(2),
+            Duration::from_secs(5),
         )
         .await;
 
@@ -385,7 +386,7 @@ mod serial_tests {
                         .unwrap()
                         .is_some()
             },
-            Duration::from_secs(2),
+            Duration::from_secs(5),
         )
         .await;
         let market_order_result = pg_cache
@@ -481,7 +482,7 @@ mod serial_tests {
                     .unwrap();
                 result.is_some() && result.unwrap().status() == OrderStatus::Filled
             },
-            Duration::from_secs(2),
+            Duration::from_secs(5),
         )
         .await;
 
@@ -518,7 +519,7 @@ mod serial_tests {
                     .unwrap()
                     .is_some()
             },
-            Duration::from_secs(2),
+            Duration::from_secs(5),
         )
         .await;
         let account_result = pg_cache.load_account(&account.id()).await.unwrap();
@@ -534,7 +535,7 @@ mod serial_tests {
                 let result = pg_cache.load_account(&account.id()).await.unwrap();
                 result.is_some() && result.unwrap().events().len() >= 2
             },
-            Duration::from_secs(2),
+            Duration::from_secs(5),
         )
         .await;
         let account_result = pg_cache.load_account(&account.id()).await.unwrap();
@@ -565,7 +566,7 @@ mod serial_tests {
                     .is_some()
                     && !pg_cache.load_quotes(&instrument.id()).unwrap().is_empty()
             },
-            Duration::from_secs(2),
+            Duration::from_secs(5),
         )
         .await;
         let quotes = pg_cache.load_quotes(&instrument.id()).unwrap();
@@ -600,7 +601,7 @@ mod serial_tests {
                     .is_some()
                     && !pg_cache.load_trades(&instrument.id()).unwrap().is_empty()
             },
-            Duration::from_secs(2),
+            Duration::from_secs(5),
         )
         .await;
         let trades = pg_cache.load_trades(&instrument.id()).unwrap();
@@ -635,7 +636,7 @@ mod serial_tests {
                     .is_some()
                     && !pg_cache.load_bars(&instrument.id()).unwrap().is_empty()
             },
-            Duration::from_secs(2),
+            Duration::from_secs(5),
         )
         .await;
         let bars = pg_cache.load_bars(&instrument.id()).unwrap();
@@ -658,7 +659,7 @@ mod serial_tests {
 
         wait_until(
             || pg_cache.load_signals(name.as_str()).unwrap().len() == 1,
-            Duration::from_secs(2),
+            Duration::from_secs(5),
         );
 
         let signals = pg_cache.load_signals(name.as_str()).unwrap();
@@ -692,7 +693,7 @@ mod serial_tests {
 
         wait_until(
             || pg_cache.load_custom_data(&data_type).unwrap().len() == 1,
-            Duration::from_secs(2),
+            Duration::from_secs(5),
         );
 
         let datas = pg_cache.load_custom_data(&data_type).unwrap();
