@@ -13,7 +13,9 @@
 //  limitations under the License.
 // -------------------------------------------------------------------------------------------------
 
-use criterion::{Criterion, black_box, criterion_group};
+use std::hint::black_box;
+
+use criterion::{Criterion, criterion_group};
 use nautilus_model::types::fixed::{f64_to_fixed_i64, f64_to_fixed_i128};
 
 pub fn bench_fixed_i64(c: &mut Criterion) {
