@@ -13,6 +13,8 @@
 //  limitations under the License.
 // -------------------------------------------------------------------------------------------------
 
+//! Implementation of a simple *cash* account – an account that cannot hold leveraged positions.
+
 use std::{
     collections::HashMap,
     fmt::Display,
@@ -63,6 +65,11 @@ impl CashAccount {
         false
     }
 
+    /// Recalculates the account balance for the specified currency based on current margins.
+    ///
+    /// # Panics
+    ///
+    /// Panics if conversion from `Decimal` to `f64` fails during balance update.
     pub fn recalculate_balance(&mut self, currency: Currency) {
         let current_balance = match self.balances.get(&currency) {
             Some(balance) => *balance,
@@ -175,6 +182,10 @@ impl Account for CashAccount {
         self.base_apply(event);
     }
 
+    fn purge_account_events(&mut self, ts_now: nautilus_core::UnixNanos, lookback_secs: u64) {
+        self.base.base_purge_account_events(ts_now, lookback_secs);
+    }
+
     fn calculate_balance_locked(
         &mut self,
         instrument: InstrumentAny,
@@ -427,7 +438,7 @@ mod tests {
                 None,
             )
             .unwrap();
-        assert_eq!(balance_locked, Money::from("800032 USD"));
+        assert_eq!(balance_locked, Money::from("800000 USD"));
     }
 
     #[rstest]
@@ -444,7 +455,7 @@ mod tests {
                 None,
             )
             .unwrap();
-        assert_eq!(balance_locked, Money::from("1000040 AUD"));
+        assert_eq!(balance_locked, Money::from("1000000 AUD"));
     }
 
     #[rstest]
