@@ -13,6 +13,9 @@
 //  limitations under the License.
 // -------------------------------------------------------------------------------------------------
 
+//! Implementation of a *margin* account capable of holding leveraged positions and tracking
+//! instrument-specific leverage ratios.
+
 #![allow(dead_code)]
 
 use std::{
@@ -106,6 +109,11 @@ impl MarginAccount {
         maintenance_margins
     }
 
+    /// Updates the initial margin for the specified instrument.
+    ///
+    /// # Panics
+    ///
+    /// Panics if an existing margin balance is found but cannot be unwrapped.
     pub fn update_initial_margin(&mut self, instrument_id: InstrumentId, margin_init: Money) {
         let margin_balance = self.margins.get(&instrument_id);
         if margin_balance.is_none() {
@@ -126,6 +134,11 @@ impl MarginAccount {
         self.recalculate_balance(margin_init.currency);
     }
 
+    /// Returns the initial margin amount for the specified instrument.
+    ///
+    /// # Panics
+    ///
+    /// Panics if no margin balance exists for the given `instrument_id`.
     #[must_use]
     pub fn initial_margin(&self, instrument_id: InstrumentId) -> Money {
         let margin_balance = self.margins.get(&instrument_id);
@@ -136,6 +149,11 @@ impl MarginAccount {
         margin_balance.unwrap().initial
     }
 
+    /// Updates the maintenance margin for the specified instrument.
+    ///
+    /// # Panics
+    ///
+    /// Panics if an existing margin balance is found but cannot be unwrapped.
     pub fn update_maintenance_margin(
         &mut self,
         instrument_id: InstrumentId,
@@ -160,6 +178,11 @@ impl MarginAccount {
         self.recalculate_balance(margin_maintenance.currency);
     }
 
+    /// Returns the maintenance margin amount for the specified instrument.
+    ///
+    /// # Panics
+    ///
+    /// Panics if no margin balance exists for the given `instrument_id`.
     #[must_use]
     pub fn maintenance_margin(&self, instrument_id: InstrumentId) -> Money {
         let margin_balance = self.margins.get(&instrument_id);
@@ -170,6 +193,11 @@ impl MarginAccount {
         margin_balance.unwrap().maintenance
     }
 
+    /// Calculates the initial margin amount for the specified instrument and quantity.
+    ///
+    /// # Panics
+    ///
+    /// Panics if conversion from `Decimal` to `f64` fails, or if `instrument.base_currency()` is `None` for inverse instruments.
     pub fn calculate_initial_margin<T: Instrument>(
         &mut self,
         instrument: T,
@@ -185,9 +213,8 @@ impl MarginAccount {
         }
         let adjusted_notional = notional / leverage;
         let initial_margin_f64 = instrument.margin_init().to_f64().unwrap();
-        let mut margin = adjusted_notional * initial_margin_f64;
-        // add taker fee
-        margin += adjusted_notional * instrument.taker_fee().to_f64().unwrap() * 2.0;
+        let margin = adjusted_notional * initial_margin_f64;
+
         let use_quote_for_inverse = use_quote_for_inverse.unwrap_or(false);
         if instrument.is_inverse() && !use_quote_for_inverse {
             Money::new(margin, instrument.base_currency().unwrap())
@@ -196,6 +223,11 @@ impl MarginAccount {
         }
     }
 
+    /// Calculates the maintenance margin amount for the specified instrument and quantity.
+    ///
+    /// # Panics
+    ///
+    /// Panics if conversion from `Decimal` to `f64` fails, or if `instrument.base_currency()` is `None` for inverse instruments.
     pub fn calculate_maintenance_margin<T: Instrument>(
         &mut self,
         instrument: T,
@@ -211,9 +243,8 @@ impl MarginAccount {
         }
         let adjusted_notional = notional / leverage;
         let margin_maint_f64 = instrument.margin_maint().to_f64().unwrap();
-        let mut margin = adjusted_notional * margin_maint_f64;
-        // Add taker fee
-        margin += adjusted_notional * instrument.taker_fee().to_f64().unwrap();
+        let margin = adjusted_notional * margin_maint_f64;
+
         let use_quote_for_inverse = use_quote_for_inverse.unwrap_or(false);
         if instrument.is_inverse() && !use_quote_for_inverse {
             Money::new(margin, instrument.base_currency().unwrap())
@@ -222,6 +253,13 @@ impl MarginAccount {
         }
     }
 
+    /// Recalculates the account balance for the specified currency based on current margins.
+    ///
+    /// # Panics
+    ///
+    /// This function panics if:
+    /// - No starting balance exists for the given `currency`.
+    /// - Total free margin would be negative.
     pub fn recalculate_balance(&mut self, currency: Currency) {
         let current_balance = match self.balances.get(&currency) {
             Some(balance) => balance,
@@ -293,6 +331,7 @@ impl Account for MarginAccount {
     fn balance_total(&self, currency: Option<Currency>) -> Option<Money> {
         self.base_balance_total(currency)
     }
+
     fn balances_total(&self) -> HashMap<Currency, Money> {
         self.base_balances_total()
     }
@@ -300,6 +339,7 @@ impl Account for MarginAccount {
     fn balance_free(&self, currency: Option<Currency>) -> Option<Money> {
         self.base_balance_free(currency)
     }
+
     fn balances_free(&self) -> HashMap<Currency, Money> {
         self.base_balances_free()
     }
@@ -307,6 +347,7 @@ impl Account for MarginAccount {
     fn balance_locked(&self, currency: Option<Currency>) -> Option<Money> {
         self.base_balance_locked(currency)
     }
+
     fn balances_locked(&self) -> HashMap<Currency, Money> {
         self.base_balances_locked()
     }
@@ -318,24 +359,35 @@ impl Account for MarginAccount {
     fn last_event(&self) -> Option<AccountState> {
         self.base_last_event()
     }
+
     fn events(&self) -> Vec<AccountState> {
         self.events.clone()
     }
+
     fn event_count(&self) -> usize {
         self.events.len()
     }
+
     fn currencies(&self) -> Vec<Currency> {
         self.balances.keys().copied().collect()
     }
+
     fn starting_balances(&self) -> HashMap<Currency, Money> {
         self.balances_starting.clone()
     }
+
     fn balances(&self) -> HashMap<Currency, AccountBalance> {
         self.balances.clone()
     }
+
     fn apply(&mut self, event: AccountState) {
         self.base_apply(event);
     }
+
+    fn purge_account_events(&mut self, ts_now: nautilus_core::UnixNanos, lookback_secs: u64) {
+        self.base.base_purge_account_events(ts_now, lookback_secs);
+    }
+
     fn calculate_balance_locked(
         &mut self,
         instrument: InstrumentAny,
@@ -346,14 +398,31 @@ impl Account for MarginAccount {
     ) -> anyhow::Result<Money> {
         self.base_calculate_balance_locked(instrument, side, quantity, price, use_quote_for_inverse)
     }
+
     fn calculate_pnls(
         &self,
-        instrument: InstrumentAny,
+        _instrument: InstrumentAny, // TBD if this should be removed
         fill: OrderFilled,
         position: Option<Position>,
     ) -> anyhow::Result<Vec<Money>> {
-        self.base_calculate_pnls(instrument, fill, position)
+        let mut pnls: Vec<Money> = Vec::new();
+
+        if let Some(ref pos) = position {
+            if pos.quantity.is_positive() && pos.entry != fill.order_side {
+                // Calculate and add PnL using the minimum of fill quantity and position quantity
+                // to avoid double-limiting that occurs in position.calculate_pnl()
+                let pnl_quantity = Quantity::from_raw(
+                    fill.last_qty.raw.min(pos.quantity.raw),
+                    fill.last_qty.precision,
+                );
+                let pnl = pos.calculate_pnl(pos.avg_px_open, fill.last_px.as_f64(), pnl_quantity);
+                pnls.push(pnl);
+            }
+        }
+
+        Ok(pnls)
     }
+
     fn calculate_commission(
         &self,
         instrument: InstrumentAny,
@@ -408,13 +477,20 @@ impl Hash for MarginAccount {
 mod tests {
     use std::collections::HashMap;
 
+    use nautilus_core::UnixNanos;
     use rstest::rstest;
 
     use crate::{
         accounts::{Account, MarginAccount, stubs::*},
-        events::{AccountState, account::stubs::*},
-        identifiers::{InstrumentId, stubs::*},
-        instruments::{CryptoPerpetual, CurrencyPair, stubs::*},
+        enums::{LiquiditySide, OrderSide, OrderType},
+        events::{AccountState, OrderFilled, account::stubs::*},
+        identifiers::{
+            AccountId, ClientOrderId, InstrumentId, PositionId, StrategyId, TradeId, TraderId,
+            VenueOrderId,
+            stubs::{uuid4, *},
+        },
+        instruments::{CryptoPerpetual, CurrencyPair, InstrumentAny, stubs::*},
+        position::Position,
         types::{Currency, Money, Price, Quantity},
     };
 
@@ -567,7 +643,7 @@ mod tests {
             Price::from("0.8000"),
             None,
         );
-        assert_eq!(result, Money::from("48.06 USD"));
+        assert_eq!(result, Money::from("48.00 USD"));
     }
 
     #[rstest]
@@ -582,7 +658,7 @@ mod tests {
             Price::from("0.8"),
             None,
         );
-        assert_eq!(result, Money::from("240.32 USD"));
+        assert_eq!(result, Money::from("240.00 USD"));
     }
 
     #[rstest]
@@ -596,14 +672,14 @@ mod tests {
             Price::from("11493.60"),
             Some(false),
         );
-        assert_eq!(result_use_quote_inverse_true, Money::from("0.10005568 BTC"));
+        assert_eq!(result_use_quote_inverse_true, Money::from("0.08700494 BTC"));
         let result_use_quote_inverse_false = margin_account.calculate_initial_margin(
             xbtusd_bitmex,
             Quantity::from(100_000),
             Price::from("11493.60"),
             Some(true),
         );
-        assert_eq!(result_use_quote_inverse_false, Money::from("1150 USD"));
+        assert_eq!(result_use_quote_inverse_false, Money::from("1000 USD"));
     }
 
     #[rstest]
@@ -617,7 +693,7 @@ mod tests {
             Price::from("11493.60"),
             None,
         );
-        assert_eq!(result, Money::from("0.03697710 BTC"));
+        assert_eq!(result, Money::from("0.03045173 BTC"));
     }
 
     #[rstest]
@@ -632,7 +708,7 @@ mod tests {
             Price::from("1"),
             None,
         );
-        assert_eq!(result, Money::from("600.40 USD"));
+        assert_eq!(result, Money::from("600.00 USD"));
     }
 
     #[rstest]
@@ -647,6 +723,159 @@ mod tests {
             Price::from("100000.00"),
             None,
         );
-        assert_eq!(result, Money::from("0.00042500 BTC"));
+        assert_eq!(result, Money::from("0.00035000 BTC"));
+    }
+
+    #[rstest]
+    fn test_calculate_pnls_github_issue_2657() {
+        // Create a margin account
+        let account_state = margin_account_state();
+        let account = MarginAccount::new(account_state, false);
+
+        // Create BTCUSDT instrument
+        let btcusdt = currency_pair_btcusdt();
+        let btcusdt_any = InstrumentAny::CurrencyPair(btcusdt);
+
+        // Create initial position with BUY 0.001 BTC at 50000.00
+        let fill1 = OrderFilled::new(
+            TraderId::from("TRADER-001"),
+            StrategyId::from("S-001"),
+            btcusdt.id,
+            ClientOrderId::from("O-1"),
+            VenueOrderId::from("V-1"),
+            AccountId::from("SIM-001"),
+            TradeId::from("T-1"),
+            OrderSide::Buy,
+            OrderType::Market,
+            Quantity::from("0.001"),
+            Price::from("50000.00"),
+            btcusdt.quote_currency,
+            LiquiditySide::Taker,
+            uuid4(),
+            UnixNanos::from(1_000_000_000),
+            UnixNanos::default(),
+            false,
+            Some(PositionId::from("P-GITHUB-2657")),
+            None,
+        );
+
+        let position = Position::new(&btcusdt_any, fill1);
+
+        // Create second fill that sells MORE than position size (0.002 > 0.001)
+        let fill2 = OrderFilled::new(
+            TraderId::from("TRADER-001"),
+            StrategyId::from("S-001"),
+            btcusdt.id,
+            ClientOrderId::from("O-2"),
+            VenueOrderId::from("V-2"),
+            AccountId::from("SIM-001"),
+            TradeId::from("T-2"),
+            OrderSide::Sell,
+            OrderType::Market,
+            Quantity::from("0.002"), // This is larger than position quantity!
+            Price::from("50075.00"),
+            btcusdt.quote_currency,
+            LiquiditySide::Taker,
+            uuid4(),
+            UnixNanos::from(2_000_000_000),
+            UnixNanos::default(),
+            false,
+            Some(PositionId::from("P-GITHUB-2657")),
+            None,
+        );
+
+        // Test the fix - should only calculate PnL for position quantity (0.001), not fill quantity (0.002)
+        let pnls = account
+            .calculate_pnls(btcusdt_any, fill2, Some(position))
+            .unwrap();
+
+        // Should have exactly one PnL entry
+        assert_eq!(pnls.len(), 1);
+
+        // Expected PnL should be for 0.001 BTC, not 0.002 BTC
+        // PnL = (50075.00 - 50000.00) * 0.001 = 75.0 * 0.001 = 0.075 USDT
+        let expected_pnl = Money::from("0.075 USDT");
+        assert_eq!(pnls[0], expected_pnl);
+    }
+
+    #[rstest]
+    fn test_calculate_pnls_with_same_side_fill_returns_empty() {
+        use nautilus_core::UnixNanos;
+
+        use crate::{
+            enums::{LiquiditySide, OrderSide, OrderType},
+            events::OrderFilled,
+            identifiers::{
+                AccountId, ClientOrderId, PositionId, StrategyId, TradeId, TraderId, VenueOrderId,
+                stubs::uuid4,
+            },
+            instruments::InstrumentAny,
+            position::Position,
+            types::{Price, Quantity},
+        };
+
+        // Create a margin account
+        let account_state = margin_account_state();
+        let account = MarginAccount::new(account_state, false);
+
+        // Create BTCUSDT instrument
+        let btcusdt = currency_pair_btcusdt();
+        let btcusdt_any = InstrumentAny::CurrencyPair(btcusdt);
+
+        // Create initial position with BUY 1.0 BTC at 50000.00
+        let fill1 = OrderFilled::new(
+            TraderId::from("TRADER-001"),
+            StrategyId::from("S-001"),
+            btcusdt.id,
+            ClientOrderId::from("O-1"),
+            VenueOrderId::from("V-1"),
+            AccountId::from("SIM-001"),
+            TradeId::from("T-1"),
+            OrderSide::Buy,
+            OrderType::Market,
+            Quantity::from("1.0"),
+            Price::from("50000.00"),
+            btcusdt.quote_currency,
+            LiquiditySide::Taker,
+            uuid4(),
+            UnixNanos::from(1_000_000_000),
+            UnixNanos::default(),
+            false,
+            Some(PositionId::from("P-123456")),
+            None,
+        );
+
+        let position = Position::new(&btcusdt_any, fill1);
+
+        // Create second fill that also BUYS (same side as position entry)
+        let fill2 = OrderFilled::new(
+            TraderId::from("TRADER-001"),
+            StrategyId::from("S-001"),
+            btcusdt.id,
+            ClientOrderId::from("O-2"),
+            VenueOrderId::from("V-2"),
+            AccountId::from("SIM-001"),
+            TradeId::from("T-2"),
+            OrderSide::Buy, // Same side as position entry
+            OrderType::Market,
+            Quantity::from("0.5"),
+            Price::from("51000.00"),
+            btcusdt.quote_currency,
+            LiquiditySide::Taker,
+            uuid4(),
+            UnixNanos::from(2_000_000_000),
+            UnixNanos::default(),
+            false,
+            Some(PositionId::from("P-123456")),
+            None,
+        );
+
+        // Test that no PnL is calculated for same-side fills
+        let pnls = account
+            .calculate_pnls(btcusdt_any, fill2, Some(position))
+            .unwrap();
+
+        // Should return empty PnL list
+        assert_eq!(pnls.len(), 0);
     }
 }
