@@ -20,12 +20,13 @@ pub mod base;
 pub mod cash;
 pub mod margin;
 
-#[cfg(feature = "stubs")]
+#[cfg(any(test, feature = "stubs"))]
 pub mod stubs;
 
 use std::collections::HashMap;
 
 use enum_dispatch::enum_dispatch;
+use nautilus_core::UnixNanos;
 
 // Re-exports
 pub use crate::accounts::{
@@ -62,6 +63,13 @@ pub trait Account: 'static + Send {
     fn starting_balances(&self) -> HashMap<Currency, Money>;
     fn balances(&self) -> HashMap<Currency, AccountBalance>;
     fn apply(&mut self, event: AccountState);
+    fn purge_account_events(&mut self, ts_now: UnixNanos, lookback_secs: u64);
+
+    /// Calculates locked balance for the order parameters.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if calculating locked balance fails.
     fn calculate_balance_locked(
         &mut self,
         instrument: InstrumentAny,
@@ -70,12 +78,24 @@ pub trait Account: 'static + Send {
         price: Price,
         use_quote_for_inverse: Option<bool>,
     ) -> anyhow::Result<Money>;
+
+    /// Calculates PnLs for the fill and position.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if calculating PnLs fails.
     fn calculate_pnls(
         &self,
         instrument: InstrumentAny,
         fill: OrderFilled,
         position: Option<Position>,
     ) -> anyhow::Result<Vec<Money>>;
+
+    /// Calculates commission for the order fill parameters.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if calculating commission fails.
     fn calculate_commission(
         &self,
         instrument: InstrumentAny,
