@@ -13,6 +13,8 @@
 //  limitations under the License.
 // -------------------------------------------------------------------------------------------------
 
+//! Domain model representing a *Bet* used by betting-market integrations (e.g. prediction markets).
+
 use std::fmt::Display;
 
 use rust_decimal::Decimal;
@@ -254,10 +256,11 @@ impl BetPosition {
         self.exposure += bet.exposure();
     }
 
-    /// Decreases the position with the provided bet.
+    /// Decreases the position with the provided bet, updating exposure and realized P&L.
     ///
-    /// This method calculates the realized PnL by comparing the incoming bet with
-    /// a corresponding bet derived from the current position.
+    /// # Panics
+    ///
+    /// Panics if there is no current side (empty position) when unwrapping the side.
     pub fn position_decrease(&mut self, bet: &Bet) {
         let abs_bet_exposure = bet.exposure().abs();
         let abs_self_exposure = self.exposure.abs();
@@ -408,7 +411,7 @@ mod tests {
     #[rstest]
     fn test_display_bet() {
         let bet = Bet::new(dec!(2.0), dec!(100.0), BetSide::Back);
-        let formatted = format!("{}", bet);
+        let formatted = format!("{bet}");
         assert!(formatted.contains("Back"));
         assert!(formatted.contains("2.00"));
         assert!(formatted.contains("100.00"));
@@ -514,7 +517,7 @@ mod tests {
         let mut position = BetPosition::default();
         let bet = Bet::new(dec!(2.0), dec!(100.0), BetSide::Back);
         position.add_bet(bet);
-        let formatted = format!("{}", position);
+        let formatted = format!("{position}");
 
         assert!(formatted.contains("price"));
         assert!(formatted.contains("exposure"));
