@@ -22,7 +22,7 @@ use nautilus_core::{UnixNanos, correctness::FAILED, serialization::Serializable}
 use serde::{Deserialize, Serialize};
 
 use super::{
-    GetTsInit,
+    HasTsInit,
     order::{BookOrder, NULL_ORDER},
 };
 use crate::{
@@ -52,7 +52,7 @@ pub struct OrderBookDelta {
     pub sequence: u64,
     /// UNIX timestamp (nanoseconds) when the book event occurred.
     pub ts_event: UnixNanos,
-    /// UNIX timestamp (nanoseconds) when the struct was initialized.
+    /// UNIX timestamp (nanoseconds) when the instance was created.
     pub ts_init: UnixNanos,
 }
 
@@ -61,8 +61,7 @@ impl OrderBookDelta {
     ///
     /// # Errors
     ///
-    /// This function returns an error:
-    /// - If `action` is [`BookAction::Add`] or [`BookAction::Update`] and `size` is not positive (> 0).
+    /// Returns an error if `action` is [`BookAction::Add`] or [`BookAction::Update`] and `size` is not positive (> 0).
     ///
     /// # Notes
     ///
@@ -95,8 +94,7 @@ impl OrderBookDelta {
     ///
     /// # Panics
     ///
-    /// This function panics:
-    /// - If `action` is [`BookAction::Add`] or [`BookAction::Update`] and `size` is not positive (> 0).
+    /// Panics if `action` is [`BookAction::Add`] or [`BookAction::Update`] and `size` is not positive (> 0).
     #[must_use]
     pub fn new(
         instrument_id: InstrumentId,
@@ -187,7 +185,7 @@ impl Display for OrderBookDelta {
 
 impl Serializable for OrderBookDelta {}
 
-impl GetTsInit for OrderBookDelta {
+impl HasTsInit for OrderBookDelta {
     fn ts_init(&self) -> UnixNanos {
         self.ts_init
     }
@@ -335,7 +333,7 @@ mod tests {
     #[rstest]
     fn test_json_serialization(stub_delta: OrderBookDelta) {
         let delta = stub_delta;
-        let serialized = delta.as_json_bytes().unwrap();
+        let serialized = delta.to_json_bytes().unwrap();
         let deserialized = OrderBookDelta::from_json_bytes(serialized.as_ref()).unwrap();
         assert_eq!(deserialized, delta);
     }
@@ -343,7 +341,7 @@ mod tests {
     #[rstest]
     fn test_msgpack_serialization(stub_delta: OrderBookDelta) {
         let delta = stub_delta;
-        let serialized = delta.as_msgpack_bytes().unwrap();
+        let serialized = delta.to_msgpack_bytes().unwrap();
         let deserialized = OrderBookDelta::from_msgpack_bytes(serialized.as_ref()).unwrap();
         assert_eq!(deserialized, delta);
     }
