@@ -27,7 +27,7 @@ use nautilus_core::{
 };
 use serde::{Deserialize, Serialize};
 
-use super::{GetTsInit, OrderBookDelta};
+use super::{HasTsInit, OrderBookDelta};
 use crate::identifiers::InstrumentId;
 
 /// Represents a grouped batch of `OrderBookDelta` updates for an `OrderBook`.
@@ -49,14 +49,18 @@ pub struct OrderBookDeltas {
     pub sequence: u64,
     /// UNIX timestamp (nanoseconds) when the book event occurred.
     pub ts_event: UnixNanos,
-    /// UNIX timestamp (nanoseconds) when the struct was initialized.
+    /// UNIX timestamp (nanoseconds) when the instance was created.
     pub ts_init: UnixNanos,
 }
 
 impl OrderBookDeltas {
     /// Creates a new [`OrderBookDeltas`] instance.
-    #[allow(clippy::too_many_arguments)]
+    ///
+    /// # Panics
+    ///
+    /// Panics if `deltas` is empty and correctness check fails.
     #[must_use]
+    #[allow(clippy::too_many_arguments)]
     pub fn new(instrument_id: InstrumentId, deltas: Vec<OrderBookDelta>) -> Self {
         Self::new_checked(instrument_id, deltas).expect(FAILED)
     }
@@ -67,6 +71,15 @@ impl OrderBookDeltas {
     ///
     /// PyO3 requires a `Result` type for proper error handling and stacktrace printing in Python.
     #[allow(clippy::too_many_arguments)]
+    /// Creates a new [`OrderBookDeltas`] instance with correctness checking.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if `deltas` is empty.
+    ///
+    /// # Panics
+    ///
+    /// Panics if `deltas` is empty when unwrapping the last element.
     pub fn new_checked(
         instrument_id: InstrumentId,
         deltas: Vec<OrderBookDelta>,
@@ -123,7 +136,7 @@ impl Display for OrderBookDeltas {
     }
 }
 
-impl GetTsInit for OrderBookDeltas {
+impl HasTsInit for OrderBookDeltas {
     fn ts_init(&self) -> UnixNanos {
         self.ts_init
     }
