@@ -28,7 +28,7 @@ pub mod quote;
 pub mod status;
 pub mod trade;
 
-#[cfg(feature = "stubs")]
+#[cfg(any(test, feature = "stubs"))]
 pub mod stubs;
 
 use std::{
@@ -114,6 +114,10 @@ impl_try_from_data!(MarkPriceUpdate, MarkPriceUpdate);
 impl_try_from_data!(IndexPriceUpdate, IndexPriceUpdate);
 impl_try_from_data!(InstrumentClose, InstrumentClose);
 
+/// Converts a vector of `Data` items to a specific variant type.
+///
+/// Filters and converts the data vector, keeping only items that can be
+/// successfully converted to the target type `T`.
 pub fn to_variant<T: TryFrom<Data>>(data: Vec<Data>) -> Vec<T> {
     data.into_iter()
         .filter_map(|d| T::try_from(d).ok())
@@ -142,11 +146,17 @@ impl Data {
     }
 }
 
-pub trait GetTsInit {
+/// Marker trait for types that carry a creation timestamp.
+///
+/// `ts_init` is the moment (UNIX nanoseconds) when this value was first generated or
+/// ingested by Nautilus. It can be used for sequencing, latency measurements,
+/// or monitoring data-pipeline delays.
+pub trait HasTsInit {
+    /// Returns the UNIX timestamp (nanoseconds) when the instance was created.
     fn ts_init(&self) -> UnixNanos;
 }
 
-impl GetTsInit for Data {
+impl HasTsInit for Data {
     fn ts_init(&self) -> UnixNanos {
         match self {
             Self::Delta(d) => d.ts_init,
@@ -162,7 +172,10 @@ impl GetTsInit for Data {
     }
 }
 
-pub fn is_monotonically_increasing_by_init<T: GetTsInit>(data: &[T]) -> bool {
+/// Checks if the data slice is monotonically increasing by initialization timestamp.
+///
+/// Returns `true` if each element's `ts_init` is less than or equal to the next element's `ts_init`.
+pub fn is_monotonically_increasing_by_init<T: HasTsInit>(data: &[T]) -> bool {
     data.windows(2)
         .all(|window| window[0].ts_init() <= window[1].ts_init())
 }
@@ -221,16 +234,6 @@ impl From<InstrumentClose> for Data {
     }
 }
 
-// TODO: https://blog.rust-lang.org/2024/03/30/i128-layout-update.html
-// i128 and u128 is now FFI compatible. However, since the clippy lint
-// hasn't been removed yet. We'll suppress with #[cfg_attr(feature = "high-precision", allow(improper_ctypes_definitions))]
-#[unsafe(no_mangle)]
-#[cfg_attr(feature = "high-precision", allow(improper_ctypes_definitions))]
-pub extern "C" fn data_clone(data: &Data) -> Data {
-    // Dummy function for cbindgen to export types
-    data.clone()
-}
-
 /// Represents a data type including metadata.
 #[derive(Clone, Serialize, Deserialize)]
 #[cfg_attr(
@@ -251,10 +254,10 @@ impl DataType {
         let topic = if let Some(ref meta) = metadata {
             let meta_str = meta
                 .iter()
-                .map(|(k, v)| format!("{}={}", k, v))
+                .map(|(k, v)| format!("{k}={v}"))
                 .collect::<Vec<_>>()
                 .join(".");
-            format!("{}.{}", type_name, meta_str)
+            format!("{type_name}.{meta_str}")
         } else {
             type_name.to_string()
         };
@@ -294,13 +297,13 @@ impl DataType {
         self.topic.as_str()
     }
 
-    /// Returns an [`Option<InstrumentId>`] from the metadata.
+    /// Returns an [`Option<InstrumentId>`] parsed from the metadata.
     ///
     /// # Panics
     ///
-    /// This function panics:
-    /// - If there is no metadata.
-    /// - If the `instrument_id` value contained in the metadata is invalid.
+    /// This function panics if:
+    /// - There is no metadata.
+    /// - The `instrument_id` value contained in the metadata is invalid.
     pub fn instrument_id(&self) -> Option<InstrumentId> {
         let metadata = self.metadata.as_ref().expect("metadata was `None`");
         let instrument_id = metadata.get("instrument_id")?;
@@ -310,52 +313,52 @@ impl DataType {
         )
     }
 
-    /// Returns an [`Option<Venue>`] from the metadata.
+    /// Returns an [`Option<Venue>`] parsed from the metadata.
     ///
     /// # Panics
     ///
-    /// This function panics:
-    /// - If there is no metadata.
-    /// - If the `venue` value contained in the metadata is invalid.
+    /// This function panics if:
+    /// - There is no metadata.
+    /// - The `venue` value contained in the metadata is invalid.
     pub fn venue(&self) -> Option<Venue> {
         let metadata = self.metadata.as_ref().expect("metadata was `None`");
         let venue_str = metadata.get("venue")?;
         Some(Venue::from(venue_str.as_str()))
     }
 
-    /// Returns an [`Option<UnixNanos>`] start from the metadata.
+    /// Returns an [`Option<UnixNanos>`] parsed from the metadata `start` field.
     ///
     /// # Panics
     ///
-    /// This function panics:
-    /// - If there is no metadata.
-    /// - If the `start` value contained in the metadata is invalid.
+    /// This function panics if:
+    /// - There is no metadata.
+    /// - The `start` value contained in the metadata is invalid.
     pub fn start(&self) -> Option<UnixNanos> {
         let metadata = self.metadata.as_ref()?;
         let start_str = metadata.get("start")?;
         Some(UnixNanos::from_str(start_str).expect("Invalid `UnixNanos` for 'start'"))
     }
 
-    /// Returns an [`Option<UnixNanos>`] end from the metadata.
+    /// Returns an [`Option<UnixNanos>`] parsed from the metadata `end` field.
     ///
     /// # Panics
     ///
-    /// This function panics:
-    /// - If there is no metadata.
-    /// - If the `end` value contained in the metadata is invalid.
+    /// This function panics if:
+    /// - There is no metadata.
+    /// - The `end` value contained in the metadata is invalid.
     pub fn end(&self) -> Option<UnixNanos> {
         let metadata = self.metadata.as_ref()?;
         let end_str = metadata.get("end")?;
         Some(UnixNanos::from_str(end_str).expect("Invalid `UnixNanos` for 'end'"))
     }
 
-    /// Returns an [`Option<usize>`] limit from the metadata.
+    /// Returns an [`Option<usize>`] parsed from the metadata `limit` field.
     ///
     /// # Panics
     ///
-    /// This function panics:
-    /// - If there is no metadata.
-    /// - If the `limit` value contained in the metadata is invalid.
+    /// This function panics if:
+    /// - There is no metadata.
+    /// - The `limit` value contained in the metadata is invalid.
     pub fn limit(&self) -> Option<usize> {
         let metadata = self.metadata.as_ref()?;
         let depth_str = metadata.get("limit")?;
@@ -543,7 +546,7 @@ mod tests {
         );
         let data_type = DataType::new("ExampleType", metadata);
 
-        assert_eq!(format!("{}", data_type), "ExampleType.key1=value1");
+        assert_eq!(format!("{data_type}"), "ExampleType.key1=value1");
     }
 
     #[rstest]
