@@ -26,7 +26,7 @@ use nautilus_core::{
 };
 use serde::{Deserialize, Serialize};
 
-use super::GetTsInit;
+use super::HasTsInit;
 use crate::{
     enums::PriceType,
     identifiers::InstrumentId,
@@ -57,7 +57,7 @@ pub struct QuoteTick {
     pub ask_size: Quantity,
     /// UNIX timestamp (nanoseconds) when the quote event occurred.
     pub ts_event: UnixNanos,
-    /// UNIX timestamp (nanoseconds) when the struct was initialized.
+    /// UNIX timestamp (nanoseconds) when the instance was created.
     pub ts_init: UnixNanos,
 }
 
@@ -66,9 +66,9 @@ impl QuoteTick {
     ///
     /// # Errors
     ///
-    /// This function returns an error:
-    /// - If `bid_price.precision` does not equal `ask_price.precision`.
-    /// - If `bid_size.precision` does not equal `ask_size.precision`.
+    /// Returns an error if:
+    /// - `bid_price.precision` does not equal `ask_price.precision`.
+    /// - `bid_size.precision` does not equal `ask_size.precision`.
     ///
     /// # Notes
     ///
@@ -109,9 +109,9 @@ impl QuoteTick {
     ///
     /// # Panics
     ///
-    /// This function panics:
-    /// - If `bid_price.precision` does not equal `ask_price.precision`.
-    /// - If `bid_size.precision` does not equal `ask_size.precision`.
+    /// This function panics if:
+    /// - `bid_price.precision` does not equal `ask_price.precision`.
+    /// - `bid_size.precision` does not equal `ask_size.precision`.
     pub fn new(
         instrument_id: InstrumentId,
         bid_price: Price,
@@ -161,6 +161,10 @@ impl QuoteTick {
     }
 
     /// Returns the [`Price`] for this quote depending on the given `price_type`.
+    ///
+    /// # Panics
+    ///
+    /// Panics if an unsupported `price_type` is provided.
     #[must_use]
     pub fn extract_price(&self, price_type: PriceType) -> Price {
         match price_type {
@@ -175,6 +179,10 @@ impl QuoteTick {
     }
 
     /// Returns the [`Quantity`] for this quote depending on the given `price_type`.
+    ///
+    /// # Panics
+    ///
+    /// Panics if an unsupported `price_type` is provided.
     #[must_use]
     pub fn extract_size(&self, price_type: PriceType) -> Quantity {
         match price_type {
@@ -206,7 +214,7 @@ impl Display for QuoteTick {
 
 impl Serializable for QuoteTick {}
 
-impl GetTsInit for QuoteTick {
+impl HasTsInit for QuoteTick {
     fn ts_init(&self) -> UnixNanos {
         self.ts_init
     }
@@ -300,7 +308,7 @@ mod tests {
     #[rstest]
     fn test_json_serialization(quote_ethusdt_binance: QuoteTick) {
         let quote = quote_ethusdt_binance;
-        let serialized = quote.as_json_bytes().unwrap();
+        let serialized = quote.to_json_bytes().unwrap();
         let deserialized = QuoteTick::from_json_bytes(serialized.as_ref()).unwrap();
         assert_eq!(deserialized, quote);
     }
@@ -308,7 +316,7 @@ mod tests {
     #[rstest]
     fn test_msgpack_serialization(quote_ethusdt_binance: QuoteTick) {
         let quote = quote_ethusdt_binance;
-        let serialized = quote.as_msgpack_bytes().unwrap();
+        let serialized = quote.to_msgpack_bytes().unwrap();
         let deserialized = QuoteTick::from_msgpack_bytes(serialized.as_ref()).unwrap();
         assert_eq!(deserialized, quote);
     }
