@@ -22,7 +22,7 @@ use indexmap::IndexMap;
 use nautilus_core::{UnixNanos, correctness::FAILED, serialization::Serializable};
 use serde::{Deserialize, Serialize};
 
-use super::GetTsInit;
+use super::HasTsInit;
 use crate::{
     enums::AggressorSide,
     identifiers::{InstrumentId, TradeId},
@@ -50,7 +50,7 @@ pub struct TradeTick {
     pub trade_id: TradeId,
     /// UNIX timestamp (nanoseconds) when the trade event occurred.
     pub ts_event: UnixNanos,
-    /// UNIX timestamp (nanoseconds) when the struct was initialized.
+    /// UNIX timestamp (nanoseconds) when the instance was created.
     pub ts_init: UnixNanos,
 }
 
@@ -59,8 +59,7 @@ impl TradeTick {
     ///
     /// # Errors
     ///
-    /// This function returns an error:
-    /// - If `size` is not positive (> 0).
+    /// Returns an error if `size` is not positive (> 0).
     ///
     /// # Notes
     ///
@@ -91,8 +90,7 @@ impl TradeTick {
     ///
     /// # Panics
     ///
-    /// This function panics:
-    /// - If `size` is not positive (> 0).
+    /// Panics if `size` is not positive (> 0).
     #[must_use]
     pub fn new(
         instrument_id: InstrumentId,
@@ -160,7 +158,7 @@ impl Display for TradeTick {
 
 impl Serializable for TradeTick {}
 
-impl GetTsInit for TradeTick {
+impl HasTsInit for TradeTick {
     fn ts_init(&self) -> UnixNanos {
         self.ts_init
     }
@@ -172,7 +170,6 @@ impl GetTsInit for TradeTick {
 #[cfg(test)]
 mod tests {
     use nautilus_core::{UnixNanos, serialization::Serializable};
-    use pyo3::{IntoPyObjectExt, Python};
     use rstest::rstest;
 
     use crate::{
@@ -255,8 +252,27 @@ mod tests {
         assert_eq!(trade.aggressor_side, AggressorSide::Buyer);
     }
 
+    #[rstest]
+    fn test_json_serialization(stub_trade_ethusdt_buyer: TradeTick) {
+        let trade = stub_trade_ethusdt_buyer;
+        let serialized = trade.to_json_bytes().unwrap();
+        let deserialized = TradeTick::from_json_bytes(serialized.as_ref()).unwrap();
+        assert_eq!(deserialized, trade);
+    }
+
+    #[rstest]
+    fn test_msgpack_serialization(stub_trade_ethusdt_buyer: TradeTick) {
+        let trade = stub_trade_ethusdt_buyer;
+        let serialized = trade.to_msgpack_bytes().unwrap();
+        let deserialized = TradeTick::from_msgpack_bytes(serialized.as_ref()).unwrap();
+        assert_eq!(deserialized, trade);
+    }
+
+    #[cfg(feature = "python")]
     #[rstest]
     fn test_from_pyobject(stub_trade_ethusdt_buyer: TradeTick) {
+        use pyo3::{IntoPyObjectExt, Python};
+
         pyo3::prepare_freethreaded_python();
         let trade = stub_trade_ethusdt_buyer;
 
@@ -266,20 +282,4 @@ mod tests {
             assert_eq!(parsed_tick, trade);
         });
     }
-
-    #[rstest]
-    fn test_json_serialization(stub_trade_ethusdt_buyer: TradeTick) {
-        let trade = stub_trade_ethusdt_buyer;
-        let serialized = trade.as_json_bytes().unwrap();
-        let deserialized = TradeTick::from_json_bytes(serialized.as_ref()).unwrap();
-        assert_eq!(deserialized, trade);
-    }
-
-    #[rstest]
-    fn test_msgpack_serialization(stub_trade_ethusdt_buyer: TradeTick) {
-        let trade = stub_trade_ethusdt_buyer;
-        let serialized = trade.as_msgpack_bytes().unwrap();
-        let deserialized = TradeTick::from_msgpack_bytes(serialized.as_ref()).unwrap();
-        assert_eq!(deserialized, trade);
-    }
 }
