@@ -22,13 +22,21 @@ use strum::{AsRefStr, Display, EnumIter, EnumString, FromRepr};
 
 use crate::enum_strum_serde;
 
+/// Provides conversion from a `u8` value to an enum type.
 pub trait FromU8 {
+    /// Converts a `u8` value to the implementing type.
+    ///
+    /// Returns `None` if the value is not a valid representation.
     fn from_u8(value: u8) -> Option<Self>
     where
         Self: Sized;
 }
 
+/// Provides conversion from a `u16` value to an enum type.
 pub trait FromU16 {
+    /// Converts a `u16` value to the implementing type.
+    ///
+    /// Returns `None` if the value is not a valid representation.
     fn from_u16(value: u16) -> Option<Self>
     where
         Self: Sized;
@@ -381,6 +389,10 @@ impl BetSide {
 
 impl From<OrderSide> for BetSide {
     /// Returns the equivalent [`BetSide`] for a given [`OrderSide`].
+    ///
+    /// # Panics
+    ///
+    /// Panics if `side` is [`OrderSide::NoOrderSide`].
     fn from(side: OrderSide) -> Self {
         match side {
             OrderSide::Buy => BetSide::Back,
@@ -847,6 +859,11 @@ pub enum OrderSide {
 }
 
 impl OrderSide {
+    /// Returns the specified [`OrderSideSpecified`] (BUY or SELL) for this side.
+    ///
+    /// # Panics
+    ///
+    /// Panics if `self` is [`OrderSide::NoOrderSide`].
     #[must_use]
     pub fn as_specified(&self) -> OrderSideSpecified {
         match &self {
@@ -1332,6 +1349,7 @@ enum_strum_serde!(MarketStatusAction);
 enum_strum_serde!(OmsType);
 enum_strum_serde!(OptionKind);
 enum_strum_serde!(OrderSide);
+enum_strum_serde!(OrderSideSpecified);
 enum_strum_serde!(OrderStatus);
 enum_strum_serde!(OrderType);
 enum_strum_serde!(PositionSide);
