@@ -35,7 +35,7 @@ pub struct Symbol(Ustr);
 impl Symbol {
     /// Creates a new [`Symbol`] instance with correctness checking.
     ///
-    /// # Error
+    /// # Errors
     ///
     /// Returns an error if `value` is not a valid string.
     ///
@@ -50,9 +50,9 @@ impl Symbol {
 
     /// Creates a new [`Symbol`] instance.
     ///
-    /// # Panic
+    /// # Panics
     ///
-    /// - If `value` is not a valid string.
+    /// Panics if `value` is not a valid string.
     pub fn new<T: AsRef<str>>(value: T) -> Self {
         Self::new_checked(value).expect(FAILED)
     }
@@ -117,7 +117,7 @@ impl Symbol {
         if root_str == self.as_str() {
             root_str.to_string()
         } else {
-            format!("{}*", root_str)
+            format!("{root_str}*")
         }
     }
 }
