@@ -122,9 +122,12 @@ impl BettingInstrument {
     /// # Notes
     ///
     /// PyO3 requires a `Result` type for proper error handling and stacktrace printing in Python.
+    /// # Errors
+    ///
+    /// Returns an error if any input validation fails (precision mismatches or non-positive increments).
     #[allow(clippy::too_many_arguments)]
     pub fn new_checked(
-        id: InstrumentId,
+        instrument_id: InstrumentId,
         raw_symbol: Symbol,
         event_type_id: u64,
         event_type_name: Ustr,
@@ -176,7 +179,7 @@ impl BettingInstrument {
         check_positive_quantity(size_increment, stringify!(size_increment))?;
 
         Ok(Self {
-            id,
+            id: instrument_id,
             raw_symbol,
             event_type_id,
             event_type_name,
@@ -214,10 +217,14 @@ impl BettingInstrument {
         })
     }
 
-    /// Creates a new [`BettingInstrument`] instance.
+    /// Creates a new [`BettingInstrument`] instance by parsing and validating input parameters.
+    ///
+    /// # Panics
+    ///
+    /// Panics if any required parameter is invalid or parsing fails during `new_checked`.
     #[allow(clippy::too_many_arguments)]
     pub fn new(
-        id: InstrumentId,
+        instrument_id: InstrumentId,
         raw_symbol: Symbol,
         event_type_id: u64,
         event_type_name: Ustr,
@@ -254,7 +261,7 @@ impl BettingInstrument {
         ts_init: UnixNanos,
     ) -> Self {
         Self::new_checked(
-            id,
+            instrument_id,
             raw_symbol,
             event_type_id,
             event_type_name,
