@@ -107,9 +107,12 @@ impl CryptoOption {
     /// # Notes
     ///
     /// PyO3 requires a `Result` type for proper error handling and stacktrace printing in Python.
+    /// # Errors
+    ///
+    /// Returns an error if any input validation fails.
     #[allow(clippy::too_many_arguments)]
     pub fn new_checked(
-        id: InstrumentId,
+        instrument_id: InstrumentId,
         raw_symbol: Symbol,
         underlying: Currency,
         quote_currency: Currency,
@@ -155,7 +158,7 @@ impl CryptoOption {
         }
 
         Ok(Self {
-            id,
+            id: instrument_id,
             raw_symbol,
             underlying,
             quote_currency,
@@ -187,9 +190,13 @@ impl CryptoOption {
     }
 
     /// Creates a new [`CryptoOption`] instance.
+    ///
+    /// # Panics
+    ///
+    /// Panics if any parameter is invalid (see `new_checked`).
     #[allow(clippy::too_many_arguments)]
     pub fn new(
-        id: InstrumentId,
+        instrument_id: InstrumentId,
         raw_symbol: Symbol,
         underlying: Currency,
         quote_currency: Currency,
@@ -218,7 +225,7 @@ impl CryptoOption {
         ts_init: UnixNanos,
     ) -> Self {
         Self::new_checked(
-            id,
+            instrument_id,
             raw_symbol,
             underlying,
             quote_currency,
