@@ -100,9 +100,12 @@ impl CryptoPerpetual {
     /// # Notes
     ///
     /// PyO3 requires a `Result` type for proper error handling and stacktrace printing in Python.
+    /// # Errors
+    ///
+    /// Returns an error if any input validation fails.
     #[allow(clippy::too_many_arguments)]
     pub fn new_checked(
-        id: InstrumentId,
+        instrument_id: InstrumentId,
         raw_symbol: Symbol,
         base_currency: Currency,
         quote_currency: Currency,
@@ -143,7 +146,7 @@ impl CryptoPerpetual {
         check_positive_quantity(size_increment, stringify!(size_increment))?;
 
         Ok(Self {
-            id,
+            id: instrument_id,
             raw_symbol,
             base_currency,
             quote_currency,
@@ -170,10 +173,14 @@ impl CryptoPerpetual {
         })
     }
 
-    /// Creates a new [`CryptoPerpetual`] instance
+    /// Creates a new [`CryptoPerpetual`] instance.
+    ///
+    /// # Panics
+    ///
+    /// Panics if any input parameter is invalid (see `new_checked`).
     #[allow(clippy::too_many_arguments)]
     pub fn new(
-        id: InstrumentId,
+        instrument_id: InstrumentId,
         raw_symbol: Symbol,
         base_currency: Currency,
         quote_currency: Currency,
@@ -199,7 +206,7 @@ impl CryptoPerpetual {
         ts_init: UnixNanos,
     ) -> Self {
         Self::new_checked(
-            id,
+            instrument_id,
             raw_symbol,
             base_currency,
             quote_currency,
