@@ -99,9 +99,12 @@ impl FuturesContract {
     /// # Notes
     ///
     /// PyO3 requires a `Result` type for proper error handling and stacktrace printing in Python.
+    /// # Errors
+    ///
+    /// Returns an error if any input validation fails.
     #[allow(clippy::too_many_arguments)]
     pub fn new_checked(
-        id: InstrumentId,
+        instrument_id: InstrumentId,
         raw_symbol: Symbol,
         asset_class: AssetClass,
         exchange: Option<Ustr>,
@@ -137,7 +140,7 @@ impl FuturesContract {
         check_positive_quantity(lot_size, stringify!(lot_size))?;
 
         Ok(Self {
-            id,
+            id: instrument_id,
             raw_symbol,
             asset_class,
             exchange,
@@ -165,9 +168,13 @@ impl FuturesContract {
     }
 
     /// Creates a new [`FuturesContract`] instance.
+    ///
+    /// # Panics
+    ///
+    /// Panics if any input parameter is invalid (see `new_checked`).
     #[allow(clippy::too_many_arguments)]
     pub fn new(
-        id: InstrumentId,
+        instrument_id: InstrumentId,
         raw_symbol: Symbol,
         asset_class: AssetClass,
         exchange: Option<Ustr>,
@@ -191,7 +198,7 @@ impl FuturesContract {
         ts_init: UnixNanos,
     ) -> Self {
         Self::new_checked(
-            id,
+            instrument_id,
             raw_symbol,
             asset_class,
             exchange,
