@@ -103,9 +103,12 @@ impl OptionContract {
     /// # Notes
     ///
     /// PyO3 requires a `Result` type for proper error handling and stacktrace printing in Python.
+    /// # Errors
+    ///
+    /// Returns an error if any input validation fails.
     #[allow(clippy::too_many_arguments)]
     pub fn new_checked(
-        id: InstrumentId,
+        instrument_id: InstrumentId,
         raw_symbol: Symbol,
         asset_class: AssetClass,
         exchange: Option<Ustr>,
@@ -143,7 +146,7 @@ impl OptionContract {
         check_positive_quantity(lot_size, stringify!(lot_size))?;
 
         Ok(Self {
-            id,
+            id: instrument_id,
             raw_symbol,
             asset_class,
             exchange,
@@ -173,9 +176,13 @@ impl OptionContract {
     }
 
     /// Creates a new [`OptionContract`] instance.
+    ///
+    /// # Panics
+    ///
+    /// Panics if any input parameter is invalid (see `new_checked`).
     #[allow(clippy::too_many_arguments)]
     pub fn new(
-        id: InstrumentId,
+        instrument_id: InstrumentId,
         raw_symbol: Symbol,
         asset_class: AssetClass,
         exchange: Option<Ustr>,
@@ -201,7 +208,7 @@ impl OptionContract {
         ts_init: UnixNanos,
     ) -> Self {
         Self::new_checked(
-            id,
+            instrument_id,
             raw_symbol,
             asset_class,
             exchange,
