@@ -92,11 +92,7 @@ impl<'de> Deserialize<'de> for SyntheticInstrument {
 
         let fields = Fields::deserialize(deserializer)?;
 
-        let variables = fields
-            .components
-            .iter()
-            .map(std::string::ToString::to_string)
-            .collect();
+        let variables = fields.components.iter().map(ToString::to_string).collect();
 
         let operator_tree =
             evalexpr::build_operator_tree(&fields.formula).map_err(serde::de::Error::custom)?;
@@ -122,6 +118,9 @@ impl SyntheticInstrument {
     /// # Notes
     ///
     /// PyO3 requires a `Result` type for proper error handling and stacktrace printing in Python.
+    /// # Errors
+    ///
+    /// Returns an error if any input validation fails.
     pub fn new_checked(
         symbol: Symbol,
         price_precision: u8,
@@ -133,10 +132,7 @@ impl SyntheticInstrument {
         let price_increment = Price::new(10f64.powi(-i32::from(price_precision)), price_precision);
 
         // Extract variables from the component instruments
-        let variables: Vec<String> = components
-            .iter()
-            .map(std::string::ToString::to_string)
-            .collect();
+        let variables: Vec<String> = components.iter().map(ToString::to_string).collect();
 
         let operator_tree = evalexpr::build_operator_tree(&formula)?;
 
@@ -154,7 +150,11 @@ impl SyntheticInstrument {
         })
     }
 
-    /// Creates a new [`SyntheticInstrument`] instance
+    /// Creates a new [`SyntheticInstrument`] instance, parsing the given formula.
+    ///
+    /// # Panics
+    ///
+    /// Panics if the provided formula is invalid and cannot be parsed.
     pub fn new(
         symbol: Symbol,
         price_precision: u8,
@@ -179,6 +179,9 @@ impl SyntheticInstrument {
         evalexpr::build_operator_tree(formula).is_ok()
     }
 
+    /// # Errors
+    ///
+    /// Returns an error if parsing the new formula fails.
     pub fn change_formula(&mut self, formula: String) -> anyhow::Result<()> {
         let operator_tree = evalexpr::build_operator_tree(&formula)?;
         self.formula = formula;
@@ -186,9 +189,16 @@ impl SyntheticInstrument {
         Ok(())
     }
 
-    /// Calculates the price of the synthetic instrument based on the given component input prices
-    /// provided as a map.
-    #[allow(dead_code)]
+    /// Calculates the price of the synthetic instrument based on component input prices provided as a map.
+    ///
+    /// # Panics
+    ///
+    /// Panics if a required component price is missing from the input map,
+    /// or if setting the value in the evaluation context fails.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if formula evaluation fails.
     pub fn calculate_from_map(&mut self, inputs: &HashMap<String, f64>) -> anyhow::Result<Price> {
         let mut input_values = Vec::new();
 
@@ -208,6 +218,9 @@ impl SyntheticInstrument {
 
     /// Calculates the price of the synthetic instrument based on the given component input prices
     /// provided as an array of `f64` values.
+    /// # Errors
+    ///
+    /// Returns an error if the input length does not match or formula evaluation fails.
     pub fn calculate(&mut self, inputs: &[f64]) -> anyhow::Result<Price> {
         if inputs.len() != self.variables.len() {
             anyhow::bail!("Invalid number of input values");
@@ -258,7 +271,7 @@ mod tests {
         inputs.insert("LTC.BINANCE".to_string(), 200.0);
         let price = synth.calculate_from_map(&inputs).unwrap();
 
-        assert_eq!(price.as_f64(), 150.0);
+        assert_eq!(price, Price::from("150.0"));
         assert_eq!(
             synth.formula,
             "(BTC.BINANCE + LTC.BINANCE) / 2.0".to_string()
@@ -270,7 +283,7 @@ mod tests {
         let mut synth = SyntheticInstrument::default();
         let inputs = vec![100.0, 200.0];
         let price = synth.calculate(&inputs).unwrap();
-        assert_eq!(price.as_f64(), 150.0);
+        assert_eq!(price, Price::from("150.0"));
     }
 
     #[rstest]
@@ -284,7 +297,7 @@ mod tests {
         inputs.insert("LTC.BINANCE".to_string(), 200.0);
         let price = synth.calculate_from_map(&inputs).unwrap();
 
-        assert_eq!(price.as_f64(), 75.0);
+        assert_eq!(price, Price::from("75.0"));
         assert_eq!(synth.formula, new_formula);
     }
 }
