@@ -29,10 +29,11 @@ pub mod stop_market;
 pub mod trailing_stop_limit;
 pub mod trailing_stop_market;
 
-#[cfg(feature = "stubs")]
+#[cfg(any(test, feature = "stubs"))]
 pub mod stubs;
 
 // Re-exports
+use anyhow::anyhow;
 use enum_dispatch::enum_dispatch;
 use indexmap::IndexMap;
 use nautilus_core::{UUID4, UnixNanos};
@@ -110,8 +111,11 @@ pub enum OrderError {
     AlreadyInitialized,
     #[error("Order had no previous state")]
     NoPreviousState,
+    #[error("{0}")]
+    Invariant(#[from] anyhow::Error),
 }
 
+/// Converts an IndexMap with `Ustr` keys and values to `String` keys and values.
 #[must_use]
 pub fn ustr_indexmap_to_str(h: IndexMap<Ustr, Ustr>) -> IndexMap<String, String> {
     h.into_iter()
@@ -119,6 +123,7 @@ pub fn ustr_indexmap_to_str(h: IndexMap<Ustr, Ustr>) -> IndexMap<String, String>
         .collect()
 }
 
+/// Converts an IndexMap with `String` keys and values to `Ustr` keys and values.
 #[must_use]
 pub fn str_indexmap_to_ustr(h: IndexMap<String, String>) -> IndexMap<Ustr, Ustr> {
     h.into_iter()
@@ -126,7 +131,40 @@ pub fn str_indexmap_to_ustr(h: IndexMap<String, String>) -> IndexMap<Ustr, Ustr>
         .collect()
 }
 
+#[inline]
+pub(crate) fn check_display_qty(
+    display_qty: Option<Quantity>,
+    quantity: Quantity,
+) -> Result<(), OrderError> {
+    if let Some(q) = display_qty {
+        if q > quantity {
+            return Err(OrderError::Invariant(anyhow!(
+                "`display_qty` may not exceed `quantity`"
+            )));
+        }
+    }
+    Ok(())
+}
+
+#[inline]
+pub(crate) fn check_time_in_force(
+    time_in_force: TimeInForce,
+    expire_time: Option<UnixNanos>,
+) -> Result<(), OrderError> {
+    if time_in_force == TimeInForce::Gtd && expire_time.unwrap_or_default() == 0 {
+        return Err(OrderError::Invariant(anyhow!(
+            "`expire_time` is required for `GTD` order"
+        )));
+    }
+    Ok(())
+}
+
 impl OrderStatus {
+    /// Transitions the order state machine based on the given `event`.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the state transition is invalid from the current status.
     #[rustfmt::skip]
     pub fn transition(&mut self, event: &OrderEventAny) -> Result<Self, OrderError> {
         let new_state = match (self, event) {
@@ -214,6 +252,9 @@ pub trait Order: 'static + Send {
     fn expire_time(&self) -> Option<UnixNanos>;
     fn price(&self) -> Option<Price>;
     fn trigger_price(&self) -> Option<Price>;
+    fn activation_price(&self) -> Option<Price> {
+        None
+    }
     fn trigger_type(&self) -> Option<TriggerType>;
     fn liquidity_side(&self) -> Option<LiquiditySide>;
     fn is_post_only(&self) -> bool;
@@ -249,6 +290,11 @@ pub trait Order: 'static + Send {
     }
     fn commissions(&self) -> &IndexMap<Currency, Money>;
 
+    /// Applies the `event` to the order.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the event is invalid for the current order status.
     fn apply(&mut self, event: OrderEventAny) -> Result<(), OrderError>;
     fn update(&mut self, event: &OrderUpdated);
 
@@ -547,6 +593,15 @@ impl OrderCore {
         }
     }
 
+    /// Applies the `event` to the order.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the event is invalid for the current order status.
+    ///
+    /// # Panics
+    ///
+    /// Panics if `event.client_order_id()` or `event.strategy_id()` does not match the order.
     pub fn apply(&mut self, event: OrderEventAny) -> Result<(), OrderError> {
         assert_eq!(self.client_order_id, event.client_order_id());
         assert_eq!(self.strategy_id, event.strategy_id());
@@ -697,6 +752,7 @@ impl OrderCore {
         });
     }
 
+    /// Returns the opposite order side.
     #[must_use]
     pub fn opposite_side(side: OrderSide) -> OrderSide {
         match side {
@@ -706,6 +762,7 @@ impl OrderCore {
         }
     }
 
+    /// Returns the order side needed to close a position.
     #[must_use]
     pub fn closing_side(side: PositionSide) -> OrderSide {
         match side {
@@ -716,6 +773,9 @@ impl OrderCore {
         }
     }
 
+    /// # Panics
+    ///
+    /// Panics if the order side is neither `Buy` nor `Sell`.
     #[must_use]
     pub fn signed_decimal_qty(&self) -> Decimal {
         match self.side {
@@ -773,14 +833,15 @@ mod tests {
     use crate::{
         enums::{OrderSide, OrderStatus, PositionSide},
         events::order::{
-            accepted::OrderAcceptedBuilder, denied::OrderDeniedBuilder, filled::OrderFilledBuilder,
+            accepted::OrderAcceptedBuilder, canceled::OrderCanceledBuilder,
+            denied::OrderDeniedBuilder, filled::OrderFilledBuilder,
             initialized::OrderInitializedBuilder, submitted::OrderSubmittedBuilder,
         },
         orders::MarketOrder,
     };
 
     // TODO: WIP
-    // fn test_initialize_market_order() {
+    // fn test_display_market_order() {
     //     let order = MarketOrder::default();
     //     assert_eq!(order.events().len(), 1);
     //     assert_eq!(
@@ -889,4 +950,111 @@ mod tests {
         assert_eq!(order.commission(&Currency::USD()), None);
         assert_eq!(order.commissions(), &IndexMap::new());
     }
+
+    #[rstest]
+    fn test_order_state_transition_to_canceled() {
+        let mut order: MarketOrder = OrderInitializedBuilder::default().build().unwrap().into();
+        let submitted = OrderSubmittedBuilder::default().build().unwrap();
+        let canceled = OrderCanceledBuilder::default().build().unwrap();
+
+        order.apply(OrderEventAny::Submitted(submitted)).unwrap();
+        order.apply(OrderEventAny::Canceled(canceled)).unwrap();
+
+        assert_eq!(order.status(), OrderStatus::Canceled);
+        assert!(order.is_closed());
+        assert!(!order.is_open());
+    }
+
+    #[rstest]
+    fn test_order_life_cycle_to_partially_filled() {
+        let init = OrderInitializedBuilder::default().build().unwrap();
+        let submitted = OrderSubmittedBuilder::default().build().unwrap();
+        let accepted = OrderAcceptedBuilder::default().build().unwrap();
+        let filled = OrderFilledBuilder::default()
+            .last_qty(Quantity::from(50_000))
+            .build()
+            .unwrap();
+
+        let mut order: MarketOrder = init.clone().into();
+        order.apply(OrderEventAny::Submitted(submitted)).unwrap();
+        order.apply(OrderEventAny::Accepted(accepted)).unwrap();
+        order.apply(OrderEventAny::Filled(filled)).unwrap();
+
+        assert_eq!(order.client_order_id, init.client_order_id);
+        assert_eq!(order.status(), OrderStatus::PartiallyFilled);
+        assert_eq!(order.filled_qty(), Quantity::from(50_000));
+        assert_eq!(order.leaves_qty(), Quantity::from(50_000));
+        assert!(order.is_open());
+        assert!(!order.is_closed());
+    }
+
+    #[rstest]
+    fn test_order_commission_calculation() {
+        let mut order: MarketOrder = OrderInitializedBuilder::default().build().unwrap().into();
+        order
+            .commissions
+            .insert(Currency::USD(), Money::new(10.0, Currency::USD()));
+
+        assert_eq!(
+            order.commission(&Currency::USD()),
+            Some(Money::new(10.0, Currency::USD()))
+        );
+        assert_eq!(
+            order.commissions_vec(),
+            vec![Money::new(10.0, Currency::USD())]
+        );
+    }
+
+    #[rstest]
+    fn test_order_is_primary() {
+        let order: MarketOrder = OrderInitializedBuilder::default()
+            .exec_algorithm_id(Some(ExecAlgorithmId::from("ALGO-001")))
+            .exec_spawn_id(Some(ClientOrderId::from("O-001")))
+            .client_order_id(ClientOrderId::from("O-001"))
+            .build()
+            .unwrap()
+            .into();
+
+        assert!(order.is_primary());
+        assert!(!order.is_secondary());
+    }
+
+    #[rstest]
+    fn test_order_is_secondary() {
+        let order: MarketOrder = OrderInitializedBuilder::default()
+            .exec_algorithm_id(Some(ExecAlgorithmId::from("ALGO-001")))
+            .exec_spawn_id(Some(ClientOrderId::from("O-002")))
+            .client_order_id(ClientOrderId::from("O-001"))
+            .build()
+            .unwrap()
+            .into();
+
+        assert!(!order.is_primary());
+        assert!(order.is_secondary());
+    }
+
+    #[rstest]
+    fn test_order_is_contingency() {
+        let order: MarketOrder = OrderInitializedBuilder::default()
+            .contingency_type(Some(ContingencyType::Oto))
+            .build()
+            .unwrap()
+            .into();
+
+        assert!(order.is_contingency());
+        assert!(order.is_parent_order());
+        assert!(!order.is_child_order());
+    }
+
+    #[rstest]
+    fn test_order_is_child_order() {
+        let order: MarketOrder = OrderInitializedBuilder::default()
+            .parent_order_id(Some(ClientOrderId::from("PARENT-001")))
+            .build()
+            .unwrap()
+            .into();
+
+        assert!(order.is_child_order());
+        assert!(!order.is_parent_order());
+    }
 }
