@@ -30,6 +30,7 @@ use crate::{
 };
 
 // Test Event Stubs
+#[derive(Debug)]
 pub struct TestOrderEventStubs;
 
 impl TestOrderEventStubs {
@@ -67,6 +68,9 @@ impl TestOrderEventStubs {
         OrderEventAny::Accepted(event)
     }
 
+    /// # Panics
+    ///
+    /// Panics if parsing the fallback price string fails or unwrapping default values fails.
     #[allow(clippy::too_many_arguments)]
     pub fn filled(
         order: &OrderAny,
@@ -120,9 +124,13 @@ impl TestOrderEventStubs {
     }
 }
 
+#[derive(Debug)]
 pub struct TestOrderStubs;
 
 impl TestOrderStubs {
+    /// # Panics
+    ///
+    /// Panics if applying the accepted event via `new_order.apply(...)` fails.
     pub fn make_accepted_order(order: &OrderAny) -> OrderAny {
         let mut new_order = order.clone();
         let accepted_event = TestOrderEventStubs::accepted(
@@ -134,6 +142,9 @@ impl TestOrderStubs {
         new_order
     }
 
+    /// # Panics
+    ///
+    /// Panics if applying the filled event via `accepted_order.apply(...)` fails.
     pub fn make_filled_order(
         order: &OrderAny,
         instrument: &InstrumentAny,
@@ -157,6 +168,7 @@ impl TestOrderStubs {
     }
 }
 
+#[derive(Debug)]
 pub struct TestOrdersGenerator {
     order_type: OrderType,
     venue_instruments: HashMap<Venue, u32>,
@@ -182,7 +194,7 @@ impl TestOrdersGenerator {
 
     fn generate_order(&self, instrument_id: InstrumentId, client_order_id_index: u32) -> OrderAny {
         let client_order_id =
-            ClientOrderId::from(format!("O-{}-{}", instrument_id, client_order_id_index));
+            ClientOrderId::from(format!("O-{instrument_id}-{client_order_id_index}"));
         OrderTestBuilder::new(self.order_type)
             .quantity(Quantity::from("1"))
             .price(Price::from("1"))
@@ -195,7 +207,7 @@ impl TestOrdersGenerator {
         let mut orders = Vec::new();
         for (venue, total_instruments) in self.venue_instruments.iter() {
             for i in 0..*total_instruments {
-                let instrument_id = InstrumentId::from(format!("SYMBOL-{}.{}", i, venue));
+                let instrument_id = InstrumentId::from(format!("SYMBOL-{i}.{venue}"));
                 for order_index in 0..self.orders_per_instrument {
                     let order = self.generate_order(instrument_id, order_index);
                     orders.push(order);
@@ -215,7 +227,7 @@ pub fn create_order_list_sample(
     // x venues * x instruments * x orders per instrument
     let mut order_generator = TestOrdersGenerator::new(OrderType::Limit);
     for i in 0..total_venues {
-        let venue = Venue::from(format!("VENUE-{}", i));
+        let venue = Venue::from(format!("VENUE-{i}"));
         order_generator.add_venue_and_total_instruments(venue, total_instruments);
     }
     order_generator.set_orders_per_instrument(orders_per_instrument);
