@@ -38,7 +38,15 @@ use crate::{
 };
 
 impl InstrumentStatus {
-    /// Create a new [`InstrumentStatus`] extracted from the given [`PyAny`].
+    /// Creates a new [`InstrumentStatus`] from a Python object.
+    ///
+    /// # Errors
+    ///
+    /// Returns a `PyErr` if extracting any attribute or converting types fails.
+    ///
+    /// # Panics
+    ///
+    /// Panics if converting `action_u16` to `MarketStatusAction` fails.
     pub fn from_pyobject(obj: &Bound<'_, PyAny>) -> PyResult<Self> {
         let instrument_id_obj: Bound<'_, PyAny> = obj.getattr("instrument_id")?.extract()?;
         let instrument_id_str: String = instrument_id_obj.getattr("value")?.extract()?;
@@ -215,23 +223,23 @@ impl InstrumentStatus {
     }
 
     /// Return a dictionary representation of the object.
-    #[pyo3(name = "as_dict")]
-    fn py_as_dict(&self, py: Python<'_>) -> PyResult<Py<PyDict>> {
+    #[pyo3(name = "to_dict")]
+    fn py_to_dict(&self, py: Python<'_>) -> PyResult<Py<PyDict>> {
         to_dict_pyo3(py, self)
     }
 
     /// Return JSON encoded bytes representation of the object.
-    #[pyo3(name = "as_json")]
-    fn py_as_json(&self, py: Python<'_>) -> Py<PyAny> {
-        // Unwrapping is safe when serializing a valid object
-        self.as_json_bytes().unwrap().into_py_any_unwrap(py)
+    #[pyo3(name = "to_json_bytes")]
+    fn py_to_json_bytes(&self, py: Python<'_>) -> Py<PyAny> {
+        // SAFETY: Unwrap safe when serializing a valid object
+        self.to_json_bytes().unwrap().into_py_any_unwrap(py)
     }
 
     /// Return MsgPack encoded bytes representation of the object.
-    #[pyo3(name = "as_msgpack")]
-    fn py_as_msgpack(&self, py: Python<'_>) -> Py<PyAny> {
-        // Unwrapping is safe when serializing a valid object
-        self.as_msgpack_bytes().unwrap().into_py_any_unwrap(py)
+    #[pyo3(name = "to_msgpack_bytes")]
+    fn py_to_msgpack_bytes(&self, py: Python<'_>) -> Py<PyAny> {
+        // SAFETY: Unwrap safe when serializing a valid object
+        self.to_msgpack_bytes().unwrap().into_py_any_unwrap(py)
     }
 }
 
@@ -247,11 +255,11 @@ mod tests {
     use crate::data::{status::InstrumentStatus, stubs::stub_instrument_status};
 
     #[rstest]
-    fn test_as_dict(stub_instrument_status: InstrumentStatus) {
+    fn test_to_dict(stub_instrument_status: InstrumentStatus) {
         pyo3::prepare_freethreaded_python();
 
         Python::with_gil(|py| {
-            let dict_string = stub_instrument_status.py_as_dict(py).unwrap().to_string();
+            let dict_string = stub_instrument_status.py_to_dict(py).unwrap().to_string();
             let expected_string = r"{'type': 'InstrumentStatus', 'instrument_id': 'MSFT.XNAS', 'action': 'TRADING', 'ts_event': 1, 'ts_init': 2, 'reason': None, 'trading_event': None, 'is_trading': None, 'is_quoting': None, 'is_short_sell_restricted': None}";
             assert_eq!(dict_string, expected_string);
         });
@@ -262,7 +270,7 @@ mod tests {
         pyo3::prepare_freethreaded_python();
 
         Python::with_gil(|py| {
-            let dict = stub_instrument_status.py_as_dict(py).unwrap();
+            let dict = stub_instrument_status.py_to_dict(py).unwrap();
             let parsed = InstrumentStatus::py_from_dict(py, dict).unwrap();
             assert_eq!(parsed, stub_instrument_status);
         });
