@@ -13,8 +13,6 @@
 //  limitations under the License.
 // -------------------------------------------------------------------------------------------------
 
-#![allow(clippy::missing_errors_doc)] // Allow missing errors docs for Python modules at this stage
-
 //! Python bindings from [PyO3](https://pyo3.rs).
 
 use pyo3::prelude::*;
@@ -30,13 +28,18 @@ pub mod macros;
 pub mod orderbook;
 pub mod orders;
 pub mod position;
+pub mod reports;
 pub mod types;
 
-/// Loaded as nautilus_pyo3.model
+/// Loaded as `nautilus_pyo3.model`.
 ///
 /// # Errors
 ///
 /// Returns a `PyErr` if registering any module components fails.
+///
+/// # Panics
+///
+/// Panics if inserting classes or functions into the Python module unexpectedly fails.
 #[pymodule]
 pub fn model(_: Python<'_>, m: &Bound<'_, PyModule>) -> PyResult<()> {
     // Types
@@ -111,6 +114,7 @@ pub fn model(_: Python<'_>, m: &Bound<'_, PyModule>) -> PyResult<()> {
     m.add_class::<crate::enums::TriggerType>()?;
     // Identifiers
     m.add_class::<crate::identifiers::AccountId>()?;
+    m.add_class::<crate::identifiers::ActorId>()?;
     m.add_class::<crate::identifiers::ClientId>()?;
     m.add_class::<crate::identifiers::ClientOrderId>()?;
     m.add_class::<crate::identifiers::ComponentId>()?;
@@ -133,6 +137,11 @@ pub fn model(_: Python<'_>, m: &Bound<'_, PyModule>) -> PyResult<()> {
     m.add_class::<crate::orders::StopMarketOrder>()?;
     m.add_class::<crate::orders::TrailingStopLimitOrder>()?;
     m.add_class::<crate::orders::TrailingStopMarketOrder>()?;
+    // Reports
+    m.add_class::<crate::reports::fill::FillReport>()?;
+    m.add_class::<crate::reports::order::OrderStatusReport>()?;
+    m.add_class::<crate::reports::position::PositionStatusReport>()?;
+    m.add_class::<crate::reports::mass_status::ExecutionMassStatus>()?;
     // Position
     m.add_class::<crate::position::Position>()?;
     // Instruments
