@@ -13,11 +13,22 @@
 //  limitations under the License.
 // -------------------------------------------------------------------------------------------------
 
+//! Network functionality for [NautilusTrader](http://nautilustrader.io).
+//!
+//! The *network* crate provides networking components including HTTP, WebSocket, and raw TCP socket
+//! clients, rate limiting, backoff strategies, and socket TLS utilities for connecting to
+//! trading venues and data providers.
+//!
+//! # Platform
+//!
 //! [NautilusTrader](http://nautilustrader.io) is an open-source, high-performance, production-grade
 //! algorithmic trading platform, providing quantitative traders with the ability to backtest
 //! portfolios of automated trading strategies on historical data with an event-driven engine,
 //! and also deploy those same strategies live, with no code changes.
 //!
+//! NautilusTrader's design, architecture, and implementation philosophy prioritizes software correctness and safety at the
+//! highest level, with the aim of supporting mission-critical, trading system backtesting and live deployment workloads.
+//!
 //! # Feature flags
 //!
 //! This crate provides feature flags to control source code inclusion during compilation,
@@ -28,19 +39,26 @@
 //! - `python`: Enables Python bindings from [PyO3](https://pyo3.rs).
 
 #![warn(rustc::all)]
+#![deny(unsafe_code)]
 #![deny(nonstandard_style)]
-#![deny(rustdoc::broken_intra_doc_links)]
+#![deny(missing_debug_implementations)]
 #![deny(clippy::missing_errors_doc)]
+#![deny(clippy::missing_panics_doc)]
+#![deny(rustdoc::broken_intra_doc_links)]
 
 pub mod backoff;
 pub mod fix;
 pub mod http;
 pub mod mode;
-pub mod ratelimiter;
+pub mod net;
 pub mod socket;
 pub mod websocket;
 
+mod logging;
 mod tls;
 
 #[cfg(feature = "python")]
 pub mod python;
+
+pub mod error;
+pub mod ratelimiter;
