@@ -13,17 +13,16 @@
 //  limitations under the License.
 // -------------------------------------------------------------------------------------------------
 
-#![allow(clippy::missing_errors_doc)] // Under development
-
-//! A rate limiter implementation heavily inspired by [governor](https://github.com/antifuchs/governor)
+//! A rate limiter implementation heavily inspired by [governor](https://github.com/antifuchs/governor).
 //!
-//! The governor does not support different quota for different key. It is an open [issue](https://github.com/antifuchs/governor/issues/193)
+//! The governor does not support different quota for different key. It is an open [issue](https://github.com/antifuchs/governor/issues/193).
 pub mod clock;
 mod gcra;
 mod nanos;
 pub mod quota;
 
 use std::{
+    fmt::Debug,
     hash::Hash,
     num::NonZeroU64,
     sync::atomic::{AtomicU64, Ordering},
@@ -49,10 +48,15 @@ use self::{
 ///
 /// Internally, the number tracked here is the theoretical arrival time (a GCRA term) in number of
 /// nanoseconds since the rate limiter was created.
-#[derive(Default)]
+#[derive(Debug, Default)]
 pub struct InMemoryState(AtomicU64);
 
 impl InMemoryState {
+    /// Measures and updates the GCRA's state atomically, retrying on concurrent modifications.
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the provided closure returns an error.
     pub(crate) fn measure_and_replace_one<T, F, E>(&self, mut f: F) -> Result<T, E>
     where
         F: FnMut(Option<Nanos>) -> Result<(T, Nanos), E>,
@@ -99,13 +103,17 @@ pub trait StateStore {
     /// The closure parameter takes the old value (`None` if this is the first measurement) of the
     /// state store at the key's location, checks if the request an be accommodated and:
     ///
-    /// * If the request is rate-limited, returns `Err(E)`.
-    /// * If the request can make it through, returns `Ok(T)` (an arbitrary positive return
+    /// - If the request is rate-limited, returns `Err(E)`.
+    /// - If the request can make it through, returns `Ok(T)` (an arbitrary positive return
     ///   value) and the updated state.
     ///
     /// It is `measure_and_replace`'s job then to safely replace the value at the key - it must
     /// only update the value if the value hasn't changed. The implementations in this
     /// crate use `AtomicU64` operations for this.
+    ///
+    /// # Errors
+    ///
+    /// Returns `Err(E)` if the closure returns an error or the request is rate-limited.
     fn measure_and_replace<T, F, E>(&self, key: &Self::Key, f: F) -> Result<T, E>
     where
         F: Fn(Option<Nanos>) -> Result<(T, Nanos), E>;
@@ -128,6 +136,10 @@ impl<K: Hash + Eq + Clone> StateStore for DashMapStateStore<K> {
     }
 }
 
+/// A rate limiter that enforces different quotas per key using the GCRA algorithm.
+///
+/// This implementation allows setting different rate limits for different keys,
+/// with an optional default quota for keys that don't have specific quotas.
 pub struct RateLimiter<K, C>
 where
     C: Clock,
@@ -139,10 +151,25 @@ where
     start: C::Instant,
 }
 
+impl<K, C> Debug for RateLimiter<K, C>
+where
+    K: Debug,
+    C: Clock,
+{
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct(stringify!(RateLimiter)).finish()
+    }
+}
+
 impl<K> RateLimiter<K, MonotonicClock>
 where
     K: Eq + Hash,
 {
+    /// Creates a new rate limiter with a base quota and keyed quotas.
+    ///
+    /// The base quota applies to all keys that don't have specific quotas.
+    /// Keyed quotas override the base quota for specific keys.
+    #[must_use]
     pub fn new_with_quota(base_quota: Option<Quota>, keyed_quotas: Vec<(K, Quota)>) -> Self {
         let clock = MonotonicClock {};
         let start = MonotonicClock::now(&clock);
@@ -161,6 +188,9 @@ impl<K> RateLimiter<K, FakeRelativeClock>
 where
     K: Hash + Eq + Clone,
 {
+    /// Advances the fake clock by the specified duration.
+    ///
+    /// This is only available for testing with `FakeRelativeClock`.
     pub fn advance_clock(&self, by: Duration) {
         self.clock.advance(by);
     }
@@ -171,10 +201,16 @@ where
     K: Hash + Eq + Clone,
     C: Clock,
 {
+    /// Adds or updates a quota for a specific key.
     pub fn add_quota_for_key(&self, key: K, value: Quota) {
         self.gcra.insert(key, Gcra::new(value));
     }
 
+    /// Checks if the given key is allowed under the rate limit.
+    ///
+    /// # Errors
+    ///
+    /// Returns `Err(NotUntil)` if the key is rate-limited, indicating when it will be allowed.
     pub fn check_key(&self, key: &K) -> Result<(), NotUntil<C::Instant>> {
         match self.gcra.get(key) {
             Some(quota) => quota.test_and_update(self.start, key, &self.state, self.clock.now()),
@@ -184,6 +220,7 @@ where
         }
     }
 
+    /// Waits until the specified key is ready (not rate-limited).
     pub async fn until_key_ready(&self, key: &K) {
         loop {
             match self.check_key(key) {
@@ -197,6 +234,9 @@ where
         }
     }
 
+    /// Waits until all specified keys are ready (not rate-limited).
+    ///
+    /// If no keys are provided, this function returns immediately.
     pub async fn await_keys_ready(&self, keys: Option<Vec<K>>) {
         let keys = keys.unwrap_or_default();
         let tasks = keys.iter().map(|key| self.until_key_ready(key));
