@@ -16,7 +16,6 @@
 use std::{num::NonZeroU32, prelude::v1::*, time::Duration};
 
 use nonzero_ext::nonzero;
-use pyo3::{exceptions::PyException, prelude::*};
 
 use super::nanos::Nanos;
 
@@ -52,39 +51,6 @@ pub struct Quota {
     pub(crate) replenish_1_per: Duration,
 }
 
-#[pymethods]
-impl Quota {
-    #[staticmethod]
-    pub fn rate_per_second(max_burst: u32) -> PyResult<Self> {
-        match NonZeroU32::new(max_burst) {
-            Some(max_burst) => Ok(Self::per_second(max_burst)),
-            None => Err(PyErr::new::<PyException, _>(
-                "Max burst capacity should be a non-zero integer",
-            )),
-        }
-    }
-
-    #[staticmethod]
-    pub fn rate_per_minute(max_burst: u32) -> PyResult<Self> {
-        match NonZeroU32::new(max_burst) {
-            Some(max_burst) => Ok(Self::per_minute(max_burst)),
-            None => Err(PyErr::new::<PyException, _>(
-                "Max burst capacity should be a non-zero integer",
-            )),
-        }
-    }
-
-    #[staticmethod]
-    pub fn rate_per_hour(max_burst: u32) -> PyResult<Self> {
-        match NonZeroU32::new(max_burst) {
-            Some(max_burst) => Ok(Self::per_hour(max_burst)),
-            None => Err(PyErr::new::<PyException, _>(
-                "Max burst capacity should be a non-zero integer",
-            )),
-        }
-    }
-}
-
 /// Constructors for Quotas
 impl Quota {
     /// Construct a quota for a number of cells per second. The given number of cells is also
@@ -208,15 +174,30 @@ impl Quota {
     /// This is useful mainly for [`crate::middleware::RateLimitingMiddleware`]
     /// where custom code may want to construct information based on
     /// the amount of burst balance remaining.
+    ///
+    /// # Panics
+    ///
+    /// Panics if the division result is 0 or exceeds `u32::MAX`.
     pub(crate) fn from_gcra_parameters(t: Nanos, tau: Nanos) -> Self {
-        // Safety assurance: As we're calling this from this crate
-        // only, and we do not allow creating a Gcra from 0
-        // parameters, this is, in fact, safe.
-        //
-        // The casts may look a little sketch, but again, they're
-        // constructed from parameters that came from the crate
-        // exactly like that.
-        let max_burst = unsafe { NonZeroU32::new_unchecked((tau.as_u64() / t.as_u64()) as u32) };
+        let t_u64 = t.as_u64();
+        let tau_u64 = tau.as_u64();
+
+        // Validate division won't be zero or overflow
+        assert!((t_u64 != 0), "Invalid GCRA parameter: t cannot be zero");
+
+        let division_result = tau_u64 / t_u64;
+        assert!(
+            (division_result != 0),
+            "Invalid GCRA parameters: tau/t results in zero burst capacity"
+        );
+        assert!(
+            u32::try_from(division_result).is_ok(),
+            "Invalid GCRA parameters: tau/t exceeds u32::MAX"
+        );
+
+        // We've verified the result is non-zero and fits in u32
+        let max_burst = NonZeroU32::new(division_result as u32)
+            .expect("Division result should be non-zero after validation");
         let replenish_1_per = t.into();
         Self {
             max_burst,
