@@ -29,6 +29,7 @@
 //! - Controller task manages lifecycle
 
 use std::{
+    fmt::Debug,
     sync::{
         Arc,
         atomic::{AtomicU8, Ordering},
@@ -42,6 +43,7 @@ use futures_util::{
 };
 use http::HeaderName;
 use nautilus_cryptography::providers::install_cryptographic_provider;
+#[cfg(feature = "python")]
 use pyo3::{prelude::*, types::PyBytes};
 use tokio::{
     net::TcpStream,
@@ -54,19 +56,29 @@ use tokio_tungstenite::{
 
 use crate::{
     backoff::ExponentialBackoff,
+    error::SendError,
+    logging::{log_task_aborted, log_task_started, log_task_stopped},
     mode::ConnectionMode,
     ratelimiter::{RateLimiter, clock::MonotonicClock, quota::Quota},
 };
+
 type MessageWriter = SplitSink<WebSocketStream<MaybeTlsStream<TcpStream>>, Message>;
 pub type MessageReader = SplitStream<WebSocketStream<MaybeTlsStream<TcpStream>>>;
 
+/// Defines how WebSocket messages are consumed.
 #[derive(Debug, Clone)]
 pub enum Consumer {
+    /// Python-based message handler.
+    #[cfg(feature = "python")]
     Python(Option<Arc<PyObject>>),
+    /// Rust-based message handler using a channel sender.
     Rust(Sender<Message>),
 }
 
 impl Consumer {
+    /// Creates a Rust-based consumer with a channel for receiving messages.
+    ///
+    /// Returns a tuple containing the consumer and a receiver for messages.
     #[must_use]
     pub fn rust_consumer() -> (Self, Receiver<Message>) {
         let (tx, rx) = mpsc::channel(100);
@@ -91,6 +103,7 @@ pub struct WebSocketConfig {
     /// The optional heartbeat message.
     pub heartbeat_msg: Option<String>,
     /// The handler for incoming pings.
+    #[cfg(feature = "python")]
     pub ping_handler: Option<Arc<PyObject>>,
     /// The timeout (milliseconds) for reconnection attempts.
     pub reconnect_timeout_ms: Option<u64>,
@@ -151,6 +164,7 @@ impl WebSocketClientInner {
             heartbeat,
             headers,
             heartbeat_msg,
+            #[cfg(feature = "python")]
             ping_handler,
             reconnect_timeout_ms,
             reconnect_delay_initial_ms,
@@ -163,6 +177,7 @@ impl WebSocketClientInner {
         let connection_mode = Arc::new(AtomicU8::new(ConnectionMode::Active.as_u8()));
 
         let read_task = match &handler {
+            #[cfg(feature = "python")]
             Consumer::Python(handler) => handler.as_ref().map(|handler| {
                 Self::spawn_python_callback_task(
                     connection_mode.clone(),
@@ -198,7 +213,8 @@ impl WebSocketClientInner {
             reconnect_backoff_factor.unwrap_or(1.5),
             reconnect_jitter_ms.unwrap_or(100),
             true, // immediate-first
-        );
+        )
+        .map_err(|e| Error::Io(std::io::Error::new(std::io::ErrorKind::InvalidInput, e)))?;
 
         Ok(Self {
             config,
@@ -239,10 +255,21 @@ impl WebSocketClientInner {
     pub async fn reconnect(&mut self) -> Result<(), Error> {
         tracing::debug!("Reconnecting");
 
+        if ConnectionMode::from_atomic(&self.connection_mode).is_disconnect() {
+            tracing::debug!("Reconnect aborted due to disconnect state");
+            return Ok(());
+        }
+
         tokio::time::timeout(self.reconnect_timeout, async {
+            // Attempt to connect; abort early if a disconnect was requested
             let (new_writer, reader) =
                 Self::connect_with_server(&self.config.url, self.config.headers.clone()).await?;
 
+            if ConnectionMode::from_atomic(&self.connection_mode).is_disconnect() {
+                tracing::debug!("Reconnect aborted mid-flight (after connect)");
+                return Ok(());
+            }
+
             if let Err(e) = self.writer_tx.send(WriterCommand::Update(new_writer)) {
                 tracing::error!("{e}");
             }
@@ -250,17 +277,30 @@ impl WebSocketClientInner {
             // Delay before closing connection
             tokio::time::sleep(Duration::from_millis(100)).await;
 
-            if let Some(ref read_task) = self.read_task.take() {
-                if !read_task.is_finished() {
-                    read_task.abort();
-                    tracing::debug!("Aborted task 'read'");
-                }
+            if ConnectionMode::from_atomic(&self.connection_mode).is_disconnect() {
+                tracing::debug!("Reconnect aborted mid-flight (after delay)");
+                return Ok(());
             }
 
+            if let Some(ref read_task) = self.read_task.take()
+                && !read_task.is_finished()
+            {
+                read_task.abort();
+                log_task_aborted("read");
+            }
+
+            // If a disconnect was requested during reconnect, do not proceed to reactivate
+            if ConnectionMode::from_atomic(&self.connection_mode).is_disconnect() {
+                tracing::debug!("Reconnect aborted mid-flight (before spawn read)");
+                return Ok(());
+            }
+
+            // Mark as active only if not disconnecting
             self.connection_mode
                 .store(ConnectionMode::Active.as_u8(), Ordering::SeqCst);
 
             self.read_task = match &self.config.handler {
+                #[cfg(feature = "python")]
                 Consumer::Python(handler) => handler.as_ref().map(|handler| {
                     Self::spawn_python_callback_task(
                         self.connection_mode.clone(),
@@ -345,13 +385,14 @@ impl WebSocketClientInner {
         })
     }
 
+    #[cfg(feature = "python")]
     fn spawn_python_callback_task(
         connection_state: Arc<AtomicU8>,
         mut reader: MessageReader,
         handler: Arc<PyObject>,
         ping_handler: Option<Arc<PyObject>>,
     ) -> tokio::task::JoinHandle<()> {
-        tracing::debug!("Started task 'read'");
+        log_task_started("read");
 
         // Interval between checking the connection mode
         let check_interval = Duration::from_millis(10);
@@ -385,13 +426,12 @@ impl WebSocketClientInner {
                     }
                     Ok(Some(Ok(Message::Ping(ping)))) => {
                         tracing::trace!("Received ping: {ping:?}");
-                        if let Some(ref handler) = ping_handler {
-                            if let Err(e) =
+                        if let Some(ref handler) = ping_handler
+                            && let Err(e) =
                                 Python::with_gil(|py| handler.call1(py, (PyBytes::new(py, &ping),)))
-                            {
-                                tracing::error!("Error calling handler: {e}");
-                                break;
-                            }
+                        {
+                            tracing::error!("Error calling handler: {e}");
+                            break;
                         }
                         continue;
                     }
@@ -427,7 +467,7 @@ impl WebSocketClientInner {
         writer: MessageWriter,
         mut writer_rx: tokio::sync::mpsc::UnboundedReceiver<WriterCommand>,
     ) -> tokio::task::JoinHandle<()> {
-        tracing::debug!("Started task 'write'");
+        log_task_started("write");
 
         // Interval between checking the connection mode
         let check_interval = Duration::from_millis(10);
@@ -500,7 +540,7 @@ impl WebSocketClientInner {
             // we ignore any error as the writer may already be closed.
             _ = active_writer.close().await;
 
-            tracing::debug!("Completed task 'write'");
+            log_task_stopped("write");
         })
     }
 
@@ -510,7 +550,7 @@ impl WebSocketClientInner {
         message: Option<String>,
         writer_tx: tokio::sync::mpsc::UnboundedSender<WriterCommand>,
     ) -> tokio::task::JoinHandle<()> {
-        tracing::debug!("Started task 'heartbeat'");
+        log_task_started("heartbeat");
 
         tokio::task::spawn(async move {
             let interval = Duration::from_secs(heartbeat_secs);
@@ -537,30 +577,30 @@ impl WebSocketClientInner {
                 }
             }
 
-            tracing::debug!("Completed task 'heartbeat'");
+            log_task_stopped("heartbeat");
         })
     }
 }
 
 impl Drop for WebSocketClientInner {
     fn drop(&mut self) {
-        if let Some(ref read_task) = self.read_task.take() {
-            if !read_task.is_finished() {
-                read_task.abort();
-                tracing::debug!("Aborted task 'read'");
-            }
+        if let Some(ref read_task) = self.read_task.take()
+            && !read_task.is_finished()
+        {
+            read_task.abort();
+            log_task_aborted("read");
         }
 
         if !self.write_task.is_finished() {
             self.write_task.abort();
-            tracing::debug!("Aborted task 'write'");
+            log_task_aborted("write");
         }
 
-        if let Some(ref handle) = self.heartbeat_task.take() {
-            if !handle.is_finished() {
-                handle.abort();
-                tracing::debug!("Aborted task 'heartbeat'");
-            }
+        if let Some(ref handle) = self.heartbeat_task.take()
+            && !handle.is_finished()
+        {
+            handle.abort();
+            log_task_aborted("heartbeat");
         }
     }
 }
@@ -580,6 +620,12 @@ pub struct WebSocketClient {
     pub(crate) rate_limiter: Arc<RateLimiter<String, MonotonicClock>>,
 }
 
+impl Debug for WebSocketClient {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct(stringify!(WebSocketClient)).finish()
+    }
+}
+
 impl WebSocketClient {
     /// Creates a websocket client that returns a stream for reading messages.
     ///
@@ -599,7 +645,7 @@ impl WebSocketClient {
         let inner = WebSocketClientInner::connect_url(config).await?;
 
         let connection_mode = inner.connection_mode.clone();
-        let rate_limiter = Arc::new(RateLimiter::new_with_quota(default_quota, keyed_quotas));
+
         let writer_tx = inner.writer_tx.clone();
         if let Err(e) = writer_tx.send(WriterCommand::Update(writer)) {
             tracing::error!("{e}");
@@ -609,10 +655,14 @@ impl WebSocketClient {
             inner,
             connection_mode.clone(),
             post_reconnect,
+            #[cfg(feature = "python")]
             None, // no post_reconnection
+            #[cfg(feature = "python")]
             None, // no post_disconnection
         );
 
+        let rate_limiter = Arc::new(RateLimiter::new_with_quota(default_quota, keyed_quotas));
+
         Ok((
             reader,
             Self {
@@ -634,9 +684,9 @@ impl WebSocketClient {
     /// Returns any websocket error.
     pub async fn connect(
         config: WebSocketConfig,
-        post_connection: Option<PyObject>,
-        post_reconnection: Option<PyObject>,
-        post_disconnection: Option<PyObject>,
+        #[cfg(feature = "python")] post_connection: Option<PyObject>,
+        #[cfg(feature = "python")] post_reconnection: Option<PyObject>,
+        #[cfg(feature = "python")] post_disconnection: Option<PyObject>,
         keyed_quotas: Vec<(String, Quota)>,
         default_quota: Option<Quota>,
     ) -> Result<Self, Error> {
@@ -648,12 +698,16 @@ impl WebSocketClient {
         let controller_task = Self::spawn_controller_task(
             inner,
             connection_mode.clone(),
-            None,               // Rust handler
-            post_reconnection,  // TODO: Deprecated
+            None, // Rust handler
+            #[cfg(feature = "python")]
+            post_reconnection, // TODO: Deprecated
+            #[cfg(feature = "python")]
             post_disconnection, // TODO: Deprecated
         );
+
         let rate_limiter = Arc::new(RateLimiter::new_with_quota(default_quota, keyed_quotas));
 
+        #[cfg(feature = "python")]
         if let Some(handler) = post_connection {
             Python::with_gil(|py| match handler.call0(py) {
                 Ok(_) => tracing::debug!("Called `post_connection` handler"),
@@ -737,7 +791,7 @@ impl WebSocketClient {
 
             if !self.controller_task.is_finished() {
                 self.controller_task.abort();
-                tracing::debug!("Aborted task 'controller'");
+                log_task_aborted("controller");
             }
         })
         .await
@@ -752,61 +806,80 @@ impl WebSocketClient {
     }
 
     /// Sends the given text `data` to the server.
-    pub async fn send_text(&self, data: String, keys: Option<Vec<String>>) {
+    ///
+    /// # Errors
+    ///
+    /// Returns a websocket error if unable to send.
+    #[allow(unused_variables)]
+    pub async fn send_text(
+        &self,
+        data: String,
+        keys: Option<Vec<String>>,
+    ) -> std::result::Result<(), SendError> {
         self.rate_limiter.await_keys_ready(keys).await;
 
         if !self.is_active() {
-            tracing::error!("Cannot send data - connection not active");
-            return;
+            return Err(SendError::Closed);
         }
 
         tracing::trace!("Sending text: {data:?}");
 
         let msg = Message::Text(data.into());
-        if let Err(e) = self.writer_tx.send(WriterCommand::Send(msg)) {
-            tracing::error!("Error sending message: {e}");
-        }
+        self.writer_tx
+            .send(WriterCommand::Send(msg))
+            .map_err(|e| SendError::BrokenPipe(e.to_string()))
     }
 
     /// Sends the given bytes `data` to the server.
-    pub async fn send_bytes(&self, data: Vec<u8>, keys: Option<Vec<String>>) {
+    ///
+    /// # Errors
+    ///
+    /// Returns a websocket error if unable to send.
+    #[allow(unused_variables)]
+    pub async fn send_bytes(
+        &self,
+        data: Vec<u8>,
+        keys: Option<Vec<String>>,
+    ) -> std::result::Result<(), SendError> {
         self.rate_limiter.await_keys_ready(keys).await;
 
         if !self.is_active() {
-            tracing::error!("Cannot send data - connection not active");
-            return;
+            return Err(SendError::Closed);
         }
 
         tracing::trace!("Sending bytes: {data:?}");
 
         let msg = Message::Binary(data.into());
-        if let Err(e) = self.writer_tx.send(WriterCommand::Send(msg)) {
-            tracing::error!("Error sending message: {e}");
-        }
+        self.writer_tx
+            .send(WriterCommand::Send(msg))
+            .map_err(|e| SendError::BrokenPipe(e.to_string()))
     }
 
     /// Sends a close message to the server.
-    pub async fn send_close_message(&self) {
+    ///
+    /// # Errors
+    ///
+    /// Returns a websocket error if unable to send.
+    pub async fn send_close_message(&self) -> std::result::Result<(), SendError> {
         if !self.is_active() {
-            tracing::error!("Cannot send close message - connection not active");
-            return;
+            return Err(SendError::Closed);
         }
 
         let msg = Message::Close(None);
-        if let Err(e) = self.writer_tx.send(WriterCommand::Send(msg)) {
-            tracing::error!("Error sending close message: {e}");
-        }
+        self.writer_tx
+            .send(WriterCommand::Send(msg))
+            .map_err(|e| SendError::BrokenPipe(e.to_string()))
     }
 
     fn spawn_controller_task(
         mut inner: WebSocketClientInner,
         connection_mode: Arc<AtomicU8>,
         post_reconnection: Option<Arc<dyn Fn() + Send + Sync>>,
-        py_post_reconnection: Option<PyObject>, // TODO: Deprecated
-        py_post_disconnection: Option<PyObject>, // TODO: Deprecated
+        #[cfg(feature = "python")] py_post_reconnection: Option<PyObject>, // TODO: Deprecated
+        #[cfg(feature = "python")] py_post_disconnection: Option<PyObject>, // TODO: Deprecated
     ) -> tokio::task::JoinHandle<()> {
         tokio::task::spawn(async move {
-            tracing::debug!("Started task 'controller'");
+            log_task_started("controller");
 
             let check_interval = Duration::from_millis(10);
 
@@ -822,18 +895,18 @@ impl WebSocketClient {
                         // Delay awaiting graceful shutdown
                         tokio::time::sleep(Duration::from_millis(100)).await;
 
-                        if let Some(task) = &inner.read_task {
-                            if !task.is_finished() {
-                                task.abort();
-                                tracing::debug!("Aborted task 'read'");
-                            }
+                        if let Some(task) = &inner.read_task
+                            && !task.is_finished()
+                        {
+                            task.abort();
+                            log_task_aborted("read");
                         }
 
-                        if let Some(task) = &inner.heartbeat_task {
-                            if !task.is_finished() {
-                                task.abort();
-                                tracing::debug!("Aborted task 'heartbeat'");
-                            }
+                        if let Some(task) = &inner.heartbeat_task
+                            && !task.is_finished()
+                        {
+                            task.abort();
+                            log_task_aborted("heartbeat");
                         }
                     })
                     .await
@@ -844,6 +917,7 @@ impl WebSocketClient {
 
                     tracing::debug!("Closed");
 
+                    #[cfg(feature = "python")]
                     if let Some(ref handler) = py_post_disconnection {
                         Python::with_gil(|py| match handler.call0(py) {
                             Ok(_) => tracing::debug!("Called `post_disconnection` handler"),
@@ -858,23 +932,32 @@ impl WebSocketClient {
                 if mode.is_reconnect() || (mode.is_active() && !inner.is_alive()) {
                     match inner.reconnect().await {
                         Ok(()) => {
-                            tracing::debug!("Reconnected successfully");
                             inner.backoff.reset();
 
-                            if let Some(ref callback) = post_reconnection {
-                                callback();
-                            }
+                            // Only invoke callbacks if not in disconnect state
+                            if ConnectionMode::from_atomic(&connection_mode).is_active() {
+                                if let Some(ref callback) = post_reconnection {
+                                    callback();
+                                }
 
-                            // TODO: Python based websocket handlers deprecated (will be removed)
-                            if let Some(ref handler) = py_post_reconnection {
-                                Python::with_gil(|py| match handler.call0(py) {
-                                    Ok(_) => {
-                                        tracing::debug!("Called `post_reconnection` handler");
-                                    }
-                                    Err(e) => tracing::error!(
-                                        "Error calling `post_reconnection` handler: {e}"
-                                    ),
-                                });
+                                // TODO: Python based websocket handlers deprecated (will be removed)
+                                #[cfg(feature = "python")]
+                                if let Some(ref callback) = py_post_reconnection {
+                                    Python::with_gil(|py| match callback.call0(py) {
+                                        Ok(_) => {
+                                            tracing::debug!("Called `post_reconnection` handler");
+                                        }
+                                        Err(e) => tracing::error!(
+                                            "Error calling `post_reconnection` handler: {e}"
+                                        ),
+                                    });
+                                }
+
+                                tracing::debug!("Reconnected successfully");
+                            } else {
+                                tracing::debug!(
+                                    "Skipping post_reconnection handlers due to disconnect state"
+                                );
                             }
                         }
                         Err(e) => {
@@ -892,14 +975,25 @@ impl WebSocketClient {
                 .connection_mode
                 .store(ConnectionMode::Closed.as_u8(), Ordering::SeqCst);
 
-            tracing::debug!("Completed task 'controller'");
+            log_task_stopped("controller");
         })
     }
 }
 
+// Abort controller task on drop to clean up background tasks
+impl Drop for WebSocketClient {
+    fn drop(&mut self) {
+        if !self.controller_task.is_finished() {
+            self.controller_task.abort();
+            log_task_aborted("controller");
+        }
+    }
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // Tests
 ////////////////////////////////////////////////////////////////////////////////
+#[cfg(feature = "python")]
 #[cfg(test)]
 #[cfg(target_os = "linux")] // Only run network tests on Linux (CI stability)
 mod tests {
@@ -1084,10 +1178,10 @@ mod tests {
         let client = setup_test_client(server.port).await;
 
         // 1) Send normal message
-        client.send_text("Hello".into(), None).await;
+        client.send_text("Hello".into(), None).await.unwrap();
 
         // 2) Trigger forced close from server
-        client.send_text("close-now".into(), None).await;
+        client.send_text("close-now".into(), None).await.unwrap();
 
         // 3) Wait a bit => read loop sees close => reconnect
         tokio::time::sleep(std::time::Duration::from_secs(1)).await;
@@ -1131,11 +1225,11 @@ mod tests {
         .unwrap();
 
         // First 2 should succeed
-        client.send_text("test1".into(), None).await;
-        client.send_text("test2".into(), None).await;
+        client.send_text("test1".into(), None).await.unwrap();
+        client.send_text("test2".into(), None).await.unwrap();
 
         // Third should error
-        client.send_text("test3".into(), None).await;
+        client.send_text("test3".into(), None).await.unwrap();
 
         // Cleanup
         client.disconnect().await;
@@ -1151,7 +1245,7 @@ mod tests {
         for i in 0..10 {
             let client = client.clone();
             handles.push(task::spawn(async move {
-                client.send_text(format!("test{i}"), None).await;
+                client.send_text(format!("test{i}"), None).await.unwrap();
             }));
         }
 
@@ -1164,3 +1258,73 @@ mod tests {
         assert!(client.is_disconnected());
     }
 }
+
+#[cfg(test)]
+mod rust_tests {
+    use tokio::{
+        net::TcpListener,
+        task,
+        time::{Duration, sleep},
+    };
+    use tokio_tungstenite::accept_async;
+
+    use super::*;
+
+    #[tokio::test]
+    async fn test_reconnect_then_disconnect() {
+        // Bind an ephemeral port
+        let listener = TcpListener::bind("127.0.0.1:0").await.unwrap();
+        let port = listener.local_addr().unwrap().port();
+
+        // Server task: accept one ws connection then close it
+        let server = task::spawn(async move {
+            let (stream, _) = listener.accept().await.unwrap();
+            let ws = accept_async(stream).await.unwrap();
+            drop(ws);
+            // Keep alive briefly
+            sleep(Duration::from_secs(1)).await;
+        });
+
+        // Build a rust consumer for incoming messages (unused here)
+        let (consumer, _rx) = Consumer::rust_consumer();
+
+        // Configure client with short reconnect backoff
+        let config = WebSocketConfig {
+            url: format!("ws://127.0.0.1:{port}"),
+            headers: vec![],
+            handler: consumer,
+            heartbeat: None,
+            heartbeat_msg: None,
+            #[cfg(feature = "python")]
+            ping_handler: None,
+            reconnect_timeout_ms: Some(1_000),
+            reconnect_delay_initial_ms: Some(50),
+            reconnect_delay_max_ms: Some(100),
+            reconnect_backoff_factor: Some(1.0),
+            reconnect_jitter_ms: Some(0),
+        };
+
+        // Connect the client
+        let client = {
+            #[cfg(feature = "python")]
+            {
+                WebSocketClient::connect(config.clone(), None, None, None, vec![], None)
+                    .await
+                    .unwrap()
+            }
+            #[cfg(not(feature = "python"))]
+            {
+                WebSocketClient::connect(config.clone(), vec![], None)
+                    .await
+                    .unwrap()
+            }
+        };
+
+        // Allow server to drop connection and client to detect
+        sleep(Duration::from_millis(100)).await;
+        // Now immediately disconnect the client
+        client.disconnect().await;
+        assert!(client.is_disconnected());
+        server.abort();
+    }
+}
