@@ -13,11 +13,16 @@
 //  limitations under the License.
 // -------------------------------------------------------------------------------------------------
 
+//! # Platform
+//!
 //! [NautilusTrader](http://nautilustrader.io) is an open-source, high-performance, production-grade
 //! algorithmic trading platform, providing quantitative traders with the ability to backtest
 //! portfolios of automated trading strategies on historical data with an event-driven engine,
 //! and also deploy those same strategies live, with no code changes.
 //!
+//! NautilusTrader's design, architecture, and implementation philosophy prioritizes software correctness and safety at the
+//! highest level, with the aim of supporting mission-critical, trading system backtesting and live deployment workloads.
+//!
 //! # Feature flags
 //!
 //! This crate provides feature flags to control source code inclusion during compilation,
@@ -36,6 +41,7 @@
 
 pub mod backend;
 pub mod config;
+pub mod parquet;
 
 #[cfg(feature = "python")]
 pub mod python;
