@@ -15,7 +15,7 @@
 
 //! Provides account management functionality.
 
-use std::{cell::RefCell, rc::Rc};
+use std::{cell::RefCell, fmt::Debug, rc::Rc};
 
 use nautilus_common::{cache::Cache, clock::Clock};
 use nautilus_core::{UUID4, UnixNanos};
@@ -29,16 +29,32 @@ use nautilus_model::{
     types::{AccountBalance, Money},
 };
 use rust_decimal::{Decimal, prelude::ToPrimitive};
+/// Manages account balance updates and calculations for portfolio management.
+///
+/// The accounts manager handles balance updates for different account types,
+/// including cash and margin accounts, based on order fills and position changes.
 pub struct AccountsManager {
     clock: Rc<RefCell<dyn Clock>>,
     cache: Rc<RefCell<Cache>>,
 }
 
+impl Debug for AccountsManager {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct(stringify!(AccountsManager)).finish()
+    }
+}
+
 impl AccountsManager {
+    /// Creates a new [`AccountsManager`] instance.
     pub fn new(clock: Rc<RefCell<dyn Clock>>, cache: Rc<RefCell<Cache>>) -> Self {
         Self { clock, cache }
     }
 
+    /// Updates the given account state based on a filled order.
+    ///
+    /// # Panics
+    ///
+    /// Panics if the position list for the filled instrument is empty.
     #[must_use]
     pub fn update_balances(
         &self,
@@ -87,6 +103,10 @@ impl AccountsManager {
         self.generate_account_state(account, fill.ts_event)
     }
 
+    /// Updates account balances based on open orders.
+    ///
+    /// For cash accounts, updates the balance locked by open orders.
+    /// For margin accounts, updates the initial margin requirements.
     #[must_use]
     pub fn update_orders(
         &self,
@@ -109,6 +129,11 @@ impl AccountsManager {
         }
     }
 
+    /// Updates the account based on current open positions.
+    ///
+    /// # Panics
+    ///
+    /// Panics if any position's `instrument_id` does not match the provided `instrument`.
     #[must_use]
     pub fn update_positions(
         &self,
@@ -279,6 +304,10 @@ impl AccountsManager {
                 continue;
             }
 
+            if order.is_reduce_only() {
+                continue; // Does not contribute to locked balance
+            }
+
             let price = if order.price().is_some() {
                 order.price()
             } else {
@@ -357,6 +386,10 @@ impl AccountsManager {
                 continue;
             }
 
+            if order.is_reduce_only() {
+                continue; // Does not contribute to margin
+            }
+
             let price = if order.price().is_some() {
                 order.price()
             } else {
@@ -456,29 +489,29 @@ impl AccountsManager {
         let mut balances = Vec::new();
         let mut commission = fill.commission;
 
-        if let Some(ref mut comm) = commission {
-            if comm.currency != base_currency {
-                let xrate = self.cache.borrow().get_xrate(
-                    fill.instrument_id.venue,
-                    comm.currency,
-                    base_currency,
-                    if fill.order_side == OrderSide::Sell {
-                        PriceType::Bid
-                    } else {
-                        PriceType::Ask
-                    },
-                );
-
-                if let Some(xrate) = xrate {
-                    *comm = Money::new(comm.as_f64() * xrate, base_currency);
+        if let Some(ref mut comm) = commission
+            && comm.currency != base_currency
+        {
+            let xrate = self.cache.borrow().get_xrate(
+                fill.instrument_id.venue,
+                comm.currency,
+                base_currency,
+                if fill.order_side == OrderSide::Sell {
+                    PriceType::Bid
                 } else {
-                    log::error!(
-                        "Cannot calculate account state: insufficient data for {}/{}",
-                        comm.currency,
-                        base_currency
-                    );
-                    return;
-                }
+                    PriceType::Ask
+                },
+            );
+
+            if let Some(xrate) = xrate {
+                *comm = Money::new(comm.as_f64() * xrate, base_currency);
+            } else {
+                log::error!(
+                    "Cannot calculate account state: insufficient data for {}/{}",
+                    comm.currency,
+                    base_currency
+                );
+                return;
             }
         }
 
