@@ -20,6 +20,7 @@
 use std::{
     cell::RefCell,
     collections::{HashMap, HashSet},
+    fmt::Debug,
     rc::Rc,
 };
 
@@ -44,7 +45,6 @@ use nautilus_model::{
     types::{Currency, Money, Price},
 };
 use rust_decimal::{Decimal, prelude::FromPrimitive};
-use ustr::Ustr;
 
 use crate::{config::PortfolioConfig, manager::AccountsManager};
 
@@ -91,6 +91,12 @@ pub struct Portfolio {
     config: PortfolioConfig,
 }
 
+impl Debug for Portfolio {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct(stringify!(Portfolio)).finish()
+    }
+}
+
 impl Portfolio {
     pub fn new(
         cache: Rc<RefCell<Cache>>,
@@ -175,15 +181,22 @@ impl Portfolio {
             )))
         };
 
-        msgbus::register("Portfolio.update_account", update_account_handler.clone());
+        msgbus::register(
+            "Portfolio.update_account".into(),
+            update_account_handler.clone(),
+        );
 
-        msgbus::subscribe("data.quotes.*", update_quote_handler, Some(10));
+        msgbus::subscribe("data.quotes.*".into(), update_quote_handler, Some(10));
         if bar_updates {
-            msgbus::subscribe("data.quotes.*EXTERNAL", update_bar_handler, Some(10));
+            msgbus::subscribe("data.quotes.*EXTERNAL".into(), update_bar_handler, Some(10));
         }
-        msgbus::subscribe("events.order.*", update_order_handler, Some(10));
-        msgbus::subscribe("events.position.*", update_position_handler, Some(10));
-        msgbus::subscribe("events.account.*", update_account_handler, Some(10));
+        msgbus::subscribe("events.order.*".into(), update_order_handler, Some(10));
+        msgbus::subscribe(
+            "events.position.*".into(),
+            update_position_handler,
+            Some(10),
+        );
+        msgbus::subscribe("events.account.*".into(), update_account_handler, Some(10));
     }
 
     pub fn reset(&mut self) {
@@ -194,11 +207,15 @@ impl Portfolio {
 
     // -- QUERIES ---------------------------------------------------------------------------------
 
+    /// Returns `true` if the portfolio has been initialized.
     #[must_use]
     pub fn is_initialized(&self) -> bool {
         self.inner.borrow().initialized
     }
 
+    /// Returns the locked balances for the given venue.
+    ///
+    /// Locked balances represent funds reserved for open orders.
     #[must_use]
     pub fn balances_locked(&self, venue: &Venue) -> HashMap<Currency, Money> {
         self.cache.borrow().account_for_venue(venue).map_or_else(
@@ -210,6 +227,9 @@ impl Portfolio {
         )
     }
 
+    /// Returns the initial margin requirements for the given venue.
+    ///
+    /// Only applicable for margin accounts. Returns empty map for cash accounts.
     #[must_use]
     pub fn margins_init(&self, venue: &Venue) -> HashMap<InstrumentId, Money> {
         self.cache.borrow().account_for_venue(venue).map_or_else(
@@ -229,6 +249,9 @@ impl Portfolio {
         )
     }
 
+    /// Returns the maintenance margin requirements for the given venue.
+    ///
+    /// Only applicable for margin accounts. Returns empty map for cash accounts.
     #[must_use]
     pub fn margins_maint(&self, venue: &Venue) -> HashMap<InstrumentId, Money> {
         self.cache.borrow().account_for_venue(venue).map_or_else(
@@ -248,6 +271,9 @@ impl Portfolio {
         )
     }
 
+    /// Returns the unrealized PnLs for all positions at the given venue.
+    ///
+    /// Calculates mark-to-market PnL based on current market prices.
     #[must_use]
     pub fn unrealized_pnls(&mut self, venue: &Venue) -> HashMap<Currency, Money> {
         let instrument_ids = {
@@ -286,6 +312,9 @@ impl Portfolio {
             .collect()
     }
 
+    /// Returns the realized PnLs for all positions at the given venue.
+    ///
+    /// Calculates total realized profit and loss from closed positions.
     #[must_use]
     pub fn realized_pnls(&mut self, venue: &Venue) -> HashMap<Currency, Money> {
         let instrument_ids = {
@@ -552,6 +581,11 @@ impl Portfolio {
 
     // -- COMMANDS --------------------------------------------------------------------------------
 
+    /// Initializes account margin based on existing open orders.
+    ///
+    /// # Panics
+    ///
+    /// Panics if updating the cache with a mutated account fails.
     pub fn initialize_orders(&mut self) {
         let mut initialized = true;
         let orders_and_instruments = {
@@ -628,6 +662,11 @@ impl Portfolio {
         self.inner.borrow_mut().initialized = initialized;
     }
 
+    /// Initializes account margin based on existing open positions.
+    ///
+    /// # Panics
+    ///
+    /// Panics if calculation of PnL or updating the cache with a mutated account fails.
     pub fn initialize_positions(&mut self) {
         self.inner.borrow_mut().unrealized_pnls.clear();
         self.inner.borrow_mut().realized_pnls.clear();
@@ -733,6 +772,9 @@ impl Portfolio {
         );
     }
 
+    /// Updates portfolio calculations based on a new quote tick.
+    ///
+    /// Recalculates unrealized PnL for positions affected by the quote update.
     pub fn update_quote_tick(&mut self, quote: &QuoteTick) {
         update_quote_tick(
             self.cache.clone(),
@@ -742,6 +784,9 @@ impl Portfolio {
         );
     }
 
+    /// Updates portfolio calculations based on a new bar.
+    ///
+    /// Updates cached bar close prices and recalculates unrealized PnL.
     pub fn update_bar(&mut self, bar: &Bar) {
         update_bar(
             self.cache.clone(),
@@ -751,10 +796,14 @@ impl Portfolio {
         );
     }
 
+    /// Updates portfolio with a new account state event.
     pub fn update_account(&mut self, event: &AccountState) {
         update_account(self.cache.clone(), event);
     }
 
+    /// Updates portfolio calculations based on an order event.
+    ///
+    /// Handles balance updates for order fills and margin calculations for order changes.
     pub fn update_order(&mut self, event: &OrderEventAny) {
         update_order(
             self.cache.clone(),
@@ -764,6 +813,9 @@ impl Portfolio {
         );
     }
 
+    /// Updates portfolio calculations based on a position event.
+    ///
+    /// Recalculates net positions, unrealized PnL, and margin requirements.
     pub fn update_position(&mut self, event: &PositionEvent) {
         update_position(
             self.cache.clone(),
@@ -1045,9 +1097,8 @@ fn update_instrument_id(
     let mut result_maint = None;
 
     let account = {
-        let borrowed_cache = cache.borrow();
-        let account = if let Some(account) = borrowed_cache.account_for_venue(&instrument_id.venue)
-        {
+        let cache_ref = cache.borrow();
+        let account = if let Some(account) = cache_ref.account_for_venue(&instrument_id.venue) {
             account
         } else {
             log::error!(
@@ -1057,8 +1108,8 @@ fn update_instrument_id(
             return;
         };
 
-        let mut borrowed_cache = cache.borrow_mut();
-        let instrument = if let Some(instrument) = borrowed_cache.instrument(instrument_id) {
+        let mut cache_ref = cache.borrow_mut();
+        let instrument = if let Some(instrument) = cache_ref.instrument(instrument_id) {
             instrument.clone()
         } else {
             log::error!("Cannot update tick: no instrument found for {instrument_id}");
@@ -1066,13 +1117,13 @@ fn update_instrument_id(
         };
 
         // Clone the orders and positions to own the data
-        let orders_open: Vec<OrderAny> = borrowed_cache
+        let orders_open: Vec<OrderAny> = cache_ref
             .orders_open(None, Some(instrument_id), None, None)
             .iter()
             .map(|o| (*o).clone())
             .collect();
 
-        let positions_open: Vec<Position> = borrowed_cache
+        let positions_open: Vec<Position> = cache_ref
             .positions_open(None, Some(instrument_id), None, None)
             .iter()
             .map(|p| (*p).clone())
@@ -1095,7 +1146,7 @@ fn update_instrument_id(
         }
 
         if let Some((ref updated_account, _)) = result_init {
-            borrowed_cache.add_account(updated_account.clone()).unwrap(); // Temp Fix to update the mutated account
+            cache_ref.add_account(updated_account.clone()).unwrap(); // Temp Fix to update the mutated account
         }
         account.clone()
     };
@@ -1127,7 +1178,7 @@ fn update_order(
     inner: Rc<RefCell<PortfolioState>>,
     event: &OrderEventAny,
 ) {
-    let borrowed_cache = cache.borrow();
+    let cache_ref = cache.borrow();
     let account_id = match event.account_id() {
         Some(account_id) => account_id,
         None => {
@@ -1135,7 +1186,7 @@ fn update_order(
         }
     };
 
-    let account = if let Some(account) = borrowed_cache.account(&account_id) {
+    let account = if let Some(account) = cache_ref.account(&account_id) {
         account
     } else {
         log::error!("Cannot update order: no account registered for {account_id}");
@@ -1166,8 +1217,8 @@ fn update_order(
         }
     }
 
-    let borrowed_cache = cache.borrow();
-    let order = if let Some(order) = borrowed_cache.order(&event.client_order_id()) {
+    let cache_ref = cache.borrow();
+    let order = if let Some(order) = cache_ref.order(&event.client_order_id()) {
         order
     } else {
         log::error!(
@@ -1181,8 +1232,7 @@ fn update_order(
         return; // No change to account state
     }
 
-    let instrument = if let Some(instrument_id) = borrowed_cache.instrument(&event.instrument_id())
-    {
+    let instrument = if let Some(instrument_id) = cache_ref.instrument(&event.instrument_id()) {
         instrument_id
     } else {
         log::error!(
@@ -1222,7 +1272,7 @@ fn update_order(
         }
     }
 
-    let orders_open = borrowed_cache.orders_open(None, Some(&event.instrument_id()), None, None);
+    let orders_open = cache_ref.orders_open(None, Some(&event.instrument_id()), None, None);
 
     let account_state = inner.borrow_mut().accounts.update_orders(
         account,
@@ -1231,12 +1281,12 @@ fn update_order(
         clock.borrow().timestamp_ns(),
     );
 
-    let mut borrowed_cache = cache.borrow_mut();
-    borrowed_cache.update_account(account.clone()).unwrap();
+    let mut cache_ref = cache.borrow_mut();
+    cache_ref.update_account(account.clone()).unwrap();
 
     if let Some(account_state) = account_state {
         msgbus::publish(
-            &Ustr::from(&format!("events.account.{}", account.id())),
+            format!("events.account.{}", account.id()).into(),
             &account_state,
         );
     } else {
@@ -1256,9 +1306,9 @@ fn update_position(
     let instrument_id = event.instrument_id();
 
     let positions_open: Vec<Position> = {
-        let borrowed_cache = cache.borrow();
+        let cache_ref = cache.borrow();
 
-        borrowed_cache
+        cache_ref
             .positions_open(None, Some(&instrument_id), None, None)
             .iter()
             .map(|o| (*o).clone())
@@ -1292,16 +1342,16 @@ fn update_position(
         .realized_pnls
         .insert(event.instrument_id(), calculated_realized_pnl);
 
-    let borrowed_cache = cache.borrow();
-    let account = borrowed_cache.account(&event.account_id());
+    let cache_ref = cache.borrow();
+    let account = cache_ref.account(&event.account_id());
 
     if let Some(AccountAny::Margin(margin_account)) = account {
         if !margin_account.calculate_account_state {
             return; // Nothing to calculate
         }
 
-        let borrowed_cache = cache.borrow();
-        let instrument = if let Some(instrument) = borrowed_cache.instrument(&instrument_id) {
+        let cache_ref = cache.borrow();
+        let instrument = if let Some(instrument) = cache_ref.instrument(&instrument_id) {
             instrument
         } else {
             log::error!("Cannot update position: no instrument found for {instrument_id}");
@@ -1314,9 +1364,9 @@ fn update_position(
             positions_open.iter().collect(),
             clock.borrow().timestamp_ns(),
         );
-        let mut borrowed_cache = cache.borrow_mut();
+        let mut cache_ref = cache.borrow_mut();
         if let Some((margin_account, _)) = result {
-            borrowed_cache
+            cache_ref
                 .add_account(AccountAny::Margin(margin_account)) // Temp Fix to update the mutated account
                 .unwrap();
         }
@@ -1329,13 +1379,13 @@ fn update_position(
 }
 
 pub fn update_account(cache: Rc<RefCell<Cache>>, event: &AccountState) {
-    let mut borrowed_cache = cache.borrow_mut();
+    let mut cache_ref = cache.borrow_mut();
 
-    if let Some(existing) = borrowed_cache.account(&event.account_id) {
+    if let Some(existing) = cache_ref.account(&event.account_id) {
         let mut account = existing.clone();
         account.apply(event.clone());
 
-        if let Err(e) = borrowed_cache.update_account(account.clone()) {
+        if let Err(e) = cache_ref.update_account(account.clone()) {
             log::error!("Failed to update account: {e}");
             return;
         }
@@ -1348,7 +1398,7 @@ pub fn update_account(cache: Rc<RefCell<Cache>>, event: &AccountState) {
             }
         };
 
-        if let Err(e) = borrowed_cache.add_account(account) {
+        if let Err(e) = cache_ref.add_account(account) {
             log::error!("Failed to add account: {e}");
             return;
         }
