@@ -40,6 +40,7 @@ use nautilus_model::{
 };
 use rstest::{fixture, rstest};
 use rust_decimal::{Decimal, prelude::FromPrimitive};
+use rust_decimal_macros::dec;
 
 use crate::portfolio::Portfolio;
 
@@ -496,9 +497,9 @@ fn test_exceed_free_balance_single_currency_raises_account_balance_negative_exce
 
     portfolio.update_order(&OrderEventAny::Submitted(submitted));
 
-    let order_filled = fill_order(&order);
-    order.apply(OrderEventAny::Filled(order_filled)).unwrap();
-    portfolio.update_order(&OrderEventAny::Filled(order_filled));
+    let fill = fill_order(&order);
+    order.apply(OrderEventAny::Filled(fill)).unwrap();
+    portfolio.update_order(&OrderEventAny::Filled(fill));
 }
 
 // TODO: It should return an error
@@ -530,16 +531,21 @@ fn test_exceed_free_balance_multi_currency_raises_account_balance_negative_excep
         .add_order(order.clone(), None, None, false)
         .unwrap();
 
-    let order_submitted = submit_order(&order);
-    order
-        .apply(OrderEventAny::Submitted(order_submitted))
-        .unwrap();
-    portfolio.update_order(&OrderEventAny::Submitted(order_submitted));
+    let submitted = submit_order(&order);
+    order.apply(OrderEventAny::Submitted(submitted)).unwrap();
+    portfolio.update_order(&OrderEventAny::Submitted(submitted));
 
     // Assert
     assert_eq!(
-        account.balances().iter().next().unwrap().1.total.as_f64(),
-        1525000.00
+        account
+            .balances()
+            .iter()
+            .next()
+            .unwrap()
+            .1
+            .total
+            .as_decimal(),
+        dec!(1525000.00)
     );
 }
 
@@ -565,26 +571,22 @@ fn test_update_orders_open_cash_account(
         .add_order(order.clone(), None, None, false)
         .unwrap();
 
-    let order_submitted = submit_order(&order);
-    order
-        .apply(OrderEventAny::Submitted(order_submitted))
-        .unwrap();
-    portfolio.update_order(&OrderEventAny::Submitted(order_submitted));
+    let submitted = submit_order(&order);
+    order.apply(OrderEventAny::Submitted(submitted)).unwrap();
+    portfolio.update_order(&OrderEventAny::Submitted(submitted));
 
     // ACCEPTED
-    let order_accepted = accept_order(&order);
-    order
-        .apply(OrderEventAny::Accepted(order_accepted))
-        .unwrap();
-    portfolio.update_order(&OrderEventAny::Accepted(order_accepted));
+    let accepted = accept_order(&order);
+    order.apply(OrderEventAny::Accepted(accepted)).unwrap();
+    portfolio.update_order(&OrderEventAny::Accepted(accepted));
 
     assert_eq!(
         portfolio
             .balances_locked(&Venue::from("SIM"))
             .get(&Currency::USD())
             .unwrap()
-            .as_f64(),
-        25000.0
+            .as_decimal(),
+        dec!(25000.0)
     );
 }
 
@@ -625,17 +627,13 @@ fn test_update_orders_open_margin_account(
         .add_order(order2, None, None, true)
         .unwrap();
 
-    let order_submitted = submit_order(&order1);
-    order1
-        .apply(OrderEventAny::Submitted(order_submitted))
-        .unwrap();
+    let submitted = submit_order(&order1);
+    order1.apply(OrderEventAny::Submitted(submitted)).unwrap();
     portfolio.cache.borrow_mut().update_order(&order1).unwrap();
 
     // Push status to Accepted
-    let order_accepted = accept_order(&order1);
-    order1
-        .apply(OrderEventAny::Accepted(order_accepted))
-        .unwrap();
+    let accepted = accept_order(&order1);
+    order1.apply(OrderEventAny::Accepted(accepted)).unwrap();
     portfolio.cache.borrow_mut().update_order(&order1).unwrap();
 
     // TODO: Replace with Execution Engine once implemented.
@@ -645,8 +643,8 @@ fn test_update_orders_open_margin_account(
         .add_order(order1.clone(), None, None, true)
         .unwrap();
 
-    let order_filled1 = fill_order(&order1);
-    order1.apply(OrderEventAny::Filled(order_filled1)).unwrap();
+    let fill1 = fill_order(&order1);
+    order1.apply(OrderEventAny::Filled(fill1)).unwrap();
 
     // Act
     let last = get_quote_tick(&instrument_btcusdt, 25001.0, 25002.0, 15.0, 12.0);
@@ -659,8 +657,8 @@ fn test_update_orders_open_margin_account(
             .margins_init(&Venue::from("BINANCE"))
             .get(&instrument_btcusdt.id())
             .unwrap()
-            .as_f64(),
-        10.5
+            .as_decimal(),
+        dec!(3.5)
     );
 }
 
@@ -687,16 +685,12 @@ fn test_order_accept_updates_margin_init(
         .add_order(order.clone(), None, None, true)
         .unwrap();
 
-    let order_submitted = submit_order(&order);
-    order
-        .apply(OrderEventAny::Submitted(order_submitted))
-        .unwrap();
+    let submitted = submit_order(&order);
+    order.apply(OrderEventAny::Submitted(submitted)).unwrap();
     portfolio.cache.borrow_mut().update_order(&order).unwrap();
 
-    let order_accepted = accept_order(&order);
-    order
-        .apply(OrderEventAny::Accepted(order_accepted))
-        .unwrap();
+    let accepted = accept_order(&order);
+    order.apply(OrderEventAny::Accepted(accepted)).unwrap();
     portfolio.cache.borrow_mut().update_order(&order).unwrap();
 
     // TODO: Replace with Execution Engine once implemented.
@@ -715,8 +709,8 @@ fn test_order_accept_updates_margin_init(
             .margins_init(&Venue::from("BINANCE"))
             .get(&instrument_btcusdt.id())
             .unwrap()
-            .as_f64(),
-        1.5
+            .as_decimal(),
+        dec!(0.5)
     );
 }
 
@@ -756,11 +750,9 @@ fn test_update_positions(mut portfolio: Portfolio, instrument_audusd: Instrument
     portfolio.update_order(&OrderEventAny::Submitted(order1_submitted));
 
     // ACCEPTED
-    let order1_accepted = accept_order(&order1);
-    order1
-        .apply(OrderEventAny::Accepted(order1_accepted))
-        .unwrap();
-    portfolio.update_order(&OrderEventAny::Accepted(order1_accepted));
+    let accepted1 = accept_order(&order1);
+    order1.apply(OrderEventAny::Accepted(accepted1)).unwrap();
+    portfolio.update_order(&OrderEventAny::Accepted(accepted1));
 
     let mut fill1 = fill_order(&order1);
     fill1.position_id = Some(PositionId::new("SSD"));
@@ -846,45 +838,43 @@ fn test_opening_one_long_position_updates_portfolio(
             .unwrap()
             .get(&Currency::USD())
             .unwrap()
-            .as_f64(),
-        10510.0
+            .as_decimal(),
+        dec!(10510.0)
     );
     assert_eq!(
         portfolio
             .unrealized_pnls(&Venue::from("SIM"))
             .get(&Currency::USD())
             .unwrap()
-            .as_f64(),
-        -6445.89
+            .as_decimal(),
+        dec!(-6445.89)
     );
-    assert_eq!(
+    assert!(
         portfolio
             .realized_pnls(&Venue::from("SIM"))
             .get(&Currency::USD())
             .unwrap()
-            .as_f64(),
-        0.0
+            .is_zero(),
     );
     assert_eq!(
         portfolio
             .net_exposure(&instrument_audusd.id())
             .unwrap()
-            .as_f64(),
-        10510.0
+            .as_decimal(),
+        dec!(10510.0)
     );
     assert_eq!(
         portfolio
             .unrealized_pnl(&instrument_audusd.id())
             .unwrap()
-            .as_f64(),
-        -6445.89
+            .as_decimal(),
+        dec!(-6445.89)
     );
-    assert_eq!(
+    assert!(
         portfolio
             .realized_pnl(&instrument_audusd.id())
             .unwrap()
-            .as_f64(),
-        0.0
+            .is_zero(),
     );
     assert_eq!(
         portfolio.net_position(&instrument_audusd.id()),
@@ -937,45 +927,43 @@ fn test_opening_one_long_position_updates_portfolio_with_bar(
             .unwrap()
             .get(&Currency::USD())
             .unwrap()
-            .as_f64(),
-        10510.0
+            .as_decimal(),
+        dec!(10510.0)
     );
     assert_eq!(
         portfolio
             .unrealized_pnls(&Venue::from("SIM"))
             .get(&Currency::USD())
             .unwrap()
-            .as_f64(),
-        -6445.89
+            .as_decimal(),
+        dec!(-6445.89)
     );
-    assert_eq!(
+    assert!(
         portfolio
             .realized_pnls(&Venue::from("SIM"))
             .get(&Currency::USD())
             .unwrap()
-            .as_f64(),
-        0.0
+            .is_zero(),
     );
     assert_eq!(
         portfolio
             .net_exposure(&instrument_audusd.id())
             .unwrap()
-            .as_f64(),
-        10510.0
+            .as_decimal(),
+        dec!(10510.0)
     );
     assert_eq!(
         portfolio
             .unrealized_pnl(&instrument_audusd.id())
             .unwrap()
-            .as_f64(),
-        -6445.89
+            .as_decimal(),
+        dec!(-6445.89)
     );
-    assert_eq!(
+    assert!(
         portfolio
             .realized_pnl(&instrument_audusd.id())
             .unwrap()
-            .as_f64(),
-        0.0
+            .is_zero(),
     );
     assert_eq!(
         portfolio.net_position(&instrument_audusd.id()),
@@ -1049,45 +1037,45 @@ fn test_opening_one_short_position_updates_portfolio(
             .unwrap()
             .get(&Currency::USD())
             .unwrap()
-            .as_f64(),
-        31020.0
+            .as_decimal(),
+        dec!(31020.0)
     );
     assert_eq!(
         portfolio
             .unrealized_pnls(&Venue::from("SIM"))
             .get(&Currency::USD())
             .unwrap()
-            .as_f64(),
-        -31000.0
+            .as_decimal(),
+        dec!(-31000.0)
     );
     assert_eq!(
         portfolio
             .realized_pnls(&Venue::from("SIM"))
             .get(&Currency::USD())
             .unwrap()
-            .as_f64(),
-        -12.2
+            .as_decimal(),
+        dec!(-12.2)
     );
     assert_eq!(
         portfolio
             .net_exposure(&instrument_audusd.id())
             .unwrap()
-            .as_f64(),
-        31020.0
+            .as_decimal(),
+        dec!(31020.0)
     );
     assert_eq!(
         portfolio
             .unrealized_pnl(&instrument_audusd.id())
             .unwrap()
-            .as_f64(),
-        -31000.0
+            .as_decimal(),
+        dec!(-31000.0)
     );
     assert_eq!(
         portfolio
             .realized_pnl(&instrument_audusd.id())
             .unwrap()
-            .as_f64(),
-        -12.2
+            .as_decimal(),
+        dec!(-12.2)
     );
     assert_eq!(
         portfolio.net_position(&instrument_audusd.id()),
@@ -1165,32 +1153,30 @@ fn test_opening_positions_with_multi_asset_account(
             .unwrap()
             .get(&Currency::ETH())
             .unwrap()
-            .as_f64(),
-        26.59574468
+            .as_decimal(),
+        dec!(26.59574468)
     );
-    assert_eq!(
+    assert!(
         portfolio
             .unrealized_pnls(&Venue::from("BITMEX"))
             .get(&Currency::ETH())
             .unwrap()
-            .as_f64(),
-        0.0
+            .is_zero()
     );
     // TODO: fix
-    // assert_eq!(
+    // assert!(
     //     portfolio
     //         .margins_maint(&Venue::from("SIM"))
     //         .get(&instrument_audusd.id())
     //         .unwrap()
-    //         .as_f64(),
-    //     0.0
+    //         .is_zero(),
     // );
     assert_eq!(
         portfolio
             .net_exposure(&instrument_ethusdt.id())
             .unwrap()
-            .as_f64(),
-        26.59574468
+            .as_decimal(),
+        dec!(26.59574468)
     );
 }
 
@@ -1257,8 +1243,8 @@ fn test_market_value_when_insufficient_data_for_xrate_returns_none(
             .unwrap()
             .get(&Currency::ETH())
             .unwrap()
-            .as_f64(),
-        0.26595745
+            .as_decimal(),
+        dec!(0.26595745)
     );
 }
 
@@ -1376,8 +1362,8 @@ fn test_opening_several_positions_updates_portfolio(
             .unwrap()
             .get(&Currency::USD())
             .unwrap()
-            .as_f64(),
-        100000.0
+            .as_decimal(),
+        dec!(100000.00)
     );
 
     assert_eq!(
@@ -1385,8 +1371,8 @@ fn test_opening_several_positions_updates_portfolio(
             .unrealized_pnls(&Venue::from("SIM"))
             .get(&Currency::USD())
             .unwrap()
-            .as_f64(),
-        -37500000.0
+            .as_decimal(),
+        dec!(-37500000.0)
     );
 
     assert_eq!(
@@ -1394,8 +1380,8 @@ fn test_opening_several_positions_updates_portfolio(
             .realized_pnls(&Venue::from("SIM"))
             .get(&Currency::USD())
             .unwrap()
-            .as_f64(),
-        -12.2
+            .as_decimal(),
+        dec!(-12.2)
     );
     // FIX: TODO: should not be empty
     assert_eq!(portfolio.margins_maint(&Venue::from("SIM")), HashMap::new());
@@ -1403,43 +1389,41 @@ fn test_opening_several_positions_updates_portfolio(
         portfolio
             .net_exposure(&instrument_audusd.id())
             .unwrap()
-            .as_f64(),
-        100000.0
+            .as_decimal(),
+        dec!(100000.0)
     );
     assert_eq!(
         portfolio
             .net_exposure(&instrument_gbpusd.id())
             .unwrap()
-            .as_f64(),
-        100000.0
+            .as_decimal(),
+        dec!(100000.0)
     );
-    assert_eq!(
+    assert!(
         portfolio
             .unrealized_pnl(&instrument_audusd.id())
             .unwrap()
-            .as_f64(),
-        0.0
+            .is_zero(),
     );
     assert_eq!(
         portfolio
             .unrealized_pnl(&instrument_gbpusd.id())
             .unwrap()
-            .as_f64(),
-        -37500000.0
+            .as_decimal(),
+        dec!(-37500000.0)
     );
-    assert_eq!(
+    assert!(
         portfolio
             .realized_pnl(&instrument_audusd.id())
             .unwrap()
-            .as_f64(),
-        0.0
+            .is_zero(),
     );
     assert_eq!(
         portfolio
             .realized_pnl(&instrument_gbpusd.id())
             .unwrap()
-            .as_f64(),
-        -12.2
+            .as_decimal(),
+        dec!(-12.2)
     );
     assert_eq!(
         portfolio.net_position(&instrument_audusd.id()),
@@ -1546,8 +1530,8 @@ fn test_modifying_position_updates_portfolio(
             .unwrap()
             .get(&Currency::USD())
             .unwrap()
-            .as_f64(),
-        100000.0
+            .as_decimal(),
+        dec!(100000.0)
     );
 
     assert_eq!(
@@ -1555,8 +1539,8 @@ fn test_modifying_position_updates_portfolio(
             .unrealized_pnls(&Venue::from("SIM"))
             .get(&Currency::USD())
             .unwrap()
-            .as_f64(),
-        -37500000.0
+            .as_decimal(),
+        dec!(-37500000.0)
     );
 
     assert_eq!(
@@ -1564,8 +1548,8 @@ fn test_modifying_position_updates_portfolio(
             .realized_pnls(&Venue::from("SIM"))
             .get(&Currency::USD())
             .unwrap()
-            .as_f64(),
-        -12.2
+            .as_decimal(),
+        dec!(-12.2)
     );
     // FIX: TODO: should not be empty
     assert_eq!(portfolio.margins_maint(&Venue::from("SIM")), HashMap::new());
@@ -1573,22 +1557,22 @@ fn test_modifying_position_updates_portfolio(
         portfolio
             .net_exposure(&instrument_audusd.id())
             .unwrap()
-            .as_f64(),
-        100000.0
+            .as_decimal(),
+        dec!(100000.0)
     );
     assert_eq!(
         portfolio
             .unrealized_pnl(&instrument_audusd.id())
             .unwrap()
-            .as_f64(),
-        -37500000.0
+            .as_decimal(),
+        dec!(-37500000.0)
     );
     assert_eq!(
         portfolio
             .realized_pnl(&instrument_audusd.id())
             .unwrap()
-            .as_f64(),
-        -12.2
+            .as_decimal(),
+        dec!(-12.2)
     );
     assert_eq!(
         portfolio.net_position(&instrument_audusd.id()),
@@ -1705,24 +1689,24 @@ fn test_closing_position_updates_portfolio(
             .unwrap()
             .get(&Currency::USD())
             .unwrap()
-            .as_f64(),
-        100000.00
+            .as_decimal(),
+        dec!(100000.00)
     );
     assert_eq!(
         portfolio
             .unrealized_pnls(&Venue::from("SIM"))
             .get(&Currency::USD())
             .unwrap()
-            .as_f64(),
-        -37500000.00
+            .as_decimal(),
+        dec!(-37500000.00)
     );
     assert_eq!(
         portfolio
             .realized_pnls(&Venue::from("SIM"))
             .get(&Currency::USD())
             .unwrap()
-            .as_f64(),
-        -12.2
+            .as_decimal(),
+        dec!(-12.2)
     );
     assert_eq!(portfolio.margins_maint(&Venue::from("SIM")), HashMap::new());
 }
@@ -1895,24 +1879,22 @@ fn test_several_positions_with_different_instruments_updates_portfolio(
             .unwrap()
             .get(&Currency::USD())
             .unwrap()
-            .as_f64(),
-        200000.00
+            .as_decimal(),
+        dec!(200000.00)
     );
-    assert_eq!(
+    assert!(
         portfolio
             .unrealized_pnls(&Venue::from("SIM"))
             .get(&Currency::USD())
             .unwrap()
-            .as_f64(),
-        0.0
+            .is_zero(),
     );
-    assert_eq!(
+    assert!(
         portfolio
             .realized_pnls(&Venue::from("SIM"))
             .get(&Currency::USD())
             .unwrap()
-            .as_f64(),
-        0.0
+            .is_zero(),
     );
     // FIX: TODO: should not be empty
     assert_eq!(portfolio.margins_maint(&Venue::from("SIM")), HashMap::new());
