@@ -13,11 +13,28 @@
 //  limitations under the License.
 // -------------------------------------------------------------------------------------------------
 
+//! Risk engine [NautilusTrader](http://nautilustrader.io).
+//!
+//! The *risk* crate provides comprehensive risk management capabilities including pre-trade
+//! order validation, position sizing calculations, and trading controls. This system ensures
+//! trading operations remain within defined risk parameters and regulatory constraints:
+//!
+//! - **Risk engine**: Central risk management orchestration with configurable trading states.
+//! - **Order validation**: Pre-trade checks for price, quantity, notional limits, and market conditions.
+//! - **Position sizing**: Fixed-risk position sizing calculations with commission and exchange rate support.
+//! - **Trading controls**: Rate limiting, balance validation, and exposure management.
+//! - **Account protection**: Multi-currency balance checks and margin requirement validation.
+//!
+//! # Platform
+//!
 //! [NautilusTrader](http://nautilustrader.io) is an open-source, high-performance, production-grade
 //! algorithmic trading platform, providing quantitative traders with the ability to backtest
 //! portfolios of automated trading strategies on historical data with an event-driven engine,
 //! and also deploy those same strategies live, with no code changes.
 //!
+//! NautilusTrader's design, architecture, and implementation philosophy prioritizes software correctness and safety at the
+//! highest level, with the aim of supporting mission-critical, trading system backtesting and live deployment workloads.
+//!
 //! # Feature flags
 //!
 //! This crate provides feature flags to control source code inclusion during compilation,
@@ -30,8 +47,10 @@
 #![warn(rustc::all)]
 #![deny(unsafe_code)]
 #![deny(nonstandard_style)]
-#![deny(rustdoc::broken_intra_doc_links)]
+#![deny(missing_debug_implementations)]
 #![deny(clippy::missing_errors_doc)]
+#![deny(clippy::missing_panics_doc)]
+#![deny(rustdoc::broken_intra_doc_links)]
 
 pub mod engine;
 pub mod sizing;
