@@ -13,10 +13,17 @@
 //  limitations under the License.
 // -------------------------------------------------------------------------------------------------
 
-//! [NautilusTrader](http://nautilustrader.io) is an open-source, high-performance, production-grade
-//! algorithmic trading platform, providing quantitative traders with the ability to backtest
-//! portfolios of automated trading strategies on historical data with an event-driven engine,
-//! and also deploy those same strategies live, with no code changes.
+//! Data serialization and format conversion for [NautilusTrader](http://nautilustrader.io).
+//!
+//! The *serialization* crate provides comprehensive data serialization capabilities for converting
+//! trading data between different formats including Apache Arrow, Parquet, and custom schemas.
+//! This enables efficient data storage, retrieval, and interoperability across different systems:
+//!
+//! - **Apache Arrow integration**: Schema definitions and encoding/decoding for market data types.
+//! - **Parquet file operations**: High-performance columnar storage for historical data analysis.
+//! - **Record batch processing**: Efficient batch operations for time-series data.
+//! - **Schema management**: Type-safe schema definitions with metadata preservation.
+//! - **Cross-format conversion**: Seamless data interchange between Arrow, Parquet, and native types.
 //!
 //! # Feature flags
 //!
@@ -31,12 +38,12 @@
 #![warn(rustc::all)]
 #![deny(unsafe_code)]
 #![deny(nonstandard_style)]
+#![deny(missing_debug_implementations)]
+#![deny(clippy::missing_errors_doc)]
+#![deny(clippy::missing_panics_doc)]
 #![deny(rustdoc::broken_intra_doc_links)]
-// #![deny(clippy::missing_errors_doc)]
 
 pub mod arrow;
-pub mod enums;
-pub mod parquet;
 
 #[cfg(feature = "python")]
 pub mod python;
