@@ -16,11 +16,10 @@
 //! Python bindings from [PyO3](https://pyo3.rs).
 
 pub mod arrow;
-pub mod enums;
 
 use pyo3::prelude::*;
 
-/// Loaded as nautilus_pyo3.serialization
+/// Loaded as `nautilus_pyo3.serialization`.
 ///
 /// # Errors
 ///
@@ -68,7 +67,5 @@ pub fn serialization(_: Python<'_>, m: &Bound<'_, PyModule>) -> PyResult<()> {
         m
     )?)?;
 
-    m.add_class::<crate::enums::ParquetWriteMode>()?;
-
     Ok(())
 }
