@@ -426,7 +426,7 @@ class BinanceOrderBookData(msgspec.Struct, frozen=True):
             delta = bid.parse_to_order_book_delta(
                 instrument_id=instrument_id,
                 side=OrderSide.BUY,
-                flags=RecordFlag.SNAPSHOT if snapshot else flags,
+                flags=RecordFlag.F_SNAPSHOT if snapshot else flags,
                 sequence=self.u,
                 ts_event=ts_event,
                 ts_init=ts_init,
@@ -443,7 +443,7 @@ class BinanceOrderBookData(msgspec.Struct, frozen=True):
             delta = ask.parse_to_order_book_delta(
                 instrument_id=instrument_id,
                 side=OrderSide.SELL,
-                flags=RecordFlag.SNAPSHOT if snapshot else flags,
+                flags=RecordFlag.F_SNAPSHOT if snapshot else flags,
                 sequence=self.u,
                 ts_event=ts_event,
                 ts_init=ts_init,
