@@ -20,7 +20,6 @@ from decimal import Decimal
 import msgspec
 import pandas as pd
 
-from nautilus_trader.adapters.binance.common.constants import BINANCE_VENUE
 from nautilus_trader.adapters.binance.common.enums import BinanceAccountType
 from nautilus_trader.adapters.binance.common.enums import BinanceEnumParser
 from nautilus_trader.adapters.binance.common.enums import BinanceErrorCode
@@ -60,6 +59,7 @@ from nautilus_trader.data.messages import SubscribeBars
 from nautilus_trader.data.messages import SubscribeData
 from nautilus_trader.data.messages import SubscribeInstrument
 from nautilus_trader.data.messages import SubscribeInstruments
+from nautilus_trader.data.messages import SubscribeMarkPrices
 from nautilus_trader.data.messages import SubscribeOrderBook
 from nautilus_trader.data.messages import SubscribeQuoteTicks
 from nautilus_trader.data.messages import SubscribeTradeTicks
@@ -147,8 +147,8 @@ class BinanceCommonDataClient(LiveMarketDataClient):
     ) -> None:
         super().__init__(
             loop=loop,
-            client_id=ClientId(name or BINANCE_VENUE.value),
-            venue=BINANCE_VENUE,
+            client_id=ClientId(name or config.venue.value),
+            venue=config.venue,
             msgbus=msgbus,
             cache=cache,
             clock=clock,
@@ -169,6 +169,10 @@ class BinanceCommonDataClient(LiveMarketDataClient):
         self._connect_websockets_delay: float = 0.0  # Delay for bulk subscriptions to come in
         self._connect_websockets_task: asyncio.Task | None = None
 
+        self._subscribe_allow_no_instrument_id = [
+            BinanceFuturesMarkPriceUpdate,
+        ]
+
         # HTTP API
         self._http_client = client
         self._http_market = market
@@ -295,7 +299,10 @@ class BinanceCommonDataClient(LiveMarketDataClient):
 
     async def _subscribe(self, command: SubscribeData) -> None:
         instrument_id: InstrumentId | None = command.data_type.metadata.get("instrument_id")
-        if instrument_id is None:
+        if (
+            instrument_id is None
+            and command.data_type.type not in self._subscribe_allow_no_instrument_id
+        ):
             self._log.error(
                 f"Cannot subscribe to `{command.data_type.type}` no instrument ID in `data_type` metadata",
             )
@@ -306,11 +313,12 @@ class BinanceCommonDataClient(LiveMarketDataClient):
         elif command.data_type.type == BinanceFuturesMarkPriceUpdate:
             if not self._binance_account_type.is_futures:
                 self._log.error(
-                    f"Cannot subscribe to `BinanceFuturesMarkPriceUpdate` "
+                    "Cannot subscribe to `BinanceFuturesMarkPriceUpdate` "
                     f"for {self._binance_account_type.value} account types",
                 )
                 return
-            await self._ws_client.subscribe_mark_price(instrument_id.symbol.value, speed=1000)
+            mark_price_symbol = instrument_id.symbol.value if instrument_id else None
+            await self._ws_client.subscribe_mark_price(mark_price_symbol, speed=1000)
         else:
             self._log.error(
                 f"Cannot subscribe to {command.data_type.type} (not implemented)",
@@ -318,9 +326,12 @@ class BinanceCommonDataClient(LiveMarketDataClient):
 
     async def _unsubscribe(self, command: UnsubscribeData) -> None:
         instrument_id: InstrumentId | None = command.data_type.metadata.get("instrument_id")
-        if instrument_id is None:
+        if (
+            instrument_id is None
+            and command.data_type.type not in self._subscribe_allow_no_instrument_id
+        ):
             self._log.error(
-                "Cannot subscribe to `BinanceFuturesMarkPriceUpdate` no instrument ID in `data_type` metadata",
+                "Cannot unsubscribe to `BinanceFuturesMarkPriceUpdate` no instrument ID in `data_type` metadata",
             )
             return
 
@@ -376,9 +387,11 @@ class BinanceCommonDataClient(LiveMarketDataClient):
             )
             return
 
-        if not command.depth:
-            # Reasonable default for full book, which works for Spot and Futures
-            depth = 1000
+        # Use the depth requested on the command, otherwise fall back to the
+        # Binance maximum (1000). Note that a depth of ``0`` means *full book*
+        # in NautilusTrader semantics, which we translate to 1000; the maximum
+        # value accepted by the Binance partial book snapshot endpoint.
+        depth: int = command.depth if command.depth else 1000
 
         if 0 < depth <= 20:
             if depth not in (5, 10, 20):
@@ -389,7 +402,7 @@ class BinanceCommonDataClient(LiveMarketDataClient):
                 )
                 return
             await self._ws_client.subscribe_partial_book_depth(
-                symbol=command.vinstrument_id.symbol.value,
+                symbol=command.instrument_id.symbol.value,
                 depth=depth,
                 speed=update_speed,
             )
@@ -432,6 +445,9 @@ class BinanceCommonDataClient(LiveMarketDataClient):
             LogColor.BLUE,
         )
 
+    async def _subscribe_mark_prices(self, command: SubscribeMarkPrices) -> None:
+        await self._ws_client.subscribe_mark_price(command.instrument_id.symbol.value, speed=1000)
+
     async def _subscribe_quote_ticks(self, command: SubscribeQuoteTicks) -> None:
         await self._ws_client.subscribe_book_ticker(command.instrument_id.symbol.value)
 
@@ -490,7 +506,10 @@ class BinanceCommonDataClient(LiveMarketDataClient):
         await self._ws_client.unsubscribe_book_ticker(command.instrument_id.symbol.value)
 
     async def _unsubscribe_trade_ticks(self, command: UnsubscribeTradeTicks) -> None:
-        await self._ws_client.unsubscribe_trades(command.instrument_id.symbol.value)
+        if self._use_agg_trade_ticks:
+            await self._ws_client.unsubscribe_agg_trades(command.instrument_id.symbol.value)
+        else:
+            await self._ws_client.unsubscribe_trades(command.instrument_id.symbol.value)
 
     async def _unsubscribe_bars(self, command: UnsubscribeBars) -> None:
         if not command.bar_type.spec.is_time_aggregated():
@@ -580,7 +599,7 @@ class BinanceCommonDataClient(LiveMarketDataClient):
 
         self._handle_trade_ticks(request.instrument_id, ticks, request.id, request.params)
 
-    async def _request_bars(self, request: RequestBars) -> None:
+    async def _request_bars(self, request: RequestBars) -> None:  # noqa: C901 (too complex)
         if request.bar_type.spec.price_type != PriceType.LAST:
             self._log.error(
                 f"Cannot request {request.bar_type} bars: "
@@ -652,6 +671,17 @@ class BinanceCommonDataClient(LiveMarketDataClient):
                 limit=request.limit if request.limit > 0 else None,
             )
 
+        # Binance always returns the *last* bar as an unfinished / partial bar
+        # which we publish separately from the historical series.  When the
+        # query returned no data we avoid raising ``IndexError`` by checking
+        # for an empty collection first.
+        if not bars:
+            self._log.warning(
+                f"No bars returned for {request.bar_type} between "
+                f"{request.start} and {request.end}",
+            )
+            return
+
         partial: Bar = bars.pop()
         self._handle_bars(request.bar_type, bars, partial, request.id, request.params)
 
@@ -922,7 +952,7 @@ class BinanceCommonDataClient(LiveMarketDataClient):
                     f"Unrecognized websocket message type: {wrapper.stream}",
                 )
         except Exception as e:
-            self._log.exception("Error handling websocket message {raw!r}", e)
+            self._log.exception(f"Error handling websocket message {raw!r}", e)
 
     def _handle_book_diff_update(self, raw: bytes) -> None:
         msg = self._decoder_order_book_msg.decode(raw)
