@@ -185,3 +185,12 @@ class BinanceFuturesLeverage(msgspec.Struct, frozen=True):
     leverage: int
     maxNotionalValue: str
     symbol: str
+
+
+class BinanceFuturesMarginTypeResponse(msgspec.Struct, frozen=True):
+    """
+    HTTP response from Binance Futures `POST /fapi/v1/marginType`.
+    """
+
+    code: int
+    msg: str
