@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------------------------------
-#  Copyright (C) 2015-2024 Nautech Systems Pty Ltd. All rights reserved.
+#  Copyright (C) 2015-2025 Nautech Systems Pty Ltd. All rights reserved.
 #  https://nautechsystems.io
 #
 #  Licensed under the GNU Lesser General Public License Version 3.0 (the "License");
@@ -87,7 +87,7 @@ class BinanceHttpClient:
 
         self._headers: dict[str, Any] = {
             "Content-Type": "application/json",
-            "User-Agent": nautilus_trader.USER_AGENT,
+            "User-Agent": nautilus_trader.NAUTILUS_USER_AGENT,
             "X-MBX-APIKEY": api_key,
         }
         self._client = HttpClient(
@@ -191,17 +191,25 @@ class BinanceHttpClient:
             keys=ratelimiter_keys,
         )
 
-        if 400 <= response.status < 500:
-            raise BinanceClientError(
-                status=response.status,
-                message=msgspec.json.decode(response.body) if response.body else None,
-                headers=response.headers,
-            )
-        elif response.status >= 500:
-            raise BinanceServerError(
-                status=response.status,
-                message=msgspec.json.decode(response.body) if response.body else None,
-                headers=response.headers,
-            )
+        response_body = response.body
+
+        if response.status >= 400:
+            try:
+                message = msgspec.json.decode(response_body) if response_body else None
+            except msgspec.DecodeError:
+                message = response_body.decode()
+
+            if response.status >= 500:
+                raise BinanceServerError(
+                    status=response.status,
+                    message=message,
+                    headers=response.headers,
+                )
+            else:
+                raise BinanceClientError(
+                    status=response.status,
+                    message=message,
+                    headers=response.headers,
+                )
 
         return response.body
