@@ -137,6 +137,9 @@ class BybitWsOrderRequestMsgOP(Enum):
     CREATE = "order.create"
     AMEND = "order.amend"
     CANCEL = "order.cancel"
+    CREATE_BATCH = "order.create-batch"
+    AMEND_BATCH = "order.amend-batch"
+    CANCEL_BATCH = "order.cancel-batch"
 
 
 @unique
@@ -186,6 +189,10 @@ class BybitOrderType(Enum):
 
 @unique
 class BybitStopOrderType(Enum):
+    """
+    https://bybit-exchange.github.io/docs/v5/enum#stopordertype
+    """
+
     NONE = ""  # Default
     UNKNOWN = "UNKNOWN"  # Classic account value
     TAKE_PROFIT = "TakeProfit"
