@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------------------------------
-#  Copyright (C) 2015-2024 Nautech Systems Pty Ltd. All rights reserved.
+#  Copyright (C) 2015-2025 Nautech Systems Pty Ltd. All rights reserved.
 #  https://nautechsystems.io
 #
 #  Licensed under the GNU Lesser General Public License Version 3.0 (the "License");
@@ -62,3 +62,10 @@ def get_ws_base_url_private(is_testnet: bool) -> str:
         return "wss://stream-testnet.bybit.com/v5/private"
     else:
         return "wss://stream.bybit.com/v5/private"
+
+
+def get_ws_base_url_trade(is_testnet: bool) -> str:
+    if is_testnet:
+        return "wss://stream-testnet.bybit.com/v5/trade"
+    else:
+        return "wss://stream.bybit.com/v5/trade"
