@@ -55,10 +55,14 @@ from nautilus_trader.data.messages import RequestInstruments
 from nautilus_trader.data.messages import RequestQuoteTicks
 from nautilus_trader.data.messages import RequestTradeTicks
 from nautilus_trader.data.messages import SubscribeBars
+from nautilus_trader.data.messages import SubscribeInstrument
+from nautilus_trader.data.messages import SubscribeInstruments
 from nautilus_trader.data.messages import SubscribeOrderBook
 from nautilus_trader.data.messages import SubscribeQuoteTicks
 from nautilus_trader.data.messages import SubscribeTradeTicks
 from nautilus_trader.data.messages import UnsubscribeBars
+from nautilus_trader.data.messages import UnsubscribeInstrument
+from nautilus_trader.data.messages import UnsubscribeInstruments
 from nautilus_trader.data.messages import UnsubscribeOrderBook
 from nautilus_trader.data.messages import UnsubscribeQuoteTicks
 from nautilus_trader.data.messages import UnsubscribeTradeTicks
@@ -79,7 +83,6 @@ from nautilus_trader.model.objects import Quantity
 
 
 if TYPE_CHECKING:
-
     from nautilus_trader.adapters.bybit.config import BybitDataClientConfig
     from nautilus_trader.adapters.bybit.http.client import BybitHttpClient
     from nautilus_trader.adapters.bybit.providers import BybitInstrumentProvider
@@ -274,6 +277,57 @@ class BybitDataClient(LiveMarketDataClient):
         except asyncio.CancelledError:
             self._log.debug("Canceled task 'update_instruments'")
 
+    async def _subscribe_instruments(self, command: SubscribeInstruments) -> None:
+        """
+        Subscribe to instruments updates.
+
+        Parameters
+        ----------
+        command : SubscribeInstruments
+            The command to subscribe to instruments.
+
+        """
+        self._log.info("Skipping subscribe_instruments, Bybit subscribes automatically")
+
+    async def _subscribe_instrument(self, command: SubscribeInstrument) -> None:
+        """
+        Subscribe to instrument updates.
+
+        Parameters
+        ----------
+        command : SubscribeInstrument
+            The command to subscribe to instrument.
+
+        """
+        self._log.info("Skipping subscribe_instrument, Bybit subscribes automatically")
+
+    async def _unsubscribe_instruments(
+        self,
+        command: UnsubscribeInstruments,
+    ) -> None:
+        """
+        Unsubscribe from instruments updates.
+
+        Parameters
+        ----------
+        command : UnsubscribeInstruments
+            The command to unsubscribe from instruments updates.
+
+        """
+        self._log.info("Skipping unsubscribe_instruments, not applicable for Bybit")
+
+    async def _unsubscribe_instrument(self, command: UnsubscribeInstrument) -> None:
+        """
+        Unsubscribe from instrument updates.
+
+        Parameters
+        ----------
+        command : UnsubscribeInstrument
+            The command to unsubscribe from instrument updates.
+
+        """
+        self._log.info("Skipping unsubscribe_instrument, not applicable for Bybit")
+
     async def _subscribe_order_book_deltas(self, command: SubscribeOrderBook) -> None:
         if command.book_type == BookType.L3_MBO:
             self._log.error(
@@ -303,7 +357,7 @@ class BybitDataClient(LiveMarketDataClient):
             case _:
                 # Theoretically unreachable but retained to keep the match exhaustive
                 raise ValueError(
-                    f"Invalit Bybit product type {product_type}",
+                    f"Invalid Bybit product type {product_type}",
                 )
 
         if depth not in depths_available:
@@ -363,18 +417,21 @@ class BybitDataClient(LiveMarketDataClient):
         ws_client = self._ws_clients[bybit_symbol.product_type]
         depth = self._depths.get(command.instrument_id, 1)
         await ws_client.unsubscribe_order_book(bybit_symbol.raw_symbol, depth=depth)
+        self._depths.pop(command.instrument_id, None)
 
     async def _unsubscribe_order_book_snapshots(self, command: UnsubscribeOrderBook) -> None:
         bybit_symbol = BybitSymbol(command.instrument_id.symbol.value)
         ws_client = self._ws_clients[bybit_symbol.product_type]
         depth = self._depths.get(command.instrument_id, 1)
         await ws_client.unsubscribe_order_book(bybit_symbol.raw_symbol, depth=depth)
+        self._depths.pop(command.instrument_id, None)
 
     async def _unsubscribe_quote_ticks(self, command: UnsubscribeQuoteTicks) -> None:
         bybit_symbol = BybitSymbol(command.instrument_id.symbol.value)
         ws_client = self._ws_clients[bybit_symbol.product_type]
         if command.instrument_id in self._tob_quotes:
             await ws_client.unsubscribe_order_book(bybit_symbol.raw_symbol, depth=1)
+            self._tob_quotes.discard(command.instrument_id)
         else:
             await ws_client.unsubscribe_tickers(bybit_symbol.raw_symbol)
 
@@ -514,8 +571,8 @@ class BybitDataClient(LiveMarketDataClient):
             ts_init=self._clock.timestamp_ns(),
             timestamp_on_close=self._bars_timestamp_on_close,
         )
-        partial: Bar = bars.pop()
-        self._handle_bars(request.bar_type, bars, partial, request.id, request.params)
+        # For historical data requests, all bars are complete (no partial bars)
+        self._handle_bars(request.bar_type, bars, None, request.id, request.params)
 
     async def _handle_ticker_data_request(self, symbol: Symbol, correlation_id: UUID4) -> None:
         bybit_symbol = BybitSymbol(symbol.value)
