@@ -190,7 +190,8 @@ class BybitExecutionClient(LiveExecutionClient):
         self._log.info(f"{config.use_ws_trade_api=}", LogColor.BLUE)
         self._log.info(f"{config.use_http_batch_api=}", LogColor.BLUE)
         self._log.info(f"{config.max_retries=}", LogColor.BLUE)
-        self._log.info(f"{config.retry_delay=}", LogColor.BLUE)
+        self._log.info(f"{config.retry_delay_initial_ms=}", LogColor.BLUE)
+        self._log.info(f"{config.retry_delay_max_ms=}", LogColor.BLUE)
         self._log.info(f"{config.recv_window_ms=:_}", LogColor.BLUE)
         self._log.info(f"{config.ws_trade_timeout_secs=}", LogColor.BLUE)
         self._log.info(f"{config.futures_leverages=}", LogColor.BLUE)
@@ -245,6 +246,12 @@ class BybitExecutionClient(LiveExecutionClient):
             self._order_single_client = self._http_account
             self._order_batch_client = self._http_account
 
+        self._is_order_single_client_ws = isinstance(
+            self._order_single_client,
+            BybitWebSocketClient,
+        )
+        self._is_order_batch_client_ws = isinstance(self._order_batch_client, BybitWebSocketClient)
+
         # Order submission
         self._submit_order_methods = {
             OrderType.MARKET: self._submit_market_order,
@@ -283,7 +290,9 @@ class BybitExecutionClient(LiveExecutionClient):
         self._retry_manager_pool = RetryManagerPool[None](
             pool_size=100,
             max_retries=config.max_retries or 0,
-            retry_delay_secs=config.retry_delay or 0.0,
+            delay_initial_ms=config.retry_delay_initial_ms or 1_000,
+            delay_max_ms=config.retry_delay_max_ms or 10_000,
+            backoff_factor=2,
             logger=self._log,
             exc_types=(BybitError,),
             retry_check=should_retry,
@@ -680,8 +689,9 @@ class BybitExecutionClient(LiveExecutionClient):
         client_order_id = command.client_order_id.value
         venue_order_id = str(command.venue_order_id) if command.venue_order_id else None
 
-        async with self._retry_manager_pool as retry_manager:
-            await retry_manager.run(
+        retry_manager = await self._retry_manager_pool.acquire()
+        try:
+            response = await retry_manager.run(
                 "cancel_order",
                 [client_order_id, venue_order_id],
                 self._order_single_client.cancel_order,
@@ -700,7 +710,34 @@ class BybitExecutionClient(LiveExecutionClient):
                     self._clock.timestamp_ns(),
                 )
 
-    async def _batch_cancel_orders(self, command: BatchCancelOrders) -> None:
+            if response:
+                ret_code = response.retCode
+                if ret_code != 0:
+                    if ret_code == 110001:  # order not exists or too late to cancel
+                        if not order.is_closed:
+                            self.generate_order_canceled(
+                                strategy_id=order.strategy_id,
+                                instrument_id=order.instrument_id,
+                                client_order_id=order.client_order_id,
+                                venue_order_id=order.venue_order_id,
+                                ts_event=self._clock.timestamp_ns(),
+                            )
+                    else:
+                        self.generate_order_cancel_rejected(
+                            strategy_id=order.strategy_id,
+                            instrument_id=order.instrument_id,
+                            client_order_id=order.client_order_id,
+                            venue_order_id=order.venue_order_id,
+                            reason=response.retMsg,
+                            ts_event=self._clock.timestamp_ns(),
+                        )
+        finally:
+            await self._retry_manager_pool.release(retry_manager)
+
+    async def _batch_cancel_orders(  # noqa: C901 (too complex)
+        self,
+        command: BatchCancelOrders,
+    ) -> None:
         # https://bybit-exchange.github.io/docs/v5/order/batch-cancel
 
         bybit_symbol = BybitSymbol(command.instrument_id.symbol.value)
@@ -734,8 +771,9 @@ class BybitExecutionClient(LiveExecutionClient):
                 for cancel in batch_cancels
             ]
 
-            async with self._retry_manager_pool as retry_manager:
-                await retry_manager.run(
+            retry_manager = await self._retry_manager_pool.acquire()
+            try:
+                response = await retry_manager.run(
                     "batch_cancel_orders",
                     None,
                     self._order_batch_client.batch_cancel_orders,
@@ -748,18 +786,52 @@ class BybitExecutionClient(LiveExecutionClient):
                         if order is None or order.is_closed:
                             continue
                         self.generate_order_cancel_rejected(
-                            order.strategy_id,
-                            order.instrument_id,
-                            order.client_order_id,
-                            order.venue_order_id,
-                            retry_manager.message,
-                            self._clock.timestamp_ns(),
+                            strategy_id=order.strategy_id,
+                            instrument_id=order.instrument_id,
+                            client_order_id=order.client_order_id,
+                            venue_order_id=order.venue_order_id,
+                            reason=retry_manager.message,
+                            ts_event=self._clock.timestamp_ns(),
                         )
 
+                if response:
+                    if self._is_order_batch_client_ws:
+                        resp_data_list = response.data.list
+                    else:
+                        resp_data_list = response.result.list
+                    for idx, ret_info in enumerate(response.retExtInfo.list):
+                        ret_code = ret_info.code
+                        if ret_code != 0:
+                            order = self._cache.order(
+                                ClientOrderId(resp_data_list[idx].orderLinkId),
+                            )
+                            if order is None or order.is_closed:
+                                continue
+                            if ret_code == 110001:  # order not exists or too late to cancel
+                                self.generate_order_canceled(
+                                    strategy_id=order.strategy_id,
+                                    instrument_id=order.instrument_id,
+                                    client_order_id=order.client_order_id,
+                                    venue_order_id=order.venue_order_id,
+                                    ts_event=self._clock.timestamp_ns(),
+                                )
+                            else:
+                                self.generate_order_cancel_rejected(
+                                    strategy_id=order.strategy_id,
+                                    instrument_id=order.instrument_id,
+                                    client_order_id=order.client_order_id,
+                                    venue_order_id=order.venue_order_id,
+                                    reason=ret_info.msg,
+                                    ts_event=self._clock.timestamp_ns(),
+                                )
+            finally:
+                await self._retry_manager_pool.release(retry_manager)
+
     async def _cancel_all_orders(self, command: CancelAllOrders) -> None:
         bybit_symbol = BybitSymbol(command.instrument_id.symbol.value)
 
-        async with self._retry_manager_pool as retry_manager:
+        retry_manager = await self._retry_manager_pool.acquire()
+        try:
             await retry_manager.run(
                 "cancel_all_orders",
                 None,
@@ -780,6 +852,8 @@ class BybitExecutionClient(LiveExecutionClient):
                         retry_manager.message,
                         self._clock.timestamp_ns(),
                     )
+        finally:
+            await self._retry_manager_pool.release(retry_manager)
 
     async def _modify_order(self, command: ModifyOrder) -> None:
         order: Order | None = self._cache.order(command.client_order_id)
@@ -800,7 +874,8 @@ class BybitExecutionClient(LiveExecutionClient):
         trigger_price = str(command.trigger_price) if command.trigger_price else None
         quantity = str(command.quantity) if command.quantity else None
 
-        async with self._retry_manager_pool as retry_manager:
+        retry_manager = await self._retry_manager_pool.acquire()
+        try:
             await retry_manager.run(
                 "modify_order",
                 [client_order_id, venue_order_id],
@@ -822,6 +897,8 @@ class BybitExecutionClient(LiveExecutionClient):
                     retry_manager.message,
                     self._clock.timestamp_ns(),
                 )
+        finally:
+            await self._retry_manager_pool.release(retry_manager)
 
     async def _submit_order(self, command: SubmitOrder) -> None:
         order = command.order
@@ -842,7 +919,8 @@ class BybitExecutionClient(LiveExecutionClient):
             ts_event=self._clock.timestamp_ns(),
         )
 
-        async with self._retry_manager_pool as retry_manager:
+        retry_manager = await self._retry_manager_pool.acquire()
+        try:
             await retry_manager.run(
                 "submit_order",
                 [order.client_order_id],
@@ -857,8 +935,13 @@ class BybitExecutionClient(LiveExecutionClient):
                     reason=retry_manager.message,
                     ts_event=self._clock.timestamp_ns(),
                 )
+        finally:
+            await self._retry_manager_pool.release(retry_manager)
 
-    async def _submit_order_list(self, command: SubmitOrderList) -> None:
+    async def _submit_order_list(  # noqa: C901 (too complex)
+        self,
+        command: SubmitOrderList,
+    ) -> None:
         bybit_symbol = BybitSymbol(command.instrument_id.symbol.value)
         product_type = bybit_symbol.product_type
         command_orders = command.order_list.orders
@@ -892,8 +975,9 @@ class BybitExecutionClient(LiveExecutionClient):
                     ts_event=now_ns,
                 )
 
-            async with self._retry_manager_pool as retry_manager:
-                await retry_manager.run(
+            retry_manager = await self._retry_manager_pool.acquire()
+            try:
+                response = await retry_manager.run(
                     "submit_order_list",
                     None,
                     self._order_batch_client.batch_place_orders,
@@ -901,6 +985,38 @@ class BybitExecutionClient(LiveExecutionClient):
                     submit_orders=submit_orders,
                 )
 
+                if not retry_manager.result:
+                    for order in batch_submits:
+                        self.generate_order_rejected(
+                            strategy_id=order.strategy_id,
+                            instrument_id=order.instrument_id,
+                            client_order_id=order.client_order_id,
+                            reason=retry_manager.message,
+                            ts_event=self._clock.timestamp_ns(),
+                        )
+
+                if response:
+                    if self._is_order_batch_client_ws:
+                        resp_data_list = response.data.list
+                    else:
+                        resp_data_list = response.result.list
+                    for idx, ret_info in enumerate(response.retExtInfo.list):
+                        if ret_info.code != 0:
+                            order = self._cache.order(
+                                ClientOrderId(resp_data_list[idx].orderLinkId),
+                            )
+                            if order is None:
+                                continue
+                            self.generate_order_rejected(
+                                strategy_id=order.strategy_id,
+                                instrument_id=order.instrument_id,
+                                client_order_id=order.client_order_id,
+                                reason=ret_info.msg,
+                                ts_event=self._clock.timestamp_ns(),
+                            )
+            finally:
+                await self._retry_manager_pool.release(retry_manager)
+
     def _check_order_validity(self, order: Order, product_type: BybitProductType) -> bool:
         # Check post only
         if order.is_post_only and order.order_type != OrderType.LIMIT:
@@ -1127,8 +1243,7 @@ class BybitExecutionClient(LiveExecutionClient):
 
         if client_order_id is None:
             self._log.debug(
-                f"Cannot process order execution for {venue_order_id!r}: "
-                "no `ClientOrderId` found (most likely due to being an external order)",
+                f"Cannot process order execution for {venue_order_id!r}: no `ClientOrderId` found (most likely due to being an external order)",
             )
             return
 
@@ -1151,8 +1266,7 @@ class BybitExecutionClient(LiveExecutionClient):
             )
             if strategy_id is None:
                 self._log.warning(
-                    f"Cannot process order execution for {client_order_id!r}: "
-                    "no strategy ID found (most likely due to being an external order)",
+                    f"Cannot process order execution for {client_order_id!r}: no strategy ID found (most likely due to being an external order)",
                 )
                 return
         else:
@@ -1403,7 +1517,7 @@ class BybitExecutionClient(LiveExecutionClient):
             price=str(order.price),
             timeInForce=time_in_force,
             orderLinkId=order.client_order_id.value,
-            reduceOnly=order.reduce_only,
+            reduceOnly=order.is_reduce_only,
             tpslMode=BybitTpSlMode.PARTIAL if product_type != BybitProductType.SPOT else None,
             triggerPrice=str(order.trigger_price),
             triggerDirection=trigger_direction,
