@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------------------------------
-#  Copyright (C) 2015-2024 Nautech Systems Pty Ltd. All rights reserved.
+#  Copyright (C) 2015-2025 Nautech Systems Pty Ltd. All rights reserved.
 #  https://nautechsystems.io
 #
 #  Licensed under the GNU Lesser General Public License Version 3.0 (the "License");
@@ -13,6 +13,10 @@
 #  limitations under the License.
 # -------------------------------------------------------------------------------------------------
 
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
 import msgspec
 
 from nautilus_trader.adapters.bybit.common.constants import BYBIT_VENUE
@@ -20,20 +24,23 @@ from nautilus_trader.adapters.bybit.common.enums import BybitProductType
 from nautilus_trader.adapters.bybit.common.symbol import BybitSymbol
 from nautilus_trader.adapters.bybit.http.account import BybitAccountHttpAPI
 from nautilus_trader.adapters.bybit.http.asset import BybitAssetHttpAPI
-from nautilus_trader.adapters.bybit.http.client import BybitHttpClient
 from nautilus_trader.adapters.bybit.http.market import BybitMarketHttpAPI
-from nautilus_trader.adapters.bybit.schemas.account.fee_rate import BybitFeeRate
 from nautilus_trader.adapters.bybit.schemas.instrument import BybitInstrument
 from nautilus_trader.adapters.bybit.schemas.instrument import BybitInstrumentInverse
 from nautilus_trader.adapters.bybit.schemas.instrument import BybitInstrumentLinear
 from nautilus_trader.adapters.bybit.schemas.instrument import BybitInstrumentList
 from nautilus_trader.adapters.bybit.schemas.instrument import BybitInstrumentOption
 from nautilus_trader.adapters.bybit.schemas.instrument import BybitInstrumentSpot
-from nautilus_trader.common.component import LiveClock
 from nautilus_trader.common.providers import InstrumentProvider
-from nautilus_trader.config import InstrumentProviderConfig
 from nautilus_trader.core.correctness import PyCondition
-from nautilus_trader.model.identifiers import InstrumentId
+
+
+if TYPE_CHECKING:
+    from nautilus_trader.adapters.bybit.http.client import BybitHttpClient
+    from nautilus_trader.adapters.bybit.schemas.account.fee_rate import BybitFeeRate
+    from nautilus_trader.common.component import LiveClock
+    from nautilus_trader.config import InstrumentProviderConfig
+    from nautilus_trader.model.identifiers import InstrumentId
 
 
 class BybitInstrumentProvider(InstrumentProvider):
@@ -93,15 +100,15 @@ class BybitInstrumentProvider(InstrumentProvider):
         fee_rates: dict[BybitProductType, list[BybitFeeRate]] = {}
 
         for product_type in self._product_types:
-            instrument_infos[product_type] = await self._http_market.fetch_instruments(
+            instrument_infos[product_type] = await self._http_market.fetch_all_instruments(
                 product_type,
             )
             fee_rates[product_type] = await self._http_account.fetch_fee_rate(
                 product_type,
             )
 
-        for product_type in instrument_infos:
-            for instrument in instrument_infos[product_type]:
+        for product_type, instruments in instrument_infos.items():
+            for instrument in instruments:
                 target_fee_rate = next(
                     (
                         item
@@ -141,7 +148,7 @@ class BybitInstrumentProvider(InstrumentProvider):
         fee_rates: dict[BybitProductType, list[BybitFeeRate]] = {}
 
         for product_type in self._product_types:
-            instrument_infos[product_type] = await self._http_market.fetch_instruments(
+            instrument_infos[product_type] = await self._http_market.fetch_all_instruments(
                 product_type,
             )
             fee_rates[product_type] = await self._http_account.fetch_fee_rate(
@@ -203,17 +210,21 @@ class BybitInstrumentProvider(InstrumentProvider):
         else:
             raise TypeError(f"Unsupported Bybit instrument, was {instrument}")
 
-    def _parse_spot_instrument(
+    def _parse_to_instrument(
         self,
-        data: BybitInstrumentSpot,
+        instrument: BybitInstrument,
         fee_rate: BybitFeeRate,
     ) -> None:
+        if isinstance(instrument, BybitInstrumentOption):
+            self._log.warning("Parsing of instrument Options is currently not supported")
+            return
+
         try:
-            base_currency = self.currency(data.baseCoin)
-            quote_currency = self.currency(data.quoteCoin)
+            base_currency = self.currency(instrument.baseCoin)
+            quote_currency = self.currency(instrument.quoteCoin)
             ts_event = self._clock.timestamp_ns()
             ts_init = self._clock.timestamp_ns()
-            instrument = data.parse_to_instrument(
+            instrument = instrument.parse_to_instrument(
                 base_currency=base_currency,
                 quote_currency=quote_currency,
                 fee_rate=fee_rate,
@@ -223,51 +234,30 @@ class BybitInstrumentProvider(InstrumentProvider):
             self.add(instrument=instrument)
         except ValueError as e:
             if self._log_warnings:
-                self._log.warning(f"Unable to parse option instrument {data.symbol}: {e}")
+                self._log.warning(
+                    f"Unable to parse {instrument.__class__.__name__} instrument {instrument.symbol}: {e}",
+                )
+
+    def _parse_spot_instrument(
+        self,
+        data: BybitInstrumentSpot,
+        fee_rate: BybitFeeRate,
+    ) -> None:
+        self._parse_to_instrument(data, fee_rate)
 
     def _parse_linear_instrument(
         self,
         data: BybitInstrumentLinear,
         fee_rate: BybitFeeRate,
     ) -> None:
-        try:
-            base_currency = self.currency(data.baseCoin)
-            quote_currency = self.currency(data.quoteCoin)
-            ts_event = self._clock.timestamp_ns()
-            ts_init = self._clock.timestamp_ns()
-            instrument = data.parse_to_instrument(
-                base_currency=base_currency,
-                quote_currency=quote_currency,
-                fee_rate=fee_rate,
-                ts_event=ts_event,
-                ts_init=ts_init,
-            )
-            self.add(instrument=instrument)
-        except ValueError as e:
-            if self._log_warnings:
-                self._log.warning(f"Unable to parse linear instrument {data.symbol}: {e}")
+        self._parse_to_instrument(data, fee_rate)
 
     def _parse_inverse_instrument(
         self,
         data: BybitInstrumentInverse,
         fee_rate: BybitFeeRate,
     ) -> None:
-        try:
-            base_currency = self.currency(data.baseCoin)
-            quote_currency = self.currency(data.quoteCoin)
-            ts_event = self._clock.timestamp_ns()
-            ts_init = self._clock.timestamp_ns()
-            instrument = data.parse_to_instrument(
-                base_currency=base_currency,
-                quote_currency=quote_currency,
-                fee_rate=fee_rate,
-                ts_event=ts_event,
-                ts_init=ts_init,
-            )
-            self.add(instrument=instrument)
-        except ValueError as e:
-            if self._log_warnings:
-                self._log.warning(f"Unable to parse inverse instrument {data.symbol}: {e}")
+        self._parse_to_instrument(data, fee_rate)
 
     def _parse_option_instrument(
         self,
@@ -275,8 +265,3 @@ class BybitInstrumentProvider(InstrumentProvider):
         fee_rate: BybitFeeRate,
     ) -> None:
         self._log.warning("Parsing of instrument Options is currently not supported")
-        try:
-            pass
-        except ValueError as e:
-            if self._log_warnings:
-                self._log.warning(f"Unable to parse option instrument {instrument.symbol}: {e}")
