@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------------------------------
-#  Copyright (C) 2015-2024 Nautech Systems Pty Ltd. All rights reserved.
+#  Copyright (C) 2015-2025 Nautech Systems Pty Ltd. All rights reserved.
 #  https://nautechsystems.io
 #
 #  Licensed under the GNU Lesser General Public License Version 3.0 (the "License");
@@ -27,6 +27,10 @@ class BybitListResult(Generic[T], msgspec.Struct):
     list: list[T]
 
 
+class BybitListResultWithCursor(BybitListResult[T]):
+    nextPageCursor: str | None = None
+
+
 def bybit_coin_result(object_type: Any):
     return msgspec.defstruct("", [("coin", list[object_type])])
 
@@ -53,17 +57,6 @@ class SpotPriceFilter(msgspec.Struct):
     tickSize: str
 
 
-class LotSizeFilter(msgspec.Struct):
-    # Maximum order quantity
-    maxOrderQty: str
-    # Minimum order quantity
-    minOrderQty: str
-    # The step to increase/reduce order quantity
-    qtyStep: str
-    # Maximum order qty for PostOnly order
-    postOnlyMaxOrderQty: str | None = None
-
-
 class SpotLotSizeFilter(msgspec.Struct):
     basePrecision: str
     quotePrecision: str
@@ -71,3 +64,25 @@ class SpotLotSizeFilter(msgspec.Struct):
     maxOrderQty: str
     minOrderAmt: str
     maxOrderAmt: str
+
+
+class LinearLotSizeFilter(msgspec.Struct):
+    # Maximum order quantity
+    maxOrderQty: str
+    # Minimum order quantity
+    minOrderQty: str
+    # The step to increase/reduce order quantity
+    qtyStep: str
+    # Maximum order qty for PostOnly order
+    postOnlyMaxOrderQty: str
+    maxMktOrderQty: str
+    minNotionalValue: str
+
+
+class OptionLotSizeFilter(msgspec.Struct):
+    # Maximum order quantity
+    maxOrderQty: str
+    # Minimum order quantity
+    minOrderQty: str
+    # The step to increase/reduce order quantity
+    qtyStep: str
