@@ -31,17 +31,30 @@ from nautilus_trader.adapters.bybit.common.enums import BybitWsOrderRequestMsgOP
 
 # fmt: off
 from nautilus_trader.adapters.bybit.endpoints.trade.amend_order import BybitAmendOrderPostParams
+from nautilus_trader.adapters.bybit.endpoints.trade.batch_amend_order import BybitBatchAmendOrderPostParams
+from nautilus_trader.adapters.bybit.endpoints.trade.batch_cancel_order import BybitBatchCancelOrder
+from nautilus_trader.adapters.bybit.endpoints.trade.batch_cancel_order import BybitBatchCancelOrderPostParams
+from nautilus_trader.adapters.bybit.endpoints.trade.batch_place_order import BybitBatchPlaceOrder
+from nautilus_trader.adapters.bybit.endpoints.trade.batch_place_order import BybitBatchPlaceOrderPostParams
 from nautilus_trader.adapters.bybit.endpoints.trade.cancel_order import BybitCancelOrderPostParams
 from nautilus_trader.adapters.bybit.endpoints.trade.place_order import BybitPlaceOrderPostParams
 from nautilus_trader.adapters.bybit.http.errors import BybitError
+from nautilus_trader.adapters.bybit.schemas.ws import BybitWsAmendOrderResponseMsg
+from nautilus_trader.adapters.bybit.schemas.ws import BybitWsBatchAmendOrderResponseMsg
+from nautilus_trader.adapters.bybit.schemas.ws import BybitWsBatchCancelOrderResponseMsg
+from nautilus_trader.adapters.bybit.schemas.ws import BybitWsBatchPlaceOrderResponseMsg
+from nautilus_trader.adapters.bybit.schemas.ws import BybitWsCancelOrderResponseMsg
 from nautilus_trader.adapters.bybit.schemas.ws import BybitWsMessageGeneral
 from nautilus_trader.adapters.bybit.schemas.ws import BybitWsOrderRequestMsg
 from nautilus_trader.adapters.bybit.schemas.ws import BybitWsOrderResponseMsg
+from nautilus_trader.adapters.bybit.schemas.ws import BybitWsOrderResponseMsgGeneral
+from nautilus_trader.adapters.bybit.schemas.ws import BybitWsPlaceOrderResponseMsg
 from nautilus_trader.adapters.bybit.schemas.ws import BybitWsPrivateChannelAuthMsg
 from nautilus_trader.adapters.bybit.schemas.ws import BybitWsTradeAuthMsg
 from nautilus_trader.common.component import LiveClock
 from nautilus_trader.common.component import Logger
 from nautilus_trader.common.enums import LogColor
+from nautilus_trader.config import PositiveFloat
 from nautilus_trader.core.nautilus_pyo3 import WebSocketClient
 from nautilus_trader.core.nautilus_pyo3 import WebSocketClientError
 from nautilus_trader.core.nautilus_pyo3 import WebSocketConfig
@@ -52,17 +65,14 @@ from nautilus_trader.core.uuid import UUID4
 if TYPE_CHECKING:
     from collections.abc import Awaitable
     from collections.abc import Callable
-    from collections.abc import Coroutine
     from typing import Any
 
-    from nautilus_trader.adapters.bybit.endpoints.trade.batch_cancel_order import BybitBatchCancelOrder
-    from nautilus_trader.adapters.bybit.endpoints.trade.batch_place_order import BybitBatchPlaceOrder
 
 # fmt: on
 
 MAX_ARGS_PER_SUBSCRIPTION_REQUEST = 10
 
-WsOrderResponseFuture = asyncio.Future[BybitWsOrderResponseMsg]
+WsOrderResponseMsgFuture = asyncio.Future[BybitWsOrderResponseMsg]
 
 
 class BybitWebSocketClient:
@@ -83,7 +93,7 @@ class BybitWebSocketClient:
         Whether the client is a private channel.
     is_trade : bool, optional
         Whether the client is a trade channel.
-    ws_trade_timeout_secs: float, default 5.0
+    ws_trade_timeout_secs: PositiveFloat, default 5.0
         The timeout for trade websocket messages.
     recv_window_ms : int, default 5_000
         The receive window (milliseconds) for Bybit WebSocket order requests.
@@ -106,7 +116,8 @@ class BybitWebSocketClient:
         loop: asyncio.AbstractEventLoop,
         is_private: bool | None = False,
         is_trade: bool | None = False,
-        ws_trade_timeout_secs: float | None = 5.0,
+        ws_trade_timeout_secs: PositiveFloat | None = 5.0,
+        ws_auth_timeout_secs: PositiveFloat | None = 5.0,
         recv_window_ms: int = 5_000,
     ) -> None:
         if is_private and is_trade:
@@ -135,13 +146,40 @@ class BybitWebSocketClient:
         self._is_trade = is_trade
         self._auth_required = is_private or is_trade
         self._is_authenticated = False
+        self._ws_auth_timeout_secs = ws_auth_timeout_secs
+
+        self._reconnect_task: asyncio.Task | None = None
+        self._auth_event = asyncio.Event()
+
+        self._pending_order_requests: dict[str, WsOrderResponseMsgFuture] = {}
 
         self._decoder_ws_message_general = msgspec_json.Decoder(BybitWsMessageGeneral)
         self._decoder_ws_private_channel_auth = msgspec_json.Decoder(BybitWsPrivateChannelAuthMsg)
         self._decoder_ws_trade_auth = msgspec_json.Decoder(BybitWsTradeAuthMsg)
-        self._decoder_ws_order_response = msgspec_json.Decoder(BybitWsOrderResponseMsg)
 
-        self._pending_order_requests: dict[str, WsOrderResponseFuture] = {}
+        # Decoders for WebSocket order response messages
+        self._decoder_ws_order_resp_general = msgspec_json.Decoder(BybitWsOrderResponseMsgGeneral)
+
+        self._decoder_ws_order_resp_place = msgspec_json.Decoder(BybitWsPlaceOrderResponseMsg)
+        self._decoder_ws_order_resp_amend = msgspec_json.Decoder(BybitWsAmendOrderResponseMsg)
+        self._decoder_ws_order_resp_cancel = msgspec_json.Decoder(BybitWsCancelOrderResponseMsg)
+        self._decoder_ws_order_resp_batch_place = msgspec_json.Decoder(
+            BybitWsBatchPlaceOrderResponseMsg,
+        )
+        self._decoder_ws_order_resp_batch_amend = msgspec_json.Decoder(
+            BybitWsBatchAmendOrderResponseMsg,
+        )
+        self._decoder_ws_order_resp_batch_cancel = msgspec_json.Decoder(
+            BybitWsBatchCancelOrderResponseMsg,
+        )
+        self._decoder_ws_order_resp_map = {
+            BybitWsOrderRequestMsgOP.CREATE: self._decoder_ws_order_resp_place,
+            BybitWsOrderRequestMsgOP.AMEND: self._decoder_ws_order_resp_amend,
+            BybitWsOrderRequestMsgOP.CANCEL: self._decoder_ws_order_resp_cancel,
+            BybitWsOrderRequestMsgOP.CREATE_BATCH: self._decoder_ws_order_resp_batch_place,
+            BybitWsOrderRequestMsgOP.AMEND_BATCH: self._decoder_ws_order_resp_batch_amend,
+            BybitWsOrderRequestMsgOP.CANCEL_BATCH: self._decoder_ws_order_resp_batch_cancel,
+        }
 
     @property
     def subscriptions(self) -> list[str]:
@@ -189,7 +227,7 @@ class BybitWebSocketClient:
 
         self._log.warning(f"Trying to reconnect to {self._base_url}")
         self._reconnecting = True
-        self._loop.create_task(self._reconnect_wrapper())
+        self._reconnect_task = self._loop.create_task(self._reconnect_wrapper())
 
     async def _reconnect_wrapper(self) -> None:
         try:
@@ -266,18 +304,38 @@ class BybitWebSocketClient:
 
         if msg.is_auth_success():
             self._is_authenticated = True
+            self._auth_event.set()
             self._log.info(f"{self.channel_type} channel authenticated", LogColor.GREEN)
         else:
             raise RuntimeError(f"{self.channel_type} channel authentication failed: {msg}")
 
     async def _authenticate(self) -> None:
         self._is_authenticated = False
-        signature = self._get_signature()
-        await self._send(signature)
+        self._auth_event.clear()
 
-        while not self._is_authenticated:
-            self._log.debug(f"Waiting for {self.channel_type} channel authentication")
-            await asyncio.sleep(0.1)
+        signature = self._get_signature()
+
+        try:
+            await self._send(signature)
+            await asyncio.wait_for(
+                self._auth_event.wait(),
+                timeout=self._ws_auth_timeout_secs,
+            )
+        except TimeoutError:
+            self._log.warning(f"{self.channel_type} channel authentication timeout")
+            raise
+        except WebSocketClientError as e:
+            self._log.exception(
+                f"{self.channel_type} channel failed to send authentication request",
+                {e},
+            )
+            raise
+        except Exception as e:
+            self._log.exception(
+                f"{self.channel_type} channel unexpected error during authentication",
+                {e},
+            )
+            raise
 
     async def _subscribe(self, subscription: str) -> None:
         self._log.debug(f"Subscribing to {subscription}")
@@ -403,7 +461,7 @@ class BybitWebSocketClient:
 
     def _handle_order_ack(self, raw: bytes) -> None:
         try:
-            msg = self._decoder_ws_order_response.decode(raw)
+            msg: BybitWsOrderResponseMsgGeneral = self._decoder_ws_order_resp_general.decode(raw)
         except Exception as e:
             self._log.exception(f"Failed to decode order ack response {raw!r}", e)
             return
@@ -413,28 +471,37 @@ class BybitWebSocketClient:
             self._log.debug(f"No `reqId` in order ack response: {msg}")
             return
 
-        ret_code = msg.retCode
         future = self._pending_order_requests.pop(req_id, None)
         if future is not None:
-            if ret_code == 0:
-                future.set_result(msg)
-            else:
-                future.set_exception(BybitError(code=ret_code, message=msg.retMsg))
+            try:
+                order_resp: BybitWsOrderResponseMsg = self._decoder_ws_order_resp_map[msg.op].decode(raw)  # type: ignore[attr-defined]
+                if order_resp.retCode == 0:
+                    future.set_result(order_resp)
+                else:
+                    future.set_exception(
+                        BybitError(code=order_resp.retCode, message=order_resp.retMsg),
+                    )
+            except Exception as e:
+                self._log.exception(f"Failed to decode order ack response {raw!r}", e)
         else:
             self._log.warning(f"Received ack for `unknown/timeout` reqId={req_id}, msg={msg}")
-            return
 
     async def _order(
         self,
         op: BybitWsOrderRequestMsgOP,
         args: list[
-            BybitPlaceOrderPostParams | BybitAmendOrderPostParams | BybitCancelOrderPostParams
+            BybitPlaceOrderPostParams
+            | BybitAmendOrderPostParams
+            | BybitCancelOrderPostParams
+            | BybitBatchPlaceOrderPostParams
+            | BybitBatchAmendOrderPostParams
+            | BybitBatchCancelOrderPostParams
         ],
-        timeout_secs: float | None,
+        timeout_secs: PositiveFloat | None,
     ) -> BybitWsOrderResponseMsg:
         req_id = UUID4().value
 
-        future: WsOrderResponseFuture = self._loop.create_future()
+        future: WsOrderResponseMsgFuture = self._loop.create_future()
         self._pending_order_requests[req_id] = future
 
         # Build request
@@ -457,25 +524,10 @@ class BybitWebSocketClient:
         except TimeoutError as e:
             self._log.error(f"Order request `{req_id}` timed out. op={op}, args={args}")
             future.cancel()
-            self._pending_order_requests.pop(req_id, None)
             raise BybitError(code=-10_408, message="Request timed out") from e
 
         return ack_resp
 
-    async def _batch_orders(
-        self,
-        tasks: list[Coroutine[Any, Any, BybitWsOrderResponseMsg]],
-    ) -> list[BybitWsOrderResponseMsg]:
-        futures = await asyncio.gather(*tasks, return_exceptions=True)
-
-        results: list[BybitWsOrderResponseMsg] = []
-        for result in futures:
-            if isinstance(result, BybitWsOrderResponseMsg):
-                results.append(result)
-            else:
-                self._log.error(f"Batch orders error: {result}")
-        return results
-
     async def place_order(
         self,
         product_type: BybitProductType,
@@ -584,49 +636,30 @@ class BybitWebSocketClient:
         self,
         product_type: BybitProductType,
         submit_orders: list[BybitBatchPlaceOrder],
-    ) -> list[BybitWsOrderResponseMsg]:
-        tasks = [
-            self.place_order(
-                product_type=product_type,
-                symbol=order.symbol,
-                side=order.side,
-                order_type=order.orderType,
-                quantity=order.qty,
-                quote_quantity=order.marketUnit == "quoteCoin",
-                price=order.price,
-                time_in_force=order.timeInForce,
-                client_order_id=order.orderLinkId,
-                reduce_only=order.reduceOnly,
-                close_on_trigger=order.closeOnTrigger,
-                trigger_price=order.triggerPrice,
-                trigger_direction=order.triggerDirection,
-                tp_order_type=order.tpOrderType,
-                sl_order_type=order.slOrderType,
-                tpsl_mode=order.tpslMode,
-                tp_trigger_price=order.takeProfit,
-                sl_trigger_price=order.stopLoss,
-                trigger_type=order.triggerBy,
-                tp_limit_price=order.tpLimitPrice,
-                sl_limit_price=order.slLimitPrice,
-            )
-            for order in submit_orders
-        ]
-
-        return await self._batch_orders(tasks)
+    ) -> BybitWsOrderResponseMsg:
+        return await self._order(
+            timeout_secs=self._ws_trade_timeout_secs,
+            op=BybitWsOrderRequestMsgOP.CREATE_BATCH,
+            args=[
+                BybitBatchPlaceOrderPostParams(
+                    category=product_type,
+                    request=submit_orders,
+                ),
+            ],
+        )
 
     async def batch_cancel_orders(
         self,
         product_type: BybitProductType,
         cancel_orders: list[BybitBatchCancelOrder],
-    ) -> list[BybitWsOrderResponseMsg]:
-        tasks = [
-            self.cancel_order(
-                product_type=product_type,
-                symbol=order.symbol,
-                client_order_id=order.orderLinkId,
-                venue_order_id=order.orderId,
-            )
-            for order in cancel_orders
-        ]
-
-        return await self._batch_orders(tasks)
+    ) -> BybitWsOrderResponseMsg:
+        return await self._order(
+            timeout_secs=self._ws_trade_timeout_secs,
+            op=BybitWsOrderRequestMsgOP.CANCEL_BATCH,
+            args=[
+                BybitBatchCancelOrderPostParams(
+                    category=product_type,
+                    request=cancel_orders,
+                ),
+            ],
+        )
