@@ -119,6 +119,7 @@ class DatabentoDataClient(LiveMarketDataClient):
     ) -> None:
         if config is None:
             config = DatabentoDataClientConfig()
+
         PyCondition.type(config, DatabentoDataClientConfig, "config")
 
         super().__init__(
@@ -138,6 +139,7 @@ class DatabentoDataClient(LiveMarketDataClient):
         self._use_exchange_as_venue: bool = config.use_exchange_as_venue
         self._timeout_initial_load: float | None = config.timeout_initial_load
         self._mbo_subscriptions_delay: float | None = config.mbo_subscriptions_delay
+        self._bars_timestamp_on_close: bool = config.bars_timestamp_on_close
         self._parent_symbols: dict[Dataset, set[str]] = defaultdict(set)
         self._venue_dataset_map: dict[Venue, Dataset] | None = config.venue_dataset_map
         self._instrument_ids: dict[Dataset, set[InstrumentId]] = defaultdict(set)
@@ -145,6 +147,7 @@ class DatabentoDataClient(LiveMarketDataClient):
         self._log.info(f"{config.use_exchange_as_venue=}", LogColor.BLUE)
         self._log.info(f"{config.timeout_initial_load=}", LogColor.BLUE)
         self._log.info(f"{config.mbo_subscriptions_delay=}", LogColor.BLUE)
+        self._log.info(f"{config.bars_timestamp_on_close=}", LogColor.BLUE)
 
         # Clients
         self._http_client = http_client
@@ -185,6 +188,7 @@ class DatabentoDataClient(LiveMarketDataClient):
         self._log.info("Initializing instruments...")
 
         coros: list[Coroutine] = []
+
         for dataset, instrument_ids in self._instrument_ids.items():
             loading_ids: list[InstrumentId] = sorted(instrument_ids)
             filters = {
@@ -224,12 +228,14 @@ class DatabentoDataClient(LiveMarketDataClient):
         for dataset, live_client in self._live_clients.items():
             if not live_client.is_running():
                 continue
+
             self._log.info(f"Stopping {dataset} live feed", LogColor.BLUE)
             live_client.close()
 
         for dataset, live_client in self._live_clients_mbo.items():
             if not live_client.is_running():
                 continue
+
             self._log.info(f"Stopping {dataset} MBO/L3 live feed", LogColor.BLUE)
             live_client.close()
 
@@ -247,8 +253,8 @@ class DatabentoDataClient(LiveMarketDataClient):
                 )
 
                 await asyncio.sleep(self._update_dataset_ranges_interval_secs)
-
                 tasks = []
+
                 for dataset in self._dataset_ranges:
                     tasks.append(self._get_dataset_range(dataset))
 
@@ -264,8 +270,8 @@ class DatabentoDataClient(LiveMarketDataClient):
             self._log.debug("Buffering MBO subscriptions...", LogColor.MAGENTA)
             await asyncio.sleep(self._mbo_subscriptions_delay or 0.0)
             self._is_buffering_mbo_subscriptions = False
-
             coros: list[Coroutine] = []
+
             for dataset, instrument_ids in self._buffered_mbo_subscriptions.items():
                 self._log.info(f"Starting {dataset} MBO/L3 live feeds")
                 coro = self._subscribe_order_book_deltas_batch(instrument_ids)
@@ -285,6 +291,7 @@ class DatabentoDataClient(LiveMarketDataClient):
                 dataset=dataset,
                 publishers_filepath=str(PUBLISHERS_FILEPATH),
                 use_exchange_as_venue=self._use_exchange_as_venue,
+                bars_timestamp_on_close=self._bars_timestamp_on_close,
             )
             self._live_clients[dataset] = live_client
 
@@ -300,6 +307,7 @@ class DatabentoDataClient(LiveMarketDataClient):
                 dataset=dataset,
                 publishers_filepath=str(PUBLISHERS_FILEPATH),
                 use_exchange_as_venue=self._use_exchange_as_venue,
+                bars_timestamp_on_close=self._bars_timestamp_on_close,
             )
             self._live_clients_mbo[dataset] = live_client
 
@@ -335,7 +343,6 @@ class DatabentoDataClient(LiveMarketDataClient):
                 return
 
             self._instrument_ids[dataset].add(instrument_id)
-
             subscribe = SubscribeInstrument(
                 instrument_id=instrument_id,
                 client_id=None,
@@ -358,6 +365,7 @@ class DatabentoDataClient(LiveMarketDataClient):
             await asyncio.sleep(0.1)
 
         available_range = self._dataset_ranges.get(dataset)
+
         if available_range:
             return available_range
 
@@ -371,7 +379,6 @@ class DatabentoDataClient(LiveMarketDataClient):
 
             available_start = pd.to_datetime(start_str, utc=True)
             available_end = pd.to_datetime(end_str, utc=True)
-
             self._dataset_ranges[dataset] = (available_start, available_end)
 
             self._log.info(
@@ -382,9 +389,11 @@ class DatabentoDataClient(LiveMarketDataClient):
             return available_start, available_end
         except asyncio.CancelledError:
             self._log.warning("Canceled task 'get_dataset_range'")
+
             return (None, pd.Timestamp.utcnow())
         except Exception as e:  # More specific exception
             self._log.exception("Error requesting dataset range", e)
+
             return (None, pd.Timestamp.utcnow())
         finally:
             self._dataset_ranges_requested.discard(dataset)
@@ -621,7 +630,6 @@ class DatabentoDataClient(LiveMarketDataClient):
                 schema = DatabentoSchema.MBP_1.value
 
             start: int | None = command.params.get("start")
-
             dataset: Dataset = self._loader.get_dataset_for_venue(command.instrument_id.venue)
             live_client = self._get_live_client(dataset)
             live_client.subscribe(
@@ -645,7 +653,6 @@ class DatabentoDataClient(LiveMarketDataClient):
             await self._ensure_subscribed_for_instrument(command.instrument_id)
 
             start: int | None = command.params.get("start")
-
             dataset: Dataset = self._loader.get_dataset_for_venue(command.instrument_id.venue)
             live_client = self._get_live_client(dataset)
             live_client.subscribe(
@@ -670,7 +677,6 @@ class DatabentoDataClient(LiveMarketDataClient):
                 return
 
             start: int | None = command.params.get("start")
-
             live_client = self._get_live_client(dataset)
             live_client.subscribe(
                 schema=schema.value,
@@ -684,7 +690,6 @@ class DatabentoDataClient(LiveMarketDataClient):
     async def _subscribe_instrument_status(self, command: SubscribeInstrumentStatus) -> None:
         try:
             dataset: Dataset = self._loader.get_dataset_for_venue(command.instrument_id.venue)
-
             live_client = self._get_live_client(dataset)
             live_client.subscribe(
                 schema=DatabentoSchema.STATUS.value,
@@ -768,10 +773,17 @@ class DatabentoDataClient(LiveMarketDataClient):
         end = data_type.metadata.get("end")
 
         dataset: Dataset = self._loader.get_dataset_for_venue(instrument_id.venue)
-        _, available_end = await self._get_dataset_range(dataset)
+        available_end = None
+
+        if not end:
+            _, available_end = await self._get_dataset_range(dataset)
 
-        start = start or available_end - pd.Timedelta(days=2)
         end = end or available_end
+        start = start or end - pd.Timedelta(days=1)
+
+        # Type assertions to help MyPy understand these cannot be None
+        assert start is not None
+        assert end is not None
 
         self._log.info(
             f"Requesting {instrument_id} instrument status: "
@@ -785,9 +797,7 @@ class DatabentoDataClient(LiveMarketDataClient):
             start=start.value,
             end=end.value,
         )
-
         status = InstrumentStatus.from_pyo3_list(pyo3_status_list)
-
         self._handle_data_response(
             data_type=data_type,
             data=status,
@@ -801,10 +811,17 @@ class DatabentoDataClient(LiveMarketDataClient):
         end = data_type.metadata.get("end")
 
         dataset: Dataset = self._loader.get_dataset_for_venue(instrument_id.venue)
-        _, available_end = await self._get_dataset_range(dataset)
+        available_end = None
+
+        if not end:
+            _, available_end = await self._get_dataset_range(dataset)
 
-        start = start or available_end - pd.Timedelta(days=2)
         end = end or available_end
+        start = start or end - pd.Timedelta(days=1)
+
+        # Type assertions to help MyPy understand these cannot be None
+        assert start is not None
+        assert end is not None
 
         self._log.info(
             f"Requesting {instrument_id} imbalance: "
@@ -818,7 +835,6 @@ class DatabentoDataClient(LiveMarketDataClient):
             start=start.value,
             end=end.value,
         )
-
         self._handle_data_response(
             data_type=data_type,
             data=pyo3_imbalances,
@@ -832,10 +848,17 @@ class DatabentoDataClient(LiveMarketDataClient):
         end = data_type.metadata.get("end")
 
         dataset: Dataset = self._loader.get_dataset_for_venue(instrument_id.venue)
-        _, available_end = await self._get_dataset_range(dataset)
+        available_end = None
+
+        if not end:
+            _, available_end = await self._get_dataset_range(dataset)
 
-        start = start or available_end - pd.Timedelta(days=2)
         end = end or available_end
+        start = start or end - pd.Timedelta(days=1)
+
+        # Type assertions to help MyPy understand these cannot be None
+        assert start is not None
+        assert end is not None
 
         self._log.info(
             f"Requesting {instrument_id} statistics: "
@@ -849,7 +872,6 @@ class DatabentoDataClient(LiveMarketDataClient):
             start=start.value,
             end=end.value,
         )
-
         self._handle_data_response(
             data_type=data_type,
             data=pyo3_statistics,
@@ -859,10 +881,15 @@ class DatabentoDataClient(LiveMarketDataClient):
 
     async def _request_instrument(self, request: RequestInstrument) -> None:
         dataset: Dataset = self._loader.get_dataset_for_venue(request.instrument_id.venue)
-        _, available_end = await self._get_dataset_range(dataset)
 
-        start = request.start or available_end - pd.Timedelta(days=2)
-        end = request.end or available_end
+        if not request.end:
+            end = request.end
+        else:
+            _, available_end = await self._get_dataset_range(dataset)
+            end = available_end
+
+        # NOTE: instruments are "published" every day at midnight
+        start = request.start or end - pd.Timedelta(days=1)
 
         self._log.info(
             f"Requesting {request.instrument_id} instrument definition: "
@@ -877,8 +904,8 @@ class DatabentoDataClient(LiveMarketDataClient):
             start=start.value,
             end=end.value,
         )
-
         instruments = instruments_from_pyo3(pyo3_instruments)
+
         if not instruments:
             self._log.warning(
                 f"No instrument found for request: {request.instrument_id=}, {request.id=}",
@@ -889,10 +916,15 @@ class DatabentoDataClient(LiveMarketDataClient):
 
     async def _request_instruments(self, request: RequestInstruments) -> None:
         dataset: Dataset = self._loader.get_dataset_for_venue(request.venue)
-        _, available_end = await self._get_dataset_range(dataset)
 
-        start = request.start or available_end - pd.Timedelta(days=2)
-        end = request.end or available_end
+        if not request.end:
+            end = request.end
+        else:
+            _, available_end = await self._get_dataset_range(dataset)
+            end = available_end
+
+        # NOTE: instruments are "published" every day at midnight
+        start = request.start or end - pd.Timedelta(days=1)
 
         self._log.info(
             f"Requesting {request.venue} instrument definitions: "
@@ -906,7 +938,6 @@ class DatabentoDataClient(LiveMarketDataClient):
             instrument_id_to_pyo3(InstrumentId.from_str(f"{symbol}.{request.venue}"))
             for symbol in parent_symbols
         ]
-
         pyo3_instruments = await self._http_client.get_range_instruments(
             dataset=dataset,
             instrument_ids=pyo3_instrument_ids,
@@ -919,10 +950,15 @@ class DatabentoDataClient(LiveMarketDataClient):
 
     async def _request_quote_ticks(self, request: RequestQuoteTicks) -> None:
         dataset: Dataset = self._loader.get_dataset_for_venue(request.instrument_id.venue)
-        _, available_end = await self._get_dataset_range(dataset)
 
-        start = request.start or available_end - pd.Timedelta(days=1)
-        end = request.end or available_end
+        if not request.end:
+            end = request.end
+        else:
+            _, available_end = await self._get_dataset_range(dataset)
+            end = available_end
+
+        # NOTE: instruments are "published" every day at midnight
+        start = request.start or end - pd.Timedelta(days=1)
 
         if request.limit > 0:
             self._log.warning(
@@ -936,6 +972,7 @@ class DatabentoDataClient(LiveMarketDataClient):
 
         # allowed schema values: mbp-1, bbo-1s, bbo-1m
         schema: str | None = request.params.get("schema")
+
         if schema is None or schema not in [
             DatabentoSchema.MBP_1.value,
             DatabentoSchema.BBO_1S.value,
@@ -950,17 +987,21 @@ class DatabentoDataClient(LiveMarketDataClient):
             end=end.value,
             schema=schema,
         )
-
         quotes = QuoteTick.from_pyo3_list(pyo3_quotes)
 
         self._handle_quote_ticks(request.instrument_id, quotes, request.id, request.params)
 
     async def _request_trade_ticks(self, request: RequestTradeTicks) -> None:
         dataset: Dataset = self._loader.get_dataset_for_venue(request.instrument_id.venue)
-        _, available_end = await self._get_dataset_range(dataset)
 
-        start = request.start or available_end - pd.Timedelta(days=1)
-        end = request.end or available_end
+        if not request.end:
+            end = request.end
+        else:
+            _, available_end = await self._get_dataset_range(dataset)
+            end = available_end
+
+        # NOTE: instruments are "published" every day at midnight
+        start = request.start or end - pd.Timedelta(days=1)
 
         if request.limit > 0:
             self._log.warning(
@@ -978,17 +1019,21 @@ class DatabentoDataClient(LiveMarketDataClient):
             start=start.value,
             end=end.value,
         )
-
         trades = TradeTick.from_pyo3_list(pyo3_trades)
 
         self._handle_trade_ticks(request.instrument_id, trades, request.id, request.params)
 
     async def _request_bars(self, request: RequestBars) -> None:
         dataset: Dataset = self._loader.get_dataset_for_venue(request.bar_type.instrument_id.venue)
-        _, available_end = await self._get_dataset_range(dataset)
 
-        start = request.start or available_end - pd.Timedelta(days=1)
-        end = request.end or available_end
+        if not request.end:
+            end = request.end
+        else:
+            _, available_end = await self._get_dataset_range(dataset)
+            end = available_end
+
+        # NOTE: instruments are "published" every day at midnight
+        start = request.start or end - pd.Timedelta(days=1)
 
         if request.limit > 0:
             self._log.warning(
@@ -1009,8 +1054,8 @@ class DatabentoDataClient(LiveMarketDataClient):
             ),
             start=start.value,
             end=end.value,
+            timestamp_on_close=self._bars_timestamp_on_close,
         )
-
         bars = Bar.from_pyo3_list(pyo3_bars)
 
         self._handle_bars(
