@@ -150,6 +150,9 @@ class InteractiveBrokersClient(
         self._order_id_to_order_ref: dict[int, AccountOrderRef] = {}
         self._next_valid_order_id: int = -1
 
+        # Instrument provider (set by data/execution clients during connection)
+        self._instrument_provider = None
+
         # Start client
         self._request_id_seq: int = 10000
 
@@ -180,11 +183,13 @@ class InteractiveBrokersClient(
                     self._log.error("Max connection attempts reached, connection failed")
                     self._stop()
                     break
+
                 if self._connection_attempts > 1:
                     self._log.info(
                         f"Attempt {self._connection_attempts}: attempting to reconnect in {self._reconnect_delay} seconds...",
                     )
                     await asyncio.sleep(self._reconnect_delay)
+
                 await self._connect()
                 self._start_tws_incoming_msg_reader()
                 self._start_internal_msg_queue_processor()
@@ -194,14 +199,16 @@ class InteractiveBrokersClient(
                 # seconds, so we wait for it here.
                 await asyncio.wait_for(self._is_ib_connected.wait(), 15)
                 self._start_connection_watchdog()
+
+                self._is_client_ready.set()
+                self._log.debug("`_is_client_ready` set by `_start_async`", LogColor.BLUE)
+                self._connection_attempts = 0
+
             except TimeoutError:
-                self._log.error("Client failed to initialize. Connection timeout.")
+                self._log.error("Client failed to initialize; connection timeout")
             except Exception as e:
                 self._log.exception("Unhandled exception in client startup", e)
                 self._stop()
-        self._is_client_ready.set()
-        self._log.debug("`_is_client_ready` set by `_start_async`.", LogColor.BLUE)
-        self._connection_attempts = 0
 
     def _start_tws_incoming_msg_reader(self) -> None:
         """
@@ -209,6 +216,7 @@ class InteractiveBrokersClient(
         """
         if self._tws_incoming_msg_reader_task:
             self._tws_incoming_msg_reader_task.cancel()
+
         self._tws_incoming_msg_reader_task = self._create_task(
             self._run_tws_incoming_msg_reader(),
         )
@@ -219,11 +227,14 @@ class InteractiveBrokersClient(
         """
         if self._internal_msg_queue_processor_task:
             self._internal_msg_queue_processor_task.cancel()
+
         self._internal_msg_queue_processor_task = self._create_task(
             self._run_internal_msg_queue_processor(),
         )
+
         if self._msg_handler_processor_task:
             self._msg_handler_processor_task.cancel()
+
         self._msg_handler_processor_task = self._create_task(
             self._run_msg_handler_processor(),
         )
@@ -234,6 +245,7 @@ class InteractiveBrokersClient(
         """
         if self._connection_watchdog_task:
             self._connection_watchdog_task.cancel()
+
         self._connection_watchdog_task = self._create_task(
             self._run_connection_watchdog(),
         )
@@ -249,7 +261,7 @@ class InteractiveBrokersClient(
 
         if self._is_client_ready.is_set():
             self._is_client_ready.clear()
-            self._log.debug("`_is_client_ready` unset by `_stop_async`.", LogColor.BLUE)
+            self._log.debug("`_is_client_ready` unset by `_stop_async`", LogColor.BLUE)
 
         # Cancel tasks
         tasks = [
@@ -263,6 +275,7 @@ class InteractiveBrokersClient(
                 task.cancel()
 
         try:
+            tasks = [t for t in tasks if t is not None]
             await asyncio.gather(*tasks, return_exceptions=True)
             self._log.info("All tasks canceled successfully.")
         except Exception as e:
@@ -315,6 +328,7 @@ class InteractiveBrokersClient(
 
         for subscription in self._subscriptions.get_all():
             self._log.info(f"Resubscribing to {subscription.name} subscription...")
+
             try:
                 if iscoroutinefunction(subscription.handle):
                     await subscription.handle()
@@ -337,7 +351,7 @@ class InteractiveBrokersClient(
             if not self._is_client_ready.is_set():
                 await asyncio.wait_for(self._is_client_ready.wait(), timeout)
         except TimeoutError as e:
-            self._log.error(f"Client is not ready. {e}")
+            self._log.error(f"Client is not ready: {e}")
 
     async def _run_connection_watchdog(self) -> None:
         """
@@ -351,10 +365,9 @@ class InteractiveBrokersClient(
         try:
             while True:
                 await asyncio.sleep(1)
+
                 if not self._is_ib_connected.is_set() or not self._eclient.isConnected():
-                    self._log.error(
-                        "Connection watchdog detects connection lost.",
-                    )
+                    self._log.error("Connection watchdog detects connection lost")
                     await self._handle_disconnection()
         except asyncio.CancelledError:
             self._log.debug("Client connection watchdog task was canceled.")
@@ -365,9 +378,11 @@ class InteractiveBrokersClient(
         """
         if self.is_running:
             self._degrade()
+
         if self._is_ib_connected.is_set():
-            self._log.debug("`_is_ib_connected` unset by `_handle_disconnection`.", LogColor.BLUE)
+            self._log.debug("`_is_ib_connected` unset by `_handle_disconnection`", LogColor.BLUE)
             self._is_ib_connected.clear()
+
         await asyncio.sleep(5)
         await self._handle_reconnect()
 
@@ -506,10 +521,12 @@ class InteractiveBrokersClient(
             msg = f"Request timed out for {request}. Ending request."
             self._log.debug(msg) if supress_timeout_warning else self._log.warning(msg)
             self._end_request(request.req_id, success=False, exception=e)
+
             return default_value
         except ConnectionError as e:
-            self._log.error(f"Connection error during {request}. Ending request.")
+            self._log.error(f"Connection error during {request}; ending request")
             self._end_request(request.req_id, success=False, exception=e)
+
             return default_value
 
     def _end_request(
@@ -541,6 +558,7 @@ class InteractiveBrokersClient(
                 request.cancel()
                 if exception:
                     request.future.set_exception(exception)
+
         self._requests.remove(req_id=req_id)
 
     async def _run_tws_incoming_msg_reader(self) -> None:
@@ -548,48 +566,53 @@ class InteractiveBrokersClient(
         Continuously read messages from TWS/Gateway and then put them in the internal
         message queue for processing.
         """
-        self._log.debug("Client TWS incoming message reader started.")
+        self._log.debug("Client TWS incoming message reader started")
         buf = b""
+
         try:
             while self._eclient.conn and self._eclient.conn.isConnected():
                 data = await asyncio.to_thread(self._eclient.conn.recvMsg)
                 buf += data
+
                 while buf:
                     _, msg, buf = comm.read_msg(buf)
                     self._log.debug(f"Msg buffer received: {buf!s}")
+
                     if msg:
                         # Place msg in the internal queue for processing
                         self._loop.call_soon_threadsafe(self._internal_msg_queue.put_nowait, msg)
                     else:
-                        self._log.debug("More incoming packets are needed.")
+                        self._log.debug("More incoming packets are needed")
                         break
         except asyncio.CancelledError:
-            self._log.debug("Client TWS incoming message reader was cancelled.")
+            self._log.debug("Client TWS incoming message reader was cancelled")
         except Exception as e:
             self._log.exception("Unhandled exception in Client TWS incoming message reader", e)
         finally:
             if self._is_ib_connected.is_set() and not self.is_disposed:
                 self._log.debug(
-                    "`_is_ib_connected` unset by `_run_tws_incoming_msg_reader`.",
+                    "`_is_ib_connected` unset by `_run_tws_incoming_msg_reader`",
                     LogColor.BLUE,
                 )
                 self._is_ib_connected.clear()
-            self._log.debug("Client TWS incoming message reader stopped.")
+
+            self._log.debug("Client TWS incoming message reader stopped")
 
     async def _run_internal_msg_queue_processor(self) -> None:
         """
         Continuously process messages from the internal incoming message queue.
         """
-        self._log.debug(
-            "Client internal message queue processor started.",
-        )
+        self._log.debug("Client internal message queue processor started")
+
         try:
             while (
                 self._eclient.conn and self._eclient.conn.isConnected()
             ) or not self._internal_msg_queue.empty():
                 msg = await self._internal_msg_queue.get()
+
                 if not await self._process_message(msg):
                     break
+
                 self._internal_msg_queue.task_done()
         except asyncio.CancelledError:
             log_msg = f"Internal message queue processing was cancelled. (qsize={self._internal_msg_queue.qsize()})."
@@ -601,7 +624,7 @@ class InteractiveBrokersClient(
                 )
             )
         finally:
-            self._log.debug("Internal message queue processor stopped.")
+            self._log.debug("Internal message queue processor stopped")
 
     async def _process_message(self, msg: str) -> bool:
         """
@@ -623,7 +646,9 @@ class InteractiveBrokersClient(
                 error_code=BAD_LENGTH.code(),
                 error_string=f"{BAD_LENGTH.msg()}:{len(msg)}:{msg}",
             )
+
             return False
+
         fields: tuple[bytes] = comm.read_fields(msg)
         self._log.debug(f"Msg received: {msg}")
         self._log.debug(f"Msg received fields: {fields}")
@@ -633,6 +658,7 @@ class InteractiveBrokersClient(
         # method from the EWrapper. Many of those methods are overridden in the client
         # manager and handler classes to support custom processing required for Nautilus.
         await asyncio.to_thread(self._eclient.decoder.interpret, fields)
+
         return True
 
     async def _run_msg_handler_processor(self):
@@ -663,7 +689,7 @@ class InteractiveBrokersClient(
                 )
             )
         finally:
-            self._log.debug("Handler task processor stopped.")
+            self._log.debug("Handler task processor stopped")
 
     def submit_to_msg_handler_queue(self, task: Callable[..., Any]) -> None:
         """
@@ -694,6 +720,7 @@ class InteractiveBrokersClient(
         """
         new_id = self._request_id_seq
         self._request_id_seq += 1
+
         return new_id
 
     # -- EClient overrides ------------------------------------------------------------------------
@@ -715,4 +742,5 @@ class InteractiveBrokersClient(
             del prms["self"]
         else:
             prms = fnParams
+
         self._log.debug(f"TWS API prepared request: function={fnName} data={prms}")
