@@ -13,6 +13,8 @@
 #  limitations under the License.
 # -------------------------------------------------------------------------------------------------
 
+from __future__ import annotations
+
 from decimal import Decimal
 from functools import partial
 from typing import TYPE_CHECKING
@@ -59,7 +61,7 @@ class InteractiveBrokersEWrapper(EWrapper):
     def __init__(
         self,
         nautilus_logger: Logger,
-        client: "InteractiveBrokersClient",
+        client: InteractiveBrokersClient,
     ) -> None:
         super().__init__()
         self._log = nautilus_logger
@@ -74,6 +76,7 @@ class InteractiveBrokersEWrapper(EWrapper):
             del prms["self"]
         else:
             prms = fnParams
+
         self._log.debug(f"Msg handled: function={fnName} data={prms}")
 
     def error(
@@ -504,12 +507,13 @@ class InteractiveBrokersEWrapper(EWrapper):
         position : int
             The order book's row being updated.
         marketMaker : str
-            The exchange holding the order.
+            The exchange holding the order if isSmartDepth is True,
+            otherwise the MPID of the market maker.
         operation : int
             How to refresh the row:
             - 0: insert (insert this new order into the row identified by 'position')
             - 1: update (update the existing order in the row identified by 'position')
-            - 2: delete (delete the existing order at the row identified by 'position').
+            - 2: delete (delete the existing order at the row identified by 'position')
         side : int
             0 for ask, 1 for bid.
         price : float
@@ -522,6 +526,19 @@ class InteractiveBrokersEWrapper(EWrapper):
         """
         self.logAnswer(current_fn_name(), vars())
 
+        task = partial(
+            self._client.process_update_mkt_depth_l2,
+            req_id=reqId,
+            position=position,
+            market_maker=marketMaker,
+            operation=operation,
+            side=side,
+            price=price,
+            size=size,
+            is_smart_depth=isSmartDepth,
+        )
+        self._client.submit_to_msg_handler_queue(task)
+
     def updateNewsBulletin(
         self,
         msgId: int,
