@@ -31,7 +31,6 @@ from nautilus_trader.adapters.interactive_brokers.client.common import IBPositio
 from nautilus_trader.adapters.interactive_brokers.common import IB_VENUE
 from nautilus_trader.adapters.interactive_brokers.common import IBOrderTags
 from nautilus_trader.adapters.interactive_brokers.config import InteractiveBrokersExecClientConfig
-from nautilus_trader.adapters.interactive_brokers.config import SymbologyMethod
 from nautilus_trader.adapters.interactive_brokers.parsing.execution import MAP_ORDER_ACTION
 from nautilus_trader.adapters.interactive_brokers.parsing.execution import MAP_ORDER_FIELDS
 from nautilus_trader.adapters.interactive_brokers.parsing.execution import MAP_ORDER_STATUS
@@ -40,6 +39,8 @@ from nautilus_trader.adapters.interactive_brokers.parsing.execution import MAP_T
 from nautilus_trader.adapters.interactive_brokers.parsing.execution import MAP_TRIGGER_METHOD
 from nautilus_trader.adapters.interactive_brokers.parsing.execution import ORDER_SIDE_TO_ORDER_ACTION
 from nautilus_trader.adapters.interactive_brokers.parsing.execution import timestring_to_timestamp
+from nautilus_trader.adapters.interactive_brokers.parsing.price_conversion import ib_price_to_nautilus_price
+from nautilus_trader.adapters.interactive_brokers.parsing.price_conversion import nautilus_price_to_ib_price
 from nautilus_trader.adapters.interactive_brokers.providers import InteractiveBrokersInstrumentProvider
 from nautilus_trader.cache.cache import Cache
 from nautilus_trader.common.component import LiveClock
@@ -169,7 +170,6 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
             "FullInitMarginReq",
             "FullMaintMarginReq",
         }
-
         self._account_summary_loaded: asyncio.Event = asyncio.Event()
 
         # Hot caches
@@ -184,6 +184,9 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
         await self._client.wait_until_ready(self._connection_timeout)
         await self.instrument_provider.initialize()
 
+        # Set instrument provider on client for price magnifier access
+        self._client._instrument_provider = self._instrument_provider
+
         # Validate if connected to expected TWS/Gateway using Account
         if self.account_id.get_id() in self._client.accounts():
             self._log.info(
@@ -213,8 +216,10 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
 
     async def _disconnect(self):
         self._client.registered_nautilus_clients.discard(self.id)
+
         if self._client.is_running and self._client.registered_nautilus_clients == set():
             self._client.stop()
+
         self._set_connected(False)
 
     async def generate_order_status_report(
@@ -223,12 +228,14 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
     ) -> OrderStatusReport | None:
         PyCondition.type_or_none(command.client_order_id, ClientOrderId, "client_order_id")
         PyCondition.type_or_none(command.venue_order_id, VenueOrderId, "venue_order_id")
+
         if not (command.client_order_id or command.venue_order_id):
             self._log.debug("Both `client_order_id` and `venue_order_id` cannot be None")
             return None
 
         report = None
         ib_orders = await self._client.get_open_orders(self.account_id.get_id())
+
         for ib_order in ib_orders:
             if (command.client_order_id and command.client_order_id.value == ib_order.orderRef) or (
                 command.venue_order_id
@@ -239,6 +246,7 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
             ):
                 report = await self._parse_ib_order_to_order_status_report(ib_order)
                 break
+
         if report is None:
             self._log.warning(
                 f"Order {command.client_order_id=}, {command.venue_order_id} not found, canceling",
@@ -248,14 +256,14 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
                 order_status="Cancelled",
                 reason="Not found in query",
             )
+
         return report
 
     async def _parse_ib_order_to_order_status_report(self, ib_order: IBOrder) -> OrderStatusReport:
         self._log.debug(f"Trying OrderStatusReport for {ib_order.__dict__}")
-        instrument = await self.instrument_provider.find_with_contract_id(
+        instrument = await self.instrument_provider.get_instrument(
             ib_order.contract.conId,
         )
-
         total_qty = (
             Quantity.from_int(0)
             if ib_order.totalQuantity == UNSET_DECIMAL
@@ -266,19 +274,26 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
             if ib_order.filledQuantity == UNSET_DECIMAL
             else Quantity.from_str(str(ib_order.filledQuantity))
         )
+
         if total_qty.as_double() > filled_qty.as_double() > 0:
             order_status = OrderStatus.PARTIALLY_FILLED
         else:
             order_status = MAP_ORDER_STATUS[ib_order.order_state.status]
+
         ts_init = self._clock.timestamp_ns()
-        price = (
-            None if ib_order.lmtPrice == UNSET_DOUBLE else instrument.make_price(ib_order.lmtPrice)
-        )
+
+        price_magnifier = self.instrument_provider.get_price_magnifier(instrument.id)
+        price = None
+
+        if ib_order.lmtPrice != UNSET_DOUBLE:
+            converted_price = ib_price_to_nautilus_price(ib_order.lmtPrice, price_magnifier)
+            price = instrument.make_price(converted_price)
+
         expire_time = (
             timestring_to_timestamp(ib_order.goodTillDate) if ib_order.tif == "GTD" else None
         )
-
         mapped_order_type_info = ib_to_nautilus_order_type[ib_order.orderType]
+
         if isinstance(mapped_order_type_info, tuple):
             order_type, time_in_force = mapped_order_type_info
         else:
@@ -305,12 +320,19 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
             # contingency_type=,
             expire_time=expire_time,
             price=price,
-            trigger_price=instrument.make_price(ib_order.auxPrice),
+            trigger_price=(
+                instrument.make_price(
+                    ib_price_to_nautilus_price(ib_order.auxPrice, price_magnifier),
+                )
+                if ib_order.auxPrice != UNSET_DOUBLE
+                else None
+            ),
             trigger_type=TriggerType.BID_ASK,
             # limit_offset=,
             # trailing_offset=,
         )
         self._log.debug(f"Received {order_status!r}")
+
         return order_status
 
     async def generate_order_status_reports(
@@ -318,17 +340,22 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
         command: GenerateOrderStatusReports,
     ) -> list[OrderStatusReport]:
         report = []
+
         # Create the Filled OrderStatusReport from Open Positions
         positions: list[IBPosition] = await self._client.get_positions(
             self.account_id.get_id(),
         )
+
         if not positions:
             return []
+
         ts_init = self._clock.timestamp_ns()
+
         for position in positions:
             self._log.debug(
                 f"Infer OrderStatusReport from open position {position.contract.__dict__}",
             )
+
             if position.quantity > 0:
                 order_side = OrderSide.BUY
             elif position.quantity < 0:
@@ -336,17 +363,20 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
             else:
                 continue  # Skip, IB may continue to display closed positions
 
-            instrument = await self.instrument_provider.find_with_contract_id(
+            instrument = await self.instrument_provider.get_instrument(
                 position.contract.conId,
             )
+
             if instrument is None:
                 self._log.error(
                     f"Cannot generate report: instrument not found for contract ID {position.contract.conId}",
                 )
                 continue
 
+            contract_details = self.instrument_provider.contract_details[instrument.id]
             avg_px = instrument.make_price(
-                position.avg_cost / instrument.multiplier,
+                position.avg_cost
+                / (instrument.multiplier.as_double() * contract_details.priceMagnifier),
             ).as_decimal()
             quantity = Quantity.from_str(str(position.quantity.copy_abs()))
             order_status = OrderStatusReport(
@@ -373,9 +403,11 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
         ib_orders: list[IBOrder] = await self._client.get_open_orders(
             self.account_id.get_id(),
         )
+
         for ib_order in ib_orders:
             order_status = await self._parse_ib_order_to_order_status_report(ib_order)
             report.append(order_status)
+
         return report
 
     async def generate_fill_reports(
@@ -383,6 +415,7 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
         command: GenerateFillReports,
     ) -> list[FillReport]:
         self._log.warning("Cannot generate `list[FillReport]`: not yet implemented")
+
         return []  # TODO: Implement
 
     async def generate_position_status_reports(
@@ -393,10 +426,13 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
         positions: list[IBPosition] | None = await self._client.get_positions(
             self.account_id.get_id(),
         )
+
         if not positions:
             return []
+
         for position in positions:
             self._log.debug(f"Trying PositionStatusReport for {position.contract.conId}")
+
             if position.quantity > 0:
                 side = PositionSide.LONG
             elif position.quantity < 0:
@@ -404,19 +440,17 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
             else:
                 continue  # Skip, IB may continue to display closed positions
 
-            instrument = await self.instrument_provider.find_with_contract_id(
+            instrument = await self.instrument_provider.get_instrument(
                 position.contract.conId,
             )
+
             if instrument is None:
                 self._log.error(
                     f"Cannot generate report: instrument not found for contract ID {position.contract.conId}",
                 )
                 continue
 
-            if (
-                self.instrument_provider.config.symbology_method != SymbologyMethod.DATABENTO
-                and not self._cache.instrument(instrument.id)
-            ):
+            if not self._cache.instrument(instrument.id):
                 self._handle_data(instrument)
 
             position_status = PositionStatusReport(
@@ -439,10 +473,15 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
 
         ib_order = IBOrder()
         time_in_force = order.time_in_force
+        price_magnifier = self.instrument_provider.get_price_magnifier(order.instrument_id)
+
         for key, field, fn in MAP_ORDER_FIELDS:
             if value := getattr(order, key, None):
                 if key == "order_type" and time_in_force == TimeInForce.AT_THE_CLOSE:
                     setattr(ib_order, field, fn((value, time_in_force)))
+                elif key == "price" and value is not None:
+                    converted_price = nautilus_price_to_ib_price(value.as_double(), price_magnifier)
+                    setattr(ib_order, field, converted_price)
                 else:
                     setattr(ib_order, field, fn(value))
 
@@ -457,8 +496,13 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
                 )
 
             ib_order.auxPrice = float(order.trailing_offset)
+
             if order.trigger_price:
-                ib_order.trailStopPrice = order.trigger_price.as_double()
+                converted_trigger_price = nautilus_price_to_ib_price(
+                    order.trigger_price.as_double(),
+                    price_magnifier,
+                )
+                ib_order.trailStopPrice = converted_trigger_price
                 ib_order.triggerMethod = MAP_TRIGGER_METHOD[order.trigger_type]
         elif (
             isinstance(
@@ -466,9 +510,13 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
                 MarketIfTouchedOrder | LimitIfTouchedOrder | StopLimitOrder | StopMarketOrder,
             )
         ) and order.trigger_price:
-            ib_order.auxPrice = order.trigger_price.as_double()
+            converted_aux_price = nautilus_price_to_ib_price(
+                order.trigger_price.as_double(),
+                price_magnifier,
+            )
+            ib_order.auxPrice = converted_aux_price
 
-        details = self.instrument_provider.contract_details[order.instrument_id.value]
+        details = self.instrument_provider.contract_details[order.instrument_id]
         ib_order.contract = details.contract
         ib_order.account = self.account_id.get_id()
         ib_order.clearingAccount = self.account_id.get_id()
@@ -480,6 +528,7 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
 
     def _attach_order_tags(self, ib_order: IBOrder, order: Order) -> IBOrder:
         tags: dict = {}
+
         for ot in order.tags:
             if ot.startswith("IBOrderTags:"):
                 tags = IBOrderTags.parse(ot.replace("IBOrderTags:", "")).dict()
@@ -496,6 +545,7 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
 
     async def _submit_order(self, command: SubmitOrder) -> None:
         PyCondition.type(command, SubmitOrder, "command")
+
         try:
             ib_order: IBOrder = self._transform_order_to_ib_order(command.order)
             ib_order.orderId = self._client.next_order_id()
@@ -541,6 +591,7 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
                             reason=f"The order has been rejected due to the rejection of the order with "
                             f"{order.client_order_id!r} in the list",
                         )
+
                 return
 
         # Mark last order to transmit
@@ -550,6 +601,7 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
             # Map the Parent Order Ids
             if parent_id := order_id_map.get(ib_order.parentId):
                 ib_order.parentId = parent_id
+
             # Place orders
             order_ref = ib_order.orderRef
             self._client.place_order(ib_order)
@@ -565,6 +617,7 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
 
         nautilus_order: Order = self._cache.order(command.client_order_id)
         self._log.info(f"Nautilus order status is {nautilus_order.status_string()}")
+
         try:
             ib_order: IBOrder = self._transform_order_to_ib_order(nautilus_order)
         except ValueError as e:
@@ -576,22 +629,35 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
             return
 
         ib_order.orderId = int(command.venue_order_id.value)
+
         if ib_order.parentId:
             parent_nautilus_order = self._cache.order(ClientOrderId(ib_order.parentId))
+
             if parent_nautilus_order:
                 ib_order.parentId = int(parent_nautilus_order.venue_order_id.value)
             else:
                 ib_order.parentId = 0
+
         if command.quantity and command.quantity != ib_order.totalQuantity:
             ib_order.totalQuantity = command.quantity.as_double()
+
+        price_magnifier = self.instrument_provider.get_price_magnifier(command.instrument_id)
+
         if command.price and command.price.as_double() != getattr(ib_order, "lmtPrice", None):
-            ib_order.lmtPrice = command.price.as_double()
+            converted_price = nautilus_price_to_ib_price(command.price.as_double(), price_magnifier)
+            ib_order.lmtPrice = converted_price
+
         if command.trigger_price and command.trigger_price.as_double() != getattr(
             ib_order,
             "auxPrice",
             None,
         ):
-            ib_order.auxPrice = command.trigger_price.as_double()
+            converted_trigger_price = nautilus_price_to_ib_price(
+                command.trigger_price.as_double(),
+                price_magnifier,
+            )
+            ib_order.auxPrice = converted_trigger_price
+
         self._log.info(f"Placing {ib_order!r}")
         self._client.place_order(ib_order)
 
@@ -599,6 +665,7 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
         PyCondition.not_none(command, "command")
 
         venue_order_id = command.venue_order_id
+
         if venue_order_id:
             self._client.cancel_order(int(venue_order_id.value))
         else:
@@ -609,6 +676,7 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
             instrument_id=command.instrument_id,
         ):
             venue_order_id = order.venue_order_id
+
             if venue_order_id:
                 self._client.cancel_order(int(venue_order_id.value))
             else:
@@ -629,20 +697,22 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
         for currency in self._account_summary:
             if not currency:
                 continue
+
             if self._account_summary_tags - set(self._account_summary[currency].keys()) == set():
                 self._log.info(f"{self._account_summary}", LogColor.GREEN)
                 # free = self._account_summary[currency]["FullAvailableFunds"]
                 locked = self._account_summary[currency]["FullMaintMarginReq"]
                 total = self._account_summary[currency]["NetLiquidation"]
+
                 if total - locked < locked:
                     total = 400000  # TODO: Bug; Cannot recalculate balance when no current balance
+
                 free = total - locked
                 account_balance = AccountBalance(
                     total=Money(total, Currency.from_str(currency)),
                     free=Money(free, Currency.from_str(currency)),
                     locked=Money(locked, Currency.from_str(currency)),
                 )
-
                 margin_balance = MarginBalance(
                     initial=Money(
                         self._account_summary[currency]["FullInitMarginReq"],
@@ -653,7 +723,6 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
                         currency=Currency.from_str(currency),
                     ),
                 )
-
                 self.generate_account_state(
                     balances=[account_balance],
                     margins=[margin_balance],
@@ -735,6 +804,7 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
                 f"ClientOrderId not available, order={order.__dict__}, state={order_state.__dict__}",
             )
             return
+
         if not (nautilus_order := self._cache.order(ClientOrderId(order_ref))):
             self.create_task(self.handle_order_status_report(order))
             return
@@ -759,12 +829,30 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
                 if order.totalQuantity == UNSET_DECIMAL
                 else Quantity.from_str(str(order.totalQuantity))
             )
-            price = (
-                None if order.lmtPrice == UNSET_DOUBLE else instrument.make_price(order.lmtPrice)
-            )
-            trigger_price = (
-                None if order.auxPrice == UNSET_DOUBLE else instrument.make_price(order.auxPrice)
+
+            if total_qty <= 0.0:
+                # This can be caused by a partially filled entry bracket order and SL triggered.
+                self._log.warning(f"IB order with totalQuantity <= 0, skipping: {order.__dict__}")
+                return
+
+            price_magnifier = self.instrument_provider.get_price_magnifier(
+                nautilus_order.instrument_id,
             )
+            price = None
+
+            if order.lmtPrice != UNSET_DOUBLE:
+                converted_price = ib_price_to_nautilus_price(order.lmtPrice, price_magnifier)
+                price = instrument.make_price(converted_price)
+
+            trigger_price = None
+
+            if order.auxPrice != UNSET_DOUBLE:
+                converted_trigger_price = ib_price_to_nautilus_price(
+                    order.auxPrice,
+                    price_magnifier,
+                )
+                trigger_price = instrument.make_price(converted_trigger_price)
+
             venue_order_id_modified = bool(
                 nautilus_order.venue_order_id is None
                 or nautilus_order.venue_order_id != VenueOrderId(str(order.orderId)),
@@ -814,6 +902,7 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
             return
 
         nautilus_order = self._cache.order(ClientOrderId(order_ref))
+
         if nautilus_order:
             self._handle_order_event(
                 status=status,
@@ -839,6 +928,11 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
         instrument = self.instrument_provider.find(nautilus_order.instrument_id)
 
         if instrument:
+            price_magnifier = self.instrument_provider.get_price_magnifier(
+                nautilus_order.instrument_id,
+            )
+            converted_execution_price = ib_price_to_nautilus_price(execution.price, price_magnifier)
+
             self.generate_order_filled(
                 strategy_id=nautilus_order.strategy_id,
                 instrument_id=nautilus_order.instrument_id,
@@ -849,7 +943,7 @@ class InteractiveBrokersExecutionClient(LiveExecutionClient):
                 order_side=OrderSide[ORDER_SIDE_TO_ORDER_ACTION[execution.side]],
                 order_type=nautilus_order.order_type,
                 last_qty=Quantity(execution.shares, precision=instrument.size_precision),
-                last_px=Price(execution.price, precision=instrument.price_precision),
+                last_px=Price(converted_execution_price, precision=instrument.price_precision),
                 quote_currency=instrument.quote_currency,
                 commission=Money(
                     commission_report.commission,
