@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------------------------------
-#  Copyright (C) 2015-2024 Nautech Systems Pty Ltd. All rights reserved.
+#  Copyright (C) 2015-2025 Nautech Systems Pty Ltd. All rights reserved.
 #  https://nautechsystems.io
 #
 #  Licensed under the GNU Lesser General Public License Version 3.0 (the "License");
@@ -15,10 +15,8 @@
 
 import asyncio
 from functools import partial
-from typing import Any
 
 import msgspec
-import pandas as pd
 
 from nautilus_trader.adapters.okx.common.constants import OKX_VENUE
 from nautilus_trader.adapters.okx.common.credentials import get_api_key
@@ -46,18 +44,29 @@ from nautilus_trader.common.component import LiveClock
 from nautilus_trader.common.component import MessageBus
 from nautilus_trader.common.enums import LogColor
 from nautilus_trader.core.correctness import PyCondition
-from nautilus_trader.core.uuid import UUID4
+from nautilus_trader.data.messages import RequestBars
+from nautilus_trader.data.messages import RequestData
+from nautilus_trader.data.messages import RequestInstrument
+from nautilus_trader.data.messages import RequestInstruments
+from nautilus_trader.data.messages import RequestQuoteTicks
+from nautilus_trader.data.messages import RequestTradeTicks
+from nautilus_trader.data.messages import SubscribeBars
+from nautilus_trader.data.messages import SubscribeOrderBook
+from nautilus_trader.data.messages import SubscribeQuoteTicks
+from nautilus_trader.data.messages import SubscribeTradeTicks
+from nautilus_trader.data.messages import UnsubscribeBars
+from nautilus_trader.data.messages import UnsubscribeOrderBook
+from nautilus_trader.data.messages import UnsubscribeQuoteTicks
+from nautilus_trader.data.messages import UnsubscribeTradeTicks
 from nautilus_trader.live.data_client import LiveMarketDataClient
 from nautilus_trader.model.data import Bar
 from nautilus_trader.model.data import BarType
-from nautilus_trader.model.data import DataType
 from nautilus_trader.model.data import OrderBookDeltas
 from nautilus_trader.model.data import QuoteTick
 from nautilus_trader.model.data import TradeTick
 from nautilus_trader.model.enums import BookType
 from nautilus_trader.model.identifiers import ClientId
 from nautilus_trader.model.identifiers import InstrumentId
-from nautilus_trader.model.identifiers import Venue
 from nautilus_trader.model.instruments import Instrument
 
 
@@ -226,7 +235,7 @@ class OKXDataClient(LiveMarketDataClient):
                 await self._instrument_provider.initialize(reload=True)
                 self._send_all_instruments_to_data_engine()
         except asyncio.CancelledError:
-            self._log.debug("Canceled 'update_instruments' task")
+            self._log.debug("Canceled task 'update_instruments'")
 
     async def _get_ws_client(
         self,
@@ -240,272 +249,216 @@ class OKXDataClient(LiveMarketDataClient):
 
     # -- SUBSCRIPTIONS ----------------------------------------------------------------------------
 
-    async def _subscribe_order_book_deltas(
-        self,
-        instrument_id: InstrumentId,
-        book_type: BookType,
-        depth: int | None = None,
-        params: dict[str, Any] | None = None,
-    ) -> None:
-        if book_type == BookType.L3_MBO:
+    async def _subscribe_order_book_deltas(self, command: SubscribeOrderBook) -> None:
+        if command.book_type == BookType.L3_MBO:
             self._log.error(
                 "Cannot subscribe to order book snapshot/deltas: OKX adapter currently only "
                 "supports L1_MBP and L2_MBP book subscriptions.",
             )
             return
 
-        if depth == 1 and book_type != BookType.L1_MBP:
+        if command.depth == 1 and command.book_type != BookType.L1_MBP:
             self._log.error(
                 "Inconsistent argument for `book_type` provided for order book subscription with "
-                f"`depth` argument of 1. `book_type` should be {BookType.L1_MBP}, was {book_type}",
+                f"`depth` argument of 1. `book_type` should be {BookType.L1_MBP}, was {command.book_type}",
             )
             return
 
-        if depth == 1 or book_type == BookType.L1_MBP:
-            await self._subscribe_quote_ticks(instrument_id)
+        if command.depth == 1 or command.book_type == BookType.L1_MBP:
+            quote_ticks_subscription = SubscribeQuoteTicks(
+                command_id=command.id,
+                instrument_id=command.instrument_id,
+                client_id=command.client_id,
+                venue=command.venue,
+                ts_init=command.ts_init,
+                params=command.params,
+            )
+            await self._subscribe_quote_ticks(quote_ticks_subscription)
             return
 
-        if depth is None:
+        if command.depth is None:
             self._log.warning(
                 "Depth not prescribed for order book snapshots/deltas subscription for "
-                f"{instrument_id}. Using default depth of 50.",
+                f"{command.instrument_id}. Using default depth of 50.",
             )
             depth = 50
 
-        if instrument_id in self._depth_client_map:
-            _depth, _ws_client = self._depth_client_map[instrument_id]
+        if command.instrument_id in self._depth_client_map:
+            _depth, _ws_client = self._depth_client_map[command.instrument_id]
             if _depth == depth:
                 self._log.warning(
-                    f"Already subscribed to {instrument_id} order books of depth {depth}",
+                    f"Already subscribed to {command.instrument_id} order books of depth {depth}",
                 )
                 return
             else:
                 self._log.warning(
-                    f"Already subscribed to {instrument_id} order books of depth {_depth} but "
+                    f"Already subscribed to {command.instrument_id} order books of depth {_depth} but "
                     f"requested subscription for depth {depth}. Replacing subscription of "
                     f"depth {_depth} with depth {depth}.",
                 )
-                await self._unsubscribe_order_book_deltas(instrument_id)
+                order_book_unsubscription = UnsubscribeOrderBook(
+                    command_id=command.id,
+                    instrument_id=command.instrument_id,
+                    client_id=command.client_id,
+                    venue=command.venue,
+                    ts_init=command.ts_init,
+                    params=command.params,
+                )
+                await self._unsubscribe_order_book_deltas(order_book_unsubscription)
 
         ws_client = await self._get_ws_client(OKXWsBaseUrlType.PUBLIC, tbt_books=True)
 
         # Cache the instrument/depth/client combo for unsubscribing
-        self._depth_client_map[instrument_id] = (depth, ws_client)
+        self._depth_client_map[command.instrument_id] = (depth, ws_client)
 
-        okx_symbol = OKXSymbol(instrument_id.symbol.value)
+        okx_symbol = OKXSymbol(command.instrument_id.symbol.value)
         await ws_client.subscribe_order_book(okx_symbol.raw_symbol, depth)  # type:ignore
 
         # Start book buffer for instrument in case we receive updates before snapshots
-        self._book_buffer[instrument_id] = []
+        self._book_buffer[command.instrument_id] = []
 
     # Copy subscribe method for book deltas to book snapshots (same logic)
     _subscribe_order_book_snapshots = _subscribe_order_book_deltas
 
-    async def _subscribe_quote_ticks(
-        self,
-        instrument_id: InstrumentId,
-        params: dict[str, Any] | None = None,
-    ) -> None:
-        if instrument_id in self._tob_client_map:
+    async def _subscribe_quote_ticks(self, command: SubscribeQuoteTicks) -> None:
+        if command.instrument_id in self._tob_client_map:
             self._log.warning(
-                f"Already subscribed to {instrument_id} top-of-book (quotes)",
+                f"Already subscribed to {command.instrument_id} top-of-book (quotes)",
                 LogColor.MAGENTA,
             )
             return
 
-        okx_symbol = OKXSymbol(instrument_id.symbol.value)
+        okx_symbol = OKXSymbol(command.instrument_id.symbol.value)
         ws_client = await self._get_ws_client(OKXWsBaseUrlType.PUBLIC, tbt_books=True)
         self._log.debug(
-            f"Subscribing quotes {instrument_id} via order book deltas",
+            f"Subscribing quotes {command.instrument_id} via order book deltas",
             LogColor.MAGENTA,
         )
         # Cache the instrument/depth/client combos for unsubscribing
-        self._tob_client_map[instrument_id] = ws_client
+        self._tob_client_map[command.instrument_id] = ws_client
         await ws_client.subscribe_order_book(okx_symbol.raw_symbol, 1)
 
-    async def _subscribe_trade_ticks(
-        self,
-        instrument_id: InstrumentId,
-        params: dict[str, Any] | None = None,
-    ) -> None:
-        if instrument_id in self._trades_client_map:
+    async def _subscribe_trade_ticks(self, command: SubscribeTradeTicks) -> None:
+        if command.instrument_id in self._trades_client_map:
             self._log.warning(
-                f"Already subscribed to {instrument_id} trades",
+                f"Already subscribed to {command.instrument_id} trades",
                 LogColor.MAGENTA,
             )
             return
         ws_client = await self._get_ws_client(OKXWsBaseUrlType.PUBLIC, tbt_books=False)
-        okx_symbol = OKXSymbol(instrument_id.symbol.value)
-        self._trades_client_map[instrument_id] = ws_client
+        okx_symbol = OKXSymbol(command.instrument_id.symbol.value)
+        self._trades_client_map[command.instrument_id] = ws_client
         await ws_client.subscribe_trades(okx_symbol.raw_symbol)
 
-    async def _subscribe_bars(
-        self,
-        bar_type: BarType,
-        params: dict[str, Any] | None = None,
-    ) -> None:
+    async def _subscribe_bars(self, command: SubscribeBars) -> None:
         PyCondition.is_true(
-            bar_type.is_externally_aggregated(),
+            command.bar_type.is_externally_aggregated(),
             "aggregation_source is not EXTERNAL",
         )
         self._log.error("OKX bar subscriptions are not yet implemented")
 
-    async def _unsubscribe_order_book_deltas(
-        self,
-        instrument_id: InstrumentId,
-        params: dict[str, Any] | None = None,
-    ) -> None:
+    async def _unsubscribe_order_book_deltas(self, command: UnsubscribeOrderBook) -> None:
         self._log.debug(
-            f"Unsubscribing {instrument_id} from order book deltas/snapshots",
+            f"Unsubscribing {command.instrument_id} from order book deltas/snapshots",
             LogColor.MAGENTA,
         )
-        okx_symbol = OKXSymbol(instrument_id.symbol.value)
+        okx_symbol = OKXSymbol(command.instrument_id.symbol.value)
 
         for iid, (depth, ws_client) in self._depth_client_map.items():
-            if iid == instrument_id:
+            if iid == command.instrument_id:
                 await ws_client.unsubscribe_order_book(okx_symbol.raw_symbol, depth)  # type:ignore
                 break
-        self._depth_client_map.pop(instrument_id, None)
+        self._depth_client_map.pop(command.instrument_id, None)
 
     # Copy unsubscribe method for book deltas to book snapshots (same logic)
     _unsubscribe_order_book_snapshots = _unsubscribe_order_book_deltas
 
-    async def _unsubscribe_quote_ticks(
-        self,
-        instrument_id: InstrumentId,
-        params: dict[str, Any] | None = None,
-    ) -> None:
+    async def _unsubscribe_quote_ticks(self, command: UnsubscribeQuoteTicks) -> None:
         self._log.debug(
-            f"Unsubscribing {instrument_id} from quotes (top-of-book)",
+            f"Unsubscribing {command.instrument_id} from quotes (top-of-book)",
             LogColor.MAGENTA,
         )
-        okx_symbol = OKXSymbol(instrument_id.symbol.value)
+        okx_symbol = OKXSymbol(command.instrument_id.symbol.value)
 
         for iid, ws_client in self._tob_client_map.items():
-            if iid == instrument_id:
+            if iid == command.instrument_id:
                 await ws_client.unsubscribe_order_book(okx_symbol.raw_symbol, 1)
                 break
-        self._tob_client_map.pop(instrument_id, None)
+        self._tob_client_map.pop(command.instrument_id, None)
 
-    async def _unsubscribe_trade_ticks(
-        self,
-        instrument_id: InstrumentId,
-        params: dict[str, Any] | None = None,
-    ) -> None:
-        self._log.debug(f"Unsubscribing {instrument_id} from trades", LogColor.MAGENTA)
-        okx_symbol = OKXSymbol(instrument_id.symbol.value)
+    async def _unsubscribe_trade_ticks(self, command: UnsubscribeTradeTicks) -> None:
+        self._log.debug(f"Unsubscribing {command.instrument_id} from trades", LogColor.MAGENTA)
+        okx_symbol = OKXSymbol(command.instrument_id.symbol.value)
 
         for iid, ws_client in self._trades_client_map.items():
-            if iid == instrument_id:
+            if iid == command.instrument_id:
                 await ws_client.unsubscribe_trades(okx_symbol.raw_symbol)
                 break
-        self._tob_client_map.pop(instrument_id, None)
+        self._tob_client_map.pop(command.instrument_id, None)
 
-    async def _unsubscribe_bars(
-        self,
-        bar_type: BarType,
-        params: dict[str, Any] | None = None,
-    ) -> None:
+    async def _unsubscribe_bars(self, command: UnsubscribeBars) -> None:
         self._log.error("OKX bar subscriptions are not yet implemented")
         return
 
     # -- REQUESTS ---------------------------------------------------------------------------------
 
-    async def _request(
-        self,
-        data_type: DataType,
-        correlation_id: UUID4,
-        params: dict[str, Any] | None = None,
-    ) -> None:
+    async def _request(self, request: RequestData) -> None:
         pass
 
-    async def _request_instrument(
-        self,
-        instrument_id: InstrumentId,
-        correlation_id: UUID4,
-        start: pd.Timestamp | None = None,
-        end: pd.Timestamp | None = None,
-        params: dict[str, Any] | None = None,
-    ) -> None:
-        if start is not None:
+    async def _request_instrument(self, request: RequestInstrument) -> None:
+        if request.start is not None:
             self._log.warning(
-                f"Requesting instrument {instrument_id} with specified `start` which has no effect",
+                f"Requesting instrument {request.instrument_id} with specified `start` which has no effect",
             )
 
-        if end is not None:
+        if request.end is not None:
             self._log.warning(
-                f"Requesting instrument {instrument_id} with specified `end` which has no effect",
+                f"Requesting instrument {request.instrument_id} with specified `end` which has no effect",
             )
 
-        instrument: Instrument | None = self._instrument_provider.find(instrument_id)
+        instrument: Instrument | None = self._instrument_provider.find(request.instrument_id)
         if instrument is None:
-            self._log.error(f"Cannot find instrument for {instrument_id}")
+            self._log.error(f"Cannot find instrument for {request.instrument_id}")
             return
 
-        self._handle_instrument(instrument, correlation_id, params)
+        self._handle_instrument(instrument, request.id, request.params)
 
-    async def _request_instruments(
-        self,
-        venue: Venue,
-        correlation_id: UUID4,
-        start: pd.Timestamp | None = None,
-        end: pd.Timestamp | None = None,
-        params: dict[str, Any] | None = None,
-    ) -> None:
-        if start is not None:
+    async def _request_instruments(self, request: RequestInstruments) -> None:
+        if request.start is not None:
             self._log.warning(
-                f"Requesting instruments for {venue} with specified `start` which has no effect",
+                f"Requesting instruments for {request.venue} with specified `start` which has no effect",
             )
 
-        if end is not None:
+        if request.end is not None:
             self._log.warning(
-                f"Requesting instruments for {venue} with specified `end` which has no effect",
+                f"Requesting instruments for {request.venue} with specified `end` which has no effect",
             )
 
         all_instruments = self._instrument_provider.get_all()
         target_instruments = []
         for instrument in all_instruments.values():
-            if instrument.venue == venue:
+            if instrument.venue == request.venue:
                 target_instruments.append(instrument)
 
-        self._handle_instruments(target_instruments, venue, correlation_id, params)
+        self._handle_instruments(
+            target_instruments,
+            request.venue,
+            request.id,
+            request.params,
+        )
 
-    async def _request_quote_ticks(
-        self,
-        instrument_id: InstrumentId,
-        limit: int,
-        correlation_id: UUID4,
-        start: pd.Timestamp | None = None,
-        end: pd.Timestamp | None = None,
-        params: dict[str, Any] | None = None,
-    ) -> None:
+    async def _request_quote_ticks(self, request: RequestQuoteTicks) -> None:
         self._log.error(
             "Cannot request historical quotes: not published by OKX. Subscribe to "
             "quotes or L1_MBP order book.",
         )
         return
 
-    async def _request_trade_ticks(
-        self,
-        instrument_id: InstrumentId,
-        limit: int,
-        correlation_id: UUID4,
-        start: pd.Timestamp | None = None,
-        end: pd.Timestamp | None = None,
-        params: dict[str, Any] | None = None,
-    ) -> None:
+    async def _request_trade_ticks(self, request: RequestTradeTicks) -> None:
         self._log.error("Cannot request historical trades: not yet implemented for OKX")
         return
 
-    async def _request_bars(
-        self,
-        bar_type: BarType,
-        limit: int,
-        correlation_id: UUID4,
-        start: pd.Timestamp | None = None,
-        end: pd.Timestamp | None = None,
-        params: dict[str, Any] | None = None,
-    ) -> None:
+    async def _request_bars(self, request: RequestBars) -> None:
         self._log.error("Cannot request historical bars: not yet implemented for OKX")
         return
 
