@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------------------------------
-#  Copyright (C) 2015-2024 Nautech Systems Pty Ltd. All rights reserved.
+#  Copyright (C) 2015-2025 Nautech Systems Pty Ltd. All rights reserved.
 #  https://nautechsystems.io
 #
 #  Licensed under the GNU Lesser General Public License Version 3.0 (the "License");
@@ -17,27 +17,27 @@ from os import PathLike
 from pathlib import Path
 
 from nautilus_trader.core import nautilus_pyo3
-from nautilus_trader.core.nautilus_pyo3 import drop_cvec_pycapsule
 from nautilus_trader.model.data import OrderBookDelta
 from nautilus_trader.model.data import OrderBookDepth10
 from nautilus_trader.model.data import QuoteTick
 from nautilus_trader.model.data import TradeTick
-from nautilus_trader.model.data import capsule_to_list
 from nautilus_trader.model.identifiers import InstrumentId
 
 
 class TardisCSVDataLoader:
     """
-    Provides a means of loading data from CSV files in Tardis format.
+    Loads CSV data in the Tardis format with optional GZip decompression.
+
+    This loader automatically decompresses CSV files with a ".gz" extension before parsing the data.
 
     Parameters
     ----------
-    price_precision : int
+    price_precision : int, optional
         The price precision for parsing.
-        Necessary as implicit precision in the text data may not be consistent.
-    size_precision : int
+        If not provided, the precision will be inferred from the data.
+    size_precision : int, optional
         The size precision for parsing.
-        Necessary as implicit precision in the text data may not be consistent.
+        If not provided, the precision will be inferred from the data.
     instrument_id : InstrumentId, optional
         The instrument ID to override in the data.
         This can be more efficient if the instrument is definitely know (file does not contain
@@ -47,8 +47,8 @@ class TardisCSVDataLoader:
 
     def __init__(
         self,
-        price_precision: int,
-        size_precision: int,
+        price_precision: int | None = None,
+        size_precision: int | None = None,
         instrument_id: InstrumentId | None = None,
     ) -> None:
         self._price_precision = price_precision
@@ -91,20 +91,7 @@ class TardisCSVDataLoader:
         if isinstance(filepath, Path):
             filepath = str(filepath.resolve())
 
-        if as_legacy_cython:
-            capsule = nautilus_pyo3.load_tardis_deltas_as_pycapsule(
-                filepath=str(filepath),
-                price_precision=self._price_precision,
-                size_precision=self._size_precision,
-                instrument_id=self._instrument_id,
-                limit=limit,
-            )
-            data = capsule_to_list(capsule)
-            # Drop encapsulated `CVec` as data is now transferred
-            drop_cvec_pycapsule(capsule)
-            return data
-
-        return nautilus_pyo3.load_tardis_deltas(
+        pyo3_deltas = nautilus_pyo3.load_tardis_deltas(
             filepath=str(filepath),
             price_precision=self._price_precision,
             size_precision=self._size_precision,
@@ -112,6 +99,11 @@ class TardisCSVDataLoader:
             limit=limit,
         )
 
+        if as_legacy_cython:
+            return OrderBookDelta.from_pyo3_list(pyo3_deltas)
+
+        return pyo3_deltas
+
     def load_depth10(
         self,
         filepath: PathLike[str] | str,
@@ -160,47 +152,31 @@ class TardisCSVDataLoader:
 
         match levels:
             case 5:
-                if as_legacy_cython:
-                    capsule = nautilus_pyo3.load_tardis_depth10_from_snapshot5_as_pycapsule(
-                        filepath=str(filepath),
-                        price_precision=self._price_precision,
-                        size_precision=self._size_precision,
-                        instrument_id=self._instrument_id,
-                        limit=limit,
-                    )
-                    data = capsule_to_list(capsule)
-                    # Drop encapsulated `CVec` as data is now transferred
-                    drop_cvec_pycapsule(capsule)
-                    return data
-
-                return nautilus_pyo3.load_tardis_depth10_from_snapshot5(
+                pyo3_depths = nautilus_pyo3.load_tardis_depth10_from_snapshot5(
                     filepath=str(filepath),
                     price_precision=self._price_precision,
                     size_precision=self._size_precision,
                     instrument_id=self._instrument_id,
                     limit=limit,
                 )
+
+                if as_legacy_cython:
+                    return OrderBookDepth10.from_pyo3_list(pyo3_depths)
+
+                return pyo3_depths
             case 25:
-                if as_legacy_cython:
-                    capsule = nautilus_pyo3.load_tardis_depth10_from_snapshot25_as_pycapsule(
-                        filepath=str(filepath),
-                        price_precision=self._price_precision,
-                        size_precision=self._size_precision,
-                        instrument_id=self._instrument_id,
-                        limit=limit,
-                    )
-                    data = capsule_to_list(capsule)
-                    # Drop encapsulated `CVec` as data is now transferred
-                    drop_cvec_pycapsule(capsule)
-                    return data
-
-                return nautilus_pyo3.load_tardis_depth10_from_snapshot25(
+                pyo3_depths = nautilus_pyo3.load_tardis_depth10_from_snapshot25(
                     filepath=str(filepath),
                     price_precision=self._price_precision,
                     size_precision=self._size_precision,
                     instrument_id=self._instrument_id,
                     limit=limit,
                 )
+
+                if as_legacy_cython:
+                    return OrderBookDepth10.from_pyo3_list(pyo3_depths)
+
+                return pyo3_depths
             case _:
                 raise ValueError(
                     "invalid `levels`, use either 5 or 25 corresponding to number of levels in the CSV data",
@@ -240,20 +216,7 @@ class TardisCSVDataLoader:
         if isinstance(filepath, Path):
             filepath = str(filepath.resolve())
 
-        if as_legacy_cython:
-            capsule = nautilus_pyo3.load_tardis_quotes_as_pycapsule(
-                filepath=str(filepath),
-                price_precision=self._price_precision,
-                size_precision=self._size_precision,
-                instrument_id=self._instrument_id,
-                limit=limit,
-            )
-            data = capsule_to_list(capsule)
-            # Drop encapsulated `CVec` as data is now transferred
-            drop_cvec_pycapsule(capsule)
-            return data
-
-        return nautilus_pyo3.load_tardis_quotes(
+        pyo3_quotes = nautilus_pyo3.load_tardis_quotes(
             filepath=str(filepath),
             price_precision=self._price_precision,
             size_precision=self._size_precision,
@@ -261,6 +224,11 @@ class TardisCSVDataLoader:
             limit=limit,
         )
 
+        if as_legacy_cython:
+            return QuoteTick.from_pyo3_list(pyo3_quotes)
+
+        return pyo3_quotes
+
     def load_trades(
         self,
         filepath: PathLike[str] | str,
@@ -295,23 +263,15 @@ class TardisCSVDataLoader:
         if isinstance(filepath, Path):
             filepath = str(filepath.resolve())
 
-        if as_legacy_cython:
-            capsule = nautilus_pyo3.load_tardis_trades_as_pycapsule(
-                filepath=str(filepath),
-                price_precision=self._price_precision,
-                size_precision=self._size_precision,
-                instrument_id=self._instrument_id,
-                limit=limit,
-            )
-            data = capsule_to_list(capsule)
-            # Drop encapsulated `CVec` as data is now transferred
-            drop_cvec_pycapsule(capsule)
-            return data
-
-        return nautilus_pyo3.load_tardis_trades(
+        pyo3_trades = nautilus_pyo3.load_tardis_trades(
             filepath=str(filepath),
             price_precision=self._price_precision,
             size_precision=self._size_precision,
             instrument_id=self._instrument_id,
             limit=limit,
         )
+
+        if as_legacy_cython:
+            return TradeTick.from_pyo3_list(pyo3_trades)
+
+        return pyo3_trades
