@@ -25,10 +25,15 @@ from nautilus_trader.common import Environment
 from nautilus_trader.common.config import ActorConfig
 from nautilus_trader.common.config import ImportableActorConfig
 from nautilus_trader.common.config import NautilusConfig
+from nautilus_trader.common.config import NonNegativeInt
+from nautilus_trader.common.config import msgspec_encoding_hook
+from nautilus_trader.common.config import resolve_config_path
 from nautilus_trader.common.config import resolve_path
+from nautilus_trader.core.correctness import PyCondition
 from nautilus_trader.core.datetime import dt_to_unix_nanos
 from nautilus_trader.data.config import DataEngineConfig
 from nautilus_trader.execution.config import ExecEngineConfig
+from nautilus_trader.live.config import LiveDataClientConfig
 from nautilus_trader.model.data import Bar
 from nautilus_trader.model.data import BarType
 from nautilus_trader.model.identifiers import InstrumentId
@@ -38,7 +43,6 @@ from nautilus_trader.system.config import NautilusKernelConfig
 
 
 def parse_filters_expr(s: str | None):
-    # TODO (bm) - could we do this better, probably requires writing our own parser?
     """
     Parse a pyarrow.dataset filter expression from a string.
 
@@ -50,24 +54,52 @@ def parse_filters_expr(s: str | None):
     >>> parse_filters_expr("None")
 
     """
-    from pyarrow.dataset import field
+    import re
 
-    assert field  # Required for eval
+    from pyarrow.dataset import field
 
     if not s:
         return None
 
-    def safer_eval(input_string):
-        allowed_names = {"field": field}
-        code = compile(input_string, "<string>", "eval")
+    # Normalise single-quoted filters so our regex only has to reason about
+    # the double-quoted form produced by Nautilus itself. If the expression
+    # already contains double quotes we leave it unchanged to avoid corrupting
+    # mixed quoting scenarios.
+    if "'" in s and '"' not in s:
+        s = s.replace("'", '"')
 
-        for name in code.co_names:
-            if name not in allowed_names:
-                raise NameError(f"Use of {name} not allowed")
+    # Security: Only allow very specific PyArrow field expressions
+    # Pattern matches: field("name") == "value", field("name") != "value", etc.
+    # Optional opening/closing parentheses are allowed around each comparison so
+    # we can safely compose expressions such as
+    #     (field("Currency") == "CHF") | (field("Symbol") == "USD")
+    # Supported grammar (regex-validated):
+    #     [ '(' ] field("name") <op> "literal" [ ')' ] ( ( '|' | '&' ) ... )*
+    safe_pattern = (
+        r"^(\()?"
+        r'field\("[^"]+"\)\s*[!=<>]+\s*"[^"]*"'
+        r"(\))?"
+        r'(\s*[|&]\s*(\()?field\("[^"]+"\)\s*[!=<>]+\s*"[^"]*"(\))?)*$'
+    )
 
-        return eval(code, {}, allowed_names)  # noqa
+    if not re.match(safe_pattern, s.strip()):
+        raise ValueError(
+            f"Filter expression '{s}' is not allowed. Only field() comparisons are permitted.",
+        )
 
-    return safer_eval(s)  # Only allow use of the field object
+    try:
+        # For now, rely on the regex validation above to guarantee safety and
+        # evaluate the expression in a minimal global namespace that only exposes
+        # the `field` helper. Built-ins are intentionally left untouched because
+        # PyArrow requires access to them (for example it imports `decimal` under
+        # the hood). Stripping them leads to a hard crash inside the C++ layer
+        # of Arrow. The expression is still safe because the regex prevents any
+        # reference other than the allowed `field(...)` comparisons.
+        allowed_globals = {"field": field}
+        return eval(s, allowed_globals, {})  # noqa: S307
+
+    except Exception as e:
+        raise ValueError(f"Failed to parse filter expression '{s}': {e}")
 
 
 class BacktestVenueConfig(NautilusConfig, frozen=True):
@@ -121,6 +153,14 @@ class BacktestVenueConfig(NautilusConfig, frozen=True):
         - If Low is closer to Open than High then the processing order is Open, Low, High, Close.
     trade_execution : bool, default False
         If trades should be processed by the matching engine(s) (and move the market).
+    modules : list[ImportableActorConfig], optional
+        The simulation modules for the venue.
+    fill_model : ImportableFillModelConfig, optional
+        The fill model for the venue.
+    latency_model : ImportableLatencyModelConfig, optional
+        The latency model for the venue.
+    fee_model : ImportableFeeModelConfig, optional
+        The fee model for the venue.
 
     """
 
@@ -143,8 +183,10 @@ class BacktestVenueConfig(NautilusConfig, frozen=True):
     bar_execution: bool = True
     bar_adaptive_high_low_ordering: bool = False
     trade_execution: bool = False
-    # fill_model: FillModel | None = None  # TODO: Implement
     modules: list[ImportableActorConfig] | None = None
+    fill_model: ImportableFillModelConfig | None = None
+    latency_model: ImportableLatencyModelConfig | None = None
+    fee_model: ImportableFeeModelConfig | None = None
 
 
 class BacktestDataConfig(NautilusConfig, frozen=True):
@@ -173,7 +215,7 @@ class BacktestDataConfig(NautilusConfig, frozen=True):
         The additional filter expressions for the data catalog query.
     client_id : str, optional
         The client ID for the data configuration.
-    metadata : dict, optional
+    metadata : dict or callable, optional
         The metadata for the data catalog query.
     bar_spec : BarSpecification | str, optional
         The bar specification for the data catalog query.
@@ -196,7 +238,7 @@ class BacktestDataConfig(NautilusConfig, frozen=True):
     end_time: str | int | None = None
     filter_expr: str | None = None
     client_id: str | None = None
-    metadata: dict | None = None
+    metadata: dict | Any | None = None
     bar_spec: str | None = None
     instrument_ids: list[str] | None = None
     bar_types: list[str] | None = None
@@ -252,22 +294,22 @@ class BacktestDataConfig(NautilusConfig, frozen=True):
         else:
             filter_expr = self.filter_expr
 
-        used_instrument_ids = None
+        used_identifiers = None
 
         if self.instrument_id is not None:
-            used_instrument_ids = [self.instrument_id]
+            used_identifiers = [self.instrument_id]
         elif self.instrument_ids is not None:
-            used_instrument_ids = self.instrument_ids
+            used_identifiers = self.instrument_ids
         elif self.bar_types is not None:
             bar_types: list[BarType] = [
                 BarType.from_str(bar_type) if type(bar_type) is str else bar_type
                 for bar_type in self.bar_types
             ]
-            used_instrument_ids = [bar_type.instrument_id for bar_type in bar_types]
+            used_identifiers = [bar_type.instrument_id for bar_type in bar_types]
 
         return {
             "data_cls": self.data_type,
-            "instrument_ids": used_instrument_ids,
+            "identifiers": used_identifiers,
             "start": self.start_time,
             "end": self.end_time,
             "filter_expr": parse_filters_expr(filter_expr),
@@ -380,6 +422,8 @@ class BacktestRunConfig(NautilusConfig, frozen=True):
     chunk_size : int, optional
         The number of data points to process in each chunk during streaming mode.
         If `None`, the backtest will run without streaming, loading all data at once.
+    raise_exception : bool, default False
+        If exceptions during an engine build or run should be raised to interrupt the nodes process.
     dispose_on_completion : bool, default True
         If the backtest engine should be disposed on completion of the run.
         If True, then will drop data and all state.
@@ -390,6 +434,8 @@ class BacktestRunConfig(NautilusConfig, frozen=True):
     end : datetime or str or int, optional
         The end datetime (UTC) for the backtest run.
         If ``None`` engine runs to the end of the data.
+    data_clients : dict[str, type[LiveDataClientConfig]], optional
+        The data clients configuration for the backtest run.
 
     Notes
     -----
@@ -403,9 +449,11 @@ class BacktestRunConfig(NautilusConfig, frozen=True):
     data: list[BacktestDataConfig]
     engine: BacktestEngineConfig | None = None
     chunk_size: int | None = None
+    raise_exception: bool = False
     dispose_on_completion: bool = True
     start: str | int | None = None
     end: str | int | None = None
+    data_clients: dict[str, type[LiveDataClientConfig]] | None = None
 
 
 class SimulationModuleConfig(ActorConfig, frozen=True):
@@ -414,6 +462,257 @@ class SimulationModuleConfig(ActorConfig, frozen=True):
     """
 
 
+class FillModelConfig(NautilusConfig, frozen=True):
+    """
+    Configuration for ``FillModel`` instances.
+
+    Parameters
+    ----------
+    prob_fill_on_limit : float, default 1.0
+        The probability of limit order filling if the market rests on its price.
+    prob_fill_on_stop : float, default 1.0
+        The probability of stop orders filling if the market rests on its price.
+    prob_slippage : float, default 0.0
+        The probability of order fill prices slipping by one tick.
+    random_seed : int, optional
+        The random seed (if None then no random seed).
+
+    """
+
+    prob_fill_on_limit: float = 1.0
+    prob_fill_on_stop: float = 1.0
+    prob_slippage: float = 0.0
+    random_seed: int | None = None
+
+
+class ImportableFillModelConfig(NautilusConfig, frozen=True):
+    """
+    Configuration for a fill model instance.
+
+    Parameters
+    ----------
+    fill_model_path : str
+        The fully qualified name of the fill model class.
+    config_path : str
+        The fully qualified name of the config class.
+    config : dict[str, Any]
+        The fill model configuration.
+
+    """
+
+    fill_model_path: str
+    config_path: str
+    config: dict[str, Any]
+
+
+class FillModelFactory:
+    """
+    Provides fill model creation from importable configurations.
+    """
+
+    @staticmethod
+    def create(config: ImportableFillModelConfig):
+        """
+        Create a fill model from the given configuration.
+
+        Parameters
+        ----------
+        config : ImportableFillModelConfig
+            The configuration for the building step.
+
+        Returns
+        -------
+        FillModel
+
+        Raises
+        ------
+        TypeError
+            If `config` is not of type `ImportableFillModelConfig`.
+
+        """
+        PyCondition.type(config, ImportableFillModelConfig, "config")
+        fill_model_cls = resolve_path(config.fill_model_path)
+        config_cls = resolve_config_path(config.config_path)
+        json = msgspec.json.encode(config.config, enc_hook=msgspec_encoding_hook)
+        config_obj = config_cls.parse(json)
+        return fill_model_cls(config=config_obj)
+
+
+class LatencyModelConfig(NautilusConfig, frozen=True):
+    """
+    Configuration for ``LatencyModel`` instances.
+
+    Parameters
+    ----------
+    base_latency_nanos : int, default 1_000_000_000
+        The base latency (nanoseconds) for the model.
+    insert_latency_nanos : int, default 0
+        The order insert latency (nanoseconds) for the model.
+    update_latency_nanos : int, default 0
+        The order update latency (nanoseconds) for the model.
+    cancel_latency_nanos : int, default 0
+        The order cancel latency (nanoseconds) for the model.
+
+    """
+
+    base_latency_nanos: NonNegativeInt = 1_000_000_000  # 1 millisecond in nanoseconds
+    insert_latency_nanos: NonNegativeInt = 0
+    update_latency_nanos: NonNegativeInt = 0
+    cancel_latency_nanos: NonNegativeInt = 0
+
+
+class ImportableLatencyModelConfig(NautilusConfig, frozen=True):
+    """
+    Configuration for a latency model instance.
+
+    Parameters
+    ----------
+    latency_model_path : str
+        The fully qualified name of the latency model class.
+    config_path : str
+        The fully qualified name of the config class.
+    config : dict[str, Any]
+        The latency model configuration.
+
+    """
+
+    latency_model_path: str
+    config_path: str
+    config: dict[str, Any]
+
+
+class LatencyModelFactory:
+    """
+    Provides latency model creation from importable configurations.
+    """
+
+    @staticmethod
+    def create(config: ImportableLatencyModelConfig):
+        """
+        Create a latency model from the given configuration.
+
+        Parameters
+        ----------
+        config : ImportableLatencyModelConfig
+            The configuration for the building step.
+
+        Returns
+        -------
+        LatencyModel
+
+        Raises
+        ------
+        TypeError
+            If `config` is not of type `ImportableLatencyModelConfig`.
+
+        """
+        PyCondition.type(config, ImportableLatencyModelConfig, "config")
+        latency_model_cls = resolve_path(config.latency_model_path)
+        config_cls = resolve_config_path(config.config_path)
+        json = msgspec.json.encode(config.config, enc_hook=msgspec_encoding_hook)
+        config_obj = config_cls.parse(json)
+        return latency_model_cls(config=config_obj)
+
+
+class FeeModelConfig(NautilusConfig, frozen=True):
+    """
+    Base configuration for ``FeeModel`` instances.
+    """
+
+
+class MakerTakerFeeModelConfig(FeeModelConfig, frozen=True):
+    """
+    Configuration for ``MakerTakerFeeModel`` instances.
+
+    This fee model uses the maker/taker fees defined on the instrument.
+
+    """
+
+
+class FixedFeeModelConfig(FeeModelConfig, frozen=True):
+    """
+    Configuration for ``FixedFeeModel`` instances.
+
+    Parameters
+    ----------
+    commission : Money | str
+        The fixed commission amount for trades.
+    charge_commission_once : bool, default True
+        Whether to charge the commission once per order or per fill.
+
+    """
+
+    commission: str
+    charge_commission_once: bool = True
+
+
+class PerContractFeeModelConfig(FeeModelConfig, frozen=True):
+    """
+    Configuration for ``PerContractFeeModel`` instances.
+
+    Parameters
+    ----------
+    commission : Money | str
+        The commission amount per contract.
+
+    """
+
+    commission: str
+
+
+class ImportableFeeModelConfig(NautilusConfig, frozen=True):
+    """
+    Configuration for a fee model instance.
+
+    Parameters
+    ----------
+    fee_model_path : str
+        The fully qualified name of the fee model class.
+    config_path : str
+        The fully qualified name of the config class.
+    config : dict[str, Any]
+        The fee model configuration.
+
+    """
+
+    fee_model_path: str
+    config_path: str
+    config: dict[str, Any]
+
+
+class FeeModelFactory:
+    """
+    Provides fee model creation from importable configurations.
+    """
+
+    @staticmethod
+    def create(config: ImportableFeeModelConfig):
+        """
+        Create a fee model from the given configuration.
+
+        Parameters
+        ----------
+        config : ImportableFeeModelConfig
+            The configuration for the building step.
+
+        Returns
+        -------
+        FeeModel
+
+        Raises
+        ------
+        TypeError
+            If `config` is not of type `ImportableFeeModelConfig`.
+
+        """
+        PyCondition.type(config, ImportableFeeModelConfig, "config")
+        fee_model_cls = resolve_path(config.fee_model_path)
+        config_cls = resolve_config_path(config.config_path)
+        json = msgspec.json.encode(config.config, enc_hook=msgspec_encoding_hook)
+        config_obj = config_cls.parse(json)
+        return fee_model_cls(config=config_obj)
+
+
 class FXRolloverInterestConfig(SimulationModuleConfig, frozen=True):
     """
     Provides an FX rollover interest simulation module.
