@@ -15,11 +15,12 @@
 
 import asyncio
 import math
+import os
 import uuid
 from asyncio import Queue
 from collections import Counter
 from decimal import Decimal
-from typing import Any, Final
+from typing import Any, Final, cast
 
 from nautilus_trader.cache.cache import Cache
 from nautilus_trader.common.component import LiveClock
@@ -170,7 +171,10 @@ class LiveExecutionEngine(ExecutionEngine):
         self.purge_closed_positions_buffer_mins = config.purge_closed_positions_buffer_mins
         self.purge_account_events_interval_mins = config.purge_account_events_interval_mins
         self.purge_account_events_lookback_mins = config.purge_account_events_lookback_mins
+        self.purge_from_database = config.purge_from_database
         self._inflight_check_threshold_ns: int = millis_to_nanos(self.inflight_check_threshold_ms)
+        self.graceful_shutdown_on_exception: bool = config.graceful_shutdown_on_exception
+        self._shutdown_initiated: bool = False
 
         self._log.info(f"{config.reconciliation=}", LogColor.BLUE)
         self._log.info(f"{config.reconciliation_lookback_mins=}", LogColor.BLUE)
@@ -188,6 +192,8 @@ class LiveExecutionEngine(ExecutionEngine):
         self._log.info(f"{config.purge_closed_positions_buffer_mins=}", LogColor.BLUE)
         self._log.info(f"{config.purge_account_events_interval_mins=}", LogColor.BLUE)
         self._log.info(f"{config.purge_account_events_lookback_mins=}", LogColor.BLUE)
+        self._log.info(f"{config.purge_from_database=}", LogColor.BLUE)
+        self._log.info(f"{config.graceful_shutdown_on_exception=}", LogColor.BLUE)
 
         # Register endpoints
         self._msgbus.register(endpoint="ExecEngine.reconcile_report", handler=self.reconcile_report)
@@ -320,10 +326,12 @@ class LiveExecutionEngine(ExecutionEngine):
         self._log.warning("Killing engine")
         self._kill = True
         self.stop()
+
         if self._cmd_queue_task:
             self._log.debug(f"Canceling task '{self._cmd_queue_task.get_name()}'")
             self._cmd_queue_task.cancel()
             self._cmd_queue_task = None
+
         if self._evt_queue_task:
             self._log.debug(f"Canceling task '{self._evt_queue_task.get_name()}'")
             self._evt_queue_task.cancel()
@@ -362,6 +370,26 @@ class LiveExecutionEngine(ExecutionEngine):
 
     # -- INTERNAL -------------------------------------------------------------------------------------
 
+    def _handle_queue_exception(self, e: Exception, queue_name: str) -> None:
+        self._log.exception(
+            f"Unexpected exception in {queue_name} queue processing: {e!r}",
+            e,
+        )
+        if self.graceful_shutdown_on_exception:
+            if not self._shutdown_initiated:
+                self._log.warning(
+                    "Initiating graceful shutdown due to unexpected exception",
+                )
+                self.shutdown_system(
+                    f"Unexpected exception in {queue_name} queue processing: {e!r}",
+                )
+                self._shutdown_initiated = True
+        else:
+            self._log.error(
+                "System will terminate immediately to prevent operation in degraded state",
+            )
+            os._exit(1)  # Immediate crash
+
     def _enqueue_sentinel(self) -> None:
         self._loop.call_soon_threadsafe(self._cmd_queue.put_nowait, self._sentinel)
         self._loop.call_soon_threadsafe(self._evt_queue.put_nowait, self._sentinel)
@@ -457,16 +485,20 @@ class LiveExecutionEngine(ExecutionEngine):
         )
         try:
             while True:
-                command: TradingCommand | None = await self._cmd_queue.get()
-                if command is self._sentinel:
+                try:
+                    command: TradingCommand | None = await self._cmd_queue.get()
+                    if command is self._sentinel:
+                        break
+
+                    self._execute_command(command)
+                except asyncio.CancelledError:
+                    self._log.warning("Canceled task 'run_cmd_queue'")
                     break
-                self._execute_command(command)
-        except asyncio.CancelledError:
-            self._log.warning("Canceled task 'run_cmd_queue'")
-        except Exception as e:
-            self._log.exception(f"{e!r}", e)
+                except Exception as e:
+                    self._handle_queue_exception(e, "command")
         finally:
             stopped_msg = "Command message queue stopped"
+
             if not self._cmd_queue.empty():
                 self._log.warning(f"{stopped_msg} with {self.cmd_qsize()} message(s) on queue")
             else:
@@ -478,16 +510,20 @@ class LiveExecutionEngine(ExecutionEngine):
         )
         try:
             while True:
-                event: OrderEvent | None = await self._evt_queue.get()
-                if event is self._sentinel:
+                try:
+                    event: OrderEvent | None = await self._evt_queue.get()
+                    if event is self._sentinel:
+                        break
+
+                    self._handle_event(event)
+                except asyncio.CancelledError:
+                    self._log.warning("Canceled task 'run_evt_queue'")
                     break
-                self._handle_event(event)
-        except asyncio.CancelledError:
-            self._log.warning("Canceled task 'run_evt_queue'")
-        except Exception as e:
-            self._log.exception(f"{e!r}", e)
+                except Exception as e:
+                    self._handle_queue_exception(e, "event")
         finally:
             stopped_msg = "Event message queue stopped"
+
             if not self._evt_queue.empty():
                 self._log.warning(f"{stopped_msg} with {self.evt_qsize()} message(s) on queue")
             else:
@@ -497,6 +533,7 @@ class LiveExecutionEngine(ExecutionEngine):
         try:
             while True:
                 await asyncio.sleep(self.inflight_check_interval_ms / 1000)
+
                 try:
                     await self._check_inflight_orders()
                 except Exception as e:
@@ -506,14 +543,15 @@ class LiveExecutionEngine(ExecutionEngine):
 
     async def _check_inflight_orders(self) -> None:
         self._log.debug("Checking in-flight orders status")
-
         inflight_orders: list[Order] = self._cache.orders_inflight()
         inflight_len = len(inflight_orders)
         self._log.debug(
             f"Found {inflight_len} order{'' if inflight_len == 1 else 's'} in-flight",
         )
+
         for order in inflight_orders:
             retries = self._inflight_check_retries[order.client_order_id]
+
             if retries >= self.inflight_check_max_retries:
                 self._inflight_check_retries.pop(order.client_order_id, None)
                 self._resolve_inflight_order(order)
@@ -626,13 +664,25 @@ class LiveExecutionEngine(ExecutionEngine):
                 )
                 for c in clients
             ]
-            order_reports_all = await asyncio.gather(*tasks)
-            all_order_reports = [r for reports in order_reports_all for r in reports]
+
+            order_reports_all = await asyncio.gather(*tasks, return_exceptions=True)
+            all_order_reports: list[OrderStatusReport] = []
+
+            for reports_or_exception in order_reports_all:
+                if isinstance(reports_or_exception, Exception):
+                    self._log.error(
+                        f"Failed to generate order status reports: {reports_or_exception}",
+                    )
+                    continue
+
+                reports = cast(list[OrderStatusReport], reports_or_exception)
+                all_order_reports.extend(reports)
 
             # For each report, compare the reported open status with our cache
             # If there's a discrepancy, reconcile the order report
             for report in all_order_reports:
                 is_in_open_ids = report.client_order_id in open_order_ids
+
                 if report.is_open != is_in_open_ids:
                     self._reconcile_order_report(report, trades=[])
         except Exception as e:
@@ -648,7 +698,11 @@ class LiveExecutionEngine(ExecutionEngine):
             while True:
                 await asyncio.sleep(interval_secs)
                 ts_now = self._clock.timestamp_ns()
-                self._cache.purge_closed_orders(ts_now=ts_now, buffer_secs=buffer_secs)
+                self._cache.purge_closed_orders(
+                    ts_now=ts_now,
+                    buffer_secs=buffer_secs,
+                    purge_from_database=self.purge_from_database,
+                )
         except asyncio.CancelledError:
             self._log.debug("Canceled task 'purge_closed_orders_loop'")
         except Exception as e:
@@ -663,7 +717,11 @@ class LiveExecutionEngine(ExecutionEngine):
             while True:
                 await asyncio.sleep(interval_secs)
                 ts_now = self._clock.timestamp_ns()
-                self._cache.purge_closed_positions(ts_now=ts_now, buffer_secs=buffer_secs)
+                self._cache.purge_closed_positions(
+                    ts_now=ts_now,
+                    buffer_secs=buffer_secs,
+                    purge_from_database=self.purge_from_database,
+                )
         except asyncio.CancelledError:
             self._log.debug("Canceled task 'purge_closed_positions_loop'")
         except Exception as e:
@@ -678,7 +736,11 @@ class LiveExecutionEngine(ExecutionEngine):
             while True:
                 await asyncio.sleep(interval_secs)
                 ts_now = self._clock.timestamp_ns()
-                self._cache.purge_account_events(ts_now=ts_now, lookback_secs=lookback_secs)
+                self._cache.purge_account_events(
+                    ts_now=ts_now,
+                    lookback_secs=lookback_secs,
+                    purge_from_database=self.purge_from_database,
+                )
         except asyncio.CancelledError:
             self._log.debug("Canceled task 'purge_account_events_loop'")
         except Exception as e:
@@ -692,7 +754,7 @@ class LiveExecutionEngine(ExecutionEngine):
         else:
             self._log.warning(f"Reconciliation for {value} failed")
 
-    async def reconcile_state(self, timeout_secs: float = 10.0) -> bool:
+    async def reconcile_state(self, timeout_secs: float = 10.0) -> bool:  # noqa: C901 (too complex)
         """
         Reconcile the internal execution state with all execution clients (external
         state).
@@ -728,17 +790,23 @@ class LiveExecutionEngine(ExecutionEngine):
         mass_status_coros = [
             c.generate_mass_status(reconciliation_lookback_mins) for c in self._clients.values()
         ]
-        mass_status_all = await asyncio.gather(*mass_status_coros)
+        mass_status_all = await asyncio.gather(*mass_status_coros, return_exceptions=True)
 
         # Reconcile each mass status with the execution engine
-        for mass_status in mass_status_all:
-            if mass_status is None:
+        for mass_status_or_exception in mass_status_all:
+            if isinstance(mass_status_or_exception, Exception):
+                self._log.error(f"Failed to generate mass status: {mass_status_or_exception}")
+                results.append(False)
+                continue
+
+            if mass_status_or_exception is None:
                 self._log.warning(
                     "No execution mass status available for reconciliation "
                     "(likely due to an adapter client error when generating reports)",
                 )
                 continue
 
+            mass_status = cast("ExecutionMassStatus", mass_status_or_exception)
             client_id = mass_status.client_id
             venue = mass_status.venue
             result = self._reconcile_mass_status(mass_status)
@@ -755,11 +823,14 @@ class LiveExecutionEngine(ExecutionEngine):
 
             # Check internal and external position reconciliation
             report_tasks: list[asyncio.Task] = []
+
             for position in self._cache.positions_open(venue):
                 instrument_id = position.instrument_id
+
                 if instrument_id in mass_status.position_reports:
                     self._log.debug(f"Position {instrument_id} for {client_id} already reconciled")
                     continue  # Already reconciled
+
                 self._log.info(f"{position} pending reconciliation")
                 position_status_command = GeneratePositionStatusReports(
                     instrument_id=instrument_id,
@@ -776,13 +847,26 @@ class LiveExecutionEngine(ExecutionEngine):
                 # Reconcile specific internal open positions
                 self._log.info(f"Awaiting {len(report_tasks)} position reports for {client_id}")
                 position_results: list[bool] = []
-                for task_result in await asyncio.gather(*report_tasks):
+
+                for task_result_or_exception in await asyncio.gather(
+                    *report_tasks,
+                    return_exceptions=True,
+                ):
+                    if isinstance(task_result_or_exception, Exception):
+                        self._log.error(
+                            f"Failed to generate position status reports: {task_result_or_exception}",
+                        )
+                        position_results.append(False)
+                        continue
+
+                    task_result = cast("list[PositionStatusReport]", task_result_or_exception)
+
                     for report in task_result:
                         position_result = self._reconcile_position_report(report)
                         self._log_reconciliation_result(report.instrument_id, position_result)
                         position_results.append(position_result)
 
-                result = all(position_results)
+                result = result and all(position_results)
 
             self._log_reconciliation_result(client_id, result)
             results.append(result)
@@ -864,8 +948,10 @@ class LiveExecutionEngine(ExecutionEngine):
 
             # Check and handle duplicate client order IDs
             client_order_id = order_report.client_order_id
+
             if client_order_id is not None and client_order_id in reconciled_orders:
                 self._log.error(f"Duplicate {client_order_id!r} detected: {order_report}")
+                results.append(False)
                 continue  # Determine how to handle this
 
             # Check for duplicate trade IDs
@@ -874,6 +960,7 @@ class LiveExecutionEngine(ExecutionEngine):
                     self._log.warning(
                         f"Duplicate {fill_report.trade_id!r} detected: {fill_report}",
                     )
+
                 reconciled_trades.add(fill_report.trade_id)
 
             try:
@@ -881,11 +968,13 @@ class LiveExecutionEngine(ExecutionEngine):
             except InvalidStateTrigger as e:
                 self._log.error(str(e))
                 result = False
+
             results.append(result)
             reconciled_orders.add(order_report.client_order_id)
 
         if not self.filter_position_reports:
             position_reports: list[PositionStatusReport]
+
             # Reconcile all reported positions
             for position_reports in mass_status.position_reports.values():
                 for report in position_reports:
@@ -906,11 +995,14 @@ class LiveExecutionEngine(ExecutionEngine):
         trades: list[FillReport],
     ) -> bool:
         client_order_id: ClientOrderId = report.client_order_id
+
         if client_order_id is None:
             client_order_id = self._cache.client_order_id(report.venue_order_id)
+
             if client_order_id is None:
                 # Generate external client order ID
                 client_order_id = self._generate_client_order_id()
+
             # Assign to report
             report.client_order_id = client_order_id
 
@@ -918,19 +1010,23 @@ class LiveExecutionEngine(ExecutionEngine):
         self._inflight_check_retries.pop(client_order_id, None)
 
         self._log.info(f"Reconciling order for {client_order_id!r}", LogColor.BLUE)
-
         order: Order = self._cache.order(client_order_id)
+
         if order is None:
             order = self._generate_external_order(report)
+
             if order is None:
                 # External order dropped
                 return True  # No further reconciliation
+
             # Add to cache without determining any position ID initially
             self._cache.add_order(order)
+
             if self.manage_own_order_books and py_should_handle_own_book_order(order):
                 self._add_own_book_order(order)
 
         instrument: Instrument | None = self._cache.instrument(order.instrument_id)
+
         if instrument is None:
             self._log.error(
                 f"Cannot reconcile order for {order.client_order_id!r}: "
@@ -941,11 +1037,13 @@ class LiveExecutionEngine(ExecutionEngine):
         if report.order_status == OrderStatus.REJECTED:
             if order.status != OrderStatus.REJECTED:
                 self._generate_order_rejected(order, report)
+
             return True  # Reconciled
 
         if report.order_status == OrderStatus.ACCEPTED:
             if order.status != OrderStatus.ACCEPTED:
                 self._generate_order_accepted(order, report)
+
             return True  # Reconciled
 
         # Order must have been accepted from this point
@@ -959,26 +1057,34 @@ class LiveExecutionEngine(ExecutionEngine):
         if report.order_status == OrderStatus.TRIGGERED:
             if order.status != OrderStatus.TRIGGERED:
                 self._generate_order_triggered(order, report)
+
             return True  # Reconciled
 
         if report.order_status == OrderStatus.CANCELED:
             if order.status != OrderStatus.CANCELED and order.is_open:
                 if report.ts_triggered > 0:
                     self._generate_order_triggered(order, report)
+
                 # Reconcile all trades
                 for trade in trades:
                     self._reconcile_fill_report(order, trade, instrument)
+
                 self._generate_order_canceled(order, report)
+
             return True  # Reconciled
 
         if report.order_status == OrderStatus.EXPIRED:
             if order.status != OrderStatus.EXPIRED and order.is_open:
                 if report.ts_triggered > 0:
                     self._generate_order_triggered(order, report)
+
                 self._generate_order_expired(order, report)
+
             return True  # Reconciled
 
-        # Order has some fills from this point
+        #######################################################################
+        # Order has fills from this point
+        #######################################################################
 
         # Reconcile all trades
         for trade in trades:
@@ -988,18 +1094,19 @@ class LiveExecutionEngine(ExecutionEngine):
             self._log.warning("report.avg_px was `None` when a value was expected")
 
         # Check reported filled qty against order filled qty
-        if report.filled_qty != order.filled_qty:
+        if report.filled_qty < order.filled_qty:
+            self._log.error(
+                f"report.filled_qty {report.filled_qty} < order.filled_qty {order.filled_qty}, "
+                "this could potentially be caused by duplicate fills or corrupted cached state",
+            )
+            return False  # Failed
+
+        if report.filled_qty > order.filled_qty:
             # This is due to missing fill report(s), there may now be some
             # information loss if multiple fills occurred to reach the reported
             # state, or if commissions differed from the default.
             fill: OrderFilled = self._generate_inferred_fill(order, report, instrument)
             self._handle_event(fill)
-            if report.filled_qty != order.filled_qty:
-                self._log.error(
-                    f"report.filled_qty {report.filled_qty} != order.filled_qty {order.filled_qty}, "
-                    "this could potentially be caused by corrupted or incomplete cached state",
-                )
-                return False  # Failed
 
             if report.avg_px is not None and not math.isclose(report.avg_px, order.avg_px):
                 self._log.warning(
@@ -1014,19 +1121,23 @@ class LiveExecutionEngine(ExecutionEngine):
             report.venue_order_id,
         )
         if client_order_id is None:
-            self._log.error(
-                f"Cannot reconcile FillReport: client order ID for {report.venue_order_id!r} not found",
+            self._log.warning(
+                f"FillReport received before OrderStatusReport for {report.venue_order_id!r}, "
+                "deferring reconciliation - this may require a synthetic order",
             )
             return False  # Failed
 
         order: Order | None = self._cache.order(client_order_id)
+
         if order is None:
-            self._log.error(
-                f"Cannot reconcile FillReport: no order for {client_order_id!r}",
+            self._log.warning(
+                f"FillReport received before order cached for {client_order_id!r}, "
+                "deferring reconciliation",
             )
             return False  # Failed
 
         instrument: Instrument | None = self._cache.instrument(order.instrument_id)
+
         if instrument is None:
             self._log.error(
                 f"Cannot reconcile order for {order.client_order_id!r}: "
@@ -1036,19 +1147,56 @@ class LiveExecutionEngine(ExecutionEngine):
 
         return self._reconcile_fill_report(order, report, instrument)
 
-    def _reconcile_fill_report(
+    def _reconcile_fill_report(  # noqa: C901 (too complex)
         self,
         order: Order,
         report: FillReport,
         instrument: Instrument,
     ) -> bool:
         if report.trade_id in order.trade_ids:
-            return True  # Fill already applied (assumes consistent trades)
+            # Fill already applied; check if data is consistent.
+            # An existing fill may be sourced from the cache on start,
+            # or may exist in-memory when a reconciliation is triggered.
+            existing_fill = self._get_existing_fill_for_trade_id(order, report.trade_id)
+
+            if existing_fill:
+                if not self._fill_reports_equal(existing_fill, report):
+                    differences = []
+                    if existing_fill.last_qty != report.last_qty:
+                        differences.append(f"qty: {existing_fill.last_qty} → {report.last_qty}")
+
+                    if existing_fill.last_px != report.last_px:
+                        differences.append(f"px: {existing_fill.last_px} → {report.last_px}")
+
+                    if existing_fill.commission != report.commission:
+                        differences.append(
+                            f"commission: {existing_fill.commission} → {report.commission}",
+                        )
+
+                    if existing_fill.liquidity_side != report.liquidity_side:
+                        differences.append(
+                            f"liquidity: {existing_fill.liquidity_side} → {report.liquidity_side}",
+                        )
+
+                    if existing_fill.ts_event != report.ts_event:
+                        differences.append(
+                            f"ts_event: {existing_fill.ts_event} → {report.ts_event}",
+                        )
+
+                    self._log.warning(
+                        f"Fill report data differs from existing data for trade_id {report.trade_id}, "
+                        f"differences: {', '.join(differences)}. "
+                        f"Continuing with existing cached data to maintain consistency",
+                    )
+
+            return True  # Fill already applied, continue with existing data
+
         try:
             self._generate_order_filled(order, report, instrument)
         except InvalidStateTrigger as e:
             self._log.error(str(e))
             return False
+
         # Check correct ordering of fills
         if report.ts_event < order.ts_last:
             self._log.warning(
@@ -1056,6 +1204,26 @@ class LiveExecutionEngine(ExecutionEngine):
             )
         return True
 
+    def _get_existing_fill_for_trade_id(
+        self,
+        order: Order,
+        trade_id: TradeId,
+    ) -> OrderFilled | None:
+        for event in order.events:
+            if isinstance(event, OrderFilled) and event.trade_id == trade_id:
+                return event
+
+        return None
+
+    def _fill_reports_equal(self, cached_fill: OrderFilled, report: FillReport) -> bool:
+        return (
+            cached_fill.last_qty == report.last_qty
+            and cached_fill.last_px == report.last_px
+            and cached_fill.commission == report.commission
+            and cached_fill.liquidity_side == report.liquidity_side
+            and cached_fill.ts_event == report.ts_event
+        )
+
     def _reconcile_position_report(self, report: PositionStatusReport) -> bool:
         if report.venue_position_id is not None:
             return self._reconcile_position_report_hedging(report)
@@ -1069,6 +1237,7 @@ class LiveExecutionEngine(ExecutionEngine):
         )
 
         position: Position | None = self._cache.position(report.venue_position_id)
+
         if position is None:
             self._log.error(
                 f"Cannot reconcile position: {report.venue_position_id!r} not found",
@@ -1076,6 +1245,7 @@ class LiveExecutionEngine(ExecutionEngine):
             return False  # Failed
 
         position_signed_decimal_qty: Decimal = position.signed_decimal_qty()
+
         if position_signed_decimal_qty != report.signed_decimal_qty:
             self._log.error(
                 f"Cannot reconcile {report.instrument_id} {report.venue_position_id!r}: position "
@@ -1090,6 +1260,7 @@ class LiveExecutionEngine(ExecutionEngine):
         self._log.info(f"Reconciling NET position for {report.instrument_id}", LogColor.BLUE)
 
         instrument = self._cache.instrument(report.instrument_id)
+
         if instrument is None:
             self._log.error(
                 f"Cannot reconcile position for {report.instrument_id}: instrument not found",
@@ -1102,6 +1273,7 @@ class LiveExecutionEngine(ExecutionEngine):
         )
 
         position_signed_decimal_qty: Decimal = Decimal()
+
         for position in positions_open:
             position_signed_decimal_qty += position.signed_decimal_qty()
 
@@ -1120,6 +1292,12 @@ class LiveExecutionEngine(ExecutionEngine):
             diff_quantity = Quantity(diff, instrument.size_precision)
             self._log.info(f"{diff_quantity=}", LogColor.BLUE)
 
+            if diff_quantity == 0:
+                self._log.debug(
+                    f"Difference quantity rounds to zero for {instrument.id}, skipping order generation",
+                )
+                return True
+
             order_side = (
                 OrderSide.BUY
                 if report.signed_decimal_qty > position_signed_decimal_qty
@@ -1157,6 +1335,7 @@ class LiveExecutionEngine(ExecutionEngine):
     ) -> OrderFilled:
         # Infer liquidity side
         liquidity_side: LiquiditySide = LiquiditySide.NO_LIQUIDITY_SIDE
+
         if order.order_type in (
             OrderType.MARKET,
             OrderType.STOP_MARKET,
@@ -1201,8 +1380,8 @@ class LiveExecutionEngine(ExecutionEngine):
             ts_init=self._clock.timestamp_ns(),
             reconciliation=True,
         )
-
         self._log.warning(f"Generated inferred {filled}")
+
         return filled
 
     def _generate_external_order(self, report: OrderStatusReport) -> Order | None:
@@ -1213,30 +1392,36 @@ class LiveExecutionEngine(ExecutionEngine):
 
         # Prepare order options
         options: dict[str, Any] = {}
+
         if report.price is not None:
             options["price"] = str(report.price)
+
         if report.trigger_price is not None:
             options["trigger_price"] = str(report.trigger_price)
+
         if report.trigger_type is not None:
             options["trigger_type"] = trigger_type_to_str(report.trigger_type)
+
         if report.limit_offset is not None:
             options["limit_offset"] = str(report.limit_offset)
             options["trailing_offset_type"] = trailing_offset_type_to_str(
                 report.trailing_offset_type,
             )
+
         if report.trailing_offset is not None:
             options["trailing_offset"] = str(report.trailing_offset)
             options["trailing_offset_type"] = trailing_offset_type_to_str(
                 report.trailing_offset_type,
             )
+
         if report.display_qty is not None:
             options["display_qty"] = str(report.display_qty)
 
         options["expire_time_ns"] = (
             0 if report.expire_time is None else dt_to_unix_nanos(report.expire_time)
         )
-
         strategy_id = self.get_external_order_claim(report.instrument_id)
+
         if strategy_id is None:
             strategy_id = StrategyId("EXTERNAL")
             tags = ["EXTERNAL"]
