@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------------------------------
-#  Copyright (C) 2015-2024 Nautech Systems Pty Ltd. All rights reserved.
+#  Copyright (C) 2015-2025 Nautech Systems Pty Ltd. All rights reserved.
 #  https://nautechsystems.io
 #
 #  Licensed under the GNU Lesser General Public License Version 3.0 (the "License");
@@ -21,6 +21,7 @@ from nautilus_trader.model.instruments import BinaryOption
 from nautilus_trader.model.instruments import Cfd
 from nautilus_trader.model.instruments import Commodity
 from nautilus_trader.model.instruments import CryptoFuture
+from nautilus_trader.model.instruments import CryptoOption
 from nautilus_trader.model.instruments import CryptoPerpetual
 from nautilus_trader.model.instruments import CurrencyPair
 from nautilus_trader.model.instruments import Equity
@@ -28,8 +29,8 @@ from nautilus_trader.model.instruments import FuturesContract
 from nautilus_trader.model.instruments import FuturesSpread
 from nautilus_trader.model.instruments import IndexInstrument
 from nautilus_trader.model.instruments import Instrument
-from nautilus_trader.model.instruments import OptionsContract
-from nautilus_trader.model.instruments import OptionsSpread
+from nautilus_trader.model.instruments import OptionContract
+from nautilus_trader.model.instruments import OptionSpread
 
 
 SCHEMAS = {
@@ -138,14 +139,16 @@ SCHEMAS = {
             "ts_init": pa.uint64(),
         },
     ),
-    CryptoPerpetual: pa.schema(
+    CryptoFuture: pa.schema(
         {
             "id": pa.dictionary(pa.int64(), pa.string()),
             "raw_symbol": pa.string(),
-            "base_currency": pa.dictionary(pa.int16(), pa.string()),
+            "underlying": pa.dictionary(pa.int16(), pa.string()),
             "quote_currency": pa.dictionary(pa.int16(), pa.string()),
             "settlement_currency": pa.dictionary(pa.int16(), pa.string()),
             "is_inverse": pa.bool_(),
+            "activation_ns": pa.uint64(),
+            "expiration_ns": pa.uint64(),
             "price_precision": pa.uint8(),
             "size_precision": pa.uint8(),
             "price_increment": pa.dictionary(pa.int16(), pa.string()),
@@ -166,7 +169,7 @@ SCHEMAS = {
             "ts_init": pa.uint64(),
         },
     ),
-    CryptoFuture: pa.schema(
+    CryptoOption: pa.schema(
         {
             "id": pa.dictionary(pa.int64(), pa.string()),
             "raw_symbol": pa.string(),
@@ -174,6 +177,8 @@ SCHEMAS = {
             "quote_currency": pa.dictionary(pa.int16(), pa.string()),
             "settlement_currency": pa.dictionary(pa.int16(), pa.string()),
             "is_inverse": pa.bool_(),
+            "option_kind": pa.uint8(),
+            "strike_price": pa.string(),
             "activation_ns": pa.uint64(),
             "expiration_ns": pa.uint64(),
             "price_precision": pa.uint8(),
@@ -196,6 +201,34 @@ SCHEMAS = {
             "ts_init": pa.uint64(),
         },
     ),
+    CryptoPerpetual: pa.schema(
+        {
+            "id": pa.dictionary(pa.int64(), pa.string()),
+            "raw_symbol": pa.string(),
+            "base_currency": pa.dictionary(pa.int16(), pa.string()),
+            "quote_currency": pa.dictionary(pa.int16(), pa.string()),
+            "settlement_currency": pa.dictionary(pa.int16(), pa.string()),
+            "is_inverse": pa.bool_(),
+            "price_precision": pa.uint8(),
+            "size_precision": pa.uint8(),
+            "price_increment": pa.dictionary(pa.int16(), pa.string()),
+            "size_increment": pa.dictionary(pa.int16(), pa.string()),
+            "multiplier": pa.dictionary(pa.int16(), pa.string()),
+            "max_quantity": pa.dictionary(pa.int16(), pa.string()),
+            "min_quantity": pa.dictionary(pa.int16(), pa.string()),
+            "max_notional": pa.dictionary(pa.int16(), pa.string()),
+            "min_notional": pa.dictionary(pa.int16(), pa.string()),
+            "max_price": pa.dictionary(pa.int16(), pa.string()),
+            "min_price": pa.dictionary(pa.int16(), pa.string()),
+            "margin_init": pa.string(),
+            "margin_maint": pa.string(),
+            "maker_fee": pa.string(),
+            "taker_fee": pa.string(),
+            "info": pa.binary(),
+            "ts_event": pa.uint64(),
+            "ts_init": pa.uint64(),
+        },
+    ),
     Equity: pa.schema(
         {
             "id": pa.dictionary(pa.int64(), pa.string()),
@@ -265,7 +298,7 @@ SCHEMAS = {
             "ts_init": pa.uint64(),
         },
     ),
-    OptionsContract: pa.schema(
+    OptionContract: pa.schema(
         {
             "id": pa.dictionary(pa.int64(), pa.string()),
             "raw_symbol": pa.string(),
@@ -292,7 +325,7 @@ SCHEMAS = {
             "ts_init": pa.uint64(),
         },
     ),
-    OptionsSpread: pa.schema(
+    OptionSpread: pa.schema(
         {
             "id": pa.dictionary(pa.int64(), pa.string()),
             "raw_symbol": pa.string(),
@@ -370,12 +403,13 @@ def deserialize(batch: pa.RecordBatch) -> list[Instrument]:
         b"CurrencyPair": CurrencyPair,
         b"CryptoPerpetual": CryptoPerpetual,
         b"CryptoFuture": CryptoFuture,
+        b"CryptoOption": CryptoOption,
         b"Equity": Equity,
         b"FuturesContract": FuturesContract,
         b"FuturesSpread": FuturesSpread,
         b"IndexInstrument": IndexInstrument,
-        b"OptionsContract": OptionsContract,
-        b"OptionsSpread": OptionsSpread,
+        b"OptionContract": OptionContract,
+        b"OptionSpread": OptionSpread,
     }[ins_type]
 
     maps = batch.to_pylist()
