@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------------------------------
-#  Copyright (C) 2015-2024 Nautech Systems Pty Ltd. All rights reserved.
+#  Copyright (C) 2015-2025 Nautech Systems Pty Ltd. All rights reserved.
 #  https://nautechsystems.io
 #
 #  Licensed under the GNU Lesser General Public License Version 3.0 (the "License");
@@ -36,9 +36,12 @@ from nautilus_trader.model.currencies import ADA
 from nautilus_trader.model.currencies import AUD
 from nautilus_trader.model.currencies import BTC
 from nautilus_trader.model.currencies import ETH
+from nautilus_trader.model.currencies import GBP
 from nautilus_trader.model.currencies import USD
 from nautilus_trader.model.currencies import USDC
 from nautilus_trader.model.currencies import USDT
+from nautilus_trader.model.currencies import XRP
+from nautilus_trader.model.data import Bar
 from nautilus_trader.model.data import QuoteTick
 from nautilus_trader.model.data import TradeTick
 from nautilus_trader.model.enums import AggressorSide
@@ -56,7 +59,8 @@ from nautilus_trader.model.instruments import CryptoPerpetual
 from nautilus_trader.model.instruments import CurrencyPair
 from nautilus_trader.model.instruments import Equity
 from nautilus_trader.model.instruments import FuturesContract
-from nautilus_trader.model.instruments import OptionsContract
+from nautilus_trader.model.instruments import Instrument
+from nautilus_trader.model.instruments import OptionContract
 from nautilus_trader.model.instruments import SyntheticInstrument
 from nautilus_trader.model.instruments.betting import null_handicap
 from nautilus_trader.model.objects import Currency
@@ -69,6 +73,10 @@ from nautilus_trader.persistence.loaders import ParquetBarDataLoader
 from nautilus_trader.persistence.loaders import ParquetTickDataLoader
 
 
+# Constants
+NANOSECONDS_IN_SECOND = 1_000_000_000  # 1 billion nanoseconds in a second
+
+
 class TestInstrumentProvider:
     """
     Provides instrument template methods for backtesting.
@@ -188,7 +196,7 @@ class TestInstrumentProvider:
         )
 
     @staticmethod
-    def btcusdt_perp_binance() -> CurrencyPair:
+    def btcusdt_perp_binance() -> CryptoPerpetual:
         """
         Return the Binance Futures BTCUSDT instrument for backtesting.
 
@@ -354,6 +362,44 @@ class TestInstrumentProvider:
             ts_init=0,
         )
 
+    @staticmethod
+    def xrpusdt_linear_bybit() -> CryptoPerpetual:
+        """
+        Return the ByBit Linear XRPUSDT instrument for backtesting.
+
+        Returns
+        -------
+        CryptoPerpetual
+
+        """
+        return CryptoPerpetual(
+            instrument_id=InstrumentId(
+                symbol=Symbol("XRPUSDT-LINEAR"),
+                venue=Venue("BYBIT"),
+            ),
+            raw_symbol=Symbol("XRPUSDT"),
+            base_currency=XRP,
+            quote_currency=USDT,
+            settlement_currency=USDT,
+            is_inverse=False,
+            price_precision=4,
+            price_increment=Price.from_str("0.0001"),
+            size_precision=0,
+            size_increment=Quantity.from_str("1"),
+            max_quantity=Quantity.from_str("10965300"),
+            min_quantity=Quantity.from_str("1"),
+            max_notional=None,
+            min_notional=Money(1.0, USDT),
+            max_price=Price.from_str("199.9998"),
+            min_price=Price.from_str("0.0001"),
+            margin_init=Decimal("0.1"),
+            margin_maint=Decimal("0.1"),
+            maker_fee=Decimal("0.0002"),
+            taker_fee=Decimal("0.00055"),
+            ts_event=1646199312128000000,
+            ts_init=1646199342953849862,
+        )
+
     @staticmethod
     def xbtusd_bitmex() -> CryptoPerpetual:
         """
@@ -603,6 +649,40 @@ class TestInstrumentProvider:
             ts_init=activation_utc.value,
         )
 
+    @staticmethod
+    def eurusd_future(
+        expiry_year: int,
+        expiry_month: int,
+        venue_name: str = "XCME",
+    ) -> FuturesContract:
+        activation_date = first_friday_two_years_six_months_ago(expiry_year, expiry_month)
+        expiration_date = third_friday_of_month(expiry_year, expiry_month)
+
+        activation_time = pd.Timedelta(hours=21, minutes=30)
+        expiration_time = pd.Timedelta(hours=14, minutes=30)
+        activation_utc = pd.Timestamp(activation_date, tz=pytz.utc) + activation_time
+        expiration_utc = pd.Timestamp(expiration_date, tz=pytz.utc) + expiration_time
+
+        base_symbol = "6E"
+        raw_symbol = f"{base_symbol}{get_contract_month_code(expiry_month)}{expiry_year % 10}"
+
+        return FuturesContract(
+            instrument_id=InstrumentId(symbol=Symbol(raw_symbol), venue=Venue(venue_name)),
+            raw_symbol=Symbol(raw_symbol),
+            asset_class=AssetClass.FX,
+            exchange=venue_name,
+            currency=USD,
+            price_precision=5,
+            price_increment=Price.from_str("0.00005"),
+            multiplier=Quantity.from_int(125000),
+            lot_size=Quantity.from_int(1),
+            underlying=base_symbol,
+            activation_ns=activation_utc.value,
+            expiration_ns=expiration_utc.value,
+            ts_event=activation_utc.value,
+            ts_init=activation_utc.value,
+        )
+
     @staticmethod
     def future(
         symbol: str = "ESZ1",
@@ -628,8 +708,8 @@ class TestInstrumentProvider:
         )
 
     @staticmethod
-    def aapl_option() -> OptionsContract:
-        return OptionsContract(
+    def aapl_option() -> OptionContract:
+        return OptionContract(
             instrument_id=InstrumentId(symbol=Symbol("AAPL211217C00150000"), venue=Venue("OPRA")),
             raw_symbol=Symbol("AAPL211217C00150000"),
             asset_class=AssetClass.EQUITY,
@@ -685,6 +765,7 @@ class TestInstrumentProvider:
             currency="GBP",
             price_precision=2,  # BETFAIR_PRICE_PRECISION,
             size_precision=2,  # BETFAIR_QUANTITY_PRECISION,
+            min_notional=Money(1, GBP),
             ts_event=0,
             ts_init=0,
         )
@@ -958,6 +1039,76 @@ class TestDataGenerator:
             for idx, row in df.iterrows()
         ]
 
+    @staticmethod
+    def generate_monotonic_bars(
+        instrument: Instrument,
+        first_bar: Bar,
+        bar_count: int = 20,
+        time_change_nanos: int = 60 * NANOSECONDS_IN_SECOND,  # Default to 1 minute
+        price_change_ticks: int = 10,
+        increasing_series: bool = True,
+    ) -> list[Bar]:
+        """
+        Generate a sequence of bars with monotonic price progression.
+
+        This function creates a series of bars with consistent price progression
+        based on the specified parameters. Each subsequent bar's prices change
+        by a constant amount of ticks in the direction specified by `increasing_series`.
+
+        Parameters
+        ----------
+        instrument : Instrument
+            The instrument for which to generate bars
+        bar_type : BarType
+            The bar type specification for the generated bars
+        first_bar : Bar
+            The first bar in the sequence with initial OHLCV values
+        bar_count : int
+            The total number of bars to generate (including first_bar)
+        time_change_nanos : int
+            The time increment between consecutive bars in nanoseconds
+        price_change_ticks : int
+            The price increment between consecutive bars in ticks
+        increasing_series : bool
+            If True, generates a price series with increasing prices;
+            if False, generates a series with decreasing prices
+
+        Returns
+        -------
+        list[Bar]
+            The list of generated bars with the specified progression
+
+        """
+        # Calculate price change
+        tick_size = instrument.price_increment.as_double()
+        price_change = tick_size * price_change_ticks
+
+        # Increasing or decreasing series
+        if not increasing_series:
+            price_change = -price_change
+
+        # Collection of all generated artificial bars
+        bars = [first_bar]
+
+        # Generate subsequent bars
+        for i in range(bar_count - 1):  # -1 because we already have the first bar
+            prev_bar = bars[-1]  # Get the last bar
+            ts_event = prev_bar.ts_event + time_change_nanos
+            ts_init = prev_bar.ts_init + time_change_nanos
+            next_bar = Bar(
+                bar_type=first_bar.bar_type,
+                open=instrument.make_price(prev_bar.open + price_change),
+                high=instrument.make_price(prev_bar.high + price_change),
+                low=instrument.make_price(prev_bar.low + price_change),
+                close=instrument.make_price(prev_bar.close + price_change),
+                volume=prev_bar.volume,
+                ts_event=ts_event,
+                ts_init=ts_init,
+            )
+            bars.append(next_bar)
+
+        return bars
+
 
 def get_test_data_large_path() -> Path:
     return (PACKAGE_ROOT / "tests" / "test_data" / "large").resolve()
