@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------------------------------
-#  Copyright (C) 2015-2024 Nautech Systems Pty Ltd. All rights reserved.
+#  Copyright (C) 2015-2025 Nautech Systems Pty Ltd. All rights reserved.
 #  https://nautechsystems.io
 #
 #  Licensed under the GNU Lesser General Public License Version 3.0 (the "License");
@@ -39,6 +39,8 @@ class StrategyConfig(NautilusConfig, kw_only=True, frozen=True):
     order_id_tag : str, optional
         The unique order ID tag for the strategy. Must be unique
         amongst all running strategies for a particular trader ID.
+    use_uuid_client_order_ids : bool, default False
+        If UUID4's should be used for client order ID values.
     oms_type : OmsType, optional
         The order management system type for the strategy. This will determine
         how the `ExecutionEngine` handles position IDs.
@@ -51,15 +53,23 @@ class StrategyConfig(NautilusConfig, kw_only=True, frozen=True):
     manage_gtd_expiry : bool, default False
         If all order GTD time in force expirations should be managed by the strategy.
         If True, then will ensure open orders have their GTD timers re-activated on start.
+    log_events : bool, default True
+        If events should be logged by the strategy.
+        If False, then only warning events and above are logged.
+    log_commands : bool, default True
+        If commands should be logged by the strategy.
 
     """
 
     strategy_id: StrategyId | None = None
     order_id_tag: str | None = None
+    use_uuid_client_order_ids: bool = False
     oms_type: str | None = None
     external_order_claims: list[InstrumentId] | None = None
     manage_contingent_orders: bool = False
     manage_gtd_expiry: bool = False
+    log_events: bool = True
+    log_commands: bool = True
 
 
 class ImportableStrategyConfig(NautilusConfig, frozen=True):
